@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -14,6 +13,13 @@ namespace Includes\Utils;
  */
 abstract class FileManager extends \Includes\Utils\AUtils
 {
+    /**
+     * Runtime cache of existing directories
+     *
+     * @var array
+     */
+    private static $dirTouched = [];
+
     /**
      * Checks whether a file or directory exists
      *
@@ -158,6 +164,23 @@ abstract class FileManager extends \Includes\Utils\AUtils
         return realpath($path);
     }
 
+    /**
+     * Check directory and create it if not exits
+     *
+     * @param string $dir
+     * @return bool
+     */
+    public static function touchDir(string $dir)
+    {
+        if (!isset(static::$dirTouched[$dir])) {
+            static::$dirTouched[$dir] = static::isExists($dir)
+                ? static::isDir($dir) && static::isWriteable($dir)
+                : static::$dirTouched[$dir] = static::mkdirRecursive($dir);
+        }
+
+        return static::$dirTouched[$dir];
+    }
+
     /**
      * Get command to set permissions
      *
@@ -310,7 +333,6 @@ abstract class FileManager extends \Includes\Utils\AUtils
 
                 if ($file->isDir()) {
                     static::mkdirRecursive($pathTo);
-
                 } else {
                     static::copy($pathFrom, $pathTo);
                 }
@@ -353,6 +375,9 @@ abstract class FileManager extends \Includes\Utils\AUtils
             \Includes\Utils\Converter::convertToTranslit($file)
         );
         $pathinfo = pathinfo($file);
+
+        //https://www.php.net/manual/en/function.pathinfo.php#49765
+        $pathinfo['extension'] = preg_match('/\.tar\.gz$/i', $file) ? 'tar.gz' : $pathinfo['extension'];
         $counter  = 1;
 
         while (static::isFile($path = $dir . $file)) {
@@ -402,7 +427,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
     {
         return static::mkdirRecursive(static::getDir($path))
             && (static::isFileWriteable($path) || (!static::isExists($path) && static::isOperateable($path)))
-            && false !== file_put_contents($path, $data, $flags);
+            && file_put_contents($path, $data, $flags) !== false;
     }
 
     /**
@@ -476,7 +501,6 @@ abstract class FileManager extends \Includes\Utils\AUtils
 
         if (!$overwrite && static::isFile($pathTo)) {
             $result = true;
-
         } elseif (static::isFile($pathFrom)) {
             $result = static::mkdirRecursive(static::getDir($pathTo)) && copy($pathFrom, $pathTo);
         }
@@ -499,7 +523,6 @@ abstract class FileManager extends \Includes\Utils\AUtils
 
         if (!$overwrite && static::isFile($pathTo)) {
             $result = true;
-
         } elseif (static::isFile($pathFrom)) {
             $result = static::mkdirRecursive(static::getDir($pathTo)) && rename($pathFrom, $pathTo);
         }
@@ -519,7 +542,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
     public static function moveUploadedFile($key, $dirTo = LC_DIR_TMP, $name = null, $mode = 0644)
     {
         $path = null;
-        if (isset($_FILES[$key]) && UPLOAD_ERR_OK === $_FILES[$key]['error'] && static::isDirWriteable($dirTo)) {
+        if (isset($_FILES[$key]) && $_FILES[$key]['error'] === UPLOAD_ERR_OK && static::isDirWriteable($dirTo)) {
             $path = static::getUniquePath($dirTo, $name ?: $_FILES[$key]['name']);
 
             if (move_uploaded_file($_FILES[$key]['tmp_name'], $path)) {
@@ -545,10 +568,11 @@ abstract class FileManager extends \Includes\Utils\AUtils
     public static function moveUploadedFileByMultiple($key, $position, $dirTo = LC_DIR_TMP, $name = null, $mode = 0644)
     {
         $path = null;
-        if (isset($_FILES[$key])
+        if (
+            isset($_FILES[$key])
             && isset($_FILES[$key]['name'][$position])
-            && '' != $_FILES[$key]['name'][$position]
-            && UPLOAD_ERR_OK === $_FILES[$key]['error'][$position]
+            && $_FILES[$key]['name'][$position] != ''
+            && $_FILES[$key]['error'][$position] === UPLOAD_ERR_OK
             && static::isDirWriteable($dirTo)
         ) {
             $path = static::getUniquePath($dirTo, $name ?: $_FILES[$key]['name'][$position]);
@@ -617,9 +641,10 @@ abstract class FileManager extends \Includes\Utils\AUtils
         $iterator = new \DirectoryIterator($root);
 
         foreach ($iterator as $fileinfo) {
-            if (!$fileinfo->isDot()
+            if (
+                !$fileinfo->isDot()
                 && $fileinfo->isDir()
-                && ($fileinfo->getFilename() === $name || 0 === strpos($fileinfo->getFilename(), $name . '_'))
+                && ($fileinfo->getFilename() === $name || strpos($fileinfo->getFilename(), $name . '_') === 0)
             ) {
                 $paths[] = $fileinfo->getPathname();
             }
@@ -638,13 +663,9 @@ abstract class FileManager extends \Includes\Utils\AUtils
     public static function findExecutable($filename)
     {
         $result = null;
-        $directories = explode(LC_OS_IS_WIN ? ';' : ':', @getenv('PATH'));
+        $directories = explode(':', @getenv('PATH'));
 
-        if (LC_OS_IS_WIN) {
-            $filename .= '.exe';
-        } else {
-            array_unshift($directories, '/usr/bin', '/usr/local/bin');
-        }
+        array_unshift($directories, '/usr/bin', '/usr/local/bin');
 
         // The false catalog means the filename will checked from the current directory
         $directories[] = false;
@@ -690,12 +711,10 @@ abstract class FileManager extends \Includes\Utils\AUtils
 
         if (function_exists('exif_imagetype')) {
             $result = 0 < (int)@exif_imagetype($path);
-
         } elseif (function_exists('finfo_open')) {
             $finfo = finfo_open(FILEINFO_MIME);
             $result = preg_match('/^image\/.*/', finfo_file($finfo, $path));
             finfo_close($finfo);
-
         } else {
             $data = @getimagesize($path);
             $result = is_array($data) && $data[0];
@@ -727,9 +746,9 @@ abstract class FileManager extends \Includes\Utils\AUtils
     {
         return in_array(
             strtolower(pathinfo($path, PATHINFO_EXTENSION)),
-            array(
+            [
                 'sql'
-            )
+            ]
         );
     }
 
@@ -740,7 +759,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
      */
     public static function getImageExtensions()
     {
-        return array('gif', 'jpg', 'jpeg', 'png', 'ico');
+        return ['gif', 'jpg', 'jpeg', 'png', 'ico', 'webp'];
     }
 
     /**
@@ -754,7 +773,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
     {
         $fileInfo = pathinfo($path);
 
-        return 'csv' == strtolower($fileInfo['extension']);
+        return strtolower($fileInfo['extension']) == 'csv';
     }
 
     /**
@@ -768,7 +787,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
     {
         $fileInfo = pathinfo($path);
 
-        return 'zip' == strtolower($fileInfo['extension']);
+        return strtolower($fileInfo['extension']) == 'zip';
     }
 
     /**
@@ -809,7 +828,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
         $delimiter_esc = preg_quote($delimiter, '/');
         $enclosure_esc = preg_quote($enclosure, '/');
 
-        $output = array();
+        $output = [];
         $regexp = sprintf('/(?:%s|%s|\s)/S', $delimiter_esc, $enclosure_esc);
 
         foreach ($fields as $field) {
@@ -833,7 +852,7 @@ abstract class FileManager extends \Includes\Utils\AUtils
     {
         $enclosure_esc = preg_quote($enclosure, '/');
 
-        $output = array();
+        $output = [];
         $regexp = sprintf('/(?:%s{2}|\s)/S', $enclosure_esc);
 
         foreach ($fields as $field) {
