@@ -1,109 +1,102 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
  * See https://www.x-cart.com/license-agreement.html for license details.
  */
 
-use XLite\Core\Database\Migration\UnsupportedDatabaseOperationDuringMaintenanceException;
-
+use Includes\Utils\ConfigParser;
+use Symfony\Component\HttpFoundation\Cookie;
+use Symfony\Component\HttpFoundation\Response;
+use Symfony\Component\HttpFoundation\StreamedResponse;
 
 /**
  * Application singleton
- *
- * @Swg\Swagger (
- *     schemes={"http"},
- *     host="demostore.x-cart.com",
- *     basePath="/admin.php?target=RESTAPI&",
- *     produces={"application/json", "application/xml"},
- *     consumes={"application/json", "application/x-www-form-urlencoded"},
- *     @Swg\Info (
- *         version="5.3.5.5",
- *         title="X-Cart REST API",
- *         description="",
- *     ),
- *     @Swg\ExternalDocumentation (
- *         description="Find out more about X-Cart REST API",
- *         url="https://devs.x-cart.com/rest-api/"
- *     )
- * )
- *
- * @SWG\SecurityScheme(
- *   securityDefinition="api_key",
- *   type="apiKey",
- *   in="query",
- *   name="_key"
- * )
- *
  * TODO: to revise
  * TODO[SINGLETON]: lowest priority
  */
+// phpcs:ignore PSR1.Classes.ClassDeclaration.MissingNamespace,SlevomatCodingStandard.Files.TypeNameMatchesFileName.NoMatchBetweenTypeNameAndFileName
 class XLite extends \XLite\Base
 {
-    use \XLite\Core\DependencyInjection\ContainerHolderTrait;
-
     /**
      * Core version
      */
-    const XC_VERSION = '5.4.0.8';
+    public const XC_VERSION = '5.5.1.14';
 
     /**
      * Endpoints
      */
-    const CART_SELF  = 'cart.php';
-    const ADMIN_SELF = 'admin.php';
+    public const CART_SELF  = '';
+    public const ADMIN_SELF = 'admin/';
 
     /**
      * This target will be used if the "target" params is not passed in the request
      */
-    const TARGET_DEFAULT = 'main';
-    const TARGET_404     = 'page_not_found';
+    public const TARGET_DEFAULT = 'main';
+    public const TARGET_404     = 'page_not_found';
 
     /**
      * Interfaces codes
      */
-    const ADMIN_INTERFACE    = 'admin';
-    const CUSTOMER_INTERFACE = 'customer';
-    const CONSOLE_INTERFACE  = 'console';
-    const MAIL_INTERFACE     = 'mail';
-    const COMMON_INTERFACE   = 'common';
-    const PDF_INTERFACE      = 'pdf';
+    /**
+     * @deprecated since CDev-Core 5.5.0, use \XLite::INTERFACE_ and \XLite::ZONE_ constants
+     */
+    public const ADMIN_INTERFACE    = 'admin';
+    /**
+     * @deprecated since CDev-Core 5.5.0, use \XLite::INTERFACE_ and \XLite::ZONE_ constants
+     */
+    public const CUSTOMER_INTERFACE = 'customer';
+    /**
+     * @deprecated since CDev-Core 5.5.0, use \XLite::INTERFACE_ and \XLite::ZONE_ constants
+     */
+    public const MAIL_INTERFACE     = 'mail';
+    /**
+     * @deprecated since CDev-Core 5.5.0, use \XLite::INTERFACE_ and \XLite::ZONE_ constants
+     */
+    public const COMMON_INTERFACE   = 'common';
+    /**
+     * @deprecated since CDev-Core 5.5.0, use \XLite::INTERFACE_ and \XLite::ZONE_ constants
+     */
+    public const PDF_INTERFACE      = 'pdf';
+
+    /**
+     * Predefined interfaces
+     */
+    public const INTERFACE_WEB     = 'web';
+    public const INTERFACE_MAIL    = 'mail';
+    public const INTERFACE_PDF     = 'pdf';
+
+    /**
+     * Predefined zones
+     */
+    public const ZONE_CUSTOMER = 'customer';
+    public const ZONE_ADMIN    = 'admin';
+    public const ZONE_COMMON   = 'common';
 
     /**
      * Default shop currency code (840 - US Dollar)
      */
-    const SHOP_CURRENCY_DEFAULT = 840;
+    public const SHOP_CURRENCY_DEFAULT = 840;
 
     /**
      * Temporary variable name for latest cache building time
      */
-    const CACHE_TIMESTAMP = 'cache_build_timestamp';
-
-    /**
-     * Trial period TTL (days)
-     */
-    const TRIAL_PERIOD = '30';
-
-    /**
-     * Session variable name for show trial notice flag.
-     */
-    const SHOW_TRIAL_NOTICE = 'showTrialNotice';
+    public const CACHE_TIMESTAMP = 'cache_build_timestamp';
 
     /**
      * Producer site URL
      */
-    const PRODUCER_SITE_URL = 'https://www.x-cart.com/';
+    public const PRODUCER_SITE_URL = 'https://www.x-cart.com/';
 
     /**
      * Name of the form id
      */
-    const FORM_ID = 'xcart_form_id';
+    public const FORM_ID = 'xcart_form_id';
 
     /**
      * URI to check clean URLS availability
      */
-    const CLEAN_URL_CHECK_QUERY = 'check/for/clean/urls.html';
+    public const CLEAN_URL_CHECK_QUERY = 'check/for/clean/urls.html';
 
     /**
      * Parsed version.
@@ -148,6 +141,102 @@ class XLite extends \XLite\Base
      */
     protected $currentCurrency;
 
+    /**
+     * @var string
+     */
+    protected $content = '';
+
+    /**
+     * @var int
+     */
+    protected $statusCode = Response::HTTP_OK;
+
+    /**
+     * @var array
+     */
+    protected $headers = [];
+
+    /**
+     * @var array
+     */
+    protected $cookies = [];
+
+    /**
+     * @return string
+     */
+    public function getContent(): string
+    {
+        return $this->content;
+    }
+
+    /**
+     * @param string $content
+     */
+    public function setContent(string $content): void
+    {
+        $this->content = $content;
+    }
+
+    /**
+     * @param string $content
+     */
+    public function addContent(string $content): void
+    {
+        $this->content .= $content;
+    }
+
+    /**
+     * @return mixed
+     */
+    public function getStatusCode()
+    {
+        return $this->statusCode;
+    }
+
+    /**
+     * @param mixed $statusCode
+     */
+    public function setStatusCode($statusCode): void
+    {
+        $this->statusCode = $statusCode;
+    }
+
+    /**
+     * @return array
+     */
+    public function getHeaders(): array
+    {
+        return $this->headers;
+    }
+
+    /**
+     * @param string $key
+     * @param string $value
+     * @param bool   $replace
+     */
+    public function addHeader(string $key, string $value, bool $replace = true): void
+    {
+        if ($replace === true || !isset($this->headers[$key])) {
+            $this->headers[$key] = [$value];
+        } else {
+            $this->headers[$key][] = $value;
+        }
+    }
+
+    /**
+     * @param string $name
+     * @param string $value
+     * @param array  $options
+     */
+    public function saveCookie(string $name, string $value, array $options = []): void
+    {
+        $this->cookies[] = [
+            'name'    => $name,
+            'value'   => $value,
+            'options' => $options
+        ];
+    }
+
     /**
      * Check is admin interface
      *
@@ -159,23 +248,23 @@ class XLite extends \XLite\Base
     }
 
     /**
-     * Return filename of the admin script. Defaults to 'admin.php'.
+     * Return filename of the admin script.
      *
      * @return string
      */
     public static function getAdminScript()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('host_details', 'admin_self')) ?: static::ADMIN_SELF;
+        return static::ADMIN_SELF;
     }
 
     /**
-     * Return filename of the customer script. Defaults to 'cart.php'.
+     * Return filename of the customer script.
      *
      * @return string
      */
     public static function getCustomerScript()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('host_details', 'cart_self')) ?: static::CART_SELF;
+        return static::CART_SELF;
     }
 
     /**
@@ -185,11 +274,7 @@ class XLite extends \XLite\Base
      */
     public static function isAdminScript()
     {
-        $adminScript = \Includes\Utils\FileManager::isFileReadable(static::getAdminScript())
-            ? static::getAdminScript()
-            : self::ADMIN_SELF;
-
-        return false !== strpos(static::getInstance()->getRequestedScript(), $adminScript);
+        return strpos(static::getInstance()->getRequestedScript(), self::ADMIN_SELF) !== false;
     }
 
     /**
@@ -213,47 +298,18 @@ class XLite extends \XLite\Base
     }
 
     /**
-     * Get cache cleanup flag state
-     *
-     * @return boolean
-     */
-    public static function getCleanUpCacheFlag()
-    {
-        return static::$isNeedToCleanupCache;
-    }
-
-    /**
-     * Ability to provoke cache cleanup (or to prevent it)
-     *
-     * @param boolean $flag If it's needed to cleanup cache or not
-     *
-     * @return void
-     */
-    public static function setCleanUpCacheFlag($flag)
-    {
-        static::$isNeedToCleanupCache = (true === $flag);
-        if (static::$isNeedToCleanupCache) {
-            \Includes\Decorator\Utils\CacheManager::setCacheRebuildMark();
-
-        } else {
-            \Includes\Decorator\Utils\CacheManager::unsetCacheRebuildMark();
-        }
-    }
-
-    /**
-     * Get controller
-     *
      * @return \XLite\Controller\AController
      */
     public static function getController()
     {
-        if (null === static::$controller) {
+        if (static::$controller === null) {
             $class = static::getControllerClass();
 
             // If mod_rewrite is disabled and ErrorDocument 404 is set
             //  on check/for/clean/urls.html uri we are trying do display 404
             // This is here to speedup check request
-            if (\XLite\Core\Request::getInstance()->target === static::TARGET_404
+            if (
+                \XLite\Core\Request::getInstance()->target === static::TARGET_404
                 && isset($_SERVER['REQUEST_URI'])
                 && strpos($_SERVER['REQUEST_URI'], static::CLEAN_URL_CHECK_QUERY) !== false
             ) {
@@ -266,26 +322,7 @@ class XLite extends \XLite\Base
                 $class = static::getControllerClass();
             }
 
-            if (!\XLite\Core\Request::getInstance()->isCLI()
-                && \XLite::getInstance()->getRequestedScript() !== \XLite::getInstance()->getExpectedScript()
-                && \XLite::getInstance()->getRequestedScript() !== \XLite::getInstance()->getExpectedScript(true)
-            ) {
-                \XLite\Core\Request::getInstance()->target = static::TARGET_404;
-                $class = static::getControllerClass();
-            }
-
             static::$controller = new $class(\XLite\Core\Request::getInstance()->getData());
-
-            if (
-                static::isAdminZone()
-                && 'keys_notice' != \XLite\Core\Request::getInstance()->target
-                && static::$controller->isDisplayBlockContent()
-                && static::$controller->isBlockContentAllowed()
-            ) {
-                \XLite\Core\Request::getInstance()->target = 'keys_notice';
-                static::$controller = new \XLite\Controller\Admin\KeysNotice(\XLite\Core\Request::getInstance()->getData());
-            }
-
             static::$controller->init();
         }
 
@@ -302,7 +339,7 @@ class XLite extends \XLite\Base
      */
     public static function setController($controller = null)
     {
-        if ($controller instanceof \XLite\Controller\AController || null === $controller) {
+        if ($controller instanceof \XLite\Controller\AController || $controller === null) {
             static::$controller = $controller;
         }
     }
@@ -314,106 +351,7 @@ class XLite extends \XLite\Base
      */
     public static function getInstallationLng()
     {
-        return \Includes\Utils\ConfigParser::getInstallationLng();
-    }
-
-    /**
-     * Return X-Cart 5 license of the core
-     *
-     * @param boolean $force Flag: true - ignore runtime cache
-     *
-     * @return array
-     */
-    public static function getXCNLicense()
-    {
-        return \XLite\Core\Marketplace::getInstance()->getCoreLicense();
-    }
-
-    /**
-     * Return X-Cart 5 license of the core
-     *
-     * @return string
-     */
-    public static function getXCNLicenseKey()
-    {
-        $license = static::getXCNLicense();
-
-        return $license ? $license['keyValue'] : '';
-    }
-
-    /**
-     * Return if X-Cart 5 has license of the core
-     *
-     * @return boolean
-     */
-    public static function hasXCNLicenseKey()
-    {
-        return (bool) static::getXCNLicense();
-    }
-
-    /**
-     * @return int
-     */
-    public static function getInstallationTimestamp()
-    {
-        $result = 0;
-        $installationData = \XLite\Core\Marketplace::getInstance()->getInstallationData();
-
-        if (!empty($installationData['installationDate'])) {
-            $result = (int) $installationData['installationDate'];
-        }
-
-        return $result;
-    }
-
-    /**
-     * Get number of days left before trial period will expire
-     *
-     * @param boolean $returnDays Flag: return in days
-     *
-     * @return integer
-     */
-    public static function getTrialPeriodLeft($returnDays = true)
-    {
-        $startTime = \XLite::getInstallationTimestamp();
-        $endTime   = $startTime + 86400 * \XLite::TRIAL_PERIOD;
-
-        return $returnDays
-            ? ceil(($endTime - time()) / 86400)
-            : $endTime - time();
-    }
-
-    /**
-     * Check if trial period is expired
-     *
-     * @return boolean
-     */
-    public static function isTrialPeriodExpired()
-    {
-        return !static::hasXCNLicenseKey() && 0 >= static::getTrialPeriodLeft(false);
-    }
-
-    /**
-     * Return true if registered Free license
-     *
-     * @return boolean
-     */
-    public static function isFreeLicense()
-    {
-        $result = false;
-        $key = static::getXCNLicense();
-
-        if ($key) {
-            if (2 === (int) ($key['xcnPlan'] ?? 0)) {
-                $result = true;
-
-            } else {
-                $keyData = $key['keyData'];
-                $result = isset($keyData['editionName']) && 'Free' === $keyData['editionName'];
-            }
-        }
-
-        return $result;
+        return ConfigParser::getOptions(['installation', 'installation_lng']);
     }
 
     /**
@@ -423,7 +361,7 @@ class XLite extends \XLite\Base
      */
     public static function getAffiliateId()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('affiliate', 'id'));
+        return ConfigParser::getOptions(['affiliate', 'id']);
     }
 
     /**
@@ -436,18 +374,18 @@ class XLite extends \XLite\Base
      */
     public static function getXCartURL($url = '', $useInstallationLng = true)
     {
-        $controller = '';
+        $controllerTarget = '';
         if (static::isAdminZone() && static::getController()) {
-            $controller = static::getController()->getTarget();
+            $controllerTarget = static::getController()->getTarget();
         }
 
-        $builder = \XCart\AffiliatedUrlBuilder::build(
+        return \Includes\Utils\URLManager::getAffiliatedXCartURL(
+            $url,
+            $controllerTarget,
             static::getAffiliateId(),
-            $controller,
-            static::getInstallationLng()
+            static::getInstallationLng(),
+            $useInstallationLng
         );
-
-        return $builder->getXCartURL($url, $useInstallationLng);
     }
 
     /**
@@ -474,30 +412,16 @@ class XLite extends \XLite\Base
         return \XLite\Core\Converter::getControllerClass(static::getTarget());
     }
 
-    /**
-     * Return specified (or the whole list) options
-     *
-     * @param mixed $names List (or single value) of option names OPTIONAL
-     *
-     * @return mixed
-     */
-    public function getOptions($names = null)
-    {
-        return \XLite\Core\ConfigParser::getOptions($names);
-    }
-
     /**
      * Return current endpoint script
      *
      * @param boolean $check Check if file exists and readable (default: false)
-     *s
+     *
      * @return string
      */
     public function getScript($check = false)
     {
-        return static::isAdminZone()
-             ? ( !$check || \Includes\Utils\FileManager::isFileReadable(static::getAdminScript()) ? static::getAdminScript() : self::ADMIN_SELF )
-             : ( !$check || \Includes\Utils\FileManager::isFileReadable(static::getCustomerScript()) ? static::getCustomerScript() : self::CART_SELF );
+        return static::isAdminZone() ? self::ADMIN_SELF : self::CART_SELF;
     }
 
     /**
@@ -519,7 +443,7 @@ class XLite extends \XLite\Base
      */
     protected function getExpectedScript($index = false)
     {
-        $web_dir = rtrim(\XLite::getInstance()->getOptions(array('host_details', 'web_dir')), '/');
+        $web_dir = ConfigParser::getOptions(['host_details', 'web_dir']);
         $script = $index
             ? 'index.php'
             : ltrim(static::getScript(true), '/');
@@ -536,7 +460,7 @@ class XLite extends \XLite\Base
      *
      * @return string
      */
-    public function getShopURL($url = '', $isSecure = null, array $params = array())
+    public function getShopURL($url = '', $isSecure = null, array $params = [])
     {
         return \XLite\Core\URLManager::getShopURL($url, $isSecure, $params);
     }
@@ -548,17 +472,31 @@ class XLite extends \XLite\Base
      *
      * @return string
      */
-    public function getServiceURL($path = '', $isSecure = null, array $params = array())
+    public function getServiceURL($path = '', $isSecure = null, array $params = [])
     {
         if (!$path) {
             $path = '#/';
         }
 
         if (strpos($path, '#') === 0) {
-            $path = 'service.php?locale=' . \XLite\Core\Session::getInstance()->getCurrentLanguage() . $path . '?';
+            $path = 'admin/?target=apps' . $path;
         }
 
-        return \XLite\Core\URLManager::getShopURL($path, $isSecure, $params);
+        if ($params) {
+            $path .= '?' . http_build_query($params);
+        }
+
+        if (strpos($path, '#/available-addons') !== false) {
+            $path = str_replace('#/available-addons', '#/installed-addons', $path);
+        }
+
+        return \XLite\Core\URLManager::getShopURL($path, $isSecure);
+    }
+
+    public static function getAppStoreUrl(): string
+    {
+        $marketplace = ConfigParser::getOptions(['marketplace']) ?? [];
+        return $marketplace['appstore_url'] ?? '';
     }
 
     /**
@@ -571,49 +509,6 @@ class XLite extends \XLite\Base
         return \XLite\Model\Factory::getInstance();
     }
 
-    /**
-     * Call application die (general routine)
-     *
-     * @param string $message Error message
-     *
-     * @return void
-     */
-    public function doGlobalDie($message)
-    {
-        $this->doDie($message);
-    }
-
-    /**
-     * Initialize all active modules
-     *
-     * @return void
-     */
-    public function initModules()
-    {
-        //static::checkUpgradeStatus();
-
-        \Includes\Utils\Module\Manager::initModules();
-    }
-
-    /**
-     * Set up flag if upgrade is in progress.
-     * Modules will not be disabled during initialization if this flag is set.
-     * @deprecated
-     */
-    protected static function checkUpgradeStatus()
-    {
-        $actions = array('pre_upgrade_hooks', 'update_files');
-
-        if (
-            !defined('XC_UPGRADE_IN_PROGRESS')
-            && 'upgrade' == \XLite\Core\Request::getInstance()->target
-            && !empty(\XLite\Core\Request::getInstance()->action)
-            && in_array(\XLite\Core\Request::getInstance()->action, $actions)
-        ) {
-            define('XC_UPGRADE_IN_PROGRESS', true);
-        }
-    }
-
     /**
      * Perform an action and redirect
      *
@@ -654,33 +549,9 @@ class XLite extends \XLite\Base
 
         static::getController()->processRequest();
 
-        $this->runPostRequestActions();
-
         return $this;
     }
 
-    /**
-     * Run customer zone application
-     */
-    public function runCustomerZone()
-    {
-        $level = ob_get_level();
-
-        try {
-
-            $this->run()->processRequest();
-
-        } catch (UnsupportedDatabaseOperationDuringMaintenanceException $e) {
-
-            // Get back to original output buffering level to discard all buffered content
-            while (ob_get_level() > $level) {
-                ob_end_clean();
-            }
-
-            \Includes\Decorator\Utils\CacheManager::triggerMaintenanceModeError();
-        }
-    }
-
     /**
      * Run application
      *
@@ -691,24 +562,17 @@ class XLite extends \XLite\Base
     public function run($adminZone = false)
     {
         // Set current area
-        static::$adminZone = (bool)$adminZone;
+        static::$adminZone = (bool) $adminZone;
 
         // Clear some data
-        static::clearDataOnStartup();
+        $this->clearDataOnStartup();
 
         // Initialize logger
         \XLite\Logger::getInstance();
 
-        // Initialize modules
-        $this->initModules();
-
-        if (\XLite\Core\Request::getInstance()->isCLI()) {
-            // Set skin for console interface
-            \XLite\Core\Layout::getInstance()->setConsoleSkin();
-
-        } elseif (true === static::$adminZone) {
+        if (static::$adminZone === true) {
             // Set skin for admin interface
-            \XLite\Core\Layout::getInstance()->setAdminSkin();
+            \XLite\Core\Layout::getInstance()->setInterfaceZone(\XLite::INTERFACE_WEB, \XLite::ZONE_ADMIN);
         }
 
         return $this;
@@ -721,7 +585,7 @@ class XLite extends \XLite\Base
      */
     public function getCurrency()
     {
-        if (null === $this->currentCurrency) {
+        if ($this->currentCurrency === null) {
             $this->currentCurrency = \XLite\Core\Database::getRepo('XLite\Model\Currency')
                 ->find(\XLite\Core\Config::getInstance()->General->shop_currency ?: static::SHOP_CURRENCY_DEFAULT);
         }
@@ -761,25 +625,17 @@ class XLite extends \XLite\Base
     {
         $result = static::TARGET_DEFAULT;
 
-        if (isset(\XLite\Core\Request::getInstance()->url)) {
+        if (static::$adminZone === false && isset(\XLite\Core\Request::getInstance()->url)) {
             if (static::isCheckForCleanURL()) {
                 $result = null;
                 // Request to detect support of clean URLs
                 // Just display 'OK' and exit to speedup this checking
                 die('OK');
-            };
+            }
 
             if (LC_USE_CLEAN_URLS) {
                 // Get target
                 $result = static::getTargetByCleanURL();
-
-                // Get canonical redirect URL
-                $canonicalURL = \XLite\Core\Database::getRepo('XLite\Model\CleanURL')->getRedirectCanonicalURL($result);
-
-                if ($canonicalURL && !\XLite\Core\Request::getInstance()->isAJAX()) {
-                    // Redirect
-                    \XLite\Core\Operator::redirect($canonicalURL);
-                }
             } else {
                 $result = static::TARGET_404;
             }
@@ -796,43 +652,32 @@ class XLite extends \XLite\Base
     protected static function getTargetByCleanURL()
     {
         $tmp = \XLite\Core\Request::getInstance();
-        list($target, $params) = \XLite\Core\Converter::parseCleanUrl($tmp->url, $tmp->last, $tmp->rest, $tmp->ext);
+        [$target, $params] = \XLite\Core\Converter::parseCleanUrl($tmp->url, $tmp->last, $tmp->rest, $tmp->ext);
 
         if ($target && $params) {
             $redirectUrl = \XLite\Core\Database::getRepo('XLite\Model\CleanURL')->buildURL($target, $params);
-            $redirectUrl = strtok($redirectUrl,'?');
-            $web_dir = rtrim(\XLite::getInstance()->getOptions(array('host_details', 'web_dir')), '/');
-            $selfURI = strtok(\Includes\Utils\URLManager::getSelfURI(),'?');
+            $redirectUrl = strtok($redirectUrl, '?');
+            $web_dir = ConfigParser::getOptions(['host_details', 'web_dir']);
+            $selfURI = substr(strtok(\Includes\Utils\URLManager::getSelfURI(), '?'), strlen($web_dir) + 1);
 
             if (LC_USE_CLEAN_URLS && \XLite\Core\Router::getInstance()->isUseLanguageUrls()) {
                 $language = \XLite\Core\Session::getInstance()->getLanguage();
-                if (!$language->getDefaultAuth()) {
-                    $noLangRedirectUrl = $redirectUrl;
-                    $redirectUrl = $language->getCode() . '/' . $redirectUrl;
-                }
+
+                $selfURI = strpos($selfURI, $language->getCode() . '/') === 0
+                    ? substr($selfURI, 3)
+                    : $selfURI;
             }
 
-            if (($web_dir . '/' . $redirectUrl) !== $selfURI && !\XLite\Core\Request::getInstance()->isAJAX()) {
-                // If there is not-default language selected
-                // but url doesn't contains it, so we should redirect to url with that language
-                $isRedirectToLanguageNeeded = isset($noLangRedirectUrl)
-                    && ($web_dir . '/' . $noLangRedirectUrl) === $selfURI;
-                $code = $isRedirectToLanguageNeeded
-                    ? 302
-                    : 301;
+            if ($redirectUrl !== $selfURI && !\XLite\Core\Request::getInstance()->isAJAX()) {
+                $ttl = 86400;
+                $expiresTime = gmdate('D, d M Y H:i:s', time() + $ttl) . ' GMT';
 
-                if (!$isRedirectToLanguageNeeded) {
-                    $ttl = 86400;
-                    $expiresTime = gmdate('D, d M Y H:i:s', time() + $ttl) . ' GMT';
-
-                    header("Cache-Control: max-age=$ttl, must-revalidate");
-                    header("Expires: $expiresTime");
-                }
+                \XLite::getInstance()->addHeader('Cache-Control', "max-age=$ttl, must-revalidate");
+                \XLite::getInstance()->addHeader('Expires', $expiresTime);
 
                 \XLite\Core\Operator::redirect(
                     \XLite\Core\URLManager::getShopURL($redirectUrl),
-                    false,
-                    $code
+                    301
                 );
             }
         }
@@ -857,7 +702,7 @@ class XLite extends \XLite\Base
         $parts = [$tmp->rest, $tmp->last, $tmp->url . $tmp->ext];
         $query = implode('/', array_filter($parts));
 
-        return static::CLEAN_URL_CHECK_QUERY == $query;
+        return $query == static::CLEAN_URL_CHECK_QUERY;
     }
 
     // }}}
@@ -887,7 +732,7 @@ class XLite extends \XLite\Base
      */
     public function getFormIdStrategy()
     {
-        return \XLite::getInstance()->getOptions(array('other', 'csrf_strategy'));
+        return ConfigParser::getOptions(['other', 'csrf_strategy']);
     }
 
     // }}}
@@ -898,11 +743,11 @@ class XLite extends \XLite\Base
     {
         if (!isset($this->parsedVersion)) {
             $version = explode('.', $this->getVersion());
-            $this->parsedVersion = array(
+            $this->parsedVersion = [
                 'major' => $version[0] . '.' . $version[1],
                 'minor' => !empty($version[2]) ? $version[2] : '0',
                 'build' => !empty($version[3]) ? $version[3] : '0',
-            );
+            ];
             $this->parsedVersion['minorFull'] = $this->parsedVersion['minor']
                 . ($this->parsedVersion['build'] ? '.' . $this->parsedVersion['build'] : '');
             $this->parsedVersion['hotfix'] = $this->parsedVersion['major'] . '.' . $this->parsedVersion['minor'];
@@ -1004,7 +849,7 @@ class XLite extends \XLite\Base
      */
     public static function getLastRebuildTimestamp()
     {
-        return \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getVar(\XLite::CACHE_TIMESTAMP);
+        return \XLite\View\AResourcesContainer::getLatestCacheTimestamp();
     }
 
     /**
@@ -1014,7 +859,6 @@ class XLite extends \XLite\Base
      */
     public function runPostRequestActions()
     {
-        flush();
         ignore_user_abort(true);
 
         while (\XLite\Core\Job\InMemoryJobRegistry::getInstance()->hasJobs()) {
@@ -1023,5 +867,56 @@ class XLite extends \XLite\Base
         }
     }
 
+    /**
+     * Sends response
+     *
+     * @return void
+     */
+    public function sendResponse(): void
+    {
+        $xLite = \XLite::getInstance();
+        $response = new Response($xLite->getContent(), $xLite->getStatusCode(), $xLite->getHeaders());
+
+        foreach ($this->getCookiesForHeaders() as $cookie) {
+            $response->headers->setCookie($cookie);
+        }
+
+        $response->send();
+    }
+
+    public function streamResponse(callable $callback): void
+    {
+        $xLite = \XLite::getInstance();
+        $response = new StreamedResponse($callback, $xLite->getStatusCode(), $xLite->getHeaders());
+        $response->send();
+    }
+
+    public function getCookiesForHeaders()
+    {
+        $result = [];
+
+        foreach ($this->cookies as $c) {
+            $result[] = Cookie::create($c['name'])
+                ->withValue($c['value'])
+                ->withPath($c['options']['path'])
+                ->withExpires($c['options']['expires'])
+                ->withDomain($c['options']['domain'])
+                ->withHttpOnly($c['options']['httponly'])
+                ->withSecure($c['options']['secure']);
+        }
+
+        return $result;
+    }
+
     // }}}
+
+    final public static function isTrial()
+    {
+        return (bool) ConfigParser::getOptions(['service', 'is_trial']);
+    }
+
+    final public static function areUpdateNotificationsEnabled()
+    {
+        return (bool) ConfigParser::getOptions(['service', 'display_update_notification']);
+    }
 }
