@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\Controller\Admin;
 
+use XLite\Core\WidgetCacheManager;
 
 /**
  * Abstract admin-zone controller
@@ -16,13 +16,12 @@ abstract class AAdmin extends \XLite\Controller\AController
 {
     // {{{ TODO Uncomment after traits + decorator fixed
     // And remove getItemsListClass and doActionUpdateItemsList methods
-
     use \XLite\Controller\Features\ItemsListControllerTrait;
 
     /**
      * Parameter name
      */
-    const PARAM_SEARCH_FILTER_ID = 'searchFilterId';
+    public const PARAM_SEARCH_FILTER_ID = 'searchFilterId';
 
     /**
      * List of recently logged in administrators
@@ -69,7 +68,7 @@ abstract class AAdmin extends \XLite\Controller\AController
     {
         return array_merge(
             parent::defineFreeFormIdActions(),
-            array('save_search_filter', 'search')
+            ['save_search_filter', 'search']
         );
     }
 
@@ -83,20 +82,6 @@ abstract class AAdmin extends \XLite\Controller\AController
         return \XLite\Core\Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS);
     }
 
-    /**
-     * This function called after template output
-     *
-     * @return void
-     */
-    public function postprocess()
-    {
-        parent::postprocess();
-
-        if ($this->dumpStarted) {
-            $this->displayPageFooter();
-        }
-    }
-
     /**
      * Check whether the title is to be displayed in the content area
      *
@@ -104,7 +89,7 @@ abstract class AAdmin extends \XLite\Controller\AController
      */
     public function isTitleVisible()
     {
-        return 'access_denied' !== \XLite\Core\Request::getInstance()->target;
+        return \XLite\Core\Request::getInstance()->target !== 'access_denied';
     }
 
     /**
@@ -135,15 +120,16 @@ abstract class AAdmin extends \XLite\Controller\AController
     public function handleRequest()
     {
         // Check if user is logged in and has a right access level
-        if (!$this->isPublicZone()
+        if (
+            !$this->isPublicZone()
             && !\XLite\Core\Auth::getInstance()->isAuthorized($this)
         ) {
             \XLite\Core\Session::getInstance()->lastWorkingURL = \XLite\Core\URLManager::getCurrentURL();
 
             $this->redirect($this->buildURL('login'));
-
-        } elseif ($this->isForceChangePassword()
-            && $this->getTarget() !== 'force_change_password'
+        } elseif (
+            $this->isForceChangePassword()
+            && !in_array($this->getTarget(), ['force_change_password', 'login'], true)
         ) {
             $this->redirect($this->buildURL('force_change_password'));
         } else {
@@ -151,23 +137,13 @@ abstract class AAdmin extends \XLite\Controller\AController
                 \XLite\Core\Session::getInstance()->no_https = true;
             }
 
+            $this->disableUnallowedModules();
+
             parent::handleRequest();
         }
     }
 
     /**
-     * isBlockContentAllowed
-     *
-     * @return boolean
-     */
-    public function isBlockContentAllowed()
-    {
-        return !$this->isPublicZone();
-    }
-
-    /**
-     * Define body classes
-     *
      * @param array $classes Classes
      *
      * @return array
@@ -176,20 +152,7 @@ abstract class AAdmin extends \XLite\Controller\AController
     {
         $classes = parent::defineBodyClasses($classes);
 
-        $auth = \XLite\Core\Auth::getInstance();
-        if ($auth->isLogged()
-            && $auth->getProfile()->isAdmin() == \XLite::isAdminZone()
-        ) {
-            //if (count(\XLite\Upgrade\Cell::getInstance()->getEntries())) {
-            //    $classes[] = 'upgrade-box-visible';
-            //}
-
-            if (!empty($_COOKIE['XCAdminLeftMenuCompressed'])) {
-                $classes[] = 'left-menu-compressed';
-            }
-        }
-
-        if ($auth->isAdmin()) {
+        if (\XLite\Core\Auth::getInstance()->isAdmin()) {
             $classes[] = 'login-page';
         }
 
@@ -197,10 +160,13 @@ abstract class AAdmin extends \XLite\Controller\AController
             $classes[] = 'force-change-password-section';
         }
 
+        $classes[] = isset($_COOKIE['left-menu-state']) && ($_COOKIE['left-menu-state'] === 'expanded')
+            ? 'left-menu-expanded'
+            : 'left-menu-compressed';
+
         return $classes;
     }
 
-
     /**
      * Get recently logged in admins
      *
@@ -208,8 +174,9 @@ abstract class AAdmin extends \XLite\Controller\AController
      */
     public function getRecentAdmins()
     {
-        if ($this->isLogged()
-            && null === $this->recentAdmins
+        if (
+            $this->isLogged()
+            && $this->recentAdmins === null
         ) {
             $this->recentAdmins = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findRecentAdmins();
         }
@@ -255,7 +222,9 @@ abstract class AAdmin extends \XLite\Controller\AController
         parent::callAction();
 
         if ($this->isLogged()) {
-            $this->getContainer()->get('widget_cache_manager')->invalidateBasedOnDatabaseChanges();
+            /** @var WidgetCacheManager $widgetCache */
+            $widgetCacheManager = \XCart\Container::getContainer()->get(WidgetCacheManager::class);
+            $widgetCacheManager->invalidateBasedOnDatabaseChanges();
         }
     }
 
@@ -278,84 +247,47 @@ abstract class AAdmin extends \XLite\Controller\AController
     {
         if (\XLite\Core\Auth::getInstance()->isLogged()) {
             parent::markAsAccessDenied();
-
         } else {
             $this->redirect($this->buildURL('login'));
         }
     }
 
     /**
-     * Start simplified page to display progress of some process
+     * Disable unallowed modules routine
      *
      * @return void
      */
-    protected function startDump()
+    protected function disableUnallowedModules()
     {
-        parent::startDump();
+        if ($this->isAJAX()) {
+            return;
+        }
 
-        if (!isset(\XLite\Core\Request::getInstance()->mode) || 'cp' !== \XLite\Core\Request::getInstance()->mode) {
-            $this->displayPageHeader();
+        if (
+            $this->getTarget() === 'keys_notice'
+            && $this->getAction() === 'recheck'
+        ) {
+            \XLite\Core\Session::getInstance()->shouldDisableUnallowedModules = false;
+        } elseif (!\XLite\Core\Session::getInstance()->shouldDisableUnallowedModules) {
+            \XLite\Core\Session::getInstance()->shouldDisableUnallowedModules = true;
+        } elseif (\XLite\Core\Session::getInstance()->fraudWarningDisplayed) {
+            \XLite\Core\Session::getInstance()->fraudWarningDisplayed         = null;
+            \XLite\Core\Session::getInstance()->shouldDisableUnallowedModules = null;
+
+            if (!$this->isIgnoreUnallowedModules()) {
+                $this->redirect($this->getShopURL('service.php?/disableUnallowedModules'));
+            }
         }
     }
 
     /**
-     * Display header of simplified page
+     * Return true if unallowed modules should be ignored on current page
      *
-     * @param string  $title      Title OPTIONAL
-     * @param boolean $scrollDown Scroll down flag OPTIONAL
-     *
-     * @return void
+     * @return boolean
      */
-    protected function displayPageHeader($title = '', $scrollDown = false)
+    protected function isIgnoreUnallowedModules()
     {
-        $output = <<<OUT
-<html>
-<head>
-    <title>$title</title>
-    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
-</head>
-
-<body>
-
-OUT;
-
-        if ($scrollDown) {
-            $this->dumpStarted = true;
-            $output .= func_refresh_start(false);
-        }
-
-        $output .= <<<OUT
-
-<div style='font-size: 12px;'>
-
-OUT;
-
-        echo ($output);
-    }
-
-    /**
-     * displayPageFooter
-     *
-     * @return void
-     */
-    protected function displayPageFooter()
-    {
-        $urls = (array) $this->getPageReturnURL();
-
-        foreach ($urls as $url) {
-            echo ('<br />' . $url . '<br />');
-        }
-
-        $output = <<<OUT
-
-</div>
-
-</body>
-</html>
-
-OUT;
-
-        echo ($output);
+        return false;
     }
 
     /**
@@ -365,7 +297,7 @@ OUT;
      */
     protected function getPageReturnURL()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -392,7 +324,6 @@ OUT;
             && \XLite\Core\Config::getInstance()->Security->admin_security;
     }
 
-
     /**
      * Do not change it.
      * This method defines the address of the Knowledge base help article
@@ -401,7 +332,7 @@ OUT;
      */
     public function getArticleURL()
     {
-        return static::t('https://kb.x-cart.com/general_setup/what_to_do_if_your_store_says_we_are_deploying_new_changes_and_you_cannot_access_it.html');
+        return static::t('https://support.x-cart.com/en/articles/4475799-what-to-do-if-you-cannot-access-your-store');
     }
 
     // {{{ Search filter methods
@@ -418,17 +349,16 @@ OUT;
         $key = $this->getSearchFilterKeyCell();
 
         if ($key) {
-
             if (!empty(\XLite\Core\Request::getInstance()->filter_id)) {
                 $id = intval(\XLite\Core\Request::getInstance()->filter_id);
             }
 
             if (!empty($id)) {
                 $result = $this->getSearchFilterByParams(
-                    array(
+                    [
                         'id'        => $id,
                         'filterKey' => $key,
-                    )
+                    ]
                 );
             }
         }
@@ -466,42 +396,55 @@ OUT;
     protected function doActionSaveSearchFilter()
     {
         if (method_exists($this, 'getSessionCellName') && \XLite\Core\Request::getInstance()->filterName) {
-
-            $cellName = $this->getSessionCellName();
+            $cellName     = $this->getSessionCellName();
             $searchParams = \XLite\Core\Session::getInstance()->$cellName;
 
             if (!empty($searchParams)) {
-
-                $key = $this->getSearchFilterKeyCell();
+                $errors = false;
+                $key    = $this->getSearchFilterKeyCell();
+                $name   = \XLite\Core\Request::getInstance()->filterName;
 
                 if (\XLite\Core\Request::getInstance()->search_filter_id) {
-                    $params = array();
-                    $params['id'] = \XLite\Core\Request::getInstance()->search_filter_id;
+                    $params              = [];
+                    $params['id']        = \XLite\Core\Request::getInstance()->search_filter_id;
                     $params['filterKey'] = $key;
 
                     // Search for filter
                     $filter = $this->getSearchFilterByParams($params);
                 }
 
-                if (empty($filter)) {
-                    // Filter not found - create it
-                    $filter = new \XLite\Model\SearchFilter();
-                    $filter->setFilterKey($key);
-                    $filter = \XLite\Core\Database::getRepo('XLite\Model\SearchFilter')->insert($filter);
+                if (
+                    empty($filter) ||
+                    (!empty($filter) && $filter->getName() !== $name)
+                ) {
+                    $nameExists = \XLite\Core\Database::getRepo('XLite\Model\SearchFilter')->findOneByNameAndKey($name, $key);
+                    if ($nameExists) {
+                        \XLite\Core\TopMessage::addError('Filter with specified name already exists');
+                        $errors = true;
+                    }
                 }
 
-                // Set the filter name
-                $filter->setName(\XLite\Core\Request::getInstance()->filterName);
+                if (!$errors) {
+                    if (empty($filter)) {
+                        // Filter not found - create it
+                        $filter = new \XLite\Model\SearchFilter();
+                        $filter->setFilterKey($key);
+                        $filter = \XLite\Core\Database::getRepo('XLite\Model\SearchFilter')->insert($filter);
+                    }
 
-                // Set search parameters
-                $searchParams[static::PARAM_SEARCH_FILTER_ID] = $filter->getId();
-                $filter->setParameters($searchParams);
+                    // Set the filter name
+                    $filter->setName(\XLite\Core\Request::getInstance()->filterName);
 
-                \XLite\Core\Session::getInstance()->$cellName = $searchParams;
+                    // Set search parameters
+                    $searchParams[static::PARAM_SEARCH_FILTER_ID] = $filter->getId();
+                    $filter->setParameters($searchParams);
 
-                \XLite\Core\TopMessage::addInfo('Filter has been successfully saved');
+                    \XLite\Core\Session::getInstance()->$cellName = $searchParams;
 
-                \XLite\Core\Database::getEM()->flush();
+                    \XLite\Core\TopMessage::addInfo('Filter has been successfully saved');
+
+                    \XLite\Core\Database::getEM()->flush();
+                }
             }
         }
 
@@ -516,8 +459,8 @@ OUT;
     protected function doActionDeleteSearchFilter()
     {
         if (method_exists($this, 'getSessionCellName') && 0 < intval(\XLite\Core\Request::getInstance()->filter_id)) {
-            $params = array();
-            $params['id'] = intval(\XLite\Core\Request::getInstance()->filter_id);
+            $params              = [];
+            $params['id']        = intval(\XLite\Core\Request::getInstance()->filter_id);
             $params['filterKey'] = $this->getSearchFilterKeyCell();
 
             // Search for filter
@@ -539,7 +482,7 @@ OUT;
      */
     protected function getSearchFilterParams()
     {
-        $result = array();
+        $result = [];
 
         $filter = $this->getSearchFilter();
 
@@ -547,7 +490,8 @@ OUT;
         if ($filter) {
             $result = $filter->getParameters();
 
-            if ($filter->getId()
+            if (
+                $filter->getId()
                 && (
                     empty($result[static::PARAM_SEARCH_FILTER_ID])
                     || $filter->getId() != $result[static::PARAM_SEARCH_FILTER_ID]
@@ -572,20 +516,19 @@ OUT;
         $result = null;
 
         if (method_exists($this, 'getSessionCellName')) {
-            $cellName = $this->getSessionCellName();
+            $cellName     = $this->getSessionCellName();
             $searchParams = \XLite\Core\Session::getInstance()->$cellName;
             if (isset($searchParams[static::PARAM_SEARCH_FILTER_ID])) {
                 $result = $this->getSearchFilterByParams(
-                    array(
-                        'id' => $searchParams[static::PARAM_SEARCH_FILTER_ID],
+                    [
+                        'id'        => $searchParams[static::PARAM_SEARCH_FILTER_ID],
                         'filterKey' => $this->getSearchFilterKeyCell(),
-                    )
+                    ]
                 );
             }
         }
 
         return $result;
-
     }
 
     /**
@@ -600,9 +543,9 @@ OUT;
         $result = false;
 
         if (method_exists($this, 'getSessionCellName')) {
-            $cellName = $this->getSessionCellName();
+            $cellName     = $this->getSessionCellName();
             $searchParams = \XLite\Core\Session::getInstance()->$cellName;
-            $result = isset($searchParams[static::PARAM_SEARCH_FILTER_ID])
+            $result       = isset($searchParams[static::PARAM_SEARCH_FILTER_ID])
                 && $searchParams[static::PARAM_SEARCH_FILTER_ID] == $fid;
         }
 
@@ -620,7 +563,7 @@ OUT;
      */
     public function getLocationPath()
     {
-        if (null === $this->locationPath) {
+        if ($this->locationPath === null) {
             $this->defineLocationPath();
         }
 
@@ -634,7 +577,7 @@ OUT;
      */
     protected function defineLocationPath()
     {
-        $this->locationPath = array();
+        $this->locationPath = [];
 
         // Ability to add part to the line
         $this->addBaseLocation();
