@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -11,15 +10,10 @@ namespace XLite\Controller\Admin;
 /**
  * Sales channels
  */
-class AddonsListSalesChannels extends \XLite\Controller\Admin\AddonsListMarketplace
+class AddonsListSalesChannels extends \XLite\Controller\Admin\AAdmin
 {
-    /**
-     * Return the current page title (for the content area)
-     *
-     * @return string
-     */
     public function getTitle()
     {
-        return static::t('Add sales channel');
+        return static::t('Sales channels');
     }
 }
