@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,6 +19,6 @@ class AddressFields extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        return static::t('Address fields');
+        return static::t('Cart & Checkout');
     }
 }
