@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
     /**
      * Some constants
      */
-    const PROFILES_MAX_RESULTS = 9;
+    public const PROFILES_MAX_RESULTS = 9;
 
     /**
      * Data
@@ -61,11 +60,12 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
     {
         $content = json_encode($this->data);
 
-        header('Content-Type: application/json; charset=UTF-8');
-        header('Content-Length: ' . strlen($content));
-        header('ETag: ' . md5($content));
+        $xLite = \XLite::getInstance();
+        $xLite->addHeader('Content-Type', 'application/json; charset=UTF-8');
+        $xLite->addHeader('Content-Length', strlen($content));
+        $xLite->addHeader('ETag', md5($content));
 
-        print ($content);
+        $xLite->addContent($content);
     }
 
     /**
@@ -77,13 +77,13 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
     {
         return [
             'attributeOption' => [
-                'manage catalog',
+                'ROLE_MANAGE_CATALOG',
             ],
             'profiles'        => [
-                'manage orders',
+                'ROLE_MANAGE_ORDERS',
             ],
             'categories'      => [
-                'manage catalog'
+                'ROLE_MANAGE_CATALOG'
             ],
         ];
     }
@@ -98,9 +98,8 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
         $dictionary = \XLite\Core\Request::getInstance()->dictionary;
 
         if ($dictionary) {
-            $method = 'assembleDictionary' . \XLite\Core\Converter::convertToCamelCase($dictionary);
+            $method = 'assembleDictionary' . \Includes\Utils\Converter::convertToUpperCamelCase($dictionary);
             if (method_exists($this, $method)) {
-
                 // Method name assmbled from 'assembleDictionary' + dictionary input argument
                 $data       = $this->$method((string) \XLite\Core\Request::getInstance()->term);
                 $this->data = $this->processData($data);
@@ -140,7 +139,7 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
      */
     protected function assembleDictionaryAttributeOption($term)
     {
-        $cnd = new \XLite\Core\CommonCell;
+        $cnd = new \XLite\Core\CommonCell();
         if ($term) {
             $cnd->{\XLite\Model\Repo\AttributeOption::SEARCH_NAME} = $term;
         }
@@ -188,8 +187,8 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
         $profiles = \XLite\Core\Database::getRepo('XLite\Model\Category')
             ->getFilteredCategoriesAsDTO($term);
 
-        return array_reduce($profiles, function($acc, $item) {
-            $acc[$item['id']] = isset($item['fullNameHtml']) ? $item['fullNameHtml'] : $item['fullName'];
+        return array_reduce($profiles, static function ($acc, $item) {
+            $acc[$item['id']] = $item['fullNameHtml'] ?? $item['fullName'];
             return $acc;
         }, []);
     }
@@ -206,7 +205,7 @@ class Autocomplete extends \XLite\Controller\Admin\AAdmin
         $result = [];
 
         if ($profiles) {
-            foreach ($profiles as $k => $profile) {
+            foreach ($profiles as $profile) {
                 $result[$profile->getProfileId()] = $profile->getName() . ' (' . $profile->getLogin() . ')';
             }
         }
