@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,9 @@
 
 namespace XLite\Controller\Admin;
 
+use XCart\Operation\Service\ViewListRefresh;
+use XLite\Core\WidgetCache;
+
 /**
  * Cache management page controller
  */
@@ -16,7 +18,7 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
     /**
      * Values to use for $page identification
      */
-    const CACHE_MANAGEMENT_PAGE = 'CacheManagement';
+    public const CACHE_MANAGEMENT_PAGE = 'CacheManagement';
 
     /**
      * Page
@@ -33,23 +35,10 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
     public static function defineFreeFormIdActions()
     {
         return LC_DEVELOPER_MODE
-            ? array_merge(parent::defineFreeFormIdActions(), array('rebuild'))
+            ? array_merge(parent::defineFreeFormIdActions(), ['rebuild'])
             : parent::defineFreeFormIdActions();
     }
 
-    /**
-     * doActionRebuild
-     *
-     * @return void
-     */
-    public function doActionRebuild()
-    {
-        \XLite::setCleanUpCacheFlag(true);
-
-        // To avoid the infinite loop
-        $this->setReturnURL($this->buildURL());
-    }
-
     /**
      * Get tab names
      *
@@ -64,8 +53,6 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
     }
 
     /**
-     * Get resize
-     *
      * @return \XLite\Logic\QuickData\Generator
      */
     public function getQuickDataGenerator()
@@ -76,31 +63,28 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
     /**
      * Check - export process is not-finished or not
      *
-     * @return boolean
+     * @return bool
      */
     public function isQuickDataNotFinished()
     {
         $eventName = \XLite\Logic\QuickData\Generator::getEventName();
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($eventName);
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($eventName);
 
         return $state
             && in_array(
                 $state['state'],
-                array(\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS)
+                [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS],
+                true
             )
-            && !\XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getVar($this->getQuickDataCancelFlagVarName());
+            && !\XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getVar($this->getQuickDataCancelFlagVarName());
     }
 
     /**
      * Perform some actions before redirect
      *
-     * FIXME: check. Action should not be an optional param
-     *
-     * @param string|null $action Performed action OPTIONAL
-     *
-     * @return void
+     * @param string $action Performed action
      */
-    protected function actionPostprocess($action = null)
+    protected function actionPostprocess($action)
     {
         parent::actionPostprocess($action);
 
@@ -109,72 +93,26 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
         );
     }
 
-    /**
-     * Export action
-     *
-     * @return void
-     */
     protected function doActionQuickData()
     {
         \XLite\Logic\QuickData\Generator::run($this->assembleQuickDataOptions());
 
         \XLite\Core\Database::getRepo('XLite\Model\Category')->correctCategoriesStructure();
     }
-    
-    /**
-     * Export action
-     *
-     * @return void
-     */
-    protected function doActionQuickDataToggle()
-    {
-        $value = !\XLite\Core\Config::getInstance()->CacheManagement->quick_data_rebuilding;
 
-        \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-            array(
-                'category' => 'CacheManagement',
-                'name'     => 'quick_data_rebuilding',
-                'value'    => $value,
-            )
-        );
-
-        \XLite\Core\TopMessage::addInfo(
-            $value
-                ? 'Quick data calculation during store re-deployment is enabled'
-                : 'Quick data calculation during store re-deployment is disabled'
-        );
-    }
-
-    /**
-     * Export action
-     *
-     * @return void
-     */
     protected function doActionClearCache()
     {
-        \XLite\Core\Database::getCacheDriver()->deleteAll();
-        \XLite::getInstance()->getContainer()->get('widget_cache')->deleteAll();
+        \XLite\Core\Cache::getInstance()->getDriver()->deleteAll();
+
+        /** @var WidgetCache $widgetCache */
+        $widgetCache = \XCart\Container::getContainer()->get(WidgetCache::class);
+        $widgetCache->deleteAll();
     }
 
-    /**
-     * Export action
-     *
-     * @return void
-     */
     protected function doActionRebuildViewLists()
     {
-        $plugins = [
-            new \Includes\Decorator\Plugin\Templates\Plugin\ViewLists\Main(),
-            new \Includes\Decorator\Plugin\Templates\Plugin\Compiler\Main(),
-            new \Includes\Decorator\Plugin\ModuleHandlers\Main(),
-            new \Includes\Decorator\Plugin\Templates\Plugin\ViewListsPostprocess\Main(),
-        ];
-
-        foreach ($plugins as $plugin) {
-            $plugin->executeHookHandler();
-        }
-
-        \XLite\Core\Database::getEM()->flush();
+        $viewListRefresh = \XCart\Container::getContainer()->get(ViewListRefresh::class);
+        ($viewListRefresh)();
     }
 
     /**
@@ -186,16 +124,11 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
     {
         $request = \XLite\Core\Request::getInstance();
 
-        return array(
+        return [
             'include' => $request->section,
-        );
+        ];
     }
 
-    /**
-     * Cancel
-     *
-     * @return void
-     */
     protected function doActionQuickDataCancel()
     {
         \XLite\Logic\QuickData\Generator::cancel();
@@ -204,8 +137,6 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
 
     /**
      * Preprocessor for no-action run
-     *
-     * @return void
      */
     protected function doNoAction()
     {
@@ -217,9 +148,8 @@ class CacheManagement extends \XLite\Controller\Admin\Settings
             $this->setReturnURL(
                 $this->buildURL('cache_management')
             );
-
         } elseif ($request->quick_data_failed) {
-            \XLite\Core\TopMessage::addError('The calculation of quick data has been stopped.');
+            \XLite\Core\TopMessage::addError($request->error_message ?: 'The calculation of quick data has been stopped.');
 
             $this->setReturnURL(
                 $this->buildURL('cache_management')
