@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -11,40 +10,36 @@ namespace XLite\Controller\Admin;
 use XLite\Core\Auth;
 use XLite\Core\Request;
 
-/**
- * Export controller
- */
 class Export extends \XLite\Controller\Admin\AAdmin
 {
     /**
-     * Generator
-     *
      * @var \XLite\Logic\Export\Generator
      */
     protected $generator;
 
     /**
-     * Return the current page title (for the content area)
-     *
-     * @return string
+     * @return string|null
      */
     public function getTitle()
     {
-        return static::t('Export in CSV');
+        return static::t('Import & export');
     }
 
     /**
      * Check ACL permissions
      *
-     * @return boolean
+     * @return bool
      */
     public function checkACL()
     {
-        if (Request::getInstance()->widget === 'XLite\View\PopupExport' || in_array($this->getAction(), ['itemlist_export', 'download'], true)) {
+        if (
+            Request::getInstance()->widget === 'XLite\View\PopupExport'
+            || in_array($this->getAction(), ['itemlist_export', 'download'], true)
+        ) {
             return true;
         }
 
-        return parent::checkACL() || Auth::getInstance()->isPermissionAllowed('manage export');
+        return parent::checkACL() || Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_EXPORT');
     }
 
     /**
@@ -55,52 +50,63 @@ class Export extends \XLite\Controller\Admin\AAdmin
     public function getGenerator()
     {
         if (!isset($this->generator)) {
-            $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName());
-            $this->generator = $state && isset($state['options']) ? new \XLite\Logic\Export\Generator($state['options']) : false;
+            $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName());
+
+            $this->generator = ($state && isset($state['options']))
+                ? new \XLite\Logic\Export\Generator($state['options'])
+                : false;
         }
 
         return $this->generator;
     }
 
+    /**
+     * Get current page
+     *
+     * @return string
+     */
+    public function getPage()
+    {
+        if (!\XLite\Core\Request::getInstance()->page) {
+            \XLite\Core\Request::getInstance()->page = 'new';
+        }
+
+        return \XLite\Core\Request::getInstance()->page;
+    }
+
     /**
      * Get export state
      *
-     * @return boolean
+     * @return bool
      */
     public function isExportLocked()
     {
         return \XLite\Logic\Export\Generator::isLocked();
     }
 
-    /**
-     * Export action
-     *
-     * @return void
-     */
     protected function doActionExport()
     {
         foreach (\XLite\Core\Request::getInstance()->options as $key => $value) {
             if (
                 !\XLite\Core\Config::getInstance()->Export
-                || \XLite\Core\Config::getInstance()->Export->$key != $value
+                || \XLite\Core\Config::getInstance()->Export->$key !== $value
             ) {
                 \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-                    array(
+                    [
                         'category' => 'Export',
                         'name'     => $key,
                         'value'    => $value,
-                    )
+                    ]
                 );
             }
         }
 
         if (in_array('XLite\Logic\Export\Step\AttributeValues\AttributeValueCheckbox', \XLite\Core\Request::getInstance()->section)) {
-
-            $addSections = array(
+            $addSections = [
                 'XLite\Logic\Export\Step\AttributeValues\AttributeValueSelect',
                 'XLite\Logic\Export\Step\AttributeValues\AttributeValueText',
                 'XLite\Logic\Export\Step\AttributeValues\AttributeValueHidden',
-            );
+            ];
 
             \XLite\Core\Request::getInstance()->section = array_merge(
                 \XLite\Core\Request::getInstance()->section,
@@ -113,15 +119,13 @@ class Export extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Export action
-     *
-     * @return void
      */
     protected function doActionItemlistExport()
     {
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName());
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName());
 
         if ($state) {
-            \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->removeEventState($this->getEventName());
+            \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->removeEventState($this->getEventName());
         }
 
         \XLite\Logic\Export\Generator::run($this->assembleItemsListExportOptions());
@@ -137,15 +141,15 @@ class Export extends \XLite\Controller\Admin\AAdmin
     {
         $request = \XLite\Core\Request::getInstance();
 
-        return array(
+        return [
             'include'       => $request->section,
-            'copyResources' => 'local' == \XLite\Core\Request::getInstance()->options['files'],
+            'copyResources' => \XLite\Core\Request::getInstance()->options['files'] === 'local',
             'attrs'         => $request->options['attrs'],
-            'delimiter'     => isset($request->options['delimiter']) ? $request->options['delimiter'] : \XLite\Core\Config::getInstance()->Units->csv_delim,
-            'charset'       => isset($request->options['charset']) ? $request->options['charset'] : \XLite\Core\Config::getInstance()->Units->export_import_charset,
-            'filter'        => isset($request->options['filter']) ? $request->options['filter'] : '',
-            'selection'     => isset($request->options['selection']) ? $request->options['selection'] : array(),
-        );
+            'delimiter'     => $request->options['delimiter'] ?? \XLite\Core\Config::getInstance()->Units->csv_delim,
+            'charset'       => $request->options['charset'] ?? \XLite\Core\Config::getInstance()->Units->export_import_charset,
+            'filter'        => $request->options['filter'] ?? '',
+            'selection'     => $request->options['selection'] ?? [],
+        ];
     }
 
     /**
@@ -155,18 +159,12 @@ class Export extends \XLite\Controller\Admin\AAdmin
      */
     protected function assembleItemsListExportOptions()
     {
-        $options = $this->assembleExportOptions();
+        $options              = $this->assembleExportOptions();
         $options['itemsList'] = true;
 
         return $options;
     }
 
-
-    /**
-     * Cancel
-     *
-     * @return void
-     */
     protected function doActionCancel()
     {
         \XLite\Logic\Export\Generator::cancel();
@@ -175,21 +173,16 @@ class Export extends \XLite\Controller\Admin\AAdmin
         $this->setSilenceClose(true);
     }
 
-    /**
-     * Download
-     *
-     * @return void
-     */
     protected function doActionDownload()
     {
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName());
-        $path = \XLite\Core\Request::getInstance()->path;
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName());
+        $path  = \XLite\Core\Request::getInstance()->path;
         if ($state && $path) {
             $generator = new \XLite\Logic\Export\Generator($state['options']);
-            $list = $generator->getDownloadableFiles();
+            $list      = $generator->getDownloadableFiles();
 
             $path = LC_DIR_VAR . $generator->getOptions()->dir . LC_DS . $path;
-            if (in_array($path, $list)) {
+            if (in_array($path, $list, true)) {
                 $name = basename($path);
                 header('Content-Type: ' . $this->detectMimeType($path) . '; charset=UTF-8');
                 header('Content-Disposition: attachment; filename="' . $name . '"; modification-date="' . date('r') . ';');
@@ -205,8 +198,6 @@ class Export extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Delete all files
-     *
-     * @return void
      */
     protected function doActionDeleteFiles()
     {
@@ -218,16 +209,14 @@ class Export extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Pack and download
-     *
-     * @return void
      */
     protected function doActionPack()
     {
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName());
-        $type = \XLite\Core\Request::getInstance()->type;
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName());
+        $type  = \XLite\Core\Request::getInstance()->type;
         if ($state && $type) {
             $generator = new \XLite\Logic\Export\Generator($state['options']);
-            $path = $generator->packFiles($type);
+            $path      = $generator->packFiles($type);
 
             if ($path) {
                 $name = basename($path);
@@ -248,7 +237,7 @@ class Export extends \XLite\Controller\Admin\AAdmin
      */
     public static function defineFreeFormIdActions()
     {
-        return array_merge(parent::defineFreeFormIdActions(), array('itemlist_export', 'pack', 'download', 'cancel'));
+        return array_merge(parent::defineFreeFormIdActions(), ['itemlist_export', 'pack', 'download', 'cancel']);
     }
 
     /**
@@ -264,9 +253,8 @@ class Export extends \XLite\Controller\Admin\AAdmin
 
         if (preg_match('/\.csv$/Ss', $path)) {
             $type = 'text/csv';
-
         } elseif (class_exists('finfo', false)) {
-            $fi = new \finfo(FILEINFO_MIME);
+            $fi   = new \finfo(FILEINFO_MIME);
             $type = $fi->file($path);
         }
 
@@ -309,14 +297,14 @@ class Export extends \XLite\Controller\Admin\AAdmin
     /**
      * Check - export process is not-finished or not
      *
-     * @return boolean
+     * @return bool
      */
     protected function isExportNotFinished()
     {
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName());
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName());
 
         return $state
-            && in_array($state['state'], [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS])
-            && !\XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getVar($this->getExportCancelFlagVarName());
+            && in_array((int) $state['state'], [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS], true)
+            && !\XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getVar($this->getExportCancelFlagVarName());
     }
 }
