@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -11,6 +10,7 @@ namespace XLite\Controller\Admin;
 use lsolesen\pel\PelDataWindow;
 use lsolesen\pel\PelJpeg;
 use lsolesen\pel\PelTag;
+use XLite\Core\Request;
 use XLite\Model\Base\Image;
 
 /**
@@ -18,8 +18,8 @@ use XLite\Model\Base\Image;
  */
 class Files extends \XLite\Controller\Admin\AAdmin
 {
-    const RESPONSE_WIDGET = 'widget';
-    const RESPONSE_JSON   = 'json';
+    public const RESPONSE_WIDGET = 'widget';
+    public const RESPONSE_JSON   = 'json';
 
     /**
      * Check if current page is accessible
@@ -50,7 +50,8 @@ class Files extends \XLite\Controller\Admin\AAdmin
      */
     protected function checkFile($file)
     {
-        if ($file
+        if (
+            $file
             && \XLite\Core\Request::getInstance()->is_image
             && !$file->isImage()
             && !(
@@ -59,7 +60,19 @@ class Files extends \XLite\Controller\Admin\AAdmin
             )
         ) {
             $file->removeFile();
-            $this->sendResponse(null, static::t('File is not an image'));
+
+            $responseMessage = 'File is not an image';
+
+            if (
+                \XLite\Core\Request::getInstance()->is_image
+                && !$file->isImage()
+                && strtolower(pathinfo($file->getPath(), PATHINFO_EXTENSION)) === Image::SVG_EXTENSION
+                && !Request::getInstance()->svg_allowed
+            ) {
+                $responseMessage = 'SVG images are not allowed here';
+            }
+
+            $this->sendResponse(null, static::t($responseMessage));
         }
     }
 
@@ -71,14 +84,24 @@ class Files extends \XLite\Controller\Admin\AAdmin
      */
     protected function doActionUploadFromFile()
     {
-        $file = \XLite\Core\Request::getInstance()->register
-            ? new \XLite\Model\Image\Content()
-            : new \XLite\Model\TemporaryFile();
+        $request = \XLite\Core\Request::getInstance();
 
-        if (\XLite\Core\Request::getInstance()->type === 'video') {
-            $file = \XLite\Core\Request::getInstance()->register
+        if ($request->type === 'video') {
+            $file = $request->register
                 ? new \XLite\Model\Video\Content()
                 : new \XLite\Model\Video\Temporary();
+        } else {
+            $file = $request->register
+                ? new \XLite\Model\Image\Content()
+                : new \XLite\Model\TemporaryFile();
+
+            if ($request->extended) {
+                $file->allowExtendedTypes();
+            }
+        }
+
+        if ($request->alt) {
+            $file->setAlt($request->alt);
         }
 
         $message = '';
@@ -87,7 +110,6 @@ class Files extends \XLite\Controller\Admin\AAdmin
             $this->postProcessImageUpload($file);
             \XLite\Core\Database::getEM()->persist($file);
             \XLite\Core\Database::getEM()->flush();
-
         } elseif ($file->getLoadErrorMessage()) {
             $message = call_user_func_array(['\XLite\Controller\Admin\Files',
                 't'], $file->getLoadErrorMessage());
@@ -110,14 +132,24 @@ class Files extends \XLite\Controller\Admin\AAdmin
             ? new \XLite\Model\Image\Content()
             : new \XLite\Model\TemporaryFile();
         $message = '';
+
+        if (\XLite\Core\Request::getInstance()->alt) {
+            $file->setAlt(\XLite\Core\Request::getInstance()->alt);
+        }
+
         if ($file->loadFromURL(\XLite\Core\Request::getInstance()->uploadedUrl, \XLite\Core\Request::getInstance()->copy)) {
             $this->checkFile($file);
             $this->postProcessImageUpload($file);
             \XLite\Core\Database::getEM()->persist($file);
             \XLite\Core\Database::getEM()->flush();
-
         } else {
-            $message = static::t('Make sure the URL is correct and the file referenced by the URL is a PNG/JPG/JPEG');
+            $label = 'Make sure the URL is correct and the file referenced by the URL is a PNG/JPG/JPEG/WEBP';
+
+            if (Request::getInstance()->svg_allowed) {
+                $label .= '/SVG';
+            }
+
+            $message = static::t($label);
         }
 
         $this->sendResponse($file, $message);
@@ -133,6 +165,12 @@ class Files extends \XLite\Controller\Admin\AAdmin
             && in_array($file->getStorageType(), $this->getStorageTypesToImagePostProcess())
             && $file->isFileExists(null, true)
         ) {
+            if ($file->getMime() === 'image/svg+xml') {
+                $this->setWidgetParams([
+                    'width' => $file->getWidth(),
+                    'height' => $file->getHeight()
+                ]);
+            }
             try {
                 $content = file_get_contents($file->getStoragePath());
                 $dataWindow = new PelDataWindow($content);
@@ -147,7 +185,7 @@ class Files extends \XLite\Controller\Admin\AAdmin
 
                         if (
                             $entry
-                            && (integer)$entry->getValue() !== 1
+                            && (int)$entry->getValue() !== 1
                         ) {
                             $this->processImageOrientation(
                                 $file->getStoragePath(),
@@ -158,7 +196,8 @@ class Files extends \XLite\Controller\Admin\AAdmin
                         }
                     }
                 }
-            } catch (\lsolesen\pel\PelException $e) {}
+            } catch (\lsolesen\pel\PelException $e) {
+            }
         }
     }
 
@@ -189,8 +228,8 @@ class Files extends \XLite\Controller\Admin\AAdmin
     protected function getOperationsByExifOrientation($orientation)
     {
         return [
-            'mirror' => in_array((integer)$orientation, [2, 4, 5, 7]),
-            'rotate' => $this->getDegreeByOrientation((integer)$orientation)
+            'mirror' => in_array((int)$orientation, [2, 4, 5, 7]),
+            'rotate' => $this->getDegreeByOrientation((int)$orientation)
         ];
     }
 
@@ -328,7 +367,7 @@ class Files extends \XLite\Controller\Admin\AAdmin
     protected function getSuccessResponseData($file)
     {
         $url = \XLite\Core\Request::getInstance()->register
-            ? str_replace(\XLite\Core\URLManager::getShopURL(), '', $file->getFrontURL())
+            ? '/' . str_replace(\XLite\Core\URLManager::getShopURL(), '', $file->getFrontURL())
             : $file->getFrontURL();
 
         if ($file instanceof \XLite\Model\Base\Image) {
@@ -386,7 +425,6 @@ class Files extends \XLite\Controller\Admin\AAdmin
         ]);
 
         $this->printAJAXOutput($viewer);
-        exit(0);
     }
 
     /**
