@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,12 +7,14 @@
 
 namespace XLite\Controller\Admin;
 
+use XLite\Core\Auth;
+use XLite\Model\Role\Permission;
+
 /**
  * Front page controller
  */
 class FrontPage extends \XLite\Controller\Admin\Category
 {
-
     /**
      * @param array $params
      */
@@ -24,6 +25,12 @@ class FrontPage extends \XLite\Controller\Admin\Category
         $this->params = ['target'];
     }
 
+    public function checkACL()
+    {
+        return (Auth::getInstance()->isPermissionAllowed(Permission::ROOT_ACCESS)
+                && parent::checkACL()) || Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_FRONT_PAGE');
+    }
+
     /**
      * Return the category name for the title
      *
