@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -31,7 +30,7 @@ class Images extends \XLite\Controller\Admin\AAdmin
             return static::t('Resizing images...');
         }
 
-        return static::t('Default image settings');
+        return static::t('Images settings');
     }
 
     /**
@@ -46,28 +45,28 @@ class Images extends \XLite\Controller\Admin\AAdmin
         \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
             'category' => 'Performance',
             'name'     => 'use_dynamic_image_resizing',
-            'value'    => (boolean)$request->use_dynamic_image_resizing,
+            'value'    => (bool)$request->use_dynamic_image_resizing,
         ]);
 
         if ($this->isShowUnsharpOption()) {
             \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
                 'category' => 'Performance',
                 'name'     => 'unsharp_mask_filter_on_resize',
-                'value'    => (boolean)$request->unsharp_mask_filter_on_resize,
+                'value'    => (bool)$request->unsharp_mask_filter_on_resize,
             ]);
         }
 
         \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
             'category' => 'Performance',
             'name'     => 'resize_quality',
-            'value'    => (integer)$request->resize_quality,
+            'value'    => (int)$request->resize_quality,
         ]);
 
         if (isset($request->cloud_zoom)) {
             \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
                 'category' => 'Layout',
                 'name'     => 'cloud_zoom',
-                'value'    => (boolean)$request->cloud_zoom,
+                'value'    => (bool)$request->cloud_zoom,
             ]);
         }
 
@@ -79,12 +78,25 @@ class Images extends \XLite\Controller\Admin\AAdmin
             \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
                 'category' => 'Performance',
                 'name'     => 'use_lazy_load',
-                'value'    => (boolean)$request->use_lazy_load,
+                'value'    => (bool)$request->use_lazy_load,
             ]);
         }
 
         $list = new \XLite\View\ItemsList\Model\ImagesSettings();
         $list->processQuick();
+
+        $this->createResizedLogo();
+    }
+
+    /**
+     * Create resized image for logo
+     */
+    public function createResizedLogo()
+    {
+        $logoImage = \XLite\Core\Database::getRepo('XLite\Model\Image\Common\Logo')->getLogo();
+        \XLite\Logic\ImageResize\Generator::clearImageSizesCache();
+        \Includes\Utils\FileManager::unlinkRecursive(LC_DIR_VAR . 'images/logo');
+        $logoImage->prepareSizes();
     }
 
     /**
@@ -108,11 +120,11 @@ class Images extends \XLite\Controller\Admin\AAdmin
     /**
      * Return "Unsharp mask filter on resize" setting value
      *
-     * @return boolean
+     * @return bool
      */
     public function getUnsharpMaskFilterOnResizeValue()
     {
-        return (boolean)\XLite\Core\Config::getInstance()->Performance->unsharp_mask_filter_on_resize;
+        return (bool)\XLite\Core\Config::getInstance()->Performance->unsharp_mask_filter_on_resize;
     }
 
     /**
@@ -122,7 +134,7 @@ class Images extends \XLite\Controller\Admin\AAdmin
      */
     public function getResizeQuality()
     {
-        return (integer)\XLite\Core\Config::getInstance()->Performance->resize_quality ?: 85;
+        return (int)\XLite\Core\Config::getInstance()->Performance->resize_quality ?: 85;
     }
 
     /**
@@ -146,7 +158,7 @@ class Images extends \XLite\Controller\Admin\AAdmin
     {
         if (!isset($this->imageResizeGenerator)) {
             $eventName = \XLite\Logic\ImageResize\Generator::getEventName();
-            $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($eventName);
+            $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($eventName);
             $this->imageResizeGenerator = ($state && isset($state['options']))
                 ? new \XLite\Logic\ImageResize\Generator($state['options'])
                 : false;
@@ -158,31 +170,32 @@ class Images extends \XLite\Controller\Admin\AAdmin
     /**
      * Check - export process is not-finished or not
      *
-     * @return boolean
+     * @return bool
      */
     public function isImageResizeNotFinished()
     {
         $eventName = \XLite\Logic\ImageResize\Generator::getEventName();
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($eventName);
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($eventName);
 
         return $state
             && in_array(
                 $state['state'],
-                [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS]
+                [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS],
+                true
             )
-            && !\XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getVar($this->getImageResizeCancelFlagVarName());
+            && !\XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getVar($this->getImageResizeCancelFlagVarName());
     }
 
     /**
      * Export action
-     *
-     * @return void
      */
     protected function doActionImageResize()
     {
         if (\XLite\Core\ImageOperator::getEngineType() === \XLite\Core\ImageOperator::ENGINE_SIMPLE) {
             \XLite\Core\TopMessage::addError("Image resizing requires libraries");
         } else {
+            \Includes\Utils\FileManager::unlinkRecursive(LC_DIR_VAR . 'images/category');
+            \Includes\Utils\FileManager::unlinkRecursive(LC_DIR_VAR . 'images/product');
             \XLite\Logic\ImageResize\Generator::run($this->assembleImageResizeOptions());
         }
     }
@@ -203,8 +216,6 @@ class Images extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Cancel
-     *
-     * @return void
      */
     protected function doActionImageResizeCancel()
     {
@@ -214,8 +225,6 @@ class Images extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Preprocessor for no-action run
-     *
-     * @return void
      */
     protected function doNoAction()
     {
@@ -227,7 +236,6 @@ class Images extends \XLite\Controller\Admin\AAdmin
             $this->setReturnURL(
                 $this->buildURL('images')
             );
-
         } elseif ($request->resize_failed) {
             \XLite\Core\TopMessage::addError('The generation of resized images has been stopped.');
 
@@ -254,7 +262,7 @@ class Images extends \XLite\Controller\Admin\AAdmin
     /**
      * Check if cloud zoom enabled
      *
-     * @return boolean
+     * @return bool
      */
     public function getCloudZoomEnabled()
     {
@@ -274,7 +282,7 @@ class Images extends \XLite\Controller\Admin\AAdmin
     /**
      * Check if cloud zoom supported by skin
      *
-     * @return boolean
+     * @return bool
      */
     public function isCloudZoomAllowed()
     {
