@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,9 @@
 
 namespace XLite\Controller\Admin;
 
+use XLite\Core\Database;
 use XLite\Core\Translation;
+use XLite\Model\LanguageLabelTranslation;
 
 /**
  * Language labels controller
@@ -21,7 +22,7 @@ class Labels extends \XLite\Controller\Admin\AAdmin
      *
      * @var string
      */
-    protected $params = ['target', 'code'];
+    protected $params = ['target', 'code', 'section'];
 
     /**
      * Define the actions with no secure token
@@ -40,7 +41,9 @@ class Labels extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        return static::t('Language labels');
+        return \XLite\Core\Request::getInstance()->section === 'store'
+            ? static::t('Localization')
+            : static::t('Customization');
     }
 
     /**
@@ -51,9 +54,10 @@ class Labels extends \XLite\Controller\Admin\AAdmin
     public function getReturnURL()
     {
         $request = \XLite\Core\Request::getInstance();
-        if ($request->action && $request->code) {
+        if ($request->action && $request->code && $request->section) {
             $url = $this->buildURL('labels', '', [
-                'code' => $request->code
+                'code'    => $request->code,
+                'section' => $request->section
             ]);
         } else {
             $url = parent::getReturnURL();
@@ -69,7 +73,7 @@ class Labels extends \XLite\Controller\Admin\AAdmin
      */
     public function getLanguages()
     {
-        return \XLite\Core\Database::getRepo('\XLite\Model\Language')->findAddedLanguages();
+        return Database::getRepo('\XLite\Model\Language')->findAddedLanguages();
     }
 
     /**
@@ -82,6 +86,16 @@ class Labels extends \XLite\Controller\Admin\AAdmin
         return \XLite\Core\Request::getInstance()->code ?: parent::getDefaultLanguage();
     }
 
+    /**
+     * Get current section
+     *
+     * @return string
+     */
+    public function getSection()
+    {
+        return \XLite\Core\Request::getInstance()->section ?: '';
+    }
+
     /**
      * Update labels
      *
@@ -108,23 +122,18 @@ class Labels extends \XLite\Controller\Admin\AAdmin
         $translated    = !empty($requestData['translated']) ? $requestData['translated'] : null;
         $translateFail = false;
         if ($translated && is_array($translated)) {
-
             $language = \XLite\Core\Request::getInstance()->code;
 
             if (!$language) {
-
                 \XLite\Core\TopMessage::addWarning(
                     'Text labels have not been updated successfully: the translation language has not been specified'
                 );
                 $translateFail = true;
-
-            } elseif (!\XLite\Core\Database::getRepo('\XLite\Model\Language')->findOneByCode($language)) {
-
+            } elseif (!Database::getRepo('\XLite\Model\Language')->findOneByCode($language)) {
                 \XLite\Core\TopMessage::addWarning(
                     'Text labels have not been updated successfully: the translation language has not been found'
                 );
                 $translateFail = true;
-
             } else {
                 $this->saveLabels(
                     $translated,
@@ -147,6 +156,7 @@ class Labels extends \XLite\Controller\Admin\AAdmin
     protected function doActionAdd()
     {
         $requestData = \XLite\Core\Request::getInstance()->getPostData(false);
+        $entityManager = Database::getEM();
 
         $name  = substr($requestData['name'], 0, 255);
         $label = $requestData['label'];
@@ -156,34 +166,34 @@ class Labels extends \XLite\Controller\Admin\AAdmin
             \XLite\Core\TopMessage::addError(
                 'The text label has not been added, because its name has not been specified'
             );
-
-        } elseif (\XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->findOneByName($name)) {
+        } elseif (Database::getRepo('\XLite\Model\LanguageLabel')->findOneByName($name)) {
             $this->valid = false;
             \XLite\Core\TopMessage::addError(
                 'The text label has not been added, because such a text label already exists'
             );
-
         } else {
-
             $lbl = new \XLite\Model\LanguageLabel();
             $lbl->setName($name);
+            $entityManager->persist($lbl);
 
             foreach ($label as $code => $text) {
                 if (!empty($text)) {
-                    $lbl->setEditLanguage($code)->setLabel($text);
+                    $translation = new LanguageLabelTranslation();
+                    $translation->setCode($code);
+                    $translation->setOwner($lbl);
+                    $translation->setLabel($text);
+                    $entityManager->persist($translation);
                 }
             }
 
-            $lbl = \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->insert($lbl);
+            $entityManager->flush();
 
             if ($lbl && $lbl->getLabelId()) {
-
                 // Save added label ID in session
                 $addedLabels = \XLite\Core\Session::getInstance()->added_labels;
 
                 if (is_array($addedLabels)) {
                     array_push($addedLabels, $lbl->getLabelId());
-
                 } else {
                     $addedLabels = [$lbl->getLabelId()];
                 }
@@ -209,28 +219,31 @@ class Labels extends \XLite\Controller\Admin\AAdmin
 
         $label   = $requestData['label'];
         $labelId = intval(\XLite\Core\Request::getInstance()->label_id);
-        $labelName = isset($requestData['label_name']) ? $requestData['label_name'] : null;
+        $labelName = $requestData['label_name'] ?? null;
 
+        $repo = Database::getRepo('XLite\Model\LanguageLabel');
         /** @var \XLite\Model\LanguageLabel $lbl */
-        $lbl = \XLite\Core\Database::getRepo('XLite\Model\LanguageLabel')->find($labelId)
-            ?: \XLite\Core\Database::getRepo('XLite\Model\LanguageLabel')->findOneBy(['name' => $labelName]);
+        $lbl = $repo->find($labelId)
+            ?: $repo->findOneBy(['name' => $labelName]);
 
         if (!$lbl) {
             \XLite\Core\TopMessage::addError('The edited language has not been found');
-
         } else {
-            $objects = [];
+            $list = [];
 
             foreach ($label as $code => $text) {
-                if (!empty($text) || $lbl->hasTranslation($code)) {
+                if (!empty($text)) {
                     $translation = $lbl->getTranslation($code);
                     $translation->setLabel($text);
 
-                    $objects[] = $translation;
+                    $list['update'][] = $translation;
+                } elseif ($lbl->hasTranslation($code)) {
+                    $list['delete'][] = $lbl->getTranslation($code);
                 }
             }
 
-            \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->insertInBatch($objects);
+            $repo->insertInBatch($list['update'] ?? []);
+            $repo->deleteInBatch($list['delete'] ?? []);
             Translation::getInstance()->reset();
 
             $this->onEditSuccess($lbl);
@@ -247,18 +260,31 @@ class Labels extends \XLite\Controller\Admin\AAdmin
      */
     protected function saveLabels(array $values, $code)
     {
-        $labels = \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->findByIds(
+        $repo = Database::getRepo('\XLite\Model\LanguageLabel');
+        $entityManager = Database::getEM();
+        $labels = $repo->findByIds(
             array_keys($values)
         );
 
-        $list = [];
-
         foreach ($labels as $label) {
-            $label->setEditLanguage($code)->setLabel($values[$label->getLabelId()]);
-            $list[] = $label;
+            $newValue = $values[$label->getLabelId()];
+            $translation = $label->getTranslation($code);
+            if ($newValue === '') {
+                if ($translation) {
+                    $entityManager->remove($translation);
+                }
+            } else {
+                if (!$translation) {
+                    $translation = new LanguageLabelTranslation();
+                    $translation->setCode($code);
+                    $label->addTranslations($translation);
+                }
+                $translation->setLabel($newValue);
+                $entityManager->persist($translation);
+            }
         }
+        $entityManager->flush();
 
-        \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->updateInBatch($list);
         \XLite\Core\Translation::getInstance()->reset();
     }
 
