@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,12 +8,7 @@
 namespace XLite\Controller\Admin;
 
 use Xlite\Core\Request;
-use XLite\Core\Skin;
-use XLite\Rebuild\Connector;
 
-/**
- * Layout
- */
 class Layout extends \XLite\Controller\Admin\AAdmin
 {
     /**
@@ -37,7 +31,7 @@ class Layout extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        return static::t('Layout');
+        return static::t('Themes');
     }
 
     /**
@@ -61,61 +55,36 @@ class Layout extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * Change template
+     * If it need to show free quote for design block
      *
-     * @return void
-     * @throws \Exception
+     * @return bool
      */
-    protected function doActionChangeTemplate()
+    public function showFreeQuoteBlock()
     {
-        list ($moduleId, $color) = $this->parseRequestParam(Request::getInstance()->template);
+        return true;
+    }
 
-        if ($color) {
-            \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
+    protected function doNoAction()
+    {
+        if (\XLite\Core\Request::getInstance()->rebuildId) {
+            \XLite\Core\TopMessage::addInfo(
+                'If anything crops up, just rollback or contact our support team - they know how to fix it right away.',
                 [
-                    'category' => 'Layout',
-                    'name' => 'color',
-                    'value' => $color,
+                    'rollback_url' => \XLite::getInstance()->getShopURL('service.php?/rollback', null, ['id' => \XLite\Core\Request::getInstance()->rebuildId])
                 ]
             );
-        }
 
-        if ($moduleId && $moduleId !== Skin::getInstance()->getCurrentSkinModuleId()) {
-            Connector::enableSkin($moduleId, $this->buildFullURL('layout'));
+            $this->setReturnURL($this->buildURL('layout'));
         }
     }
 
-    /**
-     * Return switch data
-     *
-     * @param $value
-     * @return array
-     */
-    protected function parseRequestParam($value)
-    {
-        if (Skin::SKIN_STANDARD !== $value) {
-            return (false !== strpos($value, '_'))
-                ? explode('_', $value)
-                : [$value, null];
-        }
-
-        return [Skin::SKIN_STANDARD, 'Default'];
-    }
-
-    /**
-     * Change layout
-     *
-     * @return void
-     */
     protected function doActionChangeLayout()
     {
         $layoutType = Request::getInstance()->layout_type;
         $layoutGroup = Request::getInstance()->layout_group ?: \XLite\Core\Layout::LAYOUT_GROUP_DEFAULT;
 
         $availableLayoutTypes = \XLite\Core\Layout::getInstance()->getAvailableLayoutTypes();
-        $groupAvailableTypes = isset($availableLayoutTypes[$layoutGroup])
-            ? $availableLayoutTypes[$layoutGroup]
-            : [];
+        $groupAvailableTypes = $availableLayoutTypes[$layoutGroup] ?? [];
 
         if (in_array($layoutType, $groupAvailableTypes, true)) {
             $group_suffix = ($layoutGroup == \XLite\Core\Layout::LAYOUT_GROUP_DEFAULT ? '' : '_' . $layoutGroup);
