@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,11 +7,10 @@
 
 namespace XLite\Controller\Admin;
 
-
 class Logs extends \XLite\Controller\Admin\AAdmin
 {
     public function getTitle()
     {
-        return 'System logs';
+        return static::t('System logs');
     }
-}
\ No newline at end of file
+}
