@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\Controller\Admin;
 
-use Includes\Utils\Module\Manager;
+use XCart\Domain\ModuleManagerDomain;
 
 /**
  * Module settings
@@ -20,6 +19,15 @@ class Module extends \XLite\Controller\Admin\AAdmin
      */
     protected $module;
 
+    private ModuleManagerDomain $moduleManagerDomain;
+
+    public function __construct(array $params = [])
+    {
+        parent::__construct($params);
+
+        $this->moduleManagerDomain = \XCart\Container::getContainer()->get(ModuleManagerDomain::class);
+    }
+
     /**
      * @param array $classes Classes
      *
@@ -29,7 +37,7 @@ class Module extends \XLite\Controller\Admin\AAdmin
     {
         $classes = parent::defineBodyClasses($classes);
 
-        list($author, $name) = \Includes\Utils\Module\Module::explodeModuleId($this->getModule());
+        [$author, $name] = \Includes\Utils\Module\Module::explodeModuleId($this->getModule());
 
         if ($author && $name) {
             $classes[] = strtolower('module-' . $author . '-' . $name);
@@ -43,12 +51,13 @@ class Module extends \XLite\Controller\Admin\AAdmin
         $module = $this->getModule();
 
         if (!$module) {
-            $this->setReturnURL($this->buildURL('addons_list_installed'));
-
+            $this->setReturnURL($this->buildURL(\XLite::TARGET_404));
         } else {
-            $showSettingsForm = Manager::getRegistry()->getModule($module)->showSettingsForm;
-            $settingsUrl = \Includes\Utils\Module\Module::callMainClassMethod($module, 'getSettingsForm');
-            parse_str(parse_url($settingsUrl, PHP_URL_QUERY), $settingsUrlParams);
+            $showSettingsForm = $this->moduleManagerDomain->getModule($module)['showSettingsForm'];
+
+            $settingsUrl = (string) \Includes\Utils\Module\Module::callMainClassMethod($module, 'getSettingsForm');
+            parse_str((string) parse_url($settingsUrl, PHP_URL_QUERY), $settingsUrlParams);
+
             if (
                 $showSettingsForm
                 && $settingsUrl
@@ -71,7 +80,7 @@ class Module extends \XLite\Controller\Admin\AAdmin
      */
     public function getOptions()
     {
-        list($author, $name) = \Includes\Utils\Module\Module::explodeModuleId($this->getModule());
+        [$author, $name] = \Includes\Utils\Module\Module::explodeModuleId($this->getModule());
 
         return \XLite\Core\Database::getRepo('XLite\Model\Config')
             ->findByCategoryAndVisible($author . '\\' . $name);
@@ -86,12 +95,27 @@ class Module extends \XLite\Controller\Admin\AAdmin
     public function getTitle()
     {
         $module = $this->getModule();
-        $name = Manager::getRegistry()->getModule($module)->moduleName;
+
+        [$moduleAuthor, $moduleName] = \Includes\Utils\Module\Module::explodeModuleId($module);
+
+        $customHeading = \XLite\Core\Database::getRepo('\XLite\Model\Config')
+            ->findOneBy([
+                'category' => $moduleAuthor . '\\' . $moduleName,
+                'name'     => 'settings_page_heading',
+            ]);
+
+        if ($customHeading) {
+            $customHeadingTranslation = $customHeading->getTranslation(\XLite\Core\Session::getInstance()->getLanguage()->getCode())->getOptionName();
+
+            if ($customHeadingTranslation) {
+                return $customHeadingTranslation;
+            }
+        }
 
         return static::t(
             'X module settings',
             [
-                'name' => $name,
+                'name' => $this->moduleManagerDomain->getModule($module)['moduleName'],
             ]
         );
     }
@@ -104,9 +128,9 @@ class Module extends \XLite\Controller\Admin\AAdmin
     public function getModule()
     {
         if ($this->module === null) {
-            $this->module = Manager::getRegistry()->isModuleEnabled($this->getModuleId())
+            $this->module = $this->moduleManagerDomain->isEnabled($this->getModuleId())
                 ? $this->getModuleId()
-                : false;
+                : '';
         }
 
         return $this->module;
