@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,10 +8,11 @@
 namespace XLite\Controller\Admin;
 
 use XLite\Core\Request;
+use XLite\Model\DTO\Base\ADTO;
+use XLite\Model\DTO\Settings\Notification\Admin;
+use XLite\Model\DTO\Settings\Notification\Customer;
+use XLite\Model\Notification as NotificationModel;
 
-/**
- * Notification controller
- */
 class Notification extends \XLite\Controller\Admin\AAdmin
 {
     use \XLite\Controller\Features\FormModelControllerTrait;
@@ -26,7 +26,9 @@ class Notification extends \XLite\Controller\Admin\AAdmin
 
     public function handleRequest()
     {
-        $this->handleNotificationPageParam();
+        if ($this->getNotification()) {
+            $this->handleNotificationPageParam();
+        }
 
         parent::handleRequest();
     }
@@ -40,7 +42,7 @@ class Notification extends \XLite\Controller\Admin\AAdmin
 
         if (!$this->isValidPage($page)) {
             if ($url = $this->buildValidPageUrl()) {
-                $this->redirect($this->buildValidPageUrl());
+                $this->redirect($url);
             } else {
                 $this->redirect($this->buildURL('notifications'));
             }
@@ -55,7 +57,7 @@ class Notification extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * @param $page
+     * @param string $page
      *
      * @return bool
      */
@@ -69,13 +71,13 @@ class Notification extends \XLite\Controller\Admin\AAdmin
             ], true)
             && (
                 $page !== 'customer'
-                || $notification->getEnabledForCustomer()
-                || $notification->getAvailableForCustomer()
+                || $notification?->getEnabledForCustomer()
+                || $notification?->getAvailableForCustomer()
             )
             && (
                 $page !== 'admin'
-                || $notification->getEnabledForAdmin()
-                || $notification->getAvailableForAdmin()
+                || $notification?->getEnabledForAdmin()
+                || $notification?->getAvailableForAdmin()
             );
     }
 
@@ -86,26 +88,26 @@ class Notification extends \XLite\Controller\Admin\AAdmin
     {
         $notification = $this->getNotification();
 
-        if ($notification->getAvailableForCustomer() || $notification->getEnabledForCustomer()) {
-            return $this->buildURL('notification', '', [
-                'templatesDirectory' => $notification->getTemplatesDirectory(),
-                'page'               => 'customer',
-            ]);
-        }
+        if ($notification) {
+            if ($notification->getAvailableForCustomer() || $notification->getEnabledForCustomer()) {
+                return $this->buildURL('notification', '', [
+                    'templatesDirectory' => $notification->getTemplatesDirectory(),
+                    'page'               => 'customer',
+                ]);
+            }
 
-        if ($notification->getAvailableForAdmin() || $notification->getEnabledForAdmin()) {
-            return $this->buildURL('notification', '', [
-                'templatesDirectory' => $notification->getTemplatesDirectory(),
-                'page'               => 'admin',
-            ]);
+            if ($notification->getAvailableForAdmin() || $notification->getEnabledForAdmin()) {
+                return $this->buildURL('notification', '', [
+                    'templatesDirectory' => $notification->getTemplatesDirectory(),
+                    'page'               => 'admin',
+                ]);
+            }
         }
 
         return '';
     }
 
     /**
-     * Return the current page title (for the content area)
-     *
      * @return string
      */
     public function getTitle()
@@ -118,8 +120,6 @@ class Notification extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * Returns description of current notification
-     *
      * @return string
      */
     public function getDescription()
@@ -134,7 +134,7 @@ class Notification extends \XLite\Controller\Admin\AAdmin
     /**
      * Returns object to get initial data and populate submitted data to
      *
-     * @return \XLite\Model\DTO\Base\ADTO
+     * @return ADTO
      */
     public function getFormModelObject()
     {
@@ -144,20 +144,15 @@ class Notification extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * @return \XLite\Model\DTO\Base\ADTO
+     * @return string
      */
     protected function getFormModelObjectClass()
     {
-        return 'admin' === Request::getInstance()->page
-            ? 'XLite\Model\DTO\Settings\Notification\Admin'
-            : 'XLite\Model\DTO\Settings\Notification\Customer';
+        return Request::getInstance()->page === 'admin'
+            ? Admin::class
+            : Customer::class;
     }
 
-    /**
-     * Update model
-     *
-     * @return void
-     */
     protected function doActionUpdate()
     {
         $dto = $this->getFormModelObject();
@@ -174,30 +169,26 @@ class Notification extends \XLite\Controller\Admin\AAdmin
             \XLite\Core\Database::getEM()->flush();
 
             \XLite\Core\TopMessage::addInfo('The notification has been updated');
-
         } else {
             $this->saveFormModelTmpData($rawData[$this->formName]);
         }
     }
 
     /**
-     * Returns notification
-     *
-     * @return \XLite\Model\Notification
+     * @return NotificationModel|null
      */
     public function getNotification()
     {
-        $id = \XLite\Core\Request::getInstance()->templatesDirectory;
+        $templatesDirectory = \XLite\Core\Request::getInstance()->templatesDirectory;
 
-        return $id
-            ? \XLite\Core\Database::getRepo('XLite\Model\Notification')->find($id)
+        return $templatesDirectory
+            ? \XLite\Core\Database::getRepo(NotificationModel::class)
+                ?->findOneBy(['templatesDirectory' => $templatesDirectory, 'available' => 1])
             : null;
     }
 
     /**
-     * Check controller visibility
-     *
-     * @return boolean
+     * @return bool
      */
     protected function isVisible()
     {
