@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,6 @@ namespace XLite\Controller\Admin;
  */
 class NotificationAttachments extends \XLite\Controller\Admin\Settings
 {
-
     /**
      * Return the current page title (for the content area)
      *
@@ -29,15 +27,13 @@ class NotificationAttachments extends \XLite\Controller\Admin\Settings
      *
      * @return \XLite\Model\Config[]
      */
-    public function getOptions()
+    public function getOptions($getAllOptions = false)
     {
         return \XLite\Core\Database::getRepo('XLite\Model\Config')->findByCategoryAndVisible('NotificationAttachments');
     }
 
     /**
      * Update model
-     *
-     * @return void
      */
     public function doActionUpdate()
     {
