@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\Controller\Admin;
 
+use XLite\Core\Auth;
 use XLite\Core\OrderHistory;
 
 /**
@@ -20,7 +20,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      *
      * @var array
      */
-    protected $params = array('target', 'order_id', 'order_number', 'page');
+    protected $params = ['target', 'order_id', 'order_number', 'page'];
 
     /**
      * Order (local cache)
@@ -41,7 +41,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      *
      * @var array
      */
-    protected static $changes = array();
+    protected static $changes = [];
 
     /**
      * Temporary orders list
@@ -64,7 +64,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected $orders;
 
-
     /**
      * Return variable $isNeedProcessStock
      *
@@ -84,7 +83,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         return array_merge(
             parent::defineFreeFormIdActions(),
-            array('calculate_price', 'recalculate_shipping')
+            ['calculate_price', 'recalculate_shipping']
         );
     }
 
@@ -123,15 +122,14 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $result = null;
 
-        if (null === static::$tmpOrders) {
+        if (static::$tmpOrders === null) {
             // Initialize $tmpOrders
-            static::$tmpOrders = array();
+            static::$tmpOrders = [];
         }
 
         if ($orderId && isset(static::$tmpOrders[$orderId])) {
             // Get specific temporary order data from cache
             $result = static::$tmpOrders[$orderId];
-
         } else {
             $result = static::$tmpOrders;
         }
@@ -150,9 +148,9 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $result = null;
 
-        if (null === static::$tmpOrders) {
+        if (static::$tmpOrders === null) {
             // Initialize $tmpOrders
-            static::$tmpOrders = array();
+            static::$tmpOrders = [];
         }
 
         if (isset(static::$tmpOrders[$orderId])) {
@@ -201,7 +199,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
                 // Prepare the correspondence table of order items
 
-                $itemIds = array();
+                $itemIds = [];
 
                 foreach ($newOrder->getItems() as $i) {
                     $itemIds[$i->getKey()] = $i->getItemId();
@@ -213,7 +211,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
                         static::$tmpOrders[$orderId]['items'][$item->getItemId()] = $itemIds[$key];
                     }
                 }
-
             } else {
                 \XLite\Core\TopMessage::addError('Cannot create temporary order for modification');
             }
@@ -232,15 +229,13 @@ class Order extends \XLite\Controller\Admin\AAdmin
      * @param string $name     Order property name
      * @param mixed  $newValue New property value
      * @param mixed  $oldValue Old property value
-     *
-     * @return void
      */
     public static function setOrderChanges($name, $newValue, $oldValue = null)
     {
-        static::$changes[$name] = array(
+        static::$changes[(string)$name] = [
             'old' => $oldValue,
             'new' => $newValue,
-        );
+        ];
     }
 
     /**
@@ -250,18 +245,17 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected function getOrderChanges()
     {
-        $changes = array();
+        $changes = [];
 
         foreach (static::$changes as $key => $data) {
             $names = explode(':', $key, 2);
 
             $name = static::getFieldHumanReadableName($names[0]);
-            $subname = isset($names[1]) ? $names[1] : null;
+            $subname = $names[1] ?? null;
 
             if ($subname) {
                 $subname = static::getFieldHumanReadableName($subname);
                 $changes[$name][$subname] = $data;
-
             } else {
                 $changes[$name] = $data;
             }
@@ -281,7 +275,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $names = static::getFieldHumanReadableNames();
 
-        return isset($names[$name]) ? $names[$name]: $name;
+        return $names[$name] ?? $name;
     }
 
     /**
@@ -291,7 +285,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected static function getFieldHumanReadableNames()
     {
-        return array(
+        return [
             'billingAddress'  => 'Billing address',
             'shippingAddress' => 'Shipping address',
             'shippingId'      => 'Shipping method',
@@ -305,7 +299,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
             'city'            => 'City',
             'zipcode'         => 'Zip code',
             'phone'           => 'Phone',
-        );
+        ];
     }
 
     // }}}
@@ -317,24 +311,20 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function checkACL()
     {
-        return parent::checkACL() || \XLite\Core\Auth::getInstance()->isPermissionAllowed('manage orders');
+        return parent::checkACL() || \XLite\Core\Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_ORDERS');
     }
 
-    /**
-     * handleRequest
-     *
-     * @return void
-     */
     public function handleRequest()
     {
         $request = \XLite\Core\Request::getInstance();
 
-        if ($request->action
-            && 'update' !== $request->action
+        if (
+            $request->action
+            && $request->action !== 'update'
         ) {
             $order = $this->getOrder();
 
-            if (null !== $order) {
+            if ($order !== null) {
                 $allowedTransactions = $order->getAllowedPaymentActions();
 
                 if (isset($allowedTransactions[$request->action])) {
@@ -347,7 +337,8 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
         // Set ignoreLongCalculations mode for shipping rates gathering
         foreach (\XLite\Model\Shipping::getProcessors() as $processor) {
-            if (!($processor instanceof \XLite\Model\Shipping\Processor\Offline)
+            if (
+                !($processor instanceof \XLite\Model\Shipping\Processor\Offline)
                 && $processor->isConfigured()
             ) {
                 \XLite\Model\Shipping::setIgnoreLongCalculationsMode(true);
@@ -359,6 +350,16 @@ class Order extends \XLite\Controller\Admin\AAdmin
         parent::handleRequest();
     }
 
+    /**
+     * Check controller visibility
+     *
+     * @return boolean
+     */
+    protected function isVisible()
+    {
+        return parent::isVisible() && $this->getOrders();
+    }
+
     /**
      * Check if current page is accessible
      *
@@ -369,9 +370,8 @@ class Order extends \XLite\Controller\Admin\AAdmin
         $orders = $this->getOrders();
 
         return parent::checkAccess()
-            && $orders
-            && $orders[0]
-            && $orders[0]->getProfile();
+            && (isset($orders[0])
+                && $orders[0]->getProfile());
     }
 
     /**
@@ -381,27 +381,23 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        if ('invoice' === \XLite\Core\Request::getInstance()->mode) {
+        if (\XLite\Core\Request::getInstance()->mode === 'invoice') {
             $result = (
                 \XLite\Core\Config::getInstance()->Company->company_name
                 ? \XLite\Core\Config::getInstance()->Company->company_name . ': '
                 : ''
             ) . static::t('Invoice');
-
-        } elseif ('packing_slip' === \XLite\Core\Request::getInstance()->mode) {
+        } elseif (\XLite\Core\Request::getInstance()->mode === 'packing_slip') {
             $result = (
                 \XLite\Core\Config::getInstance()->Company->company_name
                     ? \XLite\Core\Config::getInstance()->Company->company_name . ': '
                     : ''
                 ) . static::t('Packing slip');
-
-        } elseif ('XLite\View\Address\OrderModify' === ltrim(\XLite\Core\Request::getInstance()->widget, '\\')) {
+        } elseif (ltrim((string) \XLite\Core\Request::getInstance()->widget, '\\') === 'XLite\View\Address\OrderModify') {
             $result = static::t('Customer information');
-
-        } elseif ('XLite\View\SelectAddressOrder' === ltrim(\XLite\Core\Request::getInstance()->widget, '\\')) {
+        } elseif (ltrim((string) \XLite\Core\Request::getInstance()->widget, '\\') === 'XLite\View\SelectAddressOrder') {
             $result = static::t('Pick address from address book');
-
-        } elseif ('XLite\View\PaymentMethodData' === ltrim(\XLite\Core\Request::getInstance()->widget, '\\')) {
+        } elseif (ltrim((string) \XLite\Core\Request::getInstance()->widget, '\\') === 'XLite\View\PaymentMethodData') {
             $paymentMethod = null;
             if (intval(\XLite\Core\Request::getInstance()->transaction_id)) {
                 $transaction = \XLite\Core\Database::getRepo('XLite\Model\Payment\Transaction')
@@ -412,10 +408,12 @@ class Order extends \XLite\Controller\Admin\AAdmin
                         : $transaction->getMethodName();
                 }
             }
-            $result = $paymentMethod ?: static::t('Payment method data');
 
-        } else {
+            $result = $paymentMethod ?: static::t('Payment method data');
+        } elseif ($this->getOrder()) {
             $result = static::t('Order X', ['id' => $this->getOrder()->getOrderNumber()]);
+        } else {
+            $result = parent::getTitle();
         }
 
         return $result;
@@ -428,12 +426,11 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function getOrder()
     {
-        if (null === $this->order) {
+        if ($this->order === null) {
             $order = null;
             if (\XLite\Core\Request::getInstance()->order_id) {
                 $order = \XLite\Core\Database::getRepo('XLite\Model\Order')
                     ->find((int) \XLite\Core\Request::getInstance()->order_id);
-
             } elseif (\XLite\Core\Request::getInstance()->order_number) {
                 $order = \XLite\Core\Database::getRepo('XLite\Model\Order')
                     ->findOneByOrderNumber(\XLite\Core\Request::getInstance()->order_number);
@@ -454,8 +451,8 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function getOrders()
     {
-        if (null === $this->orders) {
-            $result = array();
+        if ($this->orders === null) {
+            $result = [];
 
             if (\XLite\Core\Request::getInstance()->order_ids) {
                 $orderIds = explode(',', \XLite\Core\Request::getInstance()->order_ids);
@@ -467,7 +464,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
                         $result[] = $order;
                     }
                 }
-            } else {
+            } elseif ($this->getOrder()) {
                 $result[] = $this->getOrder();
             }
 
@@ -575,7 +572,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function isOrderEditable()
     {
-        return !\XLite::isFreeLicense();
+        return true;
     }
 
     /**
@@ -588,14 +585,12 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         return \Includes\Utils\ArrayManager::filterByKeys(
             \XLite\Core\Request::getInstance()->getData(),
-            array('paymentStatus', 'shippingStatus')
+            ['paymentStatus', 'shippingStatus']
         );
     }
 
     /**
      * Recalculate shipping rates of the source order
-     *
-     * @return void
      */
     protected function doActionRecalculateShipping()
     {
@@ -617,8 +612,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
      * Display recalculate shipping data
      *
      * @param \XLite\Model\Order $order Order
-     *
-     * @return void
      */
     protected function displayRecalculateShippingData(\XLite\Model\Order $order)
     {
@@ -634,15 +627,15 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected function assembleRecalculateShippingEvent(\XLite\Model\Order $order)
     {
-        $result = array(
-            'options' => array(),
-        );
+        $result = [
+            'options' => [],
+        ];
 
         $modifier = $order->getModifier(\XLite\Model\Base\Surcharge::TYPE_SHIPPING, 'SHIPPING');
         $modifier->setMode(\XLite\Logic\Order\Modifier\AModifier::MODE_CART);
 
         foreach ($modifier->getRates() as $rate) {
-            $result['options'][$rate->getMethod()->getMethodId()] = array(
+            $result['options'][$rate->getMethod()->getMethodId()] = [
                 'name'     => html_entity_decode(
                     strip_tags($rate->getMethod()->getName()),
                     ENT_COMPAT,
@@ -653,7 +646,17 @@ class Order extends \XLite\Controller\Admin\AAdmin
                     ENT_COMPAT,
                     'UTF-8'
                 ),
-            );
+            ];
+        }
+
+        if (
+            $order->getShippingId() > 0
+            && !in_array($order->getShippingId(), array_keys($result['options']))
+        ) {
+            $result['options'][$order->getShippingId()] = [
+                'name'     => $order->getShippingMethodName(),
+                'fullName' => $order->getShippingMethodName(),
+            ];
         }
 
         return $result;
@@ -661,8 +664,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Recalculate order
-     *
-     * @return void
      */
     protected function doActionRecalculate()
     {
@@ -692,15 +693,13 @@ class Order extends \XLite\Controller\Admin\AAdmin
      * Update order items list
      *
      * @param \XLite\Model\Order $order Order object
-     *
-     * @return void
      */
     protected function updateOrderItems($order)
     {
         $list = new \XLite\View\ItemsList\Model\OrderItem(
-            array(
+            [
                 'order' => $order,
-            )
+            ]
         );
 
         $list->processQuick();
@@ -708,12 +707,40 @@ class Order extends \XLite\Controller\Admin\AAdmin
         $order->calculateInitialValues();
     }
 
+    /**
+     * Update product sales
+     *
+     * @param array $before Array of saled product in order
+     * @param \XLite\Model\Order $order Order
+     */
+    public function updateProductSales($before, $order)
+    {
+        foreach ($order->getItems() as $item) {
+            if (isset($before[$item->getID()])) {
+                if ($before[$item->getId()]['amount'] != $item->getAmount()) {
+                    $diff = $item->getAmount() - $before[$item->getId()]['amount'];
+                    if ($item->getObject()) {
+                        $item->getObject()->setSales($item->getObject()->getSales() + $diff);
+                    }
+                }
+                unset($before[$item->getID()]);
+            } else {
+                if ($item->getObject()) {
+                    $item->getObject()->setSales($item->getObject()->getSales() + $item->getAmount());
+                }
+            }
+        }
+        foreach ($before as $item) {
+            if ($item['item']->getObject()) {
+                $item['item']->getObject()->setSales($item['item']->getObject()->getSales() - $item['amount']);
+            }
+        }
+    }
+
     /**
      * Display recalculate data
      *
      * @param \XLite\Model\Order $order Order
-     *
-     * @return void
      */
     protected function displayRecalculateData(\XLite\Model\Order $order)
     {
@@ -726,8 +753,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
      * Remove temporary order
      *
      * @param \XLite\Model\Order $order Order
-     *
-     * @return void
      */
     protected function removeTemporaryOrder(\XLite\Model\Order $order)
     {
@@ -776,11 +801,11 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected function assembleRecalculateOrderEvent(\XLite\Model\Order $order)
     {
-        $result =  array(
+        $result =  [
             'subtotal'  => $order->getSubtotal(),
             'total'     => $order->getTotal(),
-            'modifiers' => array(),
-        );
+            'modifiers' => [],
+        ];
 
         foreach ($this->getSurchargeTotals(true) as $surcharge) {
             $result['modifiers'][$surcharge['code']] = abs($surcharge['cost']);
@@ -812,11 +837,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
         return $result;
     }
 
-    /**
-     * doActionUpdate
-     *
-     * @return void
-     */
     protected function doActionUpdate()
     {
         $order = $this->getOrder();
@@ -829,7 +849,9 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
         if ($this->isOrderEditable()) {
             // Update order items list
+            $before = $this->getOrderItemsAndAmountBeforeUpdate($order);
             $this->updateOrderItems($order);
+            $this->updateProductSales($before, $order);
 
             // Update common order form fields
             $this->updateCommonForm();
@@ -859,36 +881,45 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
             $this->sendOrderChangeNotification();
         }
+
+        \XLite\Core\Database::getEM()->flush();
     }
 
     protected function isOrderChanged()
     {
-        return (boolean)$this->getOrderChanges();
+        return (bool)$this->getOrderChanges();
     }
 
     /**
-     * Update common form
+     * Get order items amount and model before update
      *
-     * @return void
+     * @param \XLite\Model\Order $order Order
+     *
+     * @return array
      */
+    public function getOrderItemsAndAmountBeforeUpdate($order)
+    {
+        foreach ($order->getItems() as $item) {
+            $array[$item->getID()]['amount'] = $item->getAmount();
+            $array[$item->getID()]['item']   = $item;
+        }
+
+        return $array;
+    }
+
     protected function updateCommonForm()
     {
         $this->getOrderForm()->performAction('save');
     }
 
-    /**
-     * Update order status
-     *
-     * @return void
-     */
     protected function updateOrderStatus()
     {
         $data = $this->getRequestData();
         $order = $this->getOrder();
 
         $updateRecent = false;
-        foreach (array('paymentStatus', 'shippingStatus') as $status) {
-            $method = 'get' . \XLite\Core\Converter::convertToCamelCase($status);
+        foreach (['paymentStatus', 'shippingStatus'] as $status) {
+            $method = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($status);
             // Call assembled $method: getPaymentStatus() or getShippingStatus()
             $oldStatus = $order->$method();
             $oldStatusId = $oldStatus ? $oldStatus->getId() : null;
@@ -907,19 +938,14 @@ class Order extends \XLite\Controller\Admin\AAdmin
         );
     }
 
-    /**
-     * Update tracking
-     *
-     * @return void
-     */
     protected function updateTracking()
     {
         $numbers = $this->prepareTrackingData($this->getOrder()->getTrackingNumbers()->toArray());
 
         $list = new \XLite\View\ItemsList\Model\OrderTrackingNumber(
-            array(
+            [
                 \XLite\View\ItemsList\Model\OrderTrackingNumber::PARAM_ORDER_ID => $this->getOrder()->getOrderId(),
-            )
+            ]
         );
         $list->processQuick();
 
@@ -937,10 +963,10 @@ class Order extends \XLite\Controller\Admin\AAdmin
     protected function prepareTrackingData(array $numbers)
     {
         return array_combine(
-            array_map(function (\XLite\Model\OrderTrackingNumber $number) {
+            array_map(static function (\XLite\Model\OrderTrackingNumber $number) {
                 return $number->getTrackingId();
             }, $numbers),
-            array_map(function (\XLite\Model\OrderTrackingNumber $number) {
+            array_map(static function (\XLite\Model\OrderTrackingNumber $number) {
                 return $number->getValue();
             }, $numbers)
         );
@@ -954,7 +980,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $deleted = array_diff_key(array_diff($old, $new), $new);
         $added = array_diff_key(array_diff($new, $old), $old);
-        $changed = array_map(function ($key) use ($old, $new) {
+        $changed = array_map(static function ($key) use ($old, $new) {
             return [
                 'old' => $old[$key],
                 'new' => $new[$key],
@@ -980,11 +1006,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
         }
     }
 
-    /**
-     * Send order changed notification
-     *
-     * @return void
-     */
     protected function sendOrderChangeNotification()
     {
         if (!$this->getOrder()->isNotificationSent()) {
@@ -1007,8 +1028,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Update staff note
-     *
-     * @return void
      */
     protected function updateAdminNotes()
     {
@@ -1024,11 +1043,10 @@ class Order extends \XLite\Controller\Admin\AAdmin
         $oldNotes = $this->getOrder()->getAdminNotes();
 
         if ($oldNotes != $notes) {
-
-            $changes = array(
+            $changes = [
                 'old' => $oldNotes,
                 'new' => $notes,
-            );
+            ];
 
             \XLite\Core\OrderHistory::getInstance()
                 ->registerOrderChangeAdminNotes($this->getOrder()->getOrderId(), $changes);
@@ -1039,11 +1057,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
         }
     }
 
-    /**
-     * Update customer note
-     *
-     * @return void
-     */
     protected function updateCustomerNotes()
     {
         $notes = \XLite\Core\Request::getInstance()->notes;
@@ -1060,19 +1073,18 @@ class Order extends \XLite\Controller\Admin\AAdmin
             $oldNotes = $this->getOrder()->getNotes();
 
             if ($oldNotes != $notes) {
-
-                $changes = array(
+                $changes = [
                     'old' => $this->getOrder()->getNotes(),
                     'new' => $notes,
-                );
+                ];
 
                 \XLite\Core\OrderHistory::getInstance()
                     ->registerOrderChangeCustomerNotes($this->getOrder()->getOrderId(), $changes);
 
                 static::setOrderChanges(
                     static::t('Customer note'),
-                    $changes['old'],
-                    $changes['new']
+                    $changes['new'],
+                    $changes['old']
                 );
 
                 $this->getOrder()->setNotes($notes);
@@ -1082,15 +1094,10 @@ class Order extends \XLite\Controller\Admin\AAdmin
         }
     }
 
-    /**
-     * Update payment methods
-     *
-     * @return void
-     */
     protected function updatePaymentMethods()
     {
         if ($this->isOrderEditable()) {
-            $methods = \XLite\Core\Request::getInstance()->paymentMethods ?: array();
+            $methods = \XLite\Core\Request::getInstance()->paymentMethods ?: [];
 
             foreach ($methods as $transactionId => $methodId) {
                 $transaction = \XLite\Core\Database::getRepo('XLite\Model\Payment\Transaction')->find($transactionId);
@@ -1118,8 +1125,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
     /**
      * Send tracking information action
-     *
-     * @return void
      */
     protected function doActionSendTracking()
     {
@@ -1128,11 +1133,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
         \XLite\Core\TopMessage::addInfo('Tracking information has been sent');
     }
 
-    /**
-     * doActionUpdate
-     *
-     * @return void
-     */
     protected function doActionPaymentTransaction()
     {
         $order = $this->getOrder();
@@ -1152,11 +1152,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
         }
     }
 
-    /**
-     * Calculate item price
-     *
-     * @return void
-     */
     protected function doActionCalculatePrice()
     {
         if ($this->isOrderEditable()) {
@@ -1165,13 +1160,12 @@ class Order extends \XLite\Controller\Admin\AAdmin
             $item = null;
 
             if ($request->item_id) {
-                list($item, $attributes) = $this->getPreparedItemByItemId();
+                [$item, $attributes] = $this->getPreparedItemByItemId();
                 if (!$item) {
                     $this->valid = false;
                 }
-
             } elseif ($request->product_id) {
-                list($item, $attributes) = $this->getPreparedItemByProductId();
+                [$item, $attributes] = $this->getPreparedItemByProductId();
             }
 
             if ($item) {
@@ -1180,7 +1174,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
 
             if (!$item) {
                 $this->valid = false;
-
             } elseif (\XLite\Core\Request::getInstance()->isAJAX()) {
                 $this->displayRecalculateItemPrice($item);
             }
@@ -1200,17 +1193,18 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $order = $this->getOrder();
         $request = \XLite\Core\Request::getInstance();
-        $attributeValues = array();
+        $attributeValues = [];
         $item = $order->getItemByItemId($request->item_id);
 
-        if ($item
+        if (
+            $item
             && !empty($request->order_items[$request->item_id])
             && !empty($request->order_items[$request->item_id]['attribute_values'])
         ) {
             $attributeValues = $request->order_items[$request->item_id]['attribute_values'];
         }
 
-        return array($item, $attributeValues);
+        return [$item, $attributeValues];
     }
 
     /**
@@ -1222,18 +1216,18 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $order = $this->getOrder();
         $request = \XLite\Core\Request::getInstance();
-        $item = new \XLite\Model\OrderItem;
+        $item = new \XLite\Model\OrderItem();
         $item->setOrder($order);
         $item->setProduct(\XLite\Core\Database::getRepo('XLite\Model\Product')->find($request->product_id));
 
         $attributes = $request->new;
-        $attributes = reset($attributes);
-        $attributeValues = array();
+        $attributes = !empty($attributes) ? reset($attributes) : null;
+        $attributeValues = [];
         if (!empty($attributes['attribute_values'])) {
             $attributeValues = $attributes['attribute_values'];
         }
 
-        return array($item, $attributeValues);
+        return [$item, $attributeValues];
     }
 
     /**
@@ -1241,8 +1235,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
      *
      * @param \XLite\Model\OrderItem $item       Order item
      * @param array                  $attributes Attributes
-     *
-     * @return void
      */
     protected function prepareItemBeforePriceCalculation(\XLite\Model\OrderItem $item, array $attributes)
     {
@@ -1262,8 +1254,6 @@ class Order extends \XLite\Controller\Admin\AAdmin
      * Display recalculate item price
      *
      * @param \XLite\Model\OrderItem $item Order item
-     *
-     * @return void
      */
     protected function displayRecalculateItemPrice(\XLite\Model\OrderItem $item)
     {
@@ -1286,12 +1276,12 @@ class Order extends \XLite\Controller\Admin\AAdmin
             \XLite\Core\Request::getInstance()->oldAmount = null;
         }
 
-        return array(
+        return [
             'item_id'   => $item->getItemId(),
             'requestId' => \XLite\Core\Request::getInstance()->requestId,
-            'price'     => $item->getItemPrice(),
+            'price'     => $item->getNetPrice(),
             'max_qty'   => $maxAmount,
-        );
+        ];
     }
 
     /**
@@ -1303,11 +1293,11 @@ class Order extends \XLite\Controller\Admin\AAdmin
     {
         $result = parent::getViewerTemplate();
 
-        if ('invoice' === \XLite\Core\Request::getInstance()->mode) {
+        if (\XLite\Core\Request::getInstance()->mode === 'invoice') {
             $result = 'common/print_invoice.twig';
         }
 
-        if ('packing_slip' === \XLite\Core\Request::getInstance()->mode) {
+        if (\XLite\Core\Request::getInstance()->mode === 'packing_slip') {
             $result = 'common/print_packing_slip.twig';
         }
 
@@ -1324,8 +1314,13 @@ class Order extends \XLite\Controller\Admin\AAdmin
     public function getPages()
     {
         $list = parent::getPages();
-        $list['default'] = static::t('General info');
-        $list['invoice'] = static::t('Invoice');
+        if (
+            $this->getOrder()
+            && Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_ORDERS')
+        ) {
+            $list['default'] = static::t('General info');
+            $list['invoice'] = static::t('Invoice');
+        }
 
         return $list;
     }
@@ -1371,9 +1366,9 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function getOrderStatusAttributes($statusType)
     {
-        return array(
+        return [
             'class' => 'not-affect-recalculate',
-        );
+        ];
     }
 
     // }}}
@@ -1389,7 +1384,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     public function getSurchargeTotals($force = false)
     {
-        if (null === $this->modifiers || $force) {
+        if ($this->modifiers === null || $force) {
             $this->modifiers = $this->defineSurchargeTotals();
         }
 
@@ -1435,7 +1430,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
         }
 
 
-        uasort($modifiers, function ($a, $b) {
+        uasort($modifiers, static function ($a, $b) {
             $aWeight = $a['object']
                 ? $a['object']->getSortingWeight()
                 : 0;
@@ -1490,7 +1485,7 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected function assembleDefaultDumpSurcharge($type, $code, $class, $name)
     {
-        $surcharge = new \XLite\Model\Order\Surcharge;
+        $surcharge = new \XLite\Model\Order\Surcharge();
         $surcharge->setType($type);
         $surcharge->setCode($code);
         $surcharge->setClass($class);
@@ -1498,18 +1493,18 @@ class Order extends \XLite\Controller\Admin\AAdmin
         $surcharge->setName($name);
         $surcharge->setOwner(static::getTemporaryOrder($this->getOrder()->getOrderId(), false) ?: $this->getOrder());
 
-        return array(
+        return [
             'name'      => $surcharge->getTypeName(),
             'cost'      => $surcharge->getValue(),
             'available' => $surcharge->getAvailable(),
             'count'     => 1,
             'lastName'  => $surcharge->getName(),
             'code'      => $surcharge->getCode(),
-            'widget'    => \Includes\Utils\Operator::checkIfClassExists($class)
+            'widget'    => class_exists($class)
                 ? $class::getWidgetClass()
                 : \XLite\Logic\Order\Modifier\AModifier::getWidgetClass(),
             'object'    => $surcharge,
-        );
+        ];
     }
 
     /**
@@ -1519,9 +1514,9 @@ class Order extends \XLite\Controller\Admin\AAdmin
      */
     protected function getRequiredSurcharges()
     {
-        return array(
+        return [
             \XLite\Logic\Order\Modifier\Shipping::MODIFIER_CODE,
-        );
+        ];
     }
 
     // }}}
