@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,13 +7,21 @@
 
 namespace XLite\Controller\Admin;
 
-use Includes\Utils\Module\Manager;
-
 /**
  * Payment method selection  controller
  */
 class PaymentMethodSelection extends \XLite\Controller\Admin\AAdmin
 {
+    /**
+     * Constructor
+     *
+     * @param array $params Constructor parameters
+     */
+    public function __construct(array $params = [])
+    {
+        parent::__construct($params);
+    }
+
     /**
      * Define the actions with no secure token
      *
@@ -22,17 +29,7 @@ class PaymentMethodSelection extends \XLite\Controller\Admin\AAdmin
      */
     public static function defineFreeFormIdActions()
     {
-        return array_merge(parent::defineFreeFormIdActions(), array('search'));
-    }
-
-    /**
-     * Constructor
-     *
-     * @param array $params Constructor parameters
-     */
-    public function __construct(array $params = array())
-    {
-        parent::__construct($params);
+        return array_merge(parent::defineFreeFormIdActions(), ['search']);
     }
 
     /**
@@ -52,21 +49,32 @@ class PaymentMethodSelection extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        switch ($this->getPaymentType()) {
-            case \XLite\Model\Payment\Method::TYPE_ALTERNATIVE:
-                $result = static::t('Add alternative payment method');
-                break;
+        return static::t('Payment methods');
+    }
 
-            case \XLite\Model\Payment\Method::TYPE_OFFLINE:
-                $result = static::t('Add offline payment method');
-                break;
+    /**
+     * Return true if 'Install' link should be displayed
+     *
+     * @param \XLite\Model\Payment\Method $method Payment method
+     *
+     * @return string
+     */
+    public function isDisplayInstallModuleLink(\XLite\Model\Payment\Method $method)
+    {
+        return $method->getModuleName()
+            && !$this->isModuleEnabled($method);
+    }
 
-            default:
-                $result = '';
-                break;
-        }
-
-        return $result;
+    /**
+     * Returns URL to payment module
+     *
+     * @param \XLite\Model\Payment\Method $method Payment method
+     *
+     * @return string
+     */
+    public function getPaymentModuleURL(\XLite\Model\Payment\Method $method)
+    {
+        return $method->getModulePageURL();
     }
 
     /**
@@ -93,20 +101,6 @@ class PaymentMethodSelection extends \XLite\Controller\Admin\AAdmin
         return $searchParams;
     }
 
-    /**
-     * Return true if 'Install' link should be displayed
-     *
-     * @param \XLite\Model\Payment\Method $method Payment method
-     *
-     * @return string
-     */
-    public function isDisplayInstallModuleLink(\XLite\Model\Payment\Method $method)
-    {
-        return $method->getModuleName()
-            && !$this->isModuleEnabled($method)
-            && !$this->isDisplayInstallModuleButton($method);
-    }
-
     /**
      * Return true if payment method's module is enabled
      *
@@ -118,33 +112,4 @@ class PaymentMethodSelection extends \XLite\Controller\Admin\AAdmin
     {
         return (bool) $method->getProcessor();
     }
-
-    /**
-     * Return true if 'Install' button should be displayed
-     *
-     * @param \XLite\Model\Payment\Method $method Payment method
-     *
-     * @return string
-     */
-    public function isDisplayInstallModuleButton(\XLite\Model\Payment\Method $method)
-    {
-        $result = false;
-        // todo: get this info from BUS
-
-        return $result;
-    }
-
-    /**
-     * Returns URL to payment module
-     *
-     * @param \XLite\Model\Payment\Method $method Payment method
-     *
-     * @return string
-     */
-    public function getPaymentModuleURL(\XLite\Model\Payment\Method $method)
-    {
-        list($author, $name) = explode('_', $method->getModuleName());
-
-        return \Includes\Utils\Module\Manager::getRegistry()->getModuleServiceURL($author, $name);
-    }
 }
