@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -24,7 +23,7 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
      */
     public static function defineFreeFormIdActions()
     {
-        return array_merge(parent::defineFreeFormIdActions(), array('add', 'switch'));
+        return array_merge(parent::defineFreeFormIdActions(), ['add', 'switch']);
     }
 
     /**
@@ -34,7 +33,7 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        return static::t('Payment settings');
+        return static::t('Payment Methods');
     }
 
     /**
@@ -56,7 +55,7 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
      */
     protected function getMethod()
     {
-        return $this->executeCachedRuntime(function () {
+        return $this->executeCachedRuntime(static function () {
             $id = \XLite\Core\Request::getInstance()->id;
             return $id ? \XLite\Core\Database::getRepo('XLite\Model\Payment\Method')->find($id) : null;
         });
@@ -133,11 +132,11 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
     protected function dispatchAJAXEnable()
     {
         if ($this->isAJAX()) {
-            $this->printAJAX(array(
-                'href'      => $this->buildURL('payment_settings', 'disable', array('id' => \XLite\Core\Request::getInstance()->id)),
+            $this->printAJAX([
+                'href'      => $this->buildURL('payment_settings', 'disable', ['id' => \XLite\Core\Request::getInstance()->id]),
                 'removeCSS' => 'disabled',
                 'addCSS'    => 'enabled',
-            ));
+            ]);
         }
     }
 
@@ -170,11 +169,11 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
     protected function dispatchAJAXDisable()
     {
         if ($this->isAJAX()) {
-            $this->printAJAX(array(
-                'href'      => $this->buildURL('payment_settings', 'enable', array('id' => \XLite\Core\Request::getInstance()->id)),
+            $this->printAJAX([
+                'href'      => $this->buildURL('payment_settings', 'enable', ['id' => \XLite\Core\Request::getInstance()->id]),
                 'removeCSS' => 'enabled',
                 'addCSS'    => 'disabled',
-            ));
+            ]);
         }
     }
 
@@ -190,7 +189,6 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
         if ($method && !$method->isForcedEnabled()) {
             if (get_class($method->getProcessor()) == 'XLite\Model\Payment\Processor\Offline') {
                 \XLite\Core\Database::getEM()->remove($method);
-
             } else {
                 $method->setAdded(false);
             }
@@ -216,6 +214,15 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
                 \XLite\Core\Database::getEM()->flush();
             }
 
+            if (\XLite\Core\Request::getInstance()->rebuildId) {
+                \XLite\Core\TopMessage::addInfo(
+                    'If anything crops up, just rollback or contact our support team - they know how to fix it right away.',
+                    [
+                        'rollback_url' => \XLite::getInstance()->getShopURL('service.php?/rollback', null, ['id' => \XLite\Core\Request::getInstance()->rebuildId])
+                    ]
+                );
+            }
+
             $this->setReturnURL($method->getConfigurationURL(true));
         }
     }
@@ -245,15 +252,16 @@ class PaymentSettings extends \XLite\Controller\Admin\AAdmin
         $method = null;
 
         $name = (string) \XLite\Core\Request::getInstance()->name;
-        $instruction = (string) \XLite\Core\Request::getInstance()->instruction;
+        $title = (string) \XLite\Core\Request::getInstance()->title;
+        $instruction = (string) \XLite\Core\Request::getInstance()->getNonFilteredData()['instruction'] ?: null;
         $description = (string) \XLite\Core\Request::getInstance()->description;
 
         if ($name) {
-            $method = new \XLite\Model\Payment\Method;
+            $method = new \XLite\Model\Payment\Method();
             $method->setName($name);
-            $method->setTitle($name);
+            $method->setTitle($title);
             $method->setDescription($description);
-            $method->setClass('Model\\Payment\\Processor\\Offline');
+            $method->setClass('XLite\\Model\\Payment\\Processor\\Offline');
             $method->setAdded(true);
             //$method->setModuleEnabled(true);
             $method->setType(\XLite\Model\Payment\Method::TYPE_OFFLINE);
