@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,6 +8,8 @@
 namespace XLite\Controller\Admin;
 
 use XLite\Core\TopMessage;
+use XLite\Core\Database;
+use XLite\Logic\ApplyAttributeValues\Generator as ApplyAttrValuesGenerator;
 
 /**
  * Product
@@ -22,12 +23,12 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      *
      * @var array
      */
-    protected $params = array('target', 'id', 'product_id', 'page', 'backURL');
+    protected $params = ['target', 'id', 'product_id', 'page', 'backURL'];
 
     /**
      * Chuck length
      */
-    const CHUNK_LENGTH = 100;
+    public const CHUNK_LENGTH = 100;
 
     // {{{ Abstract method implementations
 
@@ -36,7 +37,7 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      *
      * NOTE: this function is public since it's neede for widgets
      *
-     * @return boolean
+     * @return bool
      */
     public function isNew()
     {
@@ -70,9 +71,9 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      *
      * @return \XLite\View\Model\AModel|void
      */
-    public function getInventoryModelForm(array $params = array())
+    public function getInventoryModelForm(array $params = [])
     {
-        $class = '\XLite\View\Model\InventoryTracking';
+        $class = 'XLite\View\Model\InventoryTracking';
 
         return \XLite\Model\CachingFactory::getObject(
             __METHOD__ . $class . (empty($params) ? '' : md5(serialize($params))),
@@ -91,6 +92,16 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
         return $this->getProduct();
     }
 
+    protected function addBaseLocation()
+    {
+        parent::addBaseLocation();
+
+        $this->addLocationNode(
+            static::t('Products'),
+            $this->buildURL('product_list')
+        );
+    }
+
     // }}}
 
     // {{{ Pages
@@ -106,13 +117,7 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
         $list['info'] = static::t('Info');
 
         if (!$this->isNew()) {
-            $list['attributes'] = [
-                'title' => static::t('Attributes'),
-                'subTabsWidget' => '\XLite\View\Tabs\Attributes',
-                'subTabsWidgetParams' => [
-                    'product' => $this->getProduct()
-                ],
-            ];
+            $list['attributes'] = static::t('Attributes');
             $list['inventory']  = static::t('Inventory tracking');
         }
 
@@ -164,14 +169,14 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
     public function getProduct()
     {
         $result = $this->productCache
-            ?: \XLite\Core\Database::getRepo('\XLite\Model\Product')->find($this->getProductId());
+            ?: Database::getRepo('XLite\Model\Product')->find($this->getProductId());
 
-        if (null === $result) {
+        if ($result === null) {
             $result = new \XLite\Model\Product();
-            
+
             if (
-                \XLite\Core\Request::getInstance()->category_id > 1 && 
-                ($category = \XLite\Core\Database::getRepo('XLite\Model\Category')->find(\XLite\Core\Request::getInstance()->category_id))
+                \XLite\Core\Request::getInstance()->category_id > 1 &&
+                ($category = Database::getRepo('XLite\Model\Category')->find(\XLite\Core\Request::getInstance()->category_id))
             ) {
                 $result->addCategory($category);
             }
@@ -188,9 +193,9 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
     public function getCategories()
     {
         return $this->isNew()
-            ? array(
+            ? [
                 $this->getCategoryId(),
-            )
+            ]
             : $this->getProduct()->getCategories();
     }
 
@@ -203,7 +208,7 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
     {
         return $this->getProduct() && $this->getProduct()->isPersistent()
             ? $this->getProduct()->getName()
-            : static::t('Add product');
+            : static::t('New Product');
     }
 
     /**
@@ -246,8 +251,6 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      * The product can be set from the view classes
      *
      * @param \XLite\Model\Product $product Product
-     *
-     * @return void
      */
     public function setProduct(\XLite\Model\Product $product)
     {
@@ -267,7 +270,7 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
         $time = \XLite\Core\Converter::time();
 
-        if (null === $field) {
+        if ($field === null) {
             if (isset($value['arrivalDate'])) {
                 $value['arrivalDate'] = ((int) strtotime($value['arrivalDate']))
                     ?: mktime(0, 0, 0, date('m', $time), date('j', $time), date('Y', $time));
@@ -278,25 +281,21 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
             }
 
             if (isset($value['productClass'])) {
-                $value['productClass'] = \XLite\Core\Database::getRepo('\XLite\Model\ProductClass')
+                $value['productClass'] = Database::getRepo('XLite\Model\ProductClass')
                     ->find($value['productClass']);
             }
 
             if (isset($value['taxClass'])) {
-                $value['taxClass'] = \XLite\Core\Database::getRepo('\XLite\Model\TaxClass')->find($value['taxClass']);
+                $value['taxClass'] = Database::getRepo('XLite\Model\TaxClass')->find($value['taxClass']);
             }
-
-        } elseif ('arrivalDate' === $field) {
+        } elseif ($field === 'arrivalDate') {
             $value = ((int) strtotime($value)) ?: mktime(0, 0, 0, date('m', $time), date('j', $time), date('Y', $time));
-
-        } elseif ('sku' === $field) {
+        } elseif ($field === 'sku') {
             $value = null;
-
-        } elseif ('productClass' === $field) {
-            $value = \XLite\Core\Database::getRepo('\XLite\Model\ProductClass')->find($value);
-
-        } elseif ('taxClass' === $field) {
-            $value = \XLite\Core\Database::getRepo('\XLite\Model\TaxClass')->find($value);
+        } elseif ($field === 'productClass') {
+            $value = Database::getRepo('XLite\Model\ProductClass')->find($value);
+        } elseif ($field === 'taxClass') {
+            $value = Database::getRepo('XLite\Model\TaxClass')->find($value);
         }
 
         return $value;
@@ -322,18 +321,22 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
         if ($form->isValid()) {
             $dto->populateTo($product, $rawData[$this->formName]);
-            \XLite\Core\Database::getEM()->persist($product);
-            \XLite\Core\Database::getEM()->flush();
+
+            if ($product->getProductId()) {
+                Database::getEM()->getUnitOfWork()->scheduleForUpdate($product);
+            }
+            Database::getEM()->persist($product);
+            Database::getEM()->flush();
 
             $dto->afterPopulate($product, $rawData[$this->formName]);
             if (!$isPersistent) {
                 $dto->afterCreate($product, $rawData[$this->formName]);
-
+                TopMessage::addInfo('Product has been created');
             } else {
                 $dto->afterUpdate($product, $rawData[$this->formName]);
+                TopMessage::addInfo('Product has been updated');
             }
-            \XLite\Core\Database::getEM()->flush();
-
+            Database::getEM()->flush();
         } else {
             $this->saveFormModelTmpData($rawData[$this->formName]);
 
@@ -359,8 +362,6 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
     /**
      * doActionUpdate
-     *
-     * @return void
      */
     // protected function doActionUpdate()
     // {
@@ -381,22 +382,18 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
     /**
      * Do action clone
-     *
-     * @return void
      */
     protected function doActionClone()
     {
         if ($this->getProduct()) {
             $newProduct = $this->getProduct()->cloneEntity();
             $newProduct->updateQuickData();
-            $this->setReturnURL($this->buildURL('product', '', array('product_id' => $newProduct->getId())));
+            $this->setReturnURL($this->buildURL('product', '', ['product_id' => $newProduct->getId()]));
         }
     }
 
     /**
      * Update inventory
-     *
-     * @return void
      */
     protected function doActionUpdateInventory()
     {
@@ -411,9 +408,13 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
         if ($form->isValid()) {
             $dto->populateTo($this->getProduct());
-            \XLite\Core\Database::getEM()->flush();
+            Database::getEM()->flush();
         } else {
             \XLite\Core\Session::getInstance()->{$this->formModelDataSessionCellName} = $data[$this->formName];
+
+            foreach ($form->getErrors(true) as $error) {
+                TopMessage::addError($error->getMessage());
+            }
         }
 
         $params = ['page' => 'inventory'];
@@ -433,22 +434,25 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
     /**
      * Update attributes
-     *
-     * @return void
      */
     protected function doActionUpdateAttributes()
     {
-        $name           = \XLite\Core\Request::getInstance()->name;
-        $attributeValue = \XLite\Core\Request::getInstance()->attributeValue;
-        $delete         = \XLite\Core\Request::getInstance()->delete;
-        $newValue       = \XLite\Core\Request::getInstance()->newValue;
-        $saveGlobally   = \XLite\Core\Request::getInstance()->save_mode;
+        Database::getEM()->clear();
+        $request = \XLite\Core\Request::getInstance();
+        $name           = $request->name;
+        $attributeValue = $request->attributeValue;
+        $delete         = $request->delete;
+        $newValue       = $request->newValue;
+        $saveGlobally   = $request->save_mode;
+        $displayMode    = $request->displayMode;
 
         // Initialize non-filtered request data
-        $nonFilteredData = \XLite\Core\Request::getInstance()->getNonFilteredData();
+        $nonFilteredData = $request->getNonFilteredData();
 
-        $repo      = \XLite\Core\Database::getRepo('\XLite\Model\Attribute');
-        $repoGroup = \XLite\Core\Database::getRepo('\XLite\Model\AttributeGroup');
+        $repo      = Database::getRepo(\XLite\Model\Attribute::class);
+        $repoGroup = Database::getRepo(\XLite\Model\AttributeGroup::class);
+
+        $product = $this->getProduct();
 
         if ($saveGlobally) {
             $oldValues = $this->getAttributeValues();
@@ -462,20 +466,33 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
                 if (isset($attributeValue[$k])) {
                     unset($attributeValue[$k]);
                 }
+                /** @var \XLite\Model\Attribute $a */
                 $a = $repo->find($k);
                 if ($a) {
-                    $repo->delete($repo->find($k), false);
+                    $this->removeAttributeEntity($a);
                 }
             }
         }
 
+        $maxPosition = 0;
         if ($name) {
+            /** @var \XLite\Model\Attribute[] $attributes */
             $attributes = $repo->findByIds(array_keys($name));
 
             if ($attributes) {
                 foreach ($attributes as $a) {
-                    if ($name[$a->getId()]) {
-                        $a->setName($name[$a->getId()]);
+                    $id = $a->getId();
+                    if ($name[$id]) {
+                        $a->setName($name[$id]);
+                        $maxPosition = max($maxPosition, $a->getPosition($product));
+                    }
+                    if (isset($displayMode[$id])) {
+                        $prop = $a->getProperty($product);
+                        $prop->setDisplayMode($displayMode[$id]);
+
+                        if ($a->getProduct()) {
+                            $a->setDisplayMode($displayMode[$id]);
+                        }
                     }
                 }
             }
@@ -485,7 +502,6 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
             $attributes = $repo->findByIds(array_keys($attributeValue));
 
             if ($attributes) {
-
                 $attributeValueNonFiltered = !empty($nonFilteredData['attributeValue'])
                     ? $nonFilteredData['attributeValue']
                     : $attributeValue;
@@ -495,17 +511,13 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
                         $value = $this->isAttributeValueAllowsTags($a)
                             ? $this->purifyValue($attributeValueNonFiltered[$a->getId()])
                             : $attributeValue[$a->getId()];
-                        $a->setAttributeValue(
-                            $this->getProduct(),
-                            $value
-                        );
+                        $a->setAttributeValue($product, $value);
                     }
                 }
             }
         }
 
         if ($newValue) {
-
             $newValueNonFiltered = !empty($nonFilteredData['newValue'])
                 ? $nonFilteredData['newValue']
                 : $newValue;
@@ -520,37 +532,43 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
                     $a = new \XLite\Model\Attribute();
                     $a->setName($data['name']);
                     $a->setType($data['type']);
+                    $a->setPosition([
+                        'product' => $product,
+                        'position' => ++$maxPosition
+                    ]);
+                    if ($data['type'] === \XLite\Model\Attribute::TYPE_SELECT) {
+                        $a->setDisplayMode($data['displayMode'], true);
+                    }
+
                     if (0 < $data['listId']) {
                         $group = $repoGroup->find($data['listId']);
                         if ($group) {
                             $a->setAttributeGroup($group);
                             $a->setProductClass($group->getProductClass());
                         }
-
                     } elseif (
-                        -2 == $data['listId']
-                        && $this->getProduct()->getProductClass()
+                        $data['listId'] == -2
+                        && $product->getProductClass()
                     ) {
-                        $a->setProductClass($this->getProduct()->getProductClass());
-
-                    } elseif (-3 == $data['listId']) {
-                        $a->setProduct($this->getProduct());
-                        $this->getProduct()->addAttributes($a);
+                        $a->setProductClass($product->getProductClass());
+                    } elseif ($data['listId'] == -3) {
+                        $a->setProduct($product);
+                        $product->addAttributes($a);
                     }
 
-                    unset($data['name'], $data['type']);
+                    unset($data['name'], $data['type'], $data['displayMode']);
                     $repo->insert($a);
 
                     if ($this->isAttributeValueAllowsTags($a)) {
                         $data = $this->purifyValue($newValueNonFiltered[$k]);
                     }
 
-                    $a->setAttributeValue($this->getProduct(), $data);
+                    $a->setAttributeValue($product, $data);
                 }
             }
         }
 
-        $this->getProduct()->updateQuickData();
+        $product->updateQuickData();
 
         if ($saveGlobally) {
             $this->applyAttributeValuesChanges(
@@ -559,8 +577,20 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
             );
         }
 
-        \XLite\Core\Database::getEM()->flush();
-        \XLite\Core\TopMessage::addInfo('Attributes have been updated successfully');
+        Database::getEM()->flush();
+        if (!$saveGlobally) {
+            \XLite\Core\TopMessage::addInfo('Attributes have been updated successfully');
+        }
+    }
+
+    /**
+     * @param \XLite\Model\Attribute $attribute
+     */
+    protected function removeAttributeEntity(\XLite\Model\Attribute $attribute)
+    {
+        $repo = Database::getRepo(\XLite\Model\Attribute::class);
+
+        $repo->delete($attribute, false);
     }
 
     /**
@@ -568,7 +598,7 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      *
      * @param \XLite\Model\Attribute $attr Attribute
      *
-     * @return boolean
+     * @return bool
      */
     protected function isAttributeValueAllowsTags(\XLite\Model\Attribute $attr)
     {
@@ -591,12 +621,10 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
 
     /**
      * Update attributes properties
-     *
-     * @return void
      */
     protected function doActionUpdateAttributesProperties()
     {
-        $list = new \XLite\View\ItemsList\AttributeProperty;
+        $list = new \XLite\View\ItemsList\AttributeProperty();
         $list->processQuick();
     }
 
@@ -607,11 +635,11 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      */
     protected function getAttributeValues()
     {
-        $result = array();
+        $result = [];
 
         foreach (\XLite\Model\Attribute::getTypes() as $type => $name) {
             $class = \XLite\Model\Attribute::getAttributeValueClass($type);
-            $result[$type] = \XLite\Core\Database::getRepo($class)->findCommonValues($this->getProduct());
+            $result[$type] = Database::getRepo($class)->findCommonValues($this->getProduct());
         }
 
         return $result;
@@ -622,61 +650,67 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
      *
      * @param array $oldValues Old values
      * @param array $newValues New values
-     *
-     * @return void
      */
     protected function applyAttributeValuesChanges(array $oldValues, array $newValues)
     {
-        $diff = array();
+        $diff = [];
         foreach (\XLite\Model\Attribute::getTypes() as $type => $name) {
             $class = \XLite\Model\Attribute::getAttributeValueClass($type);
             $diff += $class::getDiff($oldValues[$type], $newValues[$type]);
         }
 
         if ($diff) {
-            $i = 0;
-            do {
-                $processed = 0;
-                foreach (\XLite\Core\Database::getRepo('XLite\Model\Product')->findFrame($i, static::CHUNK_LENGTH) as $product) {
-                    foreach ($diff as $attributeId => $changes) {
-                        $attribute = \XLite\Core\Database::getRepo('XLite\Model\Attribute')->find($attributeId);
-                        $attribute->applyChanges($product, $changes);
-                    }
-
-                    $processed++;
-                }
-
-                if (0 < $processed) {
-                    \XLite\Core\Database::getEM()->flush();
-                    \XLite\Core\Database::getEM()->clear();
-                }
-                $i += $processed;
-
-            } while (0 < $processed);
+            ApplyAttrValuesGenerator::run(['attrsDiff' => $diff]);
         }
     }
 
     /**
-     * Update product class
+     * Check - applying attribute values process is not-finished or not
      *
-     * @return void
+     * @return bool
+     */
+    public function isApplyingAttrValuesNotFinished()
+    {
+        $eventName = ApplyAttrValuesGenerator::getEventName();
+        $state = Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($eventName);
+
+        return $state
+            && in_array(
+                $state['state'],
+                [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS],
+                true
+            )
+            && !Database::getRepo(\XLite\Model\TmpVar::class)
+                        ->getVar(ApplyAttrValuesGenerator::getCancelFlagVarName());
+    }
+
+    /**
+     * Cancel applying attribute values globally
+     */
+    protected function doActionCancelApplyingAttrValues()
+    {
+        ApplyAttrValuesGenerator::cancel();
+        \XLite\Core\TopMessage::addWarning('The global attributes changing process has been canceled.');
+    }
+
+    /**
+     * Update product class
      */
     protected function doActionUpdateProductClass()
     {
         $updateClass = false;
 
-        if (-1 == \XLite\Core\Request::getInstance()->productClass) {
+        if (\XLite\Core\Request::getInstance()->productClass == -1) {
             $name = trim(\XLite\Core\Request::getInstance()->newProductClass);
 
             if ($name) {
-                $productClass = new \XLite\Model\ProductClass;
+                $productClass = new \XLite\Model\ProductClass();
                 $productClass->setName($name);
-                \XLite\Core\Database::getRepo('\XLite\Model\ProductClass')->insert($productClass);
+                Database::getRepo('XLite\Model\ProductClass')->insert($productClass);
                 $updateClass = true;
             }
-
         } else {
-            $productClass = \XLite\Core\Database::getRepo('\XLite\Model\ProductClass')->find(
+            $productClass = Database::getRepo('XLite\Model\ProductClass')->find(
                 \XLite\Core\Request::getInstance()->productClass
             );
             $updateClass = true;
@@ -692,23 +726,36 @@ class Product extends \XLite\Controller\Admin\ACL\Catalog
             $this->getProduct()->setProductClass($productClass);
 
             if ($productClassChanged) {
-                \XLite\Core\Database::getRepo('\XLite\Model\Attribute')->generateAttributeValues(
+                Database::getRepo('XLite\Model\Attribute')->generateAttributeValues(
                     $this->getProduct(),
                     true
                 );
-                \XLite\Core\Database::getRepo('\XLite\Model\AttributeProperty')->generateClassAttributeProperties(
+                Database::getRepo('XLite\Model\AttributeProperty')->generateClassAttributeProperties(
                     $this->getProduct(),
                     $productClass
                 );
             }
 
-            \XLite\Core\Database::getEM()->flush();
+            Database::getEM()->flush();
             \XLite\Core\TopMessage::addInfo('Product class have been updated successfully');
-
         } else {
             \XLite\Core\TopMessage::addWarning('Product class name is empty');
         }
     }
 
+    /**
+     * Preprocessor for no-action run
+     */
+    protected function doNoAction()
+    {
+        $request = \XLite\Core\Request::getInstance();
+
+        if ($request->apply_attr_values_completed) {
+            \XLite\Core\TopMessage::addInfo('The global attributes have been successfully changed.');
+        } elseif ($request->apply_attr_values_failed) {
+            \XLite\Core\TopMessage::addError('An error occurred during the global attributes changing.');
+        }
+    }
+
     // }}}
 }
