@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,7 +17,7 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      *
      * @var array
      */
-    protected $params = array('target', 'page');
+    protected $params = ['target', 'page'];
 
     /**
      * Return the current page title (for the content area)
@@ -27,10 +26,10 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        $page = $this->getPage();
+        $page  = $this->getPage();
         $pages = $this->getPages();
 
-        return !empty($pages[$page]) ? $pages[$page] : static::t('Promotions');
+        return $pages[$page] ?? static::t('Discounts');
     }
 
     /**
@@ -52,23 +51,7 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      */
     public static function getPagesStatic()
     {
-        $list = array();
-
-        if (\XLite::isFreeLicense()
-            && \XLite\Core\Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
-        ) {
-            $list['volume_discounts'] = array(
-                'name' => static::t('Volume discounts'),
-                'tpl' => 'promotions/volume_discounts.twig',
-            );
-
-            $list['coupons'] = array(
-                'name' => static::t('Coupons'),
-                'tpl' => 'promotions/coupons.twig',
-            );
-        }
-
-        return $list;
+        return [];
     }
 
     /**
@@ -78,7 +61,7 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      */
     public function getPages()
     {
-        $list = array();
+        $list = [];
 
         foreach (static::getPagesStatic() as $key => $page) {
             if ($this->checkPageACL($page)) {
@@ -94,13 +77,14 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      *
      * @param array $page Page data
      *
-     * @return boolean
+     * @return bool
      */
     protected function checkPageACL($page)
     {
         $result = true;
 
-        if (empty($page['public_access'])
+        if (
+            empty($page['public_access'])
             && !\XLite\Core\Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
         ) {
             $result = !empty($page['permission'])
@@ -117,7 +101,7 @@ class Promotions extends \XLite\Controller\Admin\AAdmin
      */
     protected function getPageTemplates()
     {
-        $list = array();
+        $list = [];
 
         foreach (static::getPagesStatic() as $key => $page) {
             $list[$key] = $page['tpl'];
