@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -43,7 +42,7 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
         $result = parent::checkACL();
 
         if (!$result) {
-            foreach (static::getSearchCodePermissions() as $code => $permissions) {
+            foreach (static::getSearchCodePermissions() as $permissions) {
                 if (static::isSearchPermissionAllowed($permissions)) {
                     $result = true;
                     break;
@@ -61,17 +60,17 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
      */
     protected static function getSearchCodePermissions()
     {
-        return array(
-            'product' => array(
-                'manage catalog',
-            ),
-            'order' => array(
-                'manage orders',
-            ),
-            'profile' => array(
-                'manage users',
-            ),
-        );
+        return [
+            'product' => [
+                'ROLE_MANAGE_CATALOG',
+            ],
+            'order' => [
+                'ROLE_MANAGE_ORDERS',
+            ],
+            'profile' => [
+                'ROLE_MANAGE_USERS',
+            ],
+        ];
     }
 
     /**
@@ -96,8 +95,8 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * Search 
-     * 
+     * Search
+     *
      * @return void
      */
     protected function doActionSearch()
@@ -108,8 +107,8 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
     }
 
     /**
-     * Define redirect URL 
-     * 
+     * Define redirect URL
+     *
      * @return string
      */
     protected function defineRedirectURL()
@@ -121,10 +120,10 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
                 $url = $this->buildURL(
                     'product_list',
                     null,
-                    array(
+                    [
                         'substring'   => $request->substring,
                         'fast_search' => true,
-                    )
+                    ]
                 );
                 break;
 
@@ -132,10 +131,10 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
                 $url = $this->buildURL(
                     'order_list',
                     null,
-                    array(
+                    [
                         'substring'   => $request->substring,
                         'fast_search' => true,
-                    )
+                    ]
                 );
                 break;
 
@@ -143,10 +142,10 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
                 $url = $this->buildURL(
                     'profile_list',
                     null,
-                    array(
+                    [
                         'pattern'     => $request->substring,
                         'fast_search' => true,
-                    )
+                    ]
                 );
                 break;
 
@@ -171,7 +170,6 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
         $request->substring = trim($request->substring);
 
         if (!empty($request->substring)) {
-
             $data = explode(':', $request->substring);
 
             $data[0] = trim($data[0]);
@@ -194,10 +192,10 @@ class SearchRouter extends \XLite\Controller\Admin\AAdmin
      */
     protected function getAllowedCodes()
     {
-        return array(
+        return [
             'p' => 'product',
             'o' => 'order',
             'u' => 'profile',
-        );
+        ];
     }
 }
