@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -17,21 +16,23 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     /**
      * Values to use for $page identification
      */
-    const GENERAL_PAGE      = 'General';
-    const COMPANY_PAGE      = 'Company';
-    const EMAIL_PAGE        = 'Email';
-    const ENVIRONMENT_PAGE  = 'Environment';
-    const PERFORMANCE_PAGE  = 'Performance';
-    const UNITS_PAGE        = 'Units';
-    const LAYOUT_PAGE       = 'Layout';
-    const CLEAN_URL         = 'CleanURL';
+    public const GENERAL_PAGE     = 'General';
+    public const COMPANY_PAGE     = 'Company';
+    public const EMAIL_PAGE       = 'Email';
+    public const ENVIRONMENT_PAGE = 'Environment';
+    public const PERFORMANCE_PAGE = 'Performance';
+    public const UNITS_PAGE       = 'Units';
+    public const LAYOUT_PAGE      = 'Layout';
+    public const CLEAN_URL        = 'CleanURL';
+    public const SEO_HOMEPAGE     = 'SeoHomepage';
+    public const API_PAGE         = 'API';
 
     /**
      * Params
      *
      * @var array
      */
-    protected $params = array('target', 'page');
+    protected $params = ['target', 'page'];
 
     /**
      * Page
@@ -40,14 +41,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public $page = self::GENERAL_PAGE;
 
-    /**
-     * _waiting_list
-     * @todo: rename
-     *
-     * @var mixed
-     */
-    public $_waiting_list;
-
     /**
      * Curl response temp variable
      *
@@ -74,7 +67,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         $list = $this->getPages();
         if (isset($list[$this->page])) {
             $classes[] = 'settings-'
-                . str_replace('_', '-', \XLite\Core\Converter::convertFromCamelCase(preg_replace('/\W/', '', $list[$this->page])));
+                . \Includes\Utils\Converter::convertFromCamelCase(preg_replace('/\W/', '', $list[$this->page]), '-');
         }
 
         return $classes;
@@ -89,9 +82,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     {
         $list = $this->getPages();
 
-        return isset($list[$this->page])
-            ? $list[$this->page]
-            : '';
+        return $list[$this->page] ?? '';
     }
 
     /**
@@ -126,12 +117,16 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public function getPages()
     {
-        $list = parent::getPages();
+        $list                           = parent::getPages();
         $list[static::GENERAL_PAGE]     = static::t('Cart & checkout');
         $list[static::COMPANY_PAGE]     = static::t('Store info');
         $list[static::EMAIL_PAGE]       = static::t('Email settings');
-        $list[static::ENVIRONMENT_PAGE] = static::t('Environment');
         $list[static::CLEAN_URL]        = static::t('SEO settings');
+        $list[static::SEO_HOMEPAGE]     = static::t('Homepage');
+        $list[static::API_PAGE]         = static::t('API Settings');
+        if (!\XLite::isTrial()) {
+            $list[static::ENVIRONMENT_PAGE] = static::t('Environment');
+        }
 
         return $list;
     }
@@ -150,7 +145,8 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         }
 
         $list[static::ENVIRONMENT_PAGE] = 'settings/summary/body.twig';
-        $list[static::CLEAN_URL] = 'settings/clean_url/tabs.twig';
+        $list[static::CLEAN_URL]        = 'settings/clean_url/tabs.twig';
+        $list[static::SEO_HOMEPAGE]     = 'settings/clean_url/tabs.twig';
 
         return $list;
     }
@@ -164,16 +160,16 @@ class Settings extends \XLite\Controller\Admin\AAdmin
 
         if (\XLite\Core\Request::getInstance()->page == 'CleanURL') {
             $result = [
-                'companyName'               => \XLite\Core\Config::getInstance()->Company->company_name,
-                'companyNameLabel'          => static::t('Company name'),
-                'delimiter'                 => " > ",
-                'productTitle'              => static::t('Product'),
-                'categoryTitle'             => static::t('Category'),
-                'staticTitle'               => static::t('Page'),
-                'categoryNameLabel'         => static::t('Category name'),
-                'parentCategoryNameLabel'   => static::t('Parent category name'),
-                'productNameLabel'          => static::t('Product name'),
-                'staticPageNameLabel'       => static::t('Page name'),
+                'companyName'             => \XLite\Core\Config::getInstance()->Company->company_name,
+                'companyNameLabel'        => static::t('Company name'),
+                'delimiter'               => " > ",
+                'productTitle'            => static::t('Product'),
+                'categoryTitle'           => static::t('Category'),
+                'staticTitle'             => static::t('Page'),
+                'categoryNameLabel'       => static::t('Category name'),
+                'parentCategoryNameLabel' => static::t('Parent category name'),
+                'productNameLabel'        => static::t('Product name'),
+                'staticPageNameLabel'     => static::t('Page name'),
             ];
         }
 
@@ -187,11 +183,22 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     /**
      * Get options for current tab (category)
      *
+     * @param bool $getAllOptions
+     *
      * @return \XLite\Model\Config[]
      */
-    public function getOptions()
+    public function getOptions($getAllOptions = false)
     {
-        return \XLite\Core\Database::getRepo('XLite\Model\Config')->findByCategoryAndVisible($this->page);
+        $result = \XLite\Core\Database::getRepo('XLite\Model\Config')->findByCategoryAndVisible($this->page);
+        if ($getAllOptions || $this->page != static::CLEAN_URL) {
+            return $result;
+        }
+
+        $not_general_opts = ['home_page_title_and_meta', 'page_404', 'regular_text_404', 'show_email_404', 'about_404_page', 'result_404_page_preview'];
+
+        return array_filter($result, static function ($opt) use ($not_general_opts) {
+            return !in_array($opt->getName(), $not_general_opts);
+        });
     }
 
     /**
@@ -208,34 +215,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
 
     // {{{ Additional methods
 
-    /**
-     * Defines if the clean URL is enabled in the store
-     *
-     * @return boolean
-     */
-    public function isCleanURLEnabled()
-    {
-        return LC_USE_CLEAN_URLS;
-    }
-
-    /**
-     * Defines if the clean urls can be enabled on the current server environment
-     *
-     * @return boolean
-     */
-    public function canEnableCleanURL()
-    {
-        $urlToCheck = \XLite::getInstance()->getShopURL() . \XLite::CLEAN_URL_CHECK_QUERY;
-        $request = new \XLite\Core\HTTP\Request($urlToCheck);
-        $request->setAdditionalOption(\CURLOPT_SSL_VERIFYPEER, false);
-        $request->setAdditionalOption(\CURLOPT_SSL_VERIFYHOST, false);
-        $this->curlResponse = $request->sendRequest();
-
-        return !$this->isCleanURLEnabled()
-            && $this->curlResponse
-            && in_array($this->curlResponse->code, array(200, 301, 302));
-    }
-
     /**
      * Defines the article URL of setting up the clean URL functionality
      *
@@ -243,7 +222,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public function getCleanURLArticleURL()
     {
-        return static::t('https://kb.x-cart.com/seo_and_promotion/setting_up_seo-friendly_urls.html');
+        return static::t('https://support.x-cart.com/en/articles/4889985-seo-friendly-urls-setup');
     }
 
     /**
@@ -253,8 +232,9 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public function getInstallationDirectoryHelpLink()
     {
-        return static::t('https://kb.x-cart.com/general_setup/moving_x-cart_to_another_location.html');
+        return static::t('https://support.x-cart.com/en/articles/5214117-moving-x-cart-to-another-location');
     }
+
     /**
      * Check for the GDLib extension
      *
@@ -274,7 +254,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     {
         $res = (string) @ini_get('open_basedir');
 
-        return ('' !== $res);
+        return ($res !== '');
     }
 
     /**
@@ -344,23 +324,31 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public function get($name)
     {
-        switch($name) {
-
+        switch ($name) {
             case 'phpversion':
                 $return = PHP_VERSION;
                 break;
 
             case 'os_type':
-                list($osType) = explode(' ', PHP_OS);
+                [$osType] = explode(' ', PHP_OS);
                 $return = $osType;
                 break;
 
             case 'mysql_server':
-                $return = \Includes\Utils\Database::getDbVersion();
+                $return = \XLite\Core\Database::getEM()->getConnection()->executeQuery('SELECT VERSION()')->fetchOne();
                 break;
 
             case 'innodb_support':
-                $return = \Includes\Utils\Database::isInnoDBSupported();
+                $return = false;
+
+                $engines = \XLite\Core\Database::getEM()->getConnection()->executeQuery('SHOW ENGINES')->fetchAllAssociative();
+                foreach ($engines ?? [] as $row) {
+                    if (strcasecmp('InnoDB', $row['Engine']) === 0) {
+                        $return = true;
+                        break;
+                    }
+                }
+
                 break;
 
             case 'root_folder':
@@ -368,9 +356,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
                 break;
 
             case 'web_server':
-                $return = isset($_SERVER['SERVER_SOFTWARE'])
-                    ? $_SERVER['SERVER_SOFTWARE']
-                    : '';
+                $return = $_SERVER['SERVER_SOFTWARE'] ?? '';
                 break;
 
             case 'xml_parser':
@@ -433,7 +419,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
 
         if (!$this->is('GDLibLoaded')) {
             $return = '';
-
         } else {
             ob_start();
 
@@ -454,7 +439,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
                 $gdVersion = $isMatched
                     ? $m[1]
                     : 'unknown';
-
             }
 
             $return = 'found (' . $gdVersion . ')';
@@ -480,7 +464,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
             }
 
             $return = $libcurlVersion;
-
         } else {
             $return = false;
         }
@@ -491,8 +474,8 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     /**
      * Try permissions
      *
-     * @param  string   $dir      Dir to create
-     * @param  string   $modeStr  Permissions string
+     * @param string $dir     Dir to create
+     * @param string $modeStr Permissions string
      *
      * @return boolean
      */
@@ -513,7 +496,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
      */
     public static function defineFreeFormIdActions()
     {
-        return array_merge(parent::defineFreeFormIdActions(), array('phpinfo', 'switch_clean_url'));
+        return array_merge(parent::defineFreeFormIdActions(), ['phpinfo']);
     }
 
     /**
@@ -535,6 +518,10 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     public function doActionUpdate()
     {
         $this->getModelForm()->performAction('update');
+
+        if ($this->page === static::CLEAN_URL) {
+            $this->saveLabels();
+        }
     }
 
     /**
@@ -546,7 +533,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
     {
         $message = 'Clean_urls_error_message';
 
-        return static::t($message, array('url' => $this->curlResponse->uri));
+        return static::t($message, ['url' => $this->curlResponse->uri]);
     }
 
     /**
@@ -569,82 +556,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
                 break;
         }
 
-        return static::t('Error code explanation:') . ' ' . $code . ' '. $explanation;
-    }
-
-    /**
-     * Actions to enable the clean URL functionality
-     *
-     * @return void
-     */
-    public function doActionSwitchCleanUrl()
-    {
-        $oldValue = (bool) \XLite\Core\Config::getInstance()->CleanURL->clean_url_flag;
-        $ajaxResponse = array(
-            'Success'       => true,
-            'Error'         => '',
-            'NewState'      => !(bool) $oldValue
-        );
-
-        if ($oldValue === false && !$this->canEnableCleanURL()) {
-            $ajaxResponse['Success'] = false;
-            $ajaxResponse['Error'] = array(
-                'msg'   => $this->getErrorMessageHeader(),
-                'body'  => $this->getErrorMessageCodeExplanation($this->curlResponse->code)
-            );
-
-        } else {
-            \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-                array(
-                    'category' => 'CleanURL',
-                    'name'     => 'clean_url_flag',
-                    'value'    => !(bool) $oldValue
-                )
-            );
-        }
-
-        $this->printAJAX($ajaxResponse);
-        $this->silent = true;
-        $this->setSuppressOutput(true);
-    }
-
-    /**
-     * Actions to enable the clean URL functionality
-     *
-     * @return void
-     */
-    public function doActionEnableCleanUrl()
-    {
-        if ($this->canEnableCleanURL()) {
-            /** @var \XLite\Model\Config $cleanURLFlag */
-            $cleanURLFlag = \XLite\Core\Database::getRepo('XLite\Model\Config')->findOneBy(
-                array(
-                    'name'      => 'clean_url_flag',
-                    'category'  => 'CleanURL'
-                )
-            );
-
-            \XLite\Core\Database::getRepo('XLite\Model\Config')->update(
-                $cleanURLFlag,
-                array(
-                    'value' => true,
-                )
-            );
-
-            \XLite\Core\TopMessage::addInfo(static::t('Clean URLs are enabled'));
-        }
-
-        $this->doRedirect();
-    }
-
-    /**
-     * isWin
-     *
-     * @return boolean
-     */
-    public function isWin()
-    {
-        return (LC_OS_CODE === 'win');
+        return static::t('Error code explanation:') . ' ' . $code . ' ' . $explanation;
     }
 
     /**
@@ -659,114 +571,53 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         return \XLite\Core\Database::getRepo('XLite\Model\State')->find($stateId);
     }
 
-    // }}}
-
-    // {{{ Requirements
-
-    public function getCriticalRequirements()
+    protected function getLabelsToUpdate()
     {
-        $result = [];
-        foreach ($this->getRequirements() as $name => $requirement) {
-            if ($requirement['level'] === \Includes\Requirements::LEVEL_CRITICAL) {
-                $result[$name] = $requirement;
+        return [
+            'default_site_title'            => 'default-site-title',
+            'default_site_meta_description' => 'default-meta-description',
+            'default_site_meta_keywords'    => 'default-meta-keywords',
+        ];
+    }
+
+    /**
+     * Update lang labels, create them if necessary
+     */
+    protected function saveLabels()
+    {
+        $labelsFromDb = \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->findBy(['name' => $this->getLabelsToUpdate()]) ?: [];
+
+        $list            = [];
+        $nonFilteredData = \XLite\Core\Request::getInstance()->getNonFilteredData();
+
+        foreach ($this->getLabelsToUpdate() as $postName => $labelName) {
+            if (!isset($nonFilteredData[$postName])) {
+                continue;
             }
-        }
 
-        return $result;
-    }
-
-    public function getNonCriticalRequirements()
-    {
-        $result = [];
-        foreach ($this->getRequirements() as $name => $requirement) {
-            if ($requirement['level'] !== \Includes\Requirements::LEVEL_CRITICAL) {
-                $result[$name] = $requirement;
+            $matchedLabelEntity = null;
+            foreach ($labelsFromDb as $dbLabel) {
+                if ($dbLabel->getName() === $labelName) {
+                    $matchedLabelEntity = $dbLabel;
+                    $matchedLabelEntity->getLabelTranslation()->setLabel($nonFilteredData[$postName]);
+                    break;
+                }
             }
+
+            if (!$matchedLabelEntity) {
+                // the label was deleted in DB, so create the new one
+                $matchedLabelEntity = new \XLite\Model\LanguageLabel();
+                $matchedLabelEntity->setName($labelName);
+                \XLite\Core\Database::getEM()->persist($matchedLabelEntity);
+            }
+
+            $list[] = $matchedLabelEntity;
         }
 
-        return $result;
-    }
-
-    /**
-     * @return array
-     */
-    protected function getRequirements()
-    {
-        if ($this->requirements === null) {
-            $requirements = new \Includes\Requirements();
-
-            $this->requirements = $this->skipCheck()
-                ? $this->getSkippedRequirements($requirements)
-                : $this->getCheckedRequirements($requirements);
+        if ($list) {
+            \XLite\Core\Database::getRepo('\XLite\Model\LanguageLabel')->updateInBatch($list);
+            \XLite\Core\Translation::getInstance()->reset();
         }
-
-        return $this->requirements;
-    }
-
-    /**
-     * @return bool
-     */
-    protected function skipCheck()
-    {
-        return \XLite\Core\Request::getInstance()->doNotSkipCheck
-            ? false
-            : true;
-    }
-
-    /**
-     * @param \Includes\Requirements $requirements
-     *
-     * @return array
-     */
-    protected function getSkippedRequirements(\Includes\Requirements $requirements)
-    {
-        $result = [];
-
-        foreach ($requirements->getUnchecked() as $name => $requirement) {
-            $requirement['status'] = true;
-            $requirement['title'] = static::t($requirement['title']);
-            $requirement['skipped'] = true;
-
-            $requirement['error_description'] = '';
-
-            $result[$name] = $requirement;
-        }
-
-        return $result;
-    }
-
-    /**
-     * @param \Includes\Requirements $requirements
-     *
-     * @return array
-     */
-    protected function getCheckedRequirements(\Includes\Requirements $requirements)
-    {
-        $result = [];
-
-        foreach ($requirements->getResult() as $name => $requirement) {
-            $requirement['status'] = $requirement['state'] === \Includes\Requirements::STATE_SUCCESS;
-            $requirement['title'] = static::t($requirement['title']);
-            $requirement['skipped'] = false;
-
-            $requirement['error_description'] = isset($requirement['description'])
-                ? $this->getRequirementTranslation($name . '.' . $requirement['description'], $requirement)
-                : '';
-
-            $requirement['description'] = $this->getRequirementTranslation($name . '.label_message', $requirement);
-            $requirement['kb_description'] = $this->getRequirementTranslation($name . '.kb_message', $requirement);
-
-            $result[$name] = $requirement;
-        }
-
-        return $result;
-    }
-
-    protected function getRequirementTranslation($name, $requirement)
-    {
-        $value = static::t($name, array_filter($requirement['data'], 'is_scalar'));
-
-        return $name === $value ? '' : $value;
     }
 
     // }}}
