@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,7 +19,7 @@ class ShippingMethodSelection extends \XLite\Controller\Admin\AAdmin
      */
     public function getTitle()
     {
-        return static::t('What type of shipping rates would you like to use?');
+        return static::t('Carriers, Shipping and Rates');
     }
 
     /**
