@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,9 +21,9 @@ class ShippingRates extends \XLite\Controller\Admin\AAdmin
     {
         $method = $this->getModelForm()->getModelObject();
 
-        return $method
+        return $method && $method->getMethodId()
             ? $method->getName()
-            : static::t('Shipping rates');
+            : static::t('Add New Shipping Method');
     }
 
     /**
@@ -49,19 +48,11 @@ class ShippingRates extends \XLite\Controller\Admin\AAdmin
         $itemsList = new \XLite\View\ItemsList\Model\Shipping\Markups();
         $itemsList->processQuick();
 
+        $this->setHardRedirect(true);
         $this->setReturnURL(
-            $this->buildURL(
-                'shipping_rates',
-                '',
-                array(
-                    'widget'       => 'XLite\View\Shipping\EditMethod',
-                    'methodId'     => $this->getModelForm()->getModelObject()->getMethodId(),
-                    'shippingZone' => \XLite\Core\Request::getInstance()->shippingZone,
-                )
-            )
+            $this->buildURL('shipping_methods')
         );
 
-        $this->setInternalRedirect();
         \XLite\Core\Event::updateShippingMethods();
     }
 }
