@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,7 +17,7 @@ class TaxClasses extends \XLite\Controller\Admin\ACL\Catalog
      *
      * @return boolean
      */
-    static public function isEnabled()
+    public static function isEnabled()
     {
         return true;
     }
@@ -33,6 +32,17 @@ class TaxClasses extends \XLite\Controller\Admin\ACL\Catalog
         return static::t('Taxes');
     }
 
+    /**
+     * Update tax rate
+     *
+     * @return void
+     */
+    protected function doActionUpdate()
+    {
+        $list = new \XLite\View\ItemsList\Model\TaxClass();
+        $list->processQuick();
+    }
+
     /**
      * Export action
      *
@@ -45,11 +55,11 @@ class TaxClasses extends \XLite\Controller\Admin\ACL\Catalog
         $value = !\XLite\Core\Config::getInstance()->XC->TaxJar->taxcalculation;
 
         \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-            array(
+            [
                 'category' => 'XC\\TaxJar',
                 'name'     => 'taxcalculation',
                 'value'    => $value,
-            )
+            ]
         );
 
         \XLite\Core\TopMessage::addInfo(
