@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\Controller\Customer;
 
-use Doctrine\ORM\EntityManager;
+use XLite\Core\Exception\ClosedStorefrontException;
 
 /**
  * Abstract controller for Customer interface
@@ -51,7 +50,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     public function getLocationPath()
     {
-        if (null === $this->locationPath) {
+        if ($this->locationPath === null) {
             $this->defineLocationPath();
         }
 
@@ -65,7 +64,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     public function isCheckoutLayout()
     {
-        return in_array($this->getTarget(), array('checkout', 'checkoutPayment'), true);
+        return in_array($this->getTarget(), ['checkout', 'checkoutPayment'], true);
     }
 
     /**
@@ -95,7 +94,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function defineLocationPath()
     {
-        $this->locationPath = array();
+        $this->locationPath = [];
 
         // Ability to add part to the line
         $this->addBaseLocation();
@@ -141,7 +140,6 @@ abstract class ACustomer extends \XLite\Controller\AController
     public function shouldRenderDesktopNavbar()
     {
         return true;
-//        return $this->isAJAX() || \XLite\Core\Request::isTablet() || !\XLite\Core\Request::isMobileDevice();
     }
 
     /**
@@ -153,7 +151,6 @@ abstract class ACustomer extends \XLite\Controller\AController
     public function shouldRenderMobileNavbar()
     {
         return true;
-//        return $this->isAJAX() || \XLite\Core\Request::isMobileDevice();
     }
 
     /**
@@ -213,7 +210,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     public function getCart($doCalculate = null)
     {
-        return \XLite\Model\Cart::getInstance(null !== $doCalculate ? $doCalculate : $this->markCartCalculate());
+        return \XLite\Model\Cart::getInstance($doCalculate ?? $this->markCartCalculate());
     }
 
     /**
@@ -224,44 +221,23 @@ abstract class ACustomer extends \XLite\Controller\AController
     public function getCanonicalURL()
     {
         $params = $this->getAllParams();
-        $target = isset($params['target']) ? $params['target'] : '';
+        $target = $params['target'] ?? '';
         unset($params['target']);
         // Product pages do not count the category identificator for the canonical URL
-        if ('product' === $target) {
+        if ($target === 'product') {
             unset($params['category_id']);
         }
 
-        // Add pageId if it's presented in the current request params for SEO purposes (see BUG-3118)
-        // And remove it again because (yes, i know) SEO purposes
-//        $pageId = intval(\XLite\Core\Request::getInstance()->{\XLite\View\Pager\APager::PARAM_PAGE_ID});
-//
-//        if (1 < $pageId) {
-//            $params[\XLite\View\Pager\APager::PARAM_PAGE_ID] = $pageId;
-//        }
-
         $method = \XLite\Core\Config::getInstance()->Security->customer_security
             ? 'getSecureShopURL'
             : 'getShopURL';
 
-        if (isset($_SERVER)
-            && isset($_SERVER['QUERY_STRING'])
-            && '' === $_SERVER['QUERY_STRING']
-            && isset($_SERVER['SCRIPT_URL'])
-            && (
-                '' === $_SERVER['SCRIPT_URL']
-                || false === strpos($_SERVER['SCRIPT_URL'], '.php')
-            )
-        ) {
-            $canonicalURL = '';
-
-        } elseif ('main' === $target) {
-            $canonicalURL = $this->$method();
-
-        } elseif ('product' === $target && LC_USE_CLEAN_URLS) {
+        if ($target === 'main') {
+            $canonicalURL = $this->buildFullURL();
+        } elseif (LC_USE_CLEAN_URLS && $target === 'product') {
             $canonicalURL = $this->$method(
                 \XLite\Core\Database::getRepo('XLite\Model\CleanURL')->buildURLProductCanonical($params)
             );
-
         } else {
             $canonicalURL = $this->$method(
                 \XLite\Core\Converter::buildURL($target, '', $params, null, true)
@@ -291,9 +267,9 @@ abstract class ACustomer extends \XLite\Controller\AController
     public function getAlternateLangUrls()
     {
         $request = \XLite\Core\Request::getInstance();
-        $result = [];
+        $result  = [];
 
-        list($target, $params) = \XLite\Core\Converter::parseCleanUrl($request->url, $request->last, $request->rest, $request->ext);
+        [$target, $params] = \XLite\Core\Converter::parseCleanUrl($request->url, $request->last, $request->rest, $request->ext);
 
         $url = \XLite\Core\Database::getRepo('XLite\Model\CleanURL')->buildURL($target, $params);
         $url = strtok($url, '?');
@@ -302,12 +278,10 @@ abstract class ACustomer extends \XLite\Controller\AController
             $langUrl = $language->getCode() . '/' . $url;
 
             $result[\XLite\Core\Converter::langToLocale($language->getCode())] = \Includes\Utils\URLManager::getShopURL($langUrl);
-
         }
 
         $result['x-default'] = \Includes\Utils\URLManager::getShopURL($url);
 
-
         return $result;
     }
 
@@ -330,7 +304,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function getCartFingerprintExclude()
     {
-        $result = array();
+        $result = [];
 
         if (!$this->markCartCalculate()) {
             $result[] = 'shippingMethodsHash';
@@ -348,12 +322,12 @@ abstract class ACustomer extends \XLite\Controller\AController
      *
      * @return string
      */
-    public function getURL(array $params = array())
+    public function getURL(array $params = [])
     {
         $params = array_merge($this->getAllParams(), $params);
-        $target = isset($params['target']) ? $params['target'] : '';
+        $target = $params['target'] ?? '';
 
-        if (\XLite::TARGET_DEFAULT === $target) {
+        if ($target === \XLite::TARGET_DEFAULT) {
             $target = '';
             unset($params['target']);
         } else {
@@ -373,9 +347,9 @@ abstract class ACustomer extends \XLite\Controller\AController
      *
      * @return string
      */
-    public function getShopURL($url = '', $secure = null, array $params = array())
+    public function getShopURL($url = '', $secure = null, array $params = [])
     {
-        if (null === $secure && $this->isFullCustomerSecurity()) {
+        if ($secure === null && $this->isFullCustomerSecurity()) {
             $secure = true;
         }
 
@@ -416,16 +390,16 @@ abstract class ACustomer extends \XLite\Controller\AController
     /**
      * Send headers
      *
-     * @param  array $additional Additional headers OPTIONAL
+     * @param array $additional Additional headers OPTIONAL
      *
      * @return void
      */
-    public static function sendHeaders($additional = array())
+    public static function sendHeaders($additional = [])
     {
         parent::sendHeaders($additional);
-        $contentSecurityPolicy = \XLite::getInstance()->getOptions(array('other', 'content_security_policy'));
-        if ($contentSecurityPolicy !== null && 'disabled' !== $contentSecurityPolicy) {
-            header('Content-Security-Policy:' . $contentSecurityPolicy);
+        $contentSecurityPolicy = \Includes\Utils\ConfigParser::getOptions(['other', 'content_security_policy']);
+        if ($contentSecurityPolicy !== null && $contentSecurityPolicy !== 'disabled') {
+            \XLite::getInstance()->addHeader('Content-Security-Policy', $contentSecurityPolicy);
         }
     }
 
@@ -461,7 +435,7 @@ abstract class ACustomer extends \XLite\Controller\AController
         if (\XLite\Core\Request::getInstance()->profile_id) {
             $profile = \XLite\Core\Database::getRepo('XLite\Model\Profile')
                 ->find(\XLite\Core\Request::getInstance()->profile_id);
-            $result = $profile && \XLite\Core\Auth::getInstance()->checkProfile($profile);
+            $result  = $profile && \XLite\Core\Auth::getInstance()->checkProfile($profile);
         }
 
         return $result;
@@ -484,30 +458,7 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function closeStorefront()
     {
-        \Includes\ErrorHandler::fireError(
-            'Storefront is closed',
-            \Includes\ErrorHandler::ERROR_CLOSED
-        );
-    }
-
-    /**
-     * Return template to use in a CMS
-     *
-     * @return string
-     */
-    protected function getCMSTemplate()
-    {
-        return 'layout/content/center_top.twig';
-    }
-
-    /**
-     * Select template to use
-     *
-     * @return string
-     */
-    protected function getViewerTemplate()
-    {
-        return $this->getParam(self::PARAM_IS_EXPORTED) ? $this->getCMSTemplate() : parent::getViewerTemplate();
+        throw new ClosedStorefrontException();
     }
 
     /**
@@ -519,9 +470,11 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function updateCart($silent = false)
     {
-        $cart = $this->getCart();
-        \XLite\Core\Database::getEM()->transactional(function(EntityManager $em) use (&$cart) {
-            if ($this->markCartCalculate()) {
+        $cart    = $this->getCart();
+        $updated = $cart->updateEmptyShippingID();
+
+        \XLite\Core\Database::getEM()->transactional(function (\Doctrine\ORM\EntityManagerInterface $em) use (&$cart, $updated) {
+            if ($updated || $this->markCartCalculate()) {
                 if ($cart->isManaged()) {
                     $em->lock($cart, \Doctrine\DBAL\LockMode::PESSIMISTIC_WRITE);
                 }
@@ -532,8 +485,6 @@ abstract class ACustomer extends \XLite\Controller\AController
         if (!$silent) {
             $this->assembleEvent();
         }
-
-        $this->initialCartFingerprint = $cart->getEventFingerprint($this->getCartFingerprintExclude());
     }
 
     /**
@@ -543,9 +494,10 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function assembleEvent()
     {
-        $diff = $this->getCartFingerprintDifference(
+        $currentFingerprint = $this->getCart()->getEventFingerprint($this->getCartFingerprintExclude());
+        $diff               = $this->getCartFingerprintDifference(
             $this->initialCartFingerprint,
-            $this->getCart()->getEventFingerprint($this->getCartFingerprintExclude())
+            $currentFingerprint
         );
 
         if ($diff) {
@@ -555,7 +507,7 @@ abstract class ACustomer extends \XLite\Controller\AController
             }
         }
 
-        return (bool)$diff;
+        return (bool) $diff;
     }
 
     /**
@@ -568,17 +520,18 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function getCartFingerprintDifference(array $old, array $new)
     {
-        $diff = array();
+        $diff = [];
 
-        $items = array();
+        $items = [];
 
         // Assembly changed
-        foreach ($new['items'] as $n => $cell) {
+        foreach ($new['items'] as $cell) {
             $found = false;
             foreach ($old['items'] as $i => $oldCell) {
                 if ($cell['key'] == $oldCell['key']) {
                     if ($cell['quantity'] != $oldCell['quantity']) {
                         $cell['quantity_change'] = $cell['quantity'] - $oldCell['quantity'];
+
                         $items[] = $cell;
                     }
 
@@ -590,13 +543,16 @@ abstract class ACustomer extends \XLite\Controller\AController
 
             if (!$found) {
                 $cell['quantity_change'] = $cell['quantity'];
-                $items[] = $cell;
+                $items[]                 = $cell;
             }
         }
 
         // Assemble removed
         foreach ($old['items'] as $cell) {
             $cell['quantity_change'] = $cell['quantity'] * -1;
+            $cell['quantity']        = 0;
+
+            unset($cell['is_limit']);
             $items[] = $cell;
         }
 
@@ -604,7 +560,7 @@ abstract class ACustomer extends \XLite\Controller\AController
             $diff['items'] = $items;
         }
 
-        $cellKeys = array(
+        $cellKeys = [
             'shippingTotal',
             'shippingMethodId',
             'paymentMethodId',
@@ -616,11 +572,11 @@ abstract class ACustomer extends \XLite\Controller\AController
             'shippingMethodsHash',
             'paymentMethodsHash',
             'itemsCount',
-        );
+        ];
 
         foreach ($cellKeys as $name) {
-            $old[$name] = isset($old[$name]) ? $old[$name] : '';
-            $new[$name] = isset($new[$name]) ? $new[$name] : '';
+            $old[$name] = $old[$name] ?? '';
+            $new[$name] = $new[$name] ?? '';
 
             if ($old[$name] != $new[$name]) {
                 $diff[$name] = $new[$name];
@@ -644,12 +600,12 @@ abstract class ACustomer extends \XLite\Controller\AController
      */
     protected function posprocessCartFingerprintDifference(array $diff)
     {
-        $result = array();
+        $result = [];
 
         foreach ($diff as $name => $data) {
             $isAvail = true;
 
-            $method = 'postprocessDifference' . ucfirst($name);
+            $method = 'postprocessDifference' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
             if (method_exists($this, $method)) {
                 // postprocessDifference + <param name>
                 $isAvail = $this->{$method}($data);
@@ -663,6 +619,40 @@ abstract class ACustomer extends \XLite\Controller\AController
         return $result;
     }
 
+    /**
+     * Email can not be empty, so if it's empty, it means there wasn't an email field in the form. In that case, remove
+     * email from the differences list.
+     * The function always returns true.
+     *
+     * @param array $data Shipping address fields that were changed
+     *
+     * @return bool
+     */
+    protected function postprocessDifferenceShippingAddressFields(array &$data): bool
+    {
+        if (empty($data['email'])) {
+            unset($data['email']);
+        }
+        return true;
+    }
+
+    /**
+     * Email can not be empty, so if it's empty, it means there wasn't an email field in the form. In that case, remove
+     * email from the differences list.
+     * The function always returns true.
+     *
+     * @param array $data Shipping address fields that were changed
+     *
+     * @return bool
+     */
+    protected function postprocessDifferenceBillingAddressFields(array &$data): bool
+    {
+        if (empty($data['email'])) {
+            unset($data['email']);
+        }
+        return true;
+    }
+
     /**
      * Postprocess fingerprint difference parameter.
      * Return false if this param should be removed from event-updateCart params list.
@@ -708,7 +698,7 @@ abstract class ACustomer extends \XLite\Controller\AController
         $profile = null;
 
         try {
-            \XLite\Core\Database::getEM()->transactional(function (\XLite\Core\Doctrine\ORM\EntityManager $em) use (&$profile) {
+            \XLite\Core\Database::getEM()->transactional(function (\Doctrine\ORM\EntityManagerInterface $em) use (&$profile) {
                 $cart = $this->getCart();
                 if ($cart->isManaged()) {
                     $em->lock($cart, \Doctrine\DBAL\LockMode::PESSIMISTIC_WRITE);
@@ -717,7 +707,7 @@ abstract class ACustomer extends \XLite\Controller\AController
 
                 $profile = $cart->getProfile();
                 if (!$profile && $cart->isManaged()) {
-                    $profile = new \XLite\Model\Profile;
+                    $profile = new \XLite\Model\Profile();
                     $profile->setLogin('');
                     $profile->setOrder($cart);
                     $profile->setAnonymous(true);
@@ -727,16 +717,16 @@ abstract class ACustomer extends \XLite\Controller\AController
                 }
             });
         } catch (\Exception $e) {
-            \XLite\Logger::getInstance()->log(
-                'Failure to create anonymous profile for cart '
-                . $this->getCart()->getUniqueIdentifier() . PHP_EOL
-                . $e->getMessage() . PHP_EOL
-                . $e->getTraceAsString(),
-                LOG_ERR
+            $this->getLogger()->error(
+                'Failure to create anonymous profile for cart ',
+                [
+                    'cart-id' => $this->getCart()->getUniqueIdentifier(),
+                    'message' => $e->getMessage(),
+                    'trace'   => $e->getTrace(),
+                ]
             );
 
             if (!\XLite\Core\Database::getEM()->isOpen()) {
-
                 throw $e;
             }
         }
@@ -776,7 +766,8 @@ abstract class ACustomer extends \XLite\Controller\AController
     {
         parent::doNoAction();
 
-        if (LC_USE_CLEAN_URLS
+        if (
+            LC_USE_CLEAN_URLS
             && !\XLite::isCleanURL()
             && !$this->isAJAX()
             && !$this->isRedirectNeeded()
@@ -785,7 +776,8 @@ abstract class ACustomer extends \XLite\Controller\AController
             $this->performRedirectToCleanURL();
         }
 
-        if (!$this->isAJAX()
+        if (
+            !$this->isAJAX()
             && !$this->isRedirectNeeded()
         ) {
             \XLite\Core\Session::getInstance()->continueShoppingURL = $this->getAllParams();
@@ -803,9 +795,10 @@ abstract class ACustomer extends \XLite\Controller\AController
             || preg_match(
                 '/\/cart\.php/Si',
                 \Includes\Utils\ArrayManager::getIndex(
-                    \XLite\Core\Request::getInstance()->getServerData(), 'REQUEST_URI'
+                    \XLite\Core\Request::getInstance()->getServerData(),
+                    'REQUEST_URI'
                 )
-            );            
+            );
     }
 
     /**
@@ -823,7 +816,7 @@ abstract class ACustomer extends \XLite\Controller\AController
 
         $target = $this->getTarget();
 
-        if (\XLite::TARGET_DEFAULT === $target) {
+        if ($target === \XLite::TARGET_DEFAULT) {
             $target = '';
             unset($data['target']);
         } else {
@@ -832,7 +825,7 @@ abstract class ACustomer extends \XLite\Controller\AController
 
         $url = \XLite\Core\Converter::buildFullURL($target, '', $data);
 
-        $ttl = 86400;
+        $ttl         = 86400;
         $expiresTime = gmdate('D, d M Y H:i:s', time() + $ttl) . ' GMT';
 
         header("Cache-Control: max-age=$ttl, must-revalidate");
@@ -853,18 +846,18 @@ abstract class ACustomer extends \XLite\Controller\AController
     public function getAddressFields()
     {
         if (!isset($this->addressFields)) {
-            $result = array();
+            $result = [];
 
             foreach (\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
-                $result[$field->getServiceName()] = array(
-                    \XLite\View\Model\Address\Address::SCHEMA_CLASS    => $field->getSchemaClass(),
-                    \XLite\View\Model\Address\Address::SCHEMA_LABEL    => $field->getName(),
-                    \XLite\View\Model\Address\Address::SCHEMA_REQUIRED => $field->getRequired(),
-                    \XLite\View\Model\Address\Address::SCHEMA_MODEL_ATTRIBUTES => array(
+                $result[$field->getServiceName()] = [
+                    \XLite\View\Model\Address\Address::SCHEMA_CLASS            => $field->getSchemaClass(),
+                    \XLite\View\Model\Address\Address::SCHEMA_LABEL            => $field->getName(),
+                    \XLite\View\Model\Address\Address::SCHEMA_REQUIRED         => $field->getRequired(),
+                    \XLite\View\Model\Address\Address::SCHEMA_MODEL_ATTRIBUTES => [
                         \XLite\View\FormField\Input\Base\StringInput::PARAM_MAX_LENGTH => 'length',
-                    ),
-                    \XLite\View\FormField\AFormField::PARAM_WRAPPER_CLASS => 'address-' . $field->getServiceName(),
-                );
+                    ],
+                    \XLite\View\FormField\AFormField::PARAM_WRAPPER_CLASS      => 'address-' . $field->getServiceName()
+                ];
             }
 
             $this->addressFields = $this->getFilteredSchemaFields($result);
@@ -900,13 +893,12 @@ abstract class ACustomer extends \XLite\Controller\AController
                 if (isset($fields['custom_state'])) {
                     $fields['custom_state']['additionalClass'] = 'single-state-field';
                 }
-
             } elseif (!$deleteStateSelector && isset($fields['custom_state'])) {
                 unset($fields['custom_state']);
 
                 if (isset($fields['state_id'])) {
                     $fields['state_id'][\XLite\View\FormField\Select\State::PARAM_COUNTRY] = $address->getCountry()->getCode();
-                    $fields['state_id']['additionalClass'] = 'single-state-field';
+                    $fields['state_id']['additionalClass']                                 = 'single-state-field';
                 }
             }
         }
@@ -927,13 +919,13 @@ abstract class ACustomer extends \XLite\Controller\AController
     {
         $result = '';
 
-        if (null !== $address) {
-            $methodName = 'get' . \XLite\Core\Converter::getInstance()->convertToCamelCase($fieldName);
+        if ($address !== null) {
+            $methodName = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($fieldName);
 
             // $methodName assembled from 'get' + camelized $fieldName
             $result = $address->$methodName();
 
-            if ($result && false !== $processValue) {
+            if ($result && $processValue !== false) {
                 switch ($fieldName) {
                     case 'state_id':
                         $result = $address->getCountry()->hasStates()
@@ -956,7 +948,6 @@ abstract class ACustomer extends \XLite\Controller\AController
                         break;
 
                     default:
-
                 }
             }
         }
@@ -1010,29 +1001,26 @@ abstract class ACustomer extends \XLite\Controller\AController
         $id = intval(!$width);
 
         // $resizeData[0] - width, $resizeData[1] - height
-        return isset($resizeData[$id]) ? $resizeData[$id] : 0;
+        return $resizeData[$id] ?? 0;
     }
 
-
     /**
      * Makes given address as selected on current cart.
      * Throws core events "selectCartAddress" and "updateCart".
-     * 
+     *
      * @param  [type]  $atype               Address type (billing\shipping) short tag
      * @param  [type]  $addressId           Address id
-     * @param  boolean $hasEmptyFields      If true, sends updateCart event even if addressId hasn't changed
-     * @param  boolean $preserveSameAddress If true and shipping\billing addresses are the same, new address will be applied to both addresses; if false, only the address of given type will change.
+     * @param boolean $hasEmptyFields      If true, sends updateCart event even if addressId hasn't changed
+     * @param boolean $preserveSameAddress If true and shipping\billing addresses are the same, new address will be applied to both addresses; if false, only the address of given type will change.
      */
     protected function selectCartAddress($atype, $addressId, $hasEmptyFields = false, $preserveSameAddress = true)
     {
-        if (\XLite\Model\Address::SHIPPING != $atype && \XLite\Model\Address::BILLING != $atype) {
+        if ($atype != \XLite\Model\Address::SHIPPING && $atype != \XLite\Model\Address::BILLING) {
             $this->valid = false;
             \XLite\Core\TopMessage::addError('Address type has wrong value');
-
         } elseif (!$addressId) {
             $this->valid = false;
             \XLite\Core\TopMessage::addError('Address is not selected');
-
         } else {
             $address = \XLite\Core\Database::getRepo('XLite\Model\Address')->find($addressId);
 
@@ -1040,37 +1028,33 @@ abstract class ACustomer extends \XLite\Controller\AController
                 // Address not found
                 $this->valid = false;
                 \XLite\Core\TopMessage::addError('Address not found');
-
             } elseif (
-                \XLite\Model\Address::SHIPPING == $atype
+                $atype == \XLite\Model\Address::SHIPPING
                 && $this->getCart()->getProfile()->getShippingAddress()
                 && $address->getAddressId() == $this->getCart()->getProfile()->getShippingAddress()->getAddressId()
             ) {
                 if ($hasEmptyFields) {
                     \XLite\Core\Event::updateCart(
-                        array(
+                        [
                             'shippingAddressId' => $address->getAddressId(),
-                        )
+                        ]
                     );
                 }
-
             } elseif (
-                \XLite\Model\Address::BILLING == $atype
+                $atype == \XLite\Model\Address::BILLING
                 && $this->getCart()->getProfile()->getBillingAddress()
                 && $address->getAddressId() == $this->getCart()->getProfile()->getBillingAddress()->getAddressId()
             ) {
-
                 if ($hasEmptyFields) {
                     \XLite\Core\Event::updateCart(
-                        array(
+                        [
                             'billingAddressId' => $address->getAddressId(),
-                        )
+                        ]
                     );
                 }
-
             } else {
-                if (\XLite\Model\Address::SHIPPING == $atype) {
-                    $old = $this->getCart()->getProfile()->getShippingAddress();
+                if ($atype == \XLite\Model\Address::SHIPPING) {
+                    $old          = $this->getCart()->getProfile()->getShippingAddress();
                     $andAsBilling = false;
                     if ($old) {
                         $old->setIsShipping(false);
@@ -1078,11 +1062,9 @@ abstract class ACustomer extends \XLite\Controller\AController
                         if ($old->getIsWork() && !$andAsBilling) {
                             $this->getCart()->getProfile()->getAddresses()->removeElement($old);
                             \XLite\Core\Database::getEM()->remove($old);
-
                         } elseif ($andAsBilling && $preserveSameAddress) {
                             $old->setIsBilling(false);
                         }
-
                     } elseif (!$this->getCart()->getProfile()->getBillingAddress()) {
                         $andAsBilling = true;
                     }
@@ -1091,9 +1073,8 @@ abstract class ACustomer extends \XLite\Controller\AController
                     if ($andAsBilling && $preserveSameAddress) {
                         $address->setIsBilling($andAsBilling);
                     }
-
                 } else {
-                    $old = $this->getCart()->getProfile()->getBillingAddress();
+                    $old           = $this->getCart()->getProfile()->getBillingAddress();
                     $andAsShipping = false;
                     if ($old) {
                         $old->setIsBilling(false);
@@ -1101,11 +1082,9 @@ abstract class ACustomer extends \XLite\Controller\AController
                         if ($old->getIsWork() && !$andAsShipping) {
                             $this->getCart()->getProfile()->getAddresses()->removeElement($old);
                             \XLite\Core\Database::getEM()->remove($old);
-
                         } elseif ($andAsShipping && $preserveSameAddress) {
                             $old->setIsShipping(false);
                         }
-
                     } elseif (!$this->getCart()->getProfile()->getShippingAddress()) {
                         $andAsShipping = true;
                     }
@@ -1119,12 +1098,12 @@ abstract class ACustomer extends \XLite\Controller\AController
                 \XLite\Core\Session::getInstance()->same_address = $this->getCart()->getProfile()->isEqualAddress();
 
                 \XLite\Core\Event::selectCartAddress(
-                    array(
+                    [
                         'type'      => $atype,
                         'addressId' => $address->getAddressId(),
                         'same'      => $this->getCart()->getProfile()->isSameAddress(),
-                        'fields'    => $address->serialize()
-                    )
+                        'fields'    => $address->serialize(),
+                    ]
                 );
 
                 \XLite\Core\Database::getEM()->flush();
@@ -1133,4 +1112,20 @@ abstract class ACustomer extends \XLite\Controller\AController
             }
         }
     }
+
+    /**
+     * Mark controller run thread as access denied
+     *
+     * @return void
+     */
+    protected function markAsAccessDenied()
+    {
+        \XLite\Core\Request::getInstance()->fromURL = $this->buildURL(
+            $this->getTarget(),
+            $this->getAction(),
+            \XLite\Core\Request::getInstance()->getData()
+        );
+
+        parent::markAsAccessDenied();
+    }
 }
