@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,8 +7,6 @@
 
 namespace XLite\Controller\Customer;
 
-use XLite\Core\Database\Migration\UnsupportedDatabaseOperationDuringMaintenanceException;
-
 /**
  * \XLite\Controller\Customer\Cart
  */
@@ -64,7 +61,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
     {
         return $this->getCart()->isEmpty()
             ? static::t('Your shopping bag is empty')
-            : static::t('Your shopping bag - X items', array('count' => $this->getCart()->countQuantity()));
+            : static::t('Your shopping bag - X items', ['count' => $this->getCart()->countQuantity()]);
     }
 
     /**
@@ -89,7 +86,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function getExcludedWidgets()
     {
-        return array('\XLite\View\Minicart');
+        return ['\XLite\View\Minicart'];
     }
 
     /**
@@ -99,13 +96,13 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function getCartFingerprintExclude()
     {
-        return array(
+        return [
             'shippingMethodsHash',
             'paymentMethodsHash',
             'shippingMethodId',
             'paymentMethodId',
             'shippingTotal'
-        );
+        ];
     }
 
     /**
@@ -156,7 +153,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function getCurrentAmount()
     {
-        return intval(\XLite\Core\Request::getInstance()->amount) ?: 1;
+        return (int) \XLite\Core\Request::getInstance()->amount ?: 1;
     }
 
     /**
@@ -176,7 +173,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function getCurrentProduct()
     {
-        if (null === $this->product) {
+        if ($this->product === null) {
             $this->product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($this->getCurrentProductId());
         }
 
@@ -249,7 +246,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function correctAmountAsProduct(\XLite\Model\Product $product, $amount)
     {
-        if (null === $amount) {
+        if ($amount === null) {
             $amount = $product->getLowAvailableAmount();
         }
 
@@ -329,8 +326,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
     }
 
     /**
-     * Add order item to cart.
-     * Additional correction of item amount is made before adding.
+     * Add order item to cart
      *
      * @param \XLite\Model\OrderItem $item Order item
      *
@@ -339,19 +335,37 @@ class Cart extends \XLite\Controller\Customer\ACustomer
     protected function addItem($item)
     {
         if ($item) {
-            /** @var \XLite\Model\Cart $cart */
-            $cart = $this->getCart();
-            $cart->setIgnoreLongCalculations();
+            $this->prepareCartBeforeAmountChanging();
 
-            if (!$cart->isPersistent()) {
-                \XLite\Core\Database::getEM()->persist($cart);
-                \XLite\Core\Database::getEM()->flush();
-
-                \XLite\Core\Session::getInstance()->order_id = $cart->getOrderId();
-            }
+            return $this->getCart()->addItem($item);
         }
 
-        return $item && $this->getCart()->addItem($item);
+        return false;
+    }
+
+    /**
+     * Remove item from cart
+     *
+     * @param \XLite\Model\OrderItem $item Order item
+     */
+    protected function removeItem($item)
+    {
+        $this->prepareCartBeforeAmountChanging();
+        $this->getCart()->removeItem($item);
+    }
+
+    protected function prepareCartBeforeAmountChanging()
+    {
+        /** @var \XLite\Model\Cart $cart */
+        $cart = $this->getCart();
+        $cart->setIgnoreLongCalculations();
+
+        if (!$cart->isPersistent()) {
+            \XLite\Core\Database::getEM()->persist($cart);
+            \XLite\Core\Database::getEM()->flush();
+
+            \XLite\Core\Session::getInstance()->order_id = $cart->getOrderId();
+        }
     }
 
     /**
@@ -365,11 +379,11 @@ class Cart extends \XLite\Controller\Customer\ACustomer
     {
         \XLite\Core\TopMessage::addWarning(
             'You tried to buy more items of "{{product}}" product {{description}} than are in stock. We have {{amount}} item(s) only. Please adjust the product quantity.',
-            array(
+            [
                 'product'     => $item->getProduct()->getName(),
                 'description' => $item->getExtendedDescription(),
                 'amount'      => $item->getProductAvailableAmount()
-            )
+            ]
         );
     }
 
@@ -380,7 +394,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function processAddItemError()
     {
-        if (\XLite\Model\Cart::NOT_VALID_ERROR === $this->getCart()->getAddItemError()) {
+        if ($this->getCart()->getAddItemError() === \XLite\Model\Cart::NOT_VALID_ERROR) {
             \XLite\Core\TopMessage::addError('Product has not been added to cart');
         } elseif ($product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($this->getCurrentProductId())) {
             if (!$product->isAvailable()) {
@@ -402,6 +416,29 @@ class Cart extends \XLite\Controller\Customer\ACustomer
         \XLite\Core\Event::productAddedToCart($this->assembleProductAddedToCartEvent($item));
     }
 
+    /**
+     * Process 'Remove item' error
+     *
+     * @return void
+     */
+    protected function processRemoveItemError()
+    {
+        \XLite\Core\TopMessage::addError('Item has not been removed from your cart');
+    }
+
+    /**
+     * Process 'Remove item' success
+     *
+     * @param \XLite\Model\OrderItem $item
+     *
+     * @return void
+     */
+    protected function processRemoveItemSuccess($item)
+    {
+        \XLite\Core\TopMessage::addInfo('Item has been removed from your cart');
+        \XLite\Core\Event::productRemovedFromCart($this->assembleProductRemovedFromCartEvent($item));
+    }
+
     /**
      * Returns event data
      *
@@ -414,6 +451,18 @@ class Cart extends \XLite\Controller\Customer\ACustomer
         return [];
     }
 
+    /**
+     * Returns event data
+     *
+     * @param \XLite\Model\OrderItem $item
+     *
+     * @return array
+     */
+    protected function assembleProductRemovedFromCartEvent($item)
+    {
+        return [];
+    }
+
     /**
      * URL to return after product is added
      *
@@ -426,12 +475,10 @@ class Cart extends \XLite\Controller\Customer\ACustomer
         if (!$url) {
             if (\XLite\Core\Request::getInstance()->returnURL) {
                 $url = \XLite\Core\Request::getInstance()->returnURL;
-
             } elseif (!empty($_SERVER['HTTP_REFERER'])) {
                 $url = $_SERVER['HTTP_REFERER'];
-
             } else {
-                $url = $this->buildURL('product', '', array('product_id' => $this->getProductId()));
+                $url = $this->buildURL('product', '', ['product_id' => $this->getProductId()]);
             }
         }
 
@@ -447,7 +494,6 @@ class Cart extends \XLite\Controller\Customer\ACustomer
             // Hard redirect to cart
             $this->setReturnURL($this->buildURL('cart'));
             $this->setHardRedirect();
-
         } else {
             $this->setReturnURL($this->getURLToReturn());
         }
@@ -460,7 +506,8 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function doActionAdd()
     {
-        if (!\XLite\Core\Request::getInstance()->attribute_values
+        if (
+            !\XLite\Core\Request::getInstance()->attribute_values
             && \XLite\Core\Config::getInstance()->General->force_choose_product_options !== ''
             && $this->getCurrentProduct()
             && $this->getCurrentProduct()->hasEditableAttributes()
@@ -468,7 +515,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
             $this->setReturnURL($this->buildURL(
                 'product',
                 '',
-                array('product_id' => $this->getProductId())
+                ['product_id' => $this->getProductId()]
             ));
         } else {
             // Add product to the cart and set a top message (if needed)
@@ -476,7 +523,6 @@ class Cart extends \XLite\Controller\Customer\ACustomer
 
             if ($item && $this->addItem($item)) {
                 $this->processAddItemSuccess($item);
-
             } else {
                 $this->processAddItemError();
             }
@@ -489,6 +535,26 @@ class Cart extends \XLite\Controller\Customer\ACustomer
         }
     }
 
+    /**
+     * Remove item from cart
+     *
+     * @return void
+     */
+    protected function doActionRemove()
+    {
+        $item = $this->getCurrentItem();
+
+        if ($item) {
+            $this->removeItem($item);
+            $this->processRemoveItemSuccess($item);
+        } else {
+            $this->processRemoveItemError();
+        }
+
+        $this->updateCart();
+        $this->setURLToReturn();
+    }
+
     /**
      * Add products from the order to cart
      *
@@ -501,13 +567,13 @@ class Cart extends \XLite\Controller\Customer\ACustomer
         if (\XLite\Core\Request::getInstance()->order_id) {
             $order = \XLite\Core\Database::getRepo('\XLite\Model\Order')
                 ->find((int) \XLite\Core\Request::getInstance()->order_id);
-
         } elseif (\XLite\Core\Request::getInstance()->order_number) {
             $order = \XLite\Core\Database::getRepo('\XLite\Model\Order')
                 ->findOneByOrderNumber(\XLite\Core\Request::getInstance()->order_number);
         }
 
-        if ($order
+        if (
+            $order
             && ($order->getProfile()->getAnonymous()
                 || (\XLite\Core\Auth::getInstance()->isLogged()
                     && \XLite\Core\Auth::getInstance()->getProfile()->getProfileId() == $order->getOrigProfile()->getProfileId()
@@ -568,12 +634,12 @@ class Cart extends \XLite\Controller\Customer\ACustomer
 
         if (!is_array($amount)) {
             $amount = isset(\XLite\Core\Request::getInstance()->cart_id)
-                ? array($cartId => $amount)
-                : array();
+                ? [$cartId => $amount]
+                : [];
         } elseif (isset($cartId)) {
             $amount = isset($amount[$cartId])
-                ? array($cartId => $amount[$cartId])
-                : array();
+                ? [$cartId => $amount[$cartId]]
+                : [];
         }
 
         $result = false;
@@ -605,6 +671,7 @@ class Cart extends \XLite\Controller\Customer\ACustomer
 
         if ($result) {
             $this->updateCart();
+            $this->checkItemsAmount();
         }
     }
 
@@ -649,10 +716,6 @@ class Cart extends \XLite\Controller\Customer\ACustomer
      */
     protected function doNoAction()
     {
-        if (!$this->isAJAX()) {
-            $this->getCart()->unsetUpdatedTime();
-        }
-
         $this->updateCart();
     }
 }
