@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\Controller\Customer;
 
+use XLite\Core\WidgetCacheManager;
+
 /**
  * Checkout
  */
@@ -16,12 +17,12 @@ class Checkout extends \XLite\Controller\Customer\Cart
     /**
      * Checkout availability flag
      */
-    const CHECKOUT_AVAIL_FLAG = 'checkout_avail_flag';
+    public const CHECKOUT_AVAIL_FLAG = 'checkout_avail_flag';
 
     /**
      * Checkout available flag timeout (24 hours)
      */
-    const CHECKOUT_AVAIL_TIMEOUT = 86400;
+    public const CHECKOUT_AVAIL_TIMEOUT = 86400;
 
     /**
      * Request data
@@ -35,7 +36,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
      *
      * @var array
      */
-    protected $paymentWidgetData = array();
+    protected $paymentWidgetData = [];
 
     /**
      * Modifier (cache)
@@ -64,9 +65,9 @@ class Checkout extends \XLite\Controller\Customer\Cart
     {
         return array_merge(
             parent::defineFreeFormIdActions(),
-            array(
+            [
                 'return'
-            )
+            ]
         );
     }
 
@@ -78,7 +79,8 @@ class Checkout extends \XLite\Controller\Customer\Cart
     public function handleRequest()
     {
         // We do not verify the cart when the customer returns from the payment
-        if (\XLite\Core\Request::getInstance()->action !== 'return'
+        if (
+            \XLite\Core\Request::getInstance()->action !== 'return'
             && !$this->getCart()->checkCart()
         ) {
             $this->setHardRedirect();
@@ -176,7 +178,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     public function getLoginURL($email = null)
     {
-        $params = array();
+        $params = [];
         if ($email) {
             $params['login'] = $email;
         }
@@ -268,24 +270,23 @@ class Checkout extends \XLite\Controller\Customer\Cart
         $this->updateCart();
         $itemsAfterUpdate = $cart->getItemsFingerprint();
 
-        if ($itemsAfterUpdate !== $itemsBeforeUpdate
+        if (
+            $itemsAfterUpdate !== $itemsBeforeUpdate
             || $this->get('absence_of_product')
             || $cart->isEmpty()
         ) {
             // Cart is changed
             $this->set('absence_of_product', true);
             $this->redirect($this->buildURL('cart'));
-
         } elseif (!$this->checkCheckoutAction()) {
             // Check access
             $this->redirect($this->buildURL('checkout'));
-
         } else {
             $data = is_array(\XLite\Core\Request::getInstance()->payment)
                 ? \XLite\Core\Request::getInstance()->payment
-                : array();
+                : [];
 
-            $errors = array();
+            $errors = [];
             $firstOpenTransaction = $cart->getFirstOpenPaymentTransaction();
             if ($firstOpenTransaction) {
                 $errors = $firstOpenTransaction->getPaymentMethod()
@@ -299,12 +300,11 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 }
 
                 $this->redirect($this->buildURL('checkout'));
-
             } else {
                 $shippingMethod = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method')->findOneBy(
-                    array(
+                    [
                         'method_id' => $cart->getShippingId()
-                    )
+                    ]
                 );
 
                 if ($shippingMethod) {
@@ -328,7 +328,9 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 /** @var \XLite\Model\OrderItem $item */
                 foreach ($cart->getItems() as $item) {
                     if ($item->getInventoryAmount() <= 0) {
-                        $this->getContainer()->get('widget_cache_manager')->deleteAll();
+                        /** @var WidgetCacheManager $widgetCache */
+                        $widgetCacheManager = \XCart\Container::getContainer()->get(WidgetCacheManager::class);
+                        $widgetCacheManager->deleteAll();
 
                         break;
                     }
@@ -392,36 +394,31 @@ class Checkout extends \XLite\Controller\Customer\Cart
             if ($pstatus !== \XLite\Model\Order\Status\Payment::STATUS_QUEUED) {
                 $paymentStatusCode = $pstatus;
             }
-
         } elseif (!$cart->isOpen()) {
             // Cart is payed - create dump transaction
             $result = \XLite\Model\Payment\Transaction::COMPLETED;
             $paymentStatusCode = $cart->getCalculatedPaymentStatus(true);
-
         } else {
             $paymentStatusCode = $cart->getPaymentStatusCode();
         }
 
-        if (\XLite\Model\Payment\Transaction::PROLONGATION === $result) {
+        if ($result === \XLite\Model\Payment\Transaction::PROLONGATION) {
             $this->set('silent', true);
 
-            exit (0);
-
-        } elseif (\XLite\Model\Payment\Transaction::SILENT === $result) {
+            exit(0);
+        } elseif ($result === \XLite\Model\Payment\Transaction::SILENT) {
             $this->paymentWidgetData = $transaction->getPaymentMethod()
                 ->getProcessor()
                 ->getPaymentWidgetData();
             $this->set('silent', true);
-
-        } elseif (\XLite\Model\Payment\Transaction::SEPARATE === $result) {
+        } elseif ($result === \XLite\Model\Payment\Transaction::SEPARATE) {
             $this->setReturnURL($this->buildURL('checkoutPayment'));
-
         } elseif ($cart->isOpen()) {
             // Order is open - go to Select payment method step
             if ($transaction && $transaction->getNote()) {
                 \XLite\Core\TopMessage::getInstance()->add(
                     $transaction->getNote(),
-                    array(),
+                    [],
                     null,
                     $transaction->isFailed()
                         ? \XLite\Core\TopMessage::ERROR
@@ -431,18 +428,15 @@ class Checkout extends \XLite\Controller\Customer\Cart
             }
 
             $this->setReturnURL($this->buildURL('checkout'));
-
         } else {
             if ($cart->isPayed()) {
                 $paymentStatus = $paymentStatusCode ?: \XLite\Model\Order\Status\Payment::STATUS_PAID;
                 $cart->setPaymentStatus($paymentStatus);
                 $this->processSucceed();
-
             } elseif ($transaction && $transaction->isFailed()) {
                 $paymentStatus = \XLite\Model\Order\Status\Payment::STATUS_DECLINED;
                 $cart->setPaymentStatus($paymentStatus);
                 \XLite\Core\Database::getEM()->flush();
-
             } else {
                 $paymentStatus = \XLite\Model\Order\Status\Payment::STATUS_QUEUED;
                 $cart->setPaymentStatus($paymentStatus);
@@ -453,13 +447,13 @@ class Checkout extends \XLite\Controller\Customer\Cart
 
             $this->setReturnURL(
                 $this->buildURL(
-                    \XLite\Model\Order\Status\Payment::STATUS_DECLINED === $paymentStatus
+                    $paymentStatus === \XLite\Model\Order\Status\Payment::STATUS_DECLINED
                         ? 'checkoutFailed'
                         : 'checkoutSuccess',
                     '',
                     $cart->getOrderNumber()
-                        ? array('order_number' => $cart->getOrderNumber())
-                        : array('order_id' => $cart->getOrderId())
+                        ? ['order_number' => $cart->getOrderNumber()]
+                        : ['order_id' => $cart->getOrderId()]
                 )
             );
         }
@@ -496,12 +490,10 @@ class Checkout extends \XLite\Controller\Customer\Cart
             unset(\XLite\Core\Session::getInstance()->order_id);
             \XLite\Core\TopMessage::addError('Order not found');
             $this->setReturnURL($this->buildURL('cart'));
-
         } elseif ($cart->getOpenTotal() > 0) {
             // Order still not payed
             $this->assignTransactionMessage();
             $this->setReturnURL($this->getOpenTotalReturnURL($cart));
-
         } else {
             // Order payed or pending
             if ($cart instanceof \XLite\Model\Cart) {
@@ -517,8 +509,8 @@ class Checkout extends \XLite\Controller\Customer\Cart
                     $this->getStatusTarget($cart->getPaymentStatusCode()),
                     '',
                     $cart->getOrderNumber()
-                        ? array('order_number' => $cart->getOrderNumber())
-                        : array('order_id' => $orderId)
+                        ? ['order_number' => $cart->getOrderNumber()]
+                        : ['order_id' => $orderId]
                 )
             );
         }
@@ -549,17 +541,14 @@ class Checkout extends \XLite\Controller\Customer\Cart
         if ($txnNote) {
             $message = strip_tags($txnNote);
 
-            if (\XLite\Core\TopMessage::ERROR === $txnNoteType) {
+            if ($txnNoteType === \XLite\Core\TopMessage::ERROR) {
                 if (\XLite\Model\Payment\Transaction::getDefaultFailedReason() == $txnNote) {
                     // Display default message
                     \XLite\Core\TopMessage::addError($message);
-
                 } else {
                     // Display specific transaction message
-                    \XLite\Core\TopMessage::addError($this->getCommonErrorMessage(), array('txnNote' => $message));
+                    \XLite\Core\TopMessage::addError($this->getCommonErrorMessage(), ['txnNote' => $message]);
                 }
-
-
             } else {
                 // Display transaction success message
                 \XLite\Core\TopMessage::addInfo($message);
@@ -664,11 +653,9 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 );
 
                 $isAnonymous = false;
-
             } elseif ($doCloneProfile) {
                 $this->mergeAnonymousProfile();
             }
-
         } elseif ($doCloneProfile) {
             // Clone profile
             $this->cloneProfile();
@@ -717,7 +704,6 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 $cart->getProfile(),
                 \XLite\Model\Profile::MERGE_ALL ^ \XLite\Model\Profile::MERGE_ORDERS
             );
-
         } else {
             $profile = $cart->getProfile()->cloneEntity();
             $profile->setOrder(null);
@@ -773,7 +759,8 @@ class Checkout extends \XLite\Controller\Customer\Cart
         $cart->setOrigProfile($origProfile);
         $origProfile->setOrder(null);
 
-        if ($origProfile->getLastCheckoutEmail()
+        if (
+            $origProfile->getLastCheckoutEmail()
             && $origProfile->getLastCheckoutEmail() !== $cart->getProfile()->getLogin()
         ) {
             $cart->getProfile()->setLogin($origProfile->getLastCheckoutEmail());
@@ -802,7 +789,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     protected function isZeroOrderTotal()
     {
-        return 0 == $this->getCart()->getTotal()
+        return $this->getCart()->getTotal() == 0
             && \XLite\Core\Config::getInstance()->Payments->default_offline_payment;
     }
 
@@ -883,7 +870,8 @@ class Checkout extends \XLite\Controller\Customer\Cart
 
         $this->updateProfile();
 
-        if (!isset($this->requestData['same_address'])
+        if (
+            !isset($this->requestData['same_address'])
             && isset(\XLite\Core\Session::getInstance()->same_address)
         ) {
             $this->requestData['same_address'] = \XLite\Core\Session::getInstance()->same_address;
@@ -893,13 +881,16 @@ class Checkout extends \XLite\Controller\Customer\Cart
             $this->requestData['same_address'] = false;
         }
 
+        $this->updateAddressesPhonesToIntl();
+
         $this->updateShippingAddress();
 
         $this->updateBillingAddress();
 
         $this->setCheckoutAvailable();
 
-        if (empty($this->requestData['shippingAddress'])
+        if (
+            empty($this->requestData['shippingAddress'])
             && isset($this->requestData['same_address'])
         ) {
             \XLite\Core\Session::getInstance()->same_address = (bool)$this->requestData['same_address'];
@@ -921,7 +912,6 @@ class Checkout extends \XLite\Controller\Customer\Cart
     {
         if ($this->isAnonymous()) {
             $this->updateAnonymousProfile();
-
         } else {
             $this->updateLoggedProfile();
         }
@@ -934,12 +924,10 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     protected function updateAnonymousProfile()
     {
-        $login = isset($this->requestData['email'])
-            ? $this->requestData['email']
-            : null;
+        $login = $this->requestData['email'] ?? null;
 
-        if (null !== $login) {
-            $tmpProfile = new \XLite\Model\Profile;
+        if ($login !== null) {
+            $tmpProfile = new \XLite\Model\Profile();
             $tmpProfile->setProfileId(0);
             $tmpProfile->setLogin($login);
 
@@ -957,16 +945,16 @@ class Checkout extends \XLite\Controller\Customer\Cart
             \XLite\Core\Database::getEM()->flush($profile);
 
             \XLite\Core\Event::loginExists(
-                array(
+                [
                     'value' => $exists,
-                )
+                ]
             );
 
             if ($exists && $this->requestData['create_profile']) {
                 // Profile with same login is exists
                 $this->valid = false;
-
-            } elseif (isset($this->requestData['password'])
+            } elseif (
+                isset($this->requestData['password'])
                 && !$this->requestData['password']
                 && $this->requestData['create_profile']
             ) {
@@ -975,8 +963,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 $label = static::t('Field is required!');
 
                 \XLite\Core\Event::invalidElement('password', $label);
-
-            } elseif (false !== $this->valid) {
+            } elseif ($this->valid !== false) {
                 \XLite\Core\Session::getInstance()->order_create_profile = (bool)$this->requestData['create_profile'];
 
                 if (\XLite\Core\Session::getInstance()->order_create_profile) {
@@ -999,7 +986,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
             ? $this->getCart()->getOrigProfile()
             : null;
 
-        if (null !== $login && $profile) {
+        if ($login !== null && $profile) {
             $profile->setLastCheckoutEmail($login);
         }
     }
@@ -1018,17 +1005,18 @@ class Checkout extends \XLite\Controller\Customer\Cart
         $address = $this->prepareShippingAddress();
 
         if (is_array($data) || !$this->getAddressFields()) {
-            $data = is_array($data) ? $data : array();
+            $data = is_array($data) ? $data : [];
 
-            $noAddress = null === $address;
+            $noAddress = $address === null;
 
             $andAsBilling = false;
 
-            $new = new \XLite\Model\Address;
+            $new = new \XLite\Model\Address();
             $new->map($this->prepareAddressData($data, 'shipping'));
             $equal = null;
             foreach ($profile->getAddresses() as $profileAddress) {
-                if ($profileAddress->isEqualAddress($new)
+                if (
+                    $profileAddress->isEqualAddress($new)
                     && (!$address || $address->getAddressId() != $profileAddress->getAddressId())
                 ) {
                     $equal = $profileAddress;
@@ -1044,14 +1032,13 @@ class Checkout extends \XLite\Controller\Customer\Cart
             }
 
             if ($noAddress || (!$address->getIsWork() && !$address->isEqualAddress($new))) {
-
                 if (!$noAddress) {
                     $andAsBilling = $address->getIsBilling();
                     $address->setIsBilling(false);
                     $address->setIsShipping(false);
                 }
 
-                $address = new \XLite\Model\Address;
+                $address = new \XLite\Model\Address();
 
                 $address->setProfile($profile);
                 $address->setIsShipping(true);
@@ -1066,9 +1053,10 @@ class Checkout extends \XLite\Controller\Customer\Cart
 
             $address->map($this->prepareAddressData($data, 'shipping'));
 
-            if ($noAddress
+            if (
+                $noAddress
                 && (\XLite\Core\Session::getInstance()->same_address
-                    || null === \XLite\Core\Session::getInstance()->same_address
+                    || \XLite\Core\Session::getInstance()->same_address === null
                 )
                 && !$profile->getBillingAddress()
             ) {
@@ -1079,7 +1067,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
             \XLite\Core\Session::getInstance()->same_address = $this->getCart()->getProfile()->isEqualAddress();
 
             if ($noAddress) {
-                \XLite\Core\Event::createShippingAddress(array('id' => $address->getAddressId()));
+                \XLite\Core\Event::createShippingAddress(['id' => $address->getAddressId()]);
             }
         }
     }
@@ -1121,8 +1109,8 @@ class Checkout extends \XLite\Controller\Customer\Cart
                 // Link shipping and billing address
                 $address->setIsBilling(true);
             }
-
-        } elseif (isset($this->requestData['same_address'])
+        } elseif (
+            isset($this->requestData['same_address'])
             && !$this->requestData['same_address'] && $profile->isEqualAddress()
         ) {
             $this->unlinkShippingFromBilling();
@@ -1138,12 +1126,13 @@ class Checkout extends \XLite\Controller\Customer\Cart
 
             $andAsShipping = false;
 
-            $new = new \XLite\Model\Address;
+            $new = new \XLite\Model\Address();
             $new->map($this->prepareAddressData($data, 'billing'));
             $equal = null;
 
             foreach ($profile->getAddresses() as $addressEqual) {
-                if ($addressEqual->isEqualAddress($new)
+                if (
+                    $addressEqual->isEqualAddress($new)
                     && (!$address || $address->getAddressId() != $addressEqual->getAddressId())
                 ) {
                     $equal = $addressEqual;
@@ -1163,7 +1152,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
                     $address->setIsShipping(false);
                 }
 
-                $address = new \XLite\Model\Address;
+                $address = new \XLite\Model\Address();
                 $address->setProfile($profile);
                 $address->setIsBilling(true);
                 $address->setIsShipping($andAsShipping);
@@ -1183,7 +1172,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
         }
 
         if ($noAddress) {
-            \XLite\Core\Event::createBillingAddress(array('id' => $address->getAddressId()));
+            \XLite\Core\Event::createBillingAddress(['id' => $address->getAddressId()]);
         }
 
         if (
@@ -1195,9 +1184,41 @@ class Checkout extends \XLite\Controller\Customer\Cart
         }
     }
 
+    /**
+     * We are totally rely on intl_tel_input/js/intlTelInput.min.js lib
+     */
+    protected function updateAddressesPhonesToIntl(): void
+    {
+        $nationalIntlPairs = [];
+        $requestData       = $this->requestData;
+        foreach (['shipping', 'billing'] as $type) {
+            $requestAddress = $requestData["{$type}Address"] ?? [];
+            if (
+                !empty($requestData["{$type}Addressphone_intl_phone_number"])
+                && !empty($requestAddress['phone'])
+                && $requestAddress['phone'] !== $requestData["{$type}Addressphone_intl_phone_number"]
+            ) {
+                $nationalIntlPairs[$requestData["{$type}Addressphone_intl_phone_number"]] = $requestAddress['phone'];
+            }
+        }
+
+        if (empty($nationalIntlPairs)) {
+            return;
+        }
+        $addresses = $this->getCartProfile()->getAddresses();
+
+        /** @var \XLite\Model\Address[] $addresses */
+        foreach ($addresses as $requestAddress) {
+            $origPhone = $requestAddress->getFieldValue('phone')->getValue();
+            if (isset($nationalIntlPairs[$origPhone])) {
+                $requestAddress->setPhone($nationalIntlPairs[$origPhone]);
+            }
+        }
+    }
+
     /**
      * Prepares shipping address to update
-     * 
+     *
      * @return \XLite\Model\Address
      */
     protected function prepareShippingAddress()
@@ -1238,7 +1259,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
     {
         unset($data['save_in_book']);
 
-        $requiredFields = 'shipping' === $type
+        $requiredFields = $type === 'shipping'
             ? \XLite\Core\Database::getRepo('XLite\Model\AddressField')->getShippingRequiredFields()
             : \XLite\Core\Database::getRepo('XLite\Model\AddressField')->getBillingRequiredFields();
 
@@ -1287,11 +1308,10 @@ class Checkout extends \XLite\Controller\Customer\Cart
                     'No payment method selected'
                 );
             }
-
         } else {
             $cart = $this->getCart();
             $profile = $cart->getProfile();
-            if (null !== $profile) {
+            if ($profile !== null) {
                 $profile->setLastPaymentId($pm->getMethodId());
             }
 
@@ -1316,12 +1336,11 @@ class Checkout extends \XLite\Controller\Customer\Cart
     {
         $methodId = \XLite\Core\Request::getInstance()->methodId;
 
-        if (null !== $methodId) {
+        if ($methodId !== null) {
             $cart = $this->getCart();
             $cart->setLastShippingId($methodId);
             $cart->setShippingId($methodId);
             $this->updateCart();
-
         } else {
             $this->valid = false;
         }
@@ -1384,7 +1403,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     protected function getCartFingerprintExclude()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -1394,7 +1413,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     protected function isServiceController()
     {
-        return 'return' === $this->getAction();
+        return $this->getAction() === 'return';
     }
 
     /**
