@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,22 +7,29 @@
 
 namespace XLite\Controller\Customer;
 
+use XLite\Core\Auth;
+use XLite\Core\Converter;
+use XLite\Core\Session;
+use XLite\InjectLoggerTrait;
+
 /**
  * Login page controller
  */
 class Login extends \XLite\Controller\Customer\ACustomer
 {
+    use InjectLoggerTrait;
+
     /**
      * Index in request array; the secret token used for authorization
      */
-    const SECURE_TOKEN = 'secureToken';
+    public const SECURE_TOKEN = 'secureToken';
 
     /**
      * Controller parameters
      *
      * @var array
      */
-    protected $params = array('target', 'mode');
+    protected $params = ['target', 'mode'];
 
     /**
      * Profile found by login (without password check)
@@ -90,7 +96,7 @@ class Login extends \XLite\Controller\Customer\ACustomer
     {
         if (
             \XLite\Core\Auth::getInstance()->isLogged()
-            && 'logoff' !== \XLite\Core\Request::getInstance()->{static::PARAM_ACTION}
+            && \XLite\Core\Request::getInstance()->{static::PARAM_ACTION} !== 'logoff'
         ) {
             $this->setHardRedirect(true);
             $this->setReturnURL($this->buildURL());
@@ -106,7 +112,7 @@ class Login extends \XLite\Controller\Customer\ACustomer
      */
     public function isSecure()
     {
-        return 'logoff' !== \XLite\Core\Request::getInstance()->action
+        return \XLite\Core\Request::getInstance()->action !== 'logoff'
             ? \XLite\Core\Config::getInstance()->Security->customer_security
             : parent::isSecure();
     }
@@ -118,12 +124,8 @@ class Login extends \XLite\Controller\Customer\ACustomer
      */
     public function redirectFromLogin()
     {
-        $url = $this->getRedirectFromLoginURL();
-
-        if (isset($url)) {
-            \XLite\Core\CMSConnector::isCMSStarted()
-                ? \XLite\Core\Operator::redirect($url, true)
-                : $this->setReturnURL($url);
+        if ($url = $this->getRedirectFromLoginURL()) {
+            $this->setReturnURL($url);
         }
     }
 
@@ -145,10 +147,11 @@ class Login extends \XLite\Controller\Customer\ACustomer
     protected function getRedirectFromLoginURL()
     {
         $url = null;
-        if ($this->profile instanceof \XLite\Model\Profile
+        if (
+            $this->profile instanceof \XLite\Model\Profile
             && $this->profile->isAdmin()
         ) {
-            $url = \XLite\Core\Converter::buildURL('', '', [], \XLite::getAdminScript());
+            $url = Converter::buildURL('', '', [], \XLite::getAdminScript());
         }
 
         return $url;
@@ -172,10 +175,8 @@ class Login extends \XLite\Controller\Customer\ACustomer
             // Log in is impossible: return 'ACCESS DENIED' message
             $result = \XLite\Core\Auth::RESULT_ACCESS_DENIED;
             $this->foundProfile = null;
-
         } elseif ($this->foundProfile && $this->foundProfile->isAdmin()) {
             $result = \XLite\Core\Auth::getInstance()->loginAdministrator($data['login'], $data['password']);
-
         } else {
             // Try to log in
             $result = \XLite\Core\Auth::getInstance()->login($data['login'], $data['password'], $token);
@@ -252,24 +253,20 @@ class Login extends \XLite\Controller\Customer\ACustomer
         $this->profile = $this->performLogin();
 
         if (!($this->profile instanceof \XLite\Model\Profile)) {
-
             $this->addLoginFailedMessage($this->profile);
 
-            \XLite\Logger::getInstance()
-                ->log(sprintf('Log in action is failed (%s)', \XLite\Core\Request::getInstance()->login), LOG_WARNING);
+            $this->getLogger()->warning(sprintf('Log in action is failed (%s)', \XLite\Core\Request::getInstance()->login));
 
             if ($this->isNeedFailureRedirect()) {
                 // Redirect to admin login page is needed if founcProfile is an administrator profile
                 $url = \XLite\Core\URLManager::getShopURL(
-                    \XLite\Core\Converter::buildURL('login', '', array(), \XLite::getAdminScript())
+                    Converter::buildURL('login', '', [], \XLite::getAdminScript())
                 );
                 $this->setReturnURL($url);
                 $this->setHardRedirect(true);
-
             } else {
                 $this->set('valid', false);
             }
-
         } else {
             $profileCart = $this->getCart();
 
@@ -280,11 +277,11 @@ class Login extends \XLite\Controller\Customer\ACustomer
 
             if (!$this->getReturnURL() && !$profileCart->isEmpty()) {
                 $this->setReturnURL(
-                    \XLite\Core\Converter::buildURL('cart')
+                    Converter::buildURL('cart')
                 );
-            } elseif (strpos($this->getReturnURL(), \XLite\Core\Converter::buildURL('login')) !== false) {
+            } elseif (strpos($this->getReturnURL(), Converter::buildURL('login')) !== false) {
                 $this->setReturnURL(
-                    \XLite\Core\Converter::buildFullURL('main')
+                    Converter::buildFullURL('main')
                 );
             }
 
@@ -320,12 +317,12 @@ class Login extends \XLite\Controller\Customer\ACustomer
     {
         if (\XLite\Core\Auth::getInstance()->isOperatingAsUserMode()) {
             $this->setReturnURL(
-                \XLite\Core\Converter::buildURL(
+                Converter::buildURL(
                     'profile',
                     '',
-                    array(
+                    [
                         'profile_id' => \XLite\Core\Auth::getInstance()->getOperatingAs()
-                    ),
+                    ],
                     \XLite::getAdminScript()
                 )
             );
@@ -337,7 +334,7 @@ class Login extends \XLite\Controller\Customer\ACustomer
 
             \Includes\Utils\Session::clearAdminCookie();
 
-            $this->setReturnURL(\XLite\Core\Converter::buildFullURL());
+            $this->setReturnURL(Converter::buildFullURL());
 
             $this->getCart()->logoff();
             $this->updateCart();
@@ -364,8 +361,8 @@ class Login extends \XLite\Controller\Customer\ACustomer
     protected function getTimeLeftToUnlock()
     {
         if (!isset($this->timeLeftToUnlock)) {
-            $this->timeLeftToUnlock = \XLite\Core\Session::getInstance()->dateOfLockLogin
-                ? \XLite\Core\Session::getInstance()->dateOfLockLogin + \XLite\Core\Auth::TIME_OF_LOCK_LOGIN - \XLite\Core\Converter::time()
+            $this->timeLeftToUnlock = Session::getInstance()->dateOfLockLogin
+                ? Session::getInstance()->dateOfLockLogin + Auth::getLockLoginDuration() - Converter::time()
                 : 0;
         }
 
@@ -381,7 +378,7 @@ class Login extends \XLite\Controller\Customer\ACustomer
      */
     protected function addLoginFailedMessage($result)
     {
-        if (in_array($result, array(\XLite\Core\Auth::RESULT_ACCESS_DENIED, \XLite\Core\Auth::RESULT_PASSWORD_NOT_EQUAL))) {
+        if (in_array($result, [\XLite\Core\Auth::RESULT_ACCESS_DENIED, \XLite\Core\Auth::RESULT_PASSWORD_NOT_EQUAL])) {
             \XLite\Core\Event::invalidForm('login-form', static::t('Invalid login or password. You can use forgot password form to create a new password.'));
         } elseif ($result == \XLite\Core\Auth::RESULT_LOGIN_IS_LOCKED) {
             \XLite\Core\TopMessage::addError('Login is locked out');
