@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,9 +15,9 @@ class Profile extends \XLite\Controller\Customer\ACustomer
     /**
      * Types of model form
      */
-    const SECTIONS_MAIN      = 'main';
-    const SECTIONS_ADDRESSES = 'addresses';
-    const SECTIONS_ALL       = 'all';
+    public const SECTIONS_MAIN      = 'main';
+    public const SECTIONS_ADDRESSES = 'addresses';
+    public const SECTIONS_ALL       = 'all';
 
     /**
      * Return value for the "register" mode param
@@ -41,7 +40,7 @@ class Profile extends \XLite\Controller\Customer\ACustomer
             $this->setReturnURL($this->buildURL('login'));
         } elseif ($this->isLogged() && $this->isRegisterMode()) {
             $this->setReturnURL(
-                call_user_func_array(array($this, 'buildURL'), $this->getActionRegisterSuccessURL())
+                call_user_func_array([$this, 'buildURL'], $this->getActionRegisterSuccessURL())
             );
         }
 
@@ -78,10 +77,8 @@ class Profile extends \XLite\Controller\Customer\ACustomer
     {
         if ($this->isRegisterMode()) {
             $title = static::t('New account');
-
-        } elseif ('delete' == \XLite\Core\Request::getInstance()->mode) {
+        } elseif (\XLite\Core\Request::getInstance()->mode == 'delete') {
             $title = static::t('Delete account');
-
         } else {
             $title = static::t('Account details');
         }
@@ -96,7 +93,7 @@ class Profile extends \XLite\Controller\Customer\ACustomer
      */
     public function isTitleVisible()
     {
-        return 'delete' == \XLite\Core\Request::getInstance()->mode;
+        return \XLite\Core\Request::getInstance()->mode == 'delete';
     }
 
     /**
@@ -191,15 +188,13 @@ class Profile extends \XLite\Controller\Customer\ACustomer
         if ($this->isActionError()) {
             $this->postprocessActionRegisterFail();
             $this->setReturnURL(
-                call_user_func_array(array($this, 'buildURL'), $this->getActionRegisterFailURL())
+                call_user_func_array([$this, 'buildURL'], $this->getActionRegisterFailURL())
             );
-
-
         } else {
             $this->postprocessActionRegisterSuccess();
 
             $this->setReturnURL(
-                call_user_func_array(array($this, 'buildURL'), $this->getActionRegisterSuccessURL())
+                call_user_func_array([$this, 'buildURL'], $this->getActionRegisterSuccessURL())
             );
         }
     }
@@ -220,11 +215,11 @@ class Profile extends \XLite\Controller\Customer\ACustomer
      */
     protected function getActionRegisterFailURL()
     {
-        return array(
+        return [
             'profile',
             '',
-            array('mode' => static::getRegisterMode())
-        );
+            ['mode' => static::getRegisterMode()]
+        ];
     }
 
     /**
@@ -252,11 +247,11 @@ class Profile extends \XLite\Controller\Customer\ACustomer
      */
     protected function getActionRegisterSuccessURL()
     {
-        return array(
+        return [
             'address_book',
             '',
-            array('profile_id' => $this->getModelForm()->getProfileId(false)),
-        );
+            ['profile_id' => $this->getModelForm()->getProfileId(false)],
+        ];
     }
 
     /**
@@ -266,7 +261,7 @@ class Profile extends \XLite\Controller\Customer\ACustomer
      */
     protected function doActionUpdate()
     {
-        $result = $this->getModelForm()->performAction('update');
+        $this->getModelForm()->performAction('update');
     }
 
     /**
@@ -278,7 +273,6 @@ class Profile extends \XLite\Controller\Customer\ACustomer
     {
         if ($this->isRegisterMode()) {
             $this->doActionRegister();
-
         } else {
             $this->doActionUpdate();
         }
@@ -297,7 +291,6 @@ class Profile extends \XLite\Controller\Customer\ACustomer
             );
 
             $result = false;
-
         } else {
             $userLogin = $this->getModelForm()->getModelObject()->getLogin();
 
