@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -44,7 +43,7 @@ class Search extends \XLite\Controller\Customer\ACustomer
         $className = $this->getItemsListClass();
         $searchConditionsRequestNames = $className::getSearchParams();
         $data = $this->prepareSearchData();
-        foreach ($searchConditionsRequestNames as $name => $condition) {
+        foreach ($searchConditionsRequestNames as $condition) {
             if (isset($data[$condition])) {
                 $sessionSearchConditions[$condition] = $data[$condition];
             }
@@ -94,8 +93,8 @@ class Search extends \XLite\Controller\Customer\ACustomer
     protected function doNoAction()
     {
         Session::getInstance()->{$this->getSessionCellName()} = array_merge(
-            $this->prepareSearchData(),
-            $this->getSessionSearchConditions()
+            $this->getSessionSearchConditions(),
+            $this->prepareSearchData()
         );
 
         parent::doNoAction();
@@ -134,7 +133,7 @@ class Search extends \XLite\Controller\Customer\ACustomer
             ProducsSearch::PARAM_SEARCH_IN_SUBCATS,
         ];
 
-        foreach ($searchParams as $modelParam => $requestParam) {
+        foreach ($searchParams as $requestParam) {
             if (isset(\XLite\Core\Request::getInstance()->$requestParam)) {
                 $productsSearch[$requestParam] = \XLite\Core\Request::getInstance()->$requestParam;
             }
@@ -156,6 +155,8 @@ class Search extends \XLite\Controller\Customer\ACustomer
             $productsSearch
         );
 
+        $productsSearch['isHidden'] = true;
+
         Session::getInstance()->{$this->getAdvancedPanelCellName()} = array_intersect(array_keys($productsSearch), array_values($advancedParams));
 
         return $productsSearch;
@@ -180,5 +181,4 @@ class Search extends \XLite\Controller\Customer\ACustomer
     {
         return 'show_advanced_search_panel';
     }
-
 }
