@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,11 @@
 
 namespace XLite\Core;
 
+use Includes\Utils\ConfigParser;
+use XCart\Container;
+use XLite\Core\Cache\ExecuteCachedTrait;
+use XLite\Core\Exception\FatalException;
+use XLite\InjectLoggerTrait;
 use XLite\Model\Cart;
 use XLite\Model\Profile;
 
@@ -16,55 +20,54 @@ use XLite\Model\Profile;
  */
 class Auth extends \XLite\Base
 {
+    use ExecuteCachedTrait;
+    use InjectLoggerTrait;
+
     /**
      * Result codes
      */
-    const RESULT_USER_EXISTS          = 1;
-    const RESULT_REGISTER_SUCCESS     = 2;
-    const RESULT_ACCESS_DENIED        = 3;
-    const RESULT_LAST_ADMIN_ACCOUNT   = 4;
-    const RESULT_LOGIN_IS_LOCKED      = 5;
-    const RESULT_PROFILE_IS_ANONYMOUS = 6;
-    const RESULT_PASSWORD_NOT_EQUAL   = 7;
-    const RESULT_INVALID_SECURE_HASH  = 8;
+    public const RESULT_USER_EXISTS          = 1;
+    public const RESULT_REGISTER_SUCCESS     = 2;
+    public const RESULT_ACCESS_DENIED        = 3;
+    public const RESULT_LAST_ADMIN_ACCOUNT   = 4;
+    public const RESULT_LOGIN_IS_LOCKED      = 5;
+    public const RESULT_PROFILE_IS_ANONYMOUS = 6;
+    public const RESULT_PASSWORD_NOT_EQUAL   = 7;
+    public const RESULT_INVALID_SECURE_HASH  = 8;
 
     /**
      * Session var name to keep the secret token
      */
-    const SESSION_SECURE_HASH_CELL = 'secureHashCell';
+    public const SESSION_SECURE_HASH_CELL = 'secureHashCell';
 
     /**
      * Default hash algorithm
      */
-    const DEFAULT_HASH_ALGO = 'SHA512';
+    public const DEFAULT_HASH_ALGO = 'SHA512';
 
     /**
-     * Max count of login attempt
+     * Recent login cookie name
      */
-    const MAX_COUNT_OF_LOGIN_ATTEMPTS = 5;
+    public const RECENT_LOGIN_COOKIE_NAME = 'recent_login';
 
     /**
-     * Time of lock login (sec)
+     * Auth token argument name
      */
-    const TIME_OF_LOCK_LOGIN = 120;
-
-    /**
-     * Recent login cookie name 
-     */
-    const RECENT_LOGIN_COOKIE_NAME = 'recent_login';
+    public const AUTH_TOKEN = 'auth_token';
 
     /**
      * The list of session vars that must be cleared on logoff
      *
      * @var array
      */
-    protected $sessionVarsToClear = array(
+    protected $sessionVarsToClear = [
         'profile_id',
         'anonymous',
         'closedBlocks',
         'createProfilePassword',
         'dateOfLockLogin',
-    );
+        'isAdmin'
+    ];
 
     /**
      * Profile (cache)
@@ -80,6 +83,16 @@ class Auth extends \XLite\Base
      */
     protected $membershipId;
 
+    public static function getFailedLoginAttemptsMaxCount()
+    {
+        return ConfigParser::getOptions(['authentication', 'failed_login_attempts_max_count']);
+    }
+
+    public static function getLockLoginDuration()
+    {
+        return ConfigParser::getOptions(['authentication', 'lock_login_duration']);
+    }
+
     /**
      * Encrypts password (calculates MD5 hash)
      *
@@ -91,11 +104,10 @@ class Auth extends \XLite\Base
     public static function comparePassword($hash, $password)
     {
         $parts = explode(':', $hash, 2);
-        if (1 == count($parts)) {
+        if (count($parts) == 1) {
             $algo = 'MD5';
-
         } else {
-            list($algo, $hash) = $parts;
+            [$algo, $hash] = $parts;
         }
 
         return static::encryptPassword($password, $algo) == $algo . ':' . $hash;
@@ -132,13 +144,12 @@ class Auth extends \XLite\Base
      */
     protected static function encryptPasswordSHA512($password)
     {
-        if (\XLite::getInstance()->getOptions(array('installer_details', 'shared_secret_key'))) {
+        if (ConfigParser::getOptions(['installer_details', 'shared_secret_key'])) {
             $result = hash_hmac(
                 'sha512',
                 $password,
-                strval(\XLite::getInstance()->getOptions(array('installer_details', 'shared_secret_key')))
+                (string) ConfigParser::getOptions(['installer_details', 'shared_secret_key'])
             );
-
         } else {
             $result = hash('sha512', $password);
         }
@@ -170,10 +181,6 @@ class Auth extends \XLite\Base
         $result = $profile->isPersistent();
 
         if ($result) {
-
-            // Restart session
-            Session::getInstance()->restart($withCells);
-
             $loginTime = Converter::time();
 
             // Check for the first time login
@@ -192,7 +199,7 @@ class Auth extends \XLite\Base
             $profile->update();
 
             // Save profile Id in session
-            Session::getInstance()->profile_id = $profile->getProfileId();
+            Session::getInstance()->setProfile($profile);
             Session::getInstance()->forceChangePassword = $profile->getForceChangePassword();
 
             // Save login in cookies
@@ -238,10 +245,8 @@ class Auth extends \XLite\Base
 
         // Check for the valid parameters
         if (!empty($login) && !empty($password)) {
-
             if (isset($secureHash) && !$this->checkSecureHash($secureHash)) {
                 $result = static::RESULT_INVALID_SECURE_HASH;
-
             } else {
                 // Initialize order Id
                 $orderId = Request::getInstance()->anonymous
@@ -255,35 +260,48 @@ class Auth extends \XLite\Base
                     $orderId
                 );
 
+                if ($this->hasLoginLock($profile)) {
+                    $result = static::RESULT_LOGIN_IS_LOCKED;
+
                 // Check annonymous state - anonymous use cannot login
-                if (isset($profile) && !$orderId && $profile->getAnonymous()) {
+                } elseif (isset($profile) && !$orderId && $profile->getAnonymous()) {
                     $result = static::RESULT_PROFILE_IS_ANONYMOUS;
 
                 // Check password - password has must equal
                 } elseif (isset($profile) && !isset($secureHash) && !static::comparePassword($profile->getPassword(), $password)) {
                     $result = static::RESULT_PASSWORD_NOT_EQUAL;
-
                 } elseif (isset($profile)) {
                     $result = true;
                 }
-
-                if ($profile && $profile->isAdmin()) {
-                    if (Converter::time() < (Session::getInstance()->dateOfLockLogin + static::TIME_OF_LOCK_LOGIN)) {
-                        $result = static::RESULT_LOGIN_IS_LOCKED;
-
-                    } elseif (
-                        $profile
-                        && Converter::time() < ($profile->getDateOfLoginAttempt() + static::TIME_OF_LOCK_LOGIN)
-                        && static::MAX_COUNT_OF_LOGIN_ATTEMPTS <= $profile->getCountOfLoginAttempts()
-                    ) {
-                        Session::getInstance()->dateOfLockLogin = $profile->getDateOfLoginAttempt();
-                        $result = static::RESULT_LOGIN_IS_LOCKED;
-                    }
-                }
             }
         }
 
-        return array($profile, $result);
+        return [$profile, $result];
+    }
+
+    /**
+     * Check login attempts count
+     *
+     * @param Profile|null $profile
+     *
+     * @return boolean
+     */
+    public function hasLoginLock($profile)
+    {
+        if (Converter::time() < (Session::getInstance()->dateOfLockLogin + static::getLockLoginDuration())) {
+            return true;
+        }
+
+        if (
+            $profile
+            && Converter::time() < ($profile->getDateOfLoginAttempt() + static::getLockLoginDuration())
+            && $profile->getCountOfLoginAttempts() >= static::getFailedLoginAttemptsMaxCount()
+        ) {
+            Session::getInstance()->dateOfLockLogin = $profile->getDateOfLoginAttempt();
+            return true;
+        }
+
+        return false;
     }
 
     /**
@@ -300,26 +318,15 @@ class Auth extends \XLite\Base
         $result = static::RESULT_ACCESS_DENIED;
 
         if (!empty($login) && !empty($password)) {
-
-            list($profile, $result) = $this->checkLoginPassword($login, $password, $secureHash);
+            [$profile, $result] = $this->checkLoginPassword($login, $password, $secureHash);
 
             if ($result === static::RESULT_INVALID_SECURE_HASH) {
                 // TODO - potential attack; send the email to admin
-                $this->doDie('Trying to log in using an invalid secure hash string.');
+                throw new FatalException('Trying to log in using an invalid secure hash string.');
             }
 
             if (isset($profile) && $result === static::RESULT_PASSWORD_NOT_EQUAL) {
-                $countOfLoginAttempts = Converter::time() < ($profile->getDateOfLoginAttempt() + static::TIME_OF_LOCK_LOGIN)
-                    ? $profile->getCountOfLoginAttempts() + 1
-                    : 1;
-                $profile->setCountOfLoginAttempts($countOfLoginAttempts);
-                $profile->setDateOfLoginAttempt(Converter::time());
-                $profile->update();
-
-                if (\XLite::isAdminZone() && static::MAX_COUNT_OF_LOGIN_ATTEMPTS <= $profile->getCountOfLoginAttempts()) {
-                    Session::getInstance()->dateOfLockLogin = Converter::time();
-                    Mailer::sendFailedAdminLoginAdmin($profile->getLogin());
-                }
+                $this->processFailedLogin($profile);
                 $profile = null;
             }
 
@@ -339,7 +346,6 @@ class Auth extends \XLite\Base
 
             // Return profile object if it's ok
             if (isset($profile) && $this->loginProfile($profile)) {
-
                 \XLite\Core\Session::getInstance()->setLanguage($profile->getLanguage(), 'admin');
                 \XLite\Core\Session::getInstance()->setLanguage($profile->getLanguage(), 'customer');
 
@@ -365,6 +371,24 @@ class Auth extends \XLite\Base
         return $result;
     }
 
+    public function processFailedLogin(Profile $profile): void
+    {
+        $countOfLoginAttempts = Converter::time() < ($profile->getDateOfLoginAttempt() + static::getLockLoginDuration())
+            ? $profile->getCountOfLoginAttempts() + 1
+            : 1;
+        $profile->setCountOfLoginAttempts($countOfLoginAttempts);
+        $profile->setDateOfLoginAttempt(Converter::time());
+        $profile->update();
+
+        if ($profile->getCountOfLoginAttempts() >= static::getFailedLoginAttemptsMaxCount()) {
+            Session::getInstance()->dateOfLockLogin = Converter::time();
+
+            if (\XLite::isAdminZone()) {
+                Mailer::sendFailedAdminLoginAdmin($profile->getLogin());
+            }
+        }
+    }
+
     /**
      * Logs off the currently logged profile
      *
@@ -404,7 +428,7 @@ class Auth extends \XLite\Base
     public function isAnonymous()
     {
         $profile = $this->getProfile();
-        return $profile ? $profile->getAnonymous() : false;
+        return $profile ? $profile->getAnonymous() : true;
     }
 
     /**
@@ -424,6 +448,7 @@ class Auth extends \XLite\Base
     public function setOperatingAs(Profile $profile)
     {
         Session::getInstance()->operating_as_profile_id = $profile->getProfileId();
+        unset(Session::getInstance()->order_id);
     }
 
     /**
@@ -438,7 +463,7 @@ class Auth extends \XLite\Base
 
     /**
      * Check if profile in operating as user mode
-     * 
+     *
      * @return boolean
      */
     public function isOperatingAsUserMode()
@@ -455,11 +480,7 @@ class Auth extends \XLite\Base
      */
     public function getOperateAsUserPaymentMethods()
     {
-        $phoneOrdering = Database::getRepo('XLite\Model\Payment\Method')->findOneBy(
-            array(
-                'service_name' => 'PhoneOrdering'
-            )
-        );
+        $phoneOrdering = Database::getRepo('XLite\Model\Payment\Method')->findByServiceName('PhoneOrdering');
 
         return array_filter([
             $phoneOrdering
@@ -476,18 +497,18 @@ class Auth extends \XLite\Base
     public function getProfile($profileId = null)
     {
         if (isset($profileId)) {
+            /** @var Profile $profile */
             $profile = Database::getRepo('XLite\Model\Profile')->find($profileId);
             $result = $this->checkProfile($profile) ? $profile : null;
-
         } else {
-
             if (!$this->profile['isInitialized']) {
                 $this->resetProfileCache();
                 $this->profile['isInitialized'] = true;
 
+                /** @var Profile|null $entity */
                 $entity = null;
 
-                if ((bool) $this->getOperatingAs() && !\XLite::isAdminScript()) {
+                if ((bool) $this->getOperatingAs() && !\XLite::isAdminZone()) {
                     $entity = Database::getRepo('XLite\Model\Profile')->find($this->getOperatingAs());
                 }
 
@@ -500,7 +521,31 @@ class Auth extends \XLite\Base
                     $entity = Database::getRepo('XLite\Model\Profile')->find($this->getStoredProfileId());
                 }
 
+                if (
+                    $entity
+                    && (
+                        $entity->isDisabled()
+                        || (
+                            isset(Session::getInstance()->salt)
+                            && Session::getInstance()->salt !== $entity->getSalt()
+                            && !$this->getOperatingAs()
+                        )
+                        || (
+                            $this->isAdmin($entity)
+                            && Session::getInstance()->isAdminSessionExpired()
+                        )
+                    )
+                ) {
+                    Session::getInstance()->invalidate();
+                    $entity = null;
+                }
+
                 $this->profile['object'] = $entity;
+
+                if ($entity && \XLite::isAdminZone() && $this->isAdmin($entity)) {
+                    $this->rememberLogin($entity->getLogin());
+                    \Includes\Utils\Session::setAdminCookie();
+                }
             }
 
             $result = $this->profile['object'];
@@ -553,7 +598,7 @@ class Auth extends \XLite\Base
     /**
      * Checks whether the currently logged user is an administrator
      *
-     * @param Profile $profile User profile OPTIONAL
+     * @param Profile|null $profile User profile OPTIONAL
      *
      * @return boolean
      */
@@ -570,7 +615,7 @@ class Auth extends \XLite\Base
     /**
      * Return true if profile has permissions to manage admin profiles
      *
-     * @param Profile $profile User profile OPTIONAL
+     * @param Profile|null $profile User profile OPTIONAL
      *
      * @return boolean
      */
@@ -582,7 +627,7 @@ class Auth extends \XLite\Base
 
         return $profile
             && $this->isAdmin($profile)
-            && $profile->isPermissionAllowed('manage admins');
+            && $profile->isPermissionAllowed('ROLE_MANAGE_ADMINS');
     }
 
     /**
@@ -595,7 +640,7 @@ class Auth extends \XLite\Base
     public function getAccessLevel($type)
     {
         return in_array($type, $this->getUserTypes())
-            ? call_user_func(array($this, 'get' . $type . 'Accesslevel'))
+            ? call_user_func([$this, 'get' . $type . 'Accesslevel'])
             : null;
     }
 
@@ -626,10 +671,10 @@ class Auth extends \XLite\Base
      */
     public function getUserTypes()
     {
-        return array(
+        return [
             'customer' => 'Customer',
             'admin'    => 'Admin',
-        );
+        ];
     }
 
     /**
@@ -639,7 +684,7 @@ class Auth extends \XLite\Base
      */
     public function getAccessLevelsList()
     {
-        return array_map(array($this, 'getAccessLevel'), $this->getUserTypes());
+        return array_map([$this, 'getAccessLevel'], $this->getUserTypes());
     }
 
     /**
@@ -688,7 +733,6 @@ class Auth extends \XLite\Base
         $profile = $this->login($login, $password);
 
         if ($profile instanceof Profile && !$profile->isAdmin()) {
-
             // Logoff user from session
             $this->logoff();
 
@@ -715,7 +759,7 @@ class Auth extends \XLite\Base
     {
         // Check whether resource is valid (has getAccessLevel() method)
         if (!method_exists($resource, 'getAccessLevel')) {
-            $this->doDie('Auth::isAuthorized(): Authorization failed: resource invalid');
+            throw new FatalException('Auth::isAuthorized(): Authorization failed: resource invalid');
         }
 
         $profile = $this->getProfile();
@@ -730,7 +774,7 @@ class Auth extends \XLite\Base
      */
     protected function resetProfileCache()
     {
-        $this->profile = array('isInitialized' => false, 'object' => null);
+        $this->profile = ['isInitialized' => false, 'object' => null];
     }
 
     /**
@@ -812,6 +856,10 @@ class Auth extends \XLite\Base
     {
         parent::__construct();
 
+        if ($token = $this->getRequestAuthToken()) {
+            $this->loginByToken($token);
+        }
+
         $this->resetProfileCache();
     }
 
@@ -826,9 +874,14 @@ class Auth extends \XLite\Base
      */
     public function isPermissionAllowed($code)
     {
-        $profile = $this->getProfile();
+        if (!str_starts_with($code, 'ROLE_')) {
+            $code = 'ROLE_' . strtoupper(str_replace([' ', '[', ']'], ['_', '', ''], $code));
+            $this->getLogger()->debug(
+                sprintf('The code should begin with the prefix of the ROLE_, perhaps you meant: "%s"', $code)
+            );
+        }
 
-        return $profile && $profile->isPermissionAllowed($code);
+        return Container::getServiceLocator()->getAuthorizationChecker()->isGranted($code);
     }
 
     /**
@@ -852,7 +905,7 @@ class Auth extends \XLite\Base
     {
         $profile = $this->getProfile();
 
-        return $profile && call_user_func_array(array($profile, __METHOD__), func_get_args());
+        return $profile && call_user_func_array([$profile, __METHOD__], func_get_args());
     }
 
     // }}}
@@ -868,7 +921,8 @@ class Auth extends \XLite\Base
     public function isAccessibleStorefront()
     {
         return !$this->isClosedStorefront()
-            || ($this->getRequestShopKey() == $this->getShopKey());
+            || ($this->getRequestShopKey() === $this->getShopKey())
+            || $this->hasRootAccess();
     }
 
     /**
@@ -879,7 +933,7 @@ class Auth extends \XLite\Base
      */
     public function isClosedStorefront()
     {
-        return 'Y' == Config::getInstance()->Internal->shop_closed;
+        return (bool) Config::getInstance()->Internal->shop_closed;
     }
 
     /**
@@ -891,6 +945,7 @@ class Auth extends \XLite\Base
     {
         $this->changeStorefrontActivity(true);
         $this->cleanShopKey();
+        \XLite\Core\Config::updateInstance();
     }
 
     /**
@@ -900,8 +955,9 @@ class Auth extends \XLite\Base
      */
     public function closeStorefront()
     {
-        $this->changeStorefrontActivity(false);
         $this->generateShopKey();
+        $this->changeStorefrontActivity(false);
+        \XLite\Core\Config::updateInstance();
     }
 
     /**
@@ -924,11 +980,11 @@ class Auth extends \XLite\Base
     protected function changeStorefrontActivity($status = true)
     {
         Database::getRepo('\XLite\Model\Config')->createOption(
-            array(
+            [
                 'category' => 'Internal',
                 'name'     => 'shop_closed',
-                'value'    => true === $status ? 'N' : 'Y'
-            )
+                'value'    => $status === true ? 'N' : 'Y'
+            ]
         );
         Config::updateInstance();
     }
@@ -961,11 +1017,11 @@ class Auth extends \XLite\Base
     protected function storeShopKey($value = '')
     {
         Database::getRepo('\XLite\Model\Config')->createOption(
-            array(
+            [
                 'category' => 'Internal',
                 'name'     => 'shop_key',
                 'value'    => $value,
-            )
+            ]
         );
     }
 
@@ -984,7 +1040,6 @@ class Auth extends \XLite\Base
 
         if ($request->shopKey) {
             $result = $session->shopKey = $request->shopKey;
-
         } elseif ($session->shopKey) {
             $result = $session->shopKey;
         }
@@ -998,13 +1053,13 @@ class Auth extends \XLite\Base
 
     /**
      * Return array of \XLite\Model\AccessControlCell
-     * 
+     *
      * @return \XLite\Model\AccessControlCell[]
      */
     public function getAccessControlCells()
     {
         $session = Session::getInstance();
-        
+
         return $session->getAccessControlCells();
     }
 
@@ -1045,4 +1100,66 @@ class Auth extends \XLite\Base
     }
 
     // }}}
+
+    /**
+     * @return string|null
+     */
+    public function getRequestAuthToken(): ?string
+    {
+        return Request::getInstance()->{self::AUTH_TOKEN};
+    }
+
+    /**
+     * @return string|null
+     */
+    public function getAuthToken(): ?string
+    {
+        $profile = $this->getProfile();
+
+        return $this->executeCachedRuntime(function () use ($profile) {
+            return $this->isLogged()
+                ? $this->createToken($profile)
+                : null;
+        }, [__CLASS__, __METHOD__, $profile]);
+    }
+
+    /**
+     * @param Profile $profile
+     *
+     * @return string|null
+     */
+    public function createToken(Profile $profile): ?string
+    {
+        return AuthToken::generate([
+            'profile_id' => $profile->getProfileId(),
+            'exp'        => AuthToken::getDefaultExpirationTime()
+        ]);
+    }
+
+    /**
+     * @param $token
+     *
+     * @return bool
+     */
+    public function loginByToken($token): bool
+    {
+        try {
+            $data = AuthToken::decode($token);
+
+            $result = $data->profile_id
+                && $this->getStoredProfileId() !== $data->profile_id
+                && ($profile = Database::getRepo('XLite\Model\Profile')->find($data->profile_id))
+                && $this->loginProfile($profile);
+
+            if ($result) {
+                Session::getInstance()->set('profile_id', $profile->getProfileId());
+                Session::getInstance()->set('salt', $profile->getSalt());
+            }
+        } catch (\Exception $e) {
+            TopMessage::addError('Login by token is failed');
+            $this->getLogger()->error($e->getMessage(), ['trace' => $e->getTrace()]);
+        }
+
+        return $result ?? false;
+    }
 }
