@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,7 +17,7 @@ class CommonCell extends \Includes\DataStructure\Cell implements \Iterator
      *
      * @return mixed
      */
-    public function current()
+    public function current(): mixed
     {
         return current($this->properties);
     }
@@ -28,7 +27,7 @@ class CommonCell extends \Includes\DataStructure\Cell implements \Iterator
      *
      * @return mixed
      */
-    public function key()
+    public function key(): mixed
     {
         return key($this->properties);
     }
@@ -38,6 +37,7 @@ class CommonCell extends \Includes\DataStructure\Cell implements \Iterator
      *
      * @return mixed (ignored)
      */
+    #[\ReturnTypeWillChange]
     public function next()
     {
         return next($this->properties);
@@ -48,6 +48,7 @@ class CommonCell extends \Includes\DataStructure\Cell implements \Iterator
      *
      * @return mixed (ignored)
      */
+    #[\ReturnTypeWillChange]
     public function rewind()
     {
         return reset($this->properties);
@@ -58,7 +59,7 @@ class CommonCell extends \Includes\DataStructure\Cell implements \Iterator
      *
      * @return boolean
      */
-    public function valid()
+    public function valid(): bool
     {
         return !is_null($this->key());
     }
