@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -14,9 +13,9 @@ namespace XLite\Core\ConsistencyCheck;
  */
 class Inconsistency
 {
-    const ERROR = 'error';
-    const WARNING = 'warning';
-    const NOTICE = 'notice';
+    public const ERROR = 'error';
+    public const WARNING = 'warning';
+    public const NOTICE = 'notice';
 
     /**
      * @var string
