@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -44,7 +43,6 @@ class EventListener extends \XLite\Base\Singleton
                 if ($class::getInstance()->getErrors()) {
                     $this->errors = $class::getInstance()->getErrors();
                 }
-
             }
         }
 
@@ -79,7 +77,6 @@ class EventListener extends \XLite\Base\Singleton
     protected function getListeners()
     {
         return [
-            'probe'                 => ['XLite\Core\EventListener\Probe'],
             'export'                => ['XLite\Core\EventListener\Export'],
             'import'                => ['XLite\Core\EventListener\Import'],
             'imageResize'           => ['XLite\Core\EventListener\ImageResize'],
@@ -87,6 +84,7 @@ class EventListener extends \XLite\Base\Singleton
             'removeData'            => ['XLite\Core\EventListener\RemoveData'],
             'membershipsQuickData'  => ['XLite\Core\EventListener\MembershipsQuickData'],
             'sales'                 => ['XLite\Core\EventListener\Sales'],
+            'applyAttributeValues'  => ['XLite\Core\EventListener\ApplyAttributeValues'],
         ];
     }
 }
