@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,7 @@ namespace XLite\Core\EventListener;
  */
 class Import extends \XLite\Core\EventListener\Base\Countable
 {
-    const CHUNK_LENGTH = 30;
+    public const CHUNK_LENGTH = 30;
 
     /**
      * Importer
@@ -57,11 +56,11 @@ class Import extends \XLite\Core\EventListener\Base\Countable
     {
         $this->serviceTime += (microtime(true) - $this->timeMark);
 
-        if (0 === $item->current()->key()) {
+        if ($item->current()->key() === 0) {
             $item->current()->seek($this->record['position']);
         }
 
-        if (0 === $item->current()->key()) {
+        if ($item->current()->key() === 0) {
             $item->current()->initialize();
         }
 
@@ -103,7 +102,7 @@ class Import extends \XLite\Core\EventListener\Base\Countable
     protected function getItems()
     {
         if (!isset($this->importer)) {
-            $this->importer = new \XLite\Logic\Import\Importer(isset($this->record['options']) ? $this->record['options'] : array());
+            $this->importer = new \XLite\Logic\Import\Importer($this->record['options'] ?? []);
         }
 
         return $this->importer->getStep();
@@ -158,8 +157,8 @@ class Import extends \XLite\Core\EventListener\Base\Countable
             $this->getItems()->getImporter()->finalize();
             $this->record['options'] = $this->getItems()->getOptions()->getArrayCopy();
 
-            if (\XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState($this->getEventName())) {
-                \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setEventState($this->getEventName(), $this->record);
+            if (\XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState($this->getEventName())) {
+                \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setEventState($this->getEventName(), $this->record);
             }
         }
     }
@@ -169,11 +168,10 @@ class Import extends \XLite\Core\EventListener\Base\Countable
      */
     protected function compileTouchData()
     {
-        $this->record['touchData'] = array();
+        $this->record['touchData'] = [];
 
         if (0 < ($this->getItems()->getOptions()->errorsCount + $this->getItems()->getOptions()->warningsCount)) {
             $label = $this->getItems()->getErrorLanguageLabel();
-
         } else {
             $label = $this->getItems()->getNormalLanguageLabel();
         }
@@ -190,7 +188,7 @@ class Import extends \XLite\Core\EventListener\Base\Countable
     {
         return parent::isStepSuccess()
             && (
-               0 == $this->getItems()->getOptions()->step
+               $this->getItems()->getOptions()->step == 0
                || !$this->getItems()->hasErrors()
             );
     }
@@ -218,8 +216,6 @@ class Import extends \XLite\Core\EventListener\Base\Countable
     {
         parent::failTask();
 
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->removeEventState($this->getEventName());
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->removeEventState($this->getEventName());
     }
-
 }
-
