@@ -1,6 +1,5 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
-
+// phpcs:ignoreFile
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
  * See https://www.x-cart.com/license-agreement.html for license details.
@@ -8,6 +7,9 @@
 
 namespace XLite\Core;
 
+use Includes\Utils\Module\Manager;
+use XLite\Core\Exception\FatalException;
+
 /**
  * Flexy compiler
  */
@@ -16,10 +18,10 @@ class FlexyCompiler extends \XLite\Base\Singleton
     /**
      * Tag to define arrays in templates
      */
-    const TAG_ARRAY = '_ARRAY_';
+    public const TAG_ARRAY = '_ARRAY_';
 
-    const PHP_OPEN = '<?php';
-    const PHP_CLOSE = '?>';
+    public const PHP_OPEN = '<?php';
+    public const PHP_CLOSE = '?>';
 
     /**
      * Template source code
@@ -40,7 +42,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
      *
      * @var array
      */
-    protected $urlRewrite = array();
+    protected $urlRewrite = [];
 
     /**
      * Image URL output type
@@ -51,14 +53,21 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     /**
      * CCompile directory (local cache)
-     * 
+     *
      * @var string
      */
     protected $compileDir;
 
-    public $substitutionStart = array();
-    public $substitutionEnd = array();
-    public $substitutionValue = array();
+    public $substitutionStart = [];
+    public $substitutionEnd = [];
+    public $substitutionValue = [];
+
+    protected $offset = 0;
+    protected $stack = [];
+    protected $tokens = [];
+    protected $widgetNames = [];
+    protected $errorMessage = '';
+    public $result = '';
 
     public function parse($file)
     {
@@ -67,21 +76,21 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $this->init($file);
 
         $this->offset = 0;
-        $this->stack = array();
-        $this->tokens = array();
-        $this->widgetNames = array();
+        $this->stack = [];
+        $this->tokens = [];
+        $this->widgetNames = [];
         $this->errorMessage = '';
         $this->html();
-        $this->substitutionStart = array();
-        $this->substitutionEnd = array();
-        $this->substitutionValue = array();
+        $this->substitutionStart = [];
+        $this->substitutionEnd = [];
+        $this->substitutionValue = [];
 
-        return trim($this->postprocess()) . "\n";
+        return trim($this->postprocess() ?? '') . "\n";
     }
 
     function savePosition($offs = 0)
     {
-        array_push($this->stack, $this->offset+$offs);
+        array_push($this->stack, $this->offset + $offs);
         array_push($this->stack, count($this->tokens));
     }
     function rollback()
@@ -99,20 +108,20 @@ class FlexyCompiler extends \XLite\Base\Singleton
     }
     function startOffset()
     {
-        return $this->stack[count($this->stack)-2];
+        return $this->stack[count($this->stack) - 2];
     }
     function error($message)
     {
         // count \n
         $line = $col = 1;
-        for ($i=0; $i < $this->offset; $i++) {
+        for ($i = 0; $i < $this->offset; $i++) {
             if (substr($this->source, $i, 1) == "\n") {
-                $line ++;
-                $col=0;
+                $line++;
+                $col = 0;
             }
             $col++;
         }
-        $this->doDie("File $this->file, line $line, col $col: $message");
+        throw new FatalException("File $this->file, line $line, col $col: $message");
     }
     function isEos()
     {
@@ -137,18 +146,26 @@ class FlexyCompiler extends \XLite\Base\Singleton
             $this->savePosition(-1);
             $n = count($this->tokens);
             if ($this->char('/')) {
-                $this->tokens[] = array("type" => "close-tag", "start" => $this->startOffset());
-                if (!$this->tagname()) return $this->rollback();
-                if (!$this->char('>')) return $this->rollback();
+                $this->tokens[] = ["type" => "close-tag", "start" => $this->startOffset()];
+                if (!$this->tagname()) {
+                    return $this->rollback();
+                }
+                if (!$this->char('>')) {
+                    return $this->rollback();
+                }
             } else {
-                $this->tokens[] = array("type" => "tag", "start" => $this->startOffset());
-                if (!$this->tagname()) return $this->rollback();
+                $this->tokens[] = ["type" => "tag", "start" => $this->startOffset()];
+                if (!$this->tagname()) {
+                    return $this->rollback();
+                }
                 while ($this->space() && $this->attribute_definition()) {
                 }
                 if ($this->char('/')) {
                     $this->tokens[$n]['type'] = "open-close-tag";
                 }
-                if (!$this->char('>')) return $this->rollback();
+                if (!$this->char('>')) {
+                    return $this->rollback();
+                }
             }
             $this->tokens[$n]['end'] = $this->offset;
             return $this->commit();
@@ -161,25 +178,25 @@ class FlexyCompiler extends \XLite\Base\Singleton
     {
         $this->savePosition();
         $i = count($this->tokens);
-        $this->tokens[] = array("type" => "attribute", "start" => $this->offset);
+        $this->tokens[] = ["type" => "attribute", "start" => $this->offset];
         if ($this->attributename()) {
             if ($this->char('=')) {
                 // read attribute value
                 $n = count($this->tokens);
                 if ($this->char('\'')) {
-                    $this->tokens[] = array("type" => "attribute-value", "start" => $this->offset);
+                    $this->tokens[] = ["type" => "attribute-value", "start" => $this->offset];
                     while (!$this->char('\'') && !$this->isEos()) {
                         $this->attribute_text();
                     }
-                    $this->tokens[$n]['end'] = $this->offset-1;
-                } else if ($this->char('"')) {
-                    $this->tokens[] = array("type" => "attribute-value", "start" => $this->offset);
+                    $this->tokens[$n]['end'] = $this->offset - 1;
+                } elseif ($this->char('"')) {
+                    $this->tokens[] = ["type" => "attribute-value", "start" => $this->offset];
                     while (!$this->char('"') && !$this->isEos()) {
                         $this->attribute_text();
                     }
-                    $this->tokens[$n]['end'] = $this->offset-1;
+                    $this->tokens[$n]['end'] = $this->offset - 1;
                 } else {
-                    $this->tokens[] = array("type" => "attribute-value", "start" => $this->offset);
+                    $this->tokens[] = ["type" => "attribute-value", "start" => $this->offset];
                     while ($this->notChars(" \t\n\r/>") && !$this->isEos()) {
                     }
                     $this->tokens[$n]['end'] = $this->offset;
@@ -207,13 +224,13 @@ class FlexyCompiler extends \XLite\Base\Singleton
     // comment ::= '<!--' text '-->'
     function comment()
     {
-        if ($this->offset<strlen($this->source) && substr($this->source, $this->offset, 1) == '<') {
+        if ($this->offset < strlen($this->source) && substr($this->source, $this->offset, 1) == '<') {
             if (substr($this->source, $this->offset, 4) == '<!--') {
-                $pos = strpos($this->source, '-->', $this->offset+4);
-                if ($pos===FALSE) {
+                $pos = strpos($this->source, '-->', $this->offset + 4);
+                if ($pos === false) {
                     return $this->error("Comment is not closed with -->");
                 }
-                $this->offset = $pos+3;
+                $this->offset = $pos + 3;
                 return true;
             }
         }
@@ -223,9 +240,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
     // php tag ::= '< ?' php code '? >'
     function phptag()
     {
-        if ($this->offset<strlen($this->source) && substr($this->source, $this->offset, 1) == '<') {
+        if ($this->offset < strlen($this->source) && substr($this->source, $this->offset, 1) == '<') {
             if (substr($this->source, $this->offset, 2) == '<?') {
-                $this->doDie("&lt;?php&gt; tags are not allowed in templates");
+                throw new FatalException("&lt;?php&gt; tags are not allowed in templates");
             }
         }
         return false;
@@ -238,13 +255,13 @@ class FlexyCompiler extends \XLite\Base\Singleton
         if ($this->char('{')) { // skip till closing }
             $this->savePosition(-1);
             if ($this->notChars(" \t\n\r}")) {
-                $this->tokens[] = array("type"=>"flexy", "start" => $this->offset-2);
+                $this->tokens[] = ["type" => "flexy", "start" => $this->offset - 2];
                 while (!$this->char('}')) {
                     if (!$this->anyChar()) {
                         $this->error("No closing }");
                     }
                 }
-                $this->tokens[count($this->tokens)-1]['end'] = $this->offset;
+                $this->tokens[count($this->tokens) - 1]['end'] = $this->offset;
                 return $this->commit();
             } else {
                 return $this->rollback();
@@ -254,20 +271,19 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     function flexyComment()
     {
-        if ($this->offset<strlen($this->source) && substr($this->source, $this->offset, 1) == '{') {
+        if ($this->offset < strlen($this->source) && substr($this->source, $this->offset, 1) == '{') {
             if (substr($this->source, $this->offset, 2) == '{*') {
-                $this->tokens[] = array("type"=>"flexy", "start" => $this->offset);
+                $this->tokens[] = ["type" => "flexy", "start" => $this->offset];
                 $pos = strpos($this->source, '*}', $this->offset + 2);
-                if ($pos===FALSE) {
+                if ($pos === false) {
                     return $this->error("Comment is not closed with *}");
                 }
                 $this->offset = $pos + 2;
-                $this->tokens[count($this->tokens)-1]['end'] = $this->offset;
+                $this->tokens[count($this->tokens) - 1]['end'] = $this->offset;
                 return true;
             }
         }
         return false;
-
     }
 
     // space ::= ' ' | '\t' | '\n' | '\r'
@@ -301,7 +317,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
     }
     function anyChar()
     {
-        if ($this->isEos()) return false;
+        if ($this->isEos()) {
+            return false;
+        }
         $this->offset ++;
         return true;
     }
@@ -311,10 +329,10 @@ class FlexyCompiler extends \XLite\Base\Singleton
         do {
             $tagname .= $c;
             $c = substr($this->source, $this->offset++, 1);
-        } while ($c >= 'a' && $c <= 'z' || $c >= 'A' && $c <= 'Z' || $c >= '0' && $c <= '9' || $c == '_' || $c == ':' || $c=='-');
+        } while ($c >= 'a' && $c <= 'z' || $c >= 'A' && $c <= 'Z' || $c >= '0' && $c <= '9' || $c == '_' || $c == ':' || $c == '-');
         $this->offset--;
         if (strlen($tagname)) {
-            $this->tokens[count($this->tokens)-1]['name'] = $tagname;
+            $this->tokens[count($this->tokens) - 1]['name'] = $tagname;
             return true;
         }
         return false;
@@ -331,30 +349,26 @@ class FlexyCompiler extends \XLite\Base\Singleton
             $token = $this->tokens[$i];
 
             if ($token['type'] == "tag" || $token['type'] == "open-close-tag") {
-
-                if ($this->findAttr($i + 1, 'if', $pos) && (0 !== strcasecmp($token['name'], 'widget'))) {
+                if ($this->findAttr($i + 1, 'if', $pos) && (strcasecmp($token['name'], 'widget') !== 0)) {
                     if ($this->findClosingTag($i, $pos1)) {
                         $expr = $this->flexyCondition($this->getTokenText($pos + 1));
                         $this->subst($token['start'], 0, static::PHP_OPEN . ' if (' . $expr . '): ' . static::PHP_CLOSE);
                         $this->subst($this->tokens[$pos]['start'], $this->tokens[$pos]['end'], '');
-                        $this->subst($this->tokens[$pos1]['end']-1, $this->tokens[$pos1]['end'], '>' . static::PHP_OPEN . ' endif; ' . static::PHP_CLOSE);
+                        $this->subst($this->tokens[$pos1]['end'] - 1, $this->tokens[$pos1]['end'], '>' . static::PHP_OPEN . ' endif; ' . static::PHP_CLOSE);
                     }
-
-                } elseif ($this->findAttr($i+1, "iff", $pos)) {
+                } elseif ($this->findAttr($i + 1, "iff", $pos)) {
                     $expr = $this->flexyCondition($this->getTokenText($pos + 1));
                     $this->subst($token['start'], 0, static::PHP_OPEN . " if ($expr){" . static::PHP_CLOSE);
                     $this->subst($this->tokens[$pos]['start'], $this->tokens[$pos]['end'], '');
-                    $this->subst($this->tokens[$i]['end']-1, $this->tokens[$i]['end'], '>' . static::PHP_OPEN . ' }' . static::PHP_CLOSE);
-
+                    $this->subst($this->tokens[$i]['end'] - 1, $this->tokens[$i]['end'], '>' . static::PHP_OPEN . ' }' . static::PHP_CLOSE);
                 } elseif ($this->findAttr($i + 1, "foreach", $pos)) {
                     if ($this->findClosingTag($i, $pos1)) {
-                        list($expr,$k,$forvar) = $this->flexyForeach($this->getTokenText($pos+1));
+                        [$expr,$k,$forvar] = $this->flexyForeach($this->getTokenText($pos + 1));
                         $exprNumber = $forvar . 'ArraySize';
                         $exprCounter = $forvar . 'ArrayPointer';
                         $this->subst($token['start'], 0, static::PHP_OPEN . " \$$forvar = isset(\$this->$forvar) ? \$this->$forvar : null; \$_foreach_var = $expr; if (isset(\$_foreach_var)) { \$this->$exprNumber=count(\$_foreach_var); \$this->$exprCounter=0; } if (isset(\$_foreach_var)) foreach (\$_foreach_var as $k){ \$this->$exprCounter++; " . static::PHP_CLOSE);
                         $this->subst($this->tokens[$pos]['start'], $this->tokens[$pos]['end'], '');
-                        $this->subst($this->tokens[$pos1]['end']-1, $this->tokens[$pos1]['end'], ">\n" . static::PHP_OPEN . " } \$this->$forvar = \$$forvar; " . static::PHP_CLOSE);
-
+                        $this->subst($this->tokens[$pos1]['end'] - 1, $this->tokens[$pos1]['end'], ">\n" . static::PHP_OPEN . " } \$this->$forvar = \$$forvar; " . static::PHP_CLOSE);
                     } else {
                         $this->error('No closing tag for foreach');
                     }
@@ -367,10 +381,8 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
                 if ($this->findAttr($i + 1, 'selected', $pos)) {
                     $boolAttribute = 'selected';
-
                 } elseif ($this->findAttr($i + 1, 'checked', $pos)) {
                     $boolAttribute = 'checked';
-
                 } elseif ($this->findAttr($i + 1, 'disabled', $pos)) {
                     $boolAttribute = 'disabled';
                 }
@@ -378,7 +390,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
                 if (
                     $boolAttribute
                     && isset($this->tokens[$pos + 1]['type'])
-                    && 'attribute-value' == $this->tokens[$pos + 1]['type']
+                    && $this->tokens[$pos + 1]['type'] == 'attribute-value'
                 ) {
                     $expr = $this->flexyCondition($this->getTokenText($pos + 1));
                     $this->subst(
@@ -390,7 +402,6 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
                 $this->parseWidget($token, $i);
                 $this->parseList($token, $i);
-
             } elseif ($token['type'] == 'close-tag' && $this->isDumpCloseTag($token)) {
                 $this->subst($token['start'], $token['end'], '');
             }
@@ -398,9 +409,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
             if ($token['type'] == "flexy") {
                 $expr = $this->flexyEcho($this->getTokenText($i));
                 $this->subst($token['start'], $token['end'], $expr);
-
             } elseif ($token['type'] == "attribute") {
-
                 if (!strcasecmp($token['name'], 'src') || !strcasecmp($token['name'], 'background')) {
                     $rewriteData = $this->rewriteURL($this->getTokenText($i + 1));
 
@@ -412,7 +421,6 @@ class FlexyCompiler extends \XLite\Base\Singleton
                         );
                     }
                 }
-
             } elseif ($token['type'] == "attribute-value") {
                 $str = $this->getTokenText($i);
                 // find all {...}
@@ -420,8 +428,8 @@ class FlexyCompiler extends \XLite\Base\Singleton
                 while (($pos = strpos($str, "{", $pos)) !== false) {
                     $pos1 = strpos($str, "}", $pos);
                     if ($pos1 !== false) {
-                        $echo = $this->flexyEcho(substr($str, $pos, $pos1-$pos+1));
-                        $this->subst($token['start']+$pos, $token['start']+$pos1+1, $echo);
+                        $echo = $this->flexyEcho(substr($str, $pos, $pos1 - $pos + 1));
+                        $this->subst($token['start'] + $pos, $token['start'] + $pos1 + 1, $echo);
                     } else {
                         break;
                     }
@@ -435,14 +443,14 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     /**
      * Check - token is dump close tag or not
-     * 
+     *
      * @param array $token Token
-     *  
+     *
      * @return boolean
      */
     protected function isDumpCloseTag(array $token)
     {
-        return in_array($token['name'], array('widget', 'list'));
+        return in_array($token['name'], ['widget', 'list']);
     }
 
     /**
@@ -453,11 +461,11 @@ class FlexyCompiler extends \XLite\Base\Singleton
     protected function getTemplateInfo()
     {
         $skin = preg_replace('/^([a-x0-9_]+)[^a-x0-9_].+$/Ssi', '\1', substr($this->file, strlen(LC_DIR_SKINS)));
-        $template = 'common' == $skin
+        $template = $skin == 'common'
             ? substr($this->file, strlen(LC_DIR_SKINS) + strlen($skin) + 1)
             : substr($this->file, strlen(LC_DIR_SKINS) + strlen($skin) + 4);
 
-        return array($skin, $template);
+        return [$skin, $template];
     }
 
     protected function unsetAttributes(array &$attrs, array $keys)
@@ -469,7 +477,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     protected function getAttributesList(array $attrs)
     {
-        $result = array();
+        $result = [];
 
         if (isset($attrs['mode'])) {
             $result[] = '\'mode\' => array(\'' . implode('\', \'', explode(',', $attrs['mode'])) . '\')';
@@ -487,14 +495,13 @@ class FlexyCompiler extends \XLite\Base\Singleton
     {
         $result = '';
 
-        if (!isset($module) || \Includes\Utils\ModulesManager::isActiveModule($module)) {
-
+        if (!isset($module) || Manager::getRegistry()->isModuleEnabled($module)) {
             $class = isset($attrs['class']) ? $this->flexyAttribute($attrs['class'], false) : null;
 
             $arguments  = isset($class) ? $this->flexyAttribute($attrs['class']) : (isset($name) ? 'null' : '');
             $arguments .= isset($name) ? ', ' . $this->flexyAttribute($name) : '';
 
-        	$conditions = array();
+            $conditions = [];
 
             if (isset($target)) {
                 $target = str_replace(',', '\',\'', preg_replace('/[^\w,]+/', '', $target));
@@ -516,14 +523,13 @@ class FlexyCompiler extends \XLite\Base\Singleton
                 if (!empty($conditions)) {
                     $attrs['IF'] = '(' . $attrs['IF'] . ')';
                 }
-            	$conditions[] = $attrs['IF'];
+                $conditions[] = $attrs['IF'];
             }
 
-            $this->unsetAttributes($attrs, array('IF', 'FOREACH', 'class', 'mode'));
+            $this->unsetAttributes($attrs, ['IF', 'FOREACH', 'class', 'mode']);
 
-            if (empty($arguments) && (1 == count($attrs)) && isset($attrs['template'])) {
+            if (empty($arguments) && (count($attrs) == 1) && isset($attrs['template'])) {
                 $result .= '$this->display(' . $this->flexyAttribute($attrs['template'])  . ');';
-
             } else {
                 $result .= '$this->getWidget('
                     . (empty($attrs) ? (empty($arguments) ? '' : 'array()') : $this->getAttributesList($attrs))
@@ -545,9 +551,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
         array_multisort($this->substitutionStart, $this->substitutionEnd, $this->substitutionValue);
         $lastEnd = 0;
         $result = '';
-        for ($i=0; $i<count($this->substitutionStart); $i++) {
+        for ($i = 0; $i < count($this->substitutionStart); $i++) {
             if ($lastEnd <= $this->substitutionStart[$i]) {
-                $result .= substr($this->source, $lastEnd, $this->substitutionStart[$i]-$lastEnd);
+                $result .= substr($this->source, $lastEnd, $this->substitutionStart[$i] - $lastEnd);
                 $result .= $this->substitutionValue[$i];
                 $lastEnd = $this->substitutionEnd[$i];
             }
@@ -570,12 +576,11 @@ class FlexyCompiler extends \XLite\Base\Singleton
         foreach ($this->urlRewrite as $find => $replace) {
             $len = strlen($find);
 
-            if (0 === strncmp($url, $find, $len)) {
+            if (strncmp($url, $find, $len) === 0) {
                 if (is_callable($replace)) {
                     $result = call_user_func($replace, $url, $len);
-
                 } else {
-                    $result = array(0, $len, $replace);
+                    $result = [0, $len, $replace];
                 }
 
                 break;
@@ -598,13 +603,15 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $newURL = \XLite\Singletons::$handler->layout->getResourceWebPath($url, $this->imageURLOutputType);
 
         return $newURL
-            ? array(0, strlen($url), $newURL)
-            : array(0, $length, \XLite\Singletons::$handler->layout->prepareSkinURL('images', $this->imageURLOutputType));
+            ? [0, strlen($url), $newURL]
+            : [0, $length, \XLite\Singletons::$handler->layout->prepareSkinURL('images', $this->imageURLOutputType)];
     }
 
     function subst($start, $end, $value)
     {
-        if ($end==0) $end = $start;
+        if ($end == 0) {
+            $end = $start;
+        }
         $this->substitutionStart[] = $start;
         $this->substitutionEnd[] = $end;
         $this->substitutionValue[] = $value;
@@ -612,34 +619,36 @@ class FlexyCompiler extends \XLite\Base\Singleton
     function findAttr($offset, $attr, &$pos)
     {
         $pos = $offset;
-        while ($pos<count($this->tokens) && ($this->tokens[$pos]['type'] == "attribute" ||$this->tokens[$pos]['type'] == "attribute-value")) {
+        while ($pos < count($this->tokens) && ($this->tokens[$pos]['type'] == "attribute" || $this->tokens[$pos]['type'] == "attribute-value")) {
             if ($this->tokens[$pos]['type'] == "attribute"  && !strcasecmp($this->tokens[$pos]['name'], $attr)) {
                 return true;
             }
-            $pos ++;
+            $pos++;
         }
         return false;
     }
     function findClosingTag($i, &$pos)
     {
         $pos = $i;
-        $stack = array();
-        while ($pos<count($this->tokens)) {
+        $stack = [];
+        while ($pos < count($this->tokens)) {
             if ($this->tokens[$pos]['type'] == "tag" || $this->tokens[$pos]['type'] == "open-close-tag") {
-                array_push($stack,$this->tokens[$pos]['name']);
+                array_push($stack, $this->tokens[$pos]['name']);
             }
             if ($this->tokens[$pos]['type'] == "close-tag" || $this->tokens[$pos]['type'] == "open-close-tag") {
-                $k = count($stack)-1;
+                $k = count($stack) - 1;
                 while ($k >= 0 && strcasecmp($stack[$k], $this->tokens[$pos]['name'])) {
                     $k--;
                 }
-                if ($k == 0) return true;
+                if ($k == 0) {
+                    return true;
+                }
                 if ($k >= 0) {
                     // opening tag is found
                     array_splice($stack, $k);
                 }
             }
-            $pos ++;
+            $pos++;
         }
         return false;
     }
@@ -654,7 +663,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $str = $this->removeBraces($str);
         $this->condition = '';
         if (substr($str, 0, 1) == '!') {
-            $str = substr($str,1);
+            $str = substr($str, 1);
             $res = $this->flexyExpression($str);
             $not = "!";
         } else {
@@ -673,9 +682,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
     function flexyEcho($str)
     {
         if (substr($str, 0, 9) == '{foreach:') {
-            list($expr,$k,$forvar) = $this->flexyForeach(substr($str, 9));
-            $exprNumber = "$forvar"."ArraySize";
-            $exprCounter = "$forvar"."ArrayPointer";
+            [$expr,$k,$forvar] = $this->flexyForeach(substr($str, 9));
+            $exprNumber = "$forvar" . "ArraySize";
+            $exprCounter = "$forvar" . "ArrayPointer";
             return static::PHP_OPEN . " \$_foreach_var = $expr; if (isset(\$_foreach_var)) { \$this->$exprNumber=count(\$_foreach_var); \$this->$exprCounter=0; } if (isset(\$_foreach_var)) foreach (\$_foreach_var as $k){ \$this->$exprCounter++; " . static::PHP_CLOSE;
         }
         if (substr($str, 0, 4) == '{if:') {
@@ -701,10 +710,10 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $expr = $this->flexyExpression($str);
 
         switch ($str) {
-            case ':h':	// will display variable "as is"
+            case ':h':  // will display variable "as is"
                 break;
 
-            case '':	// default display
+            case '':    // default display
                 $expr = 'func_htmlspecialchars(' . $expr . ')';
                 break;
 
@@ -747,7 +756,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
                 }
         }
 
-        if (':s' !== $str) {
+        if ($str !== ':s') {
             $expr = 'echo ' . $expr;
         }
 
@@ -789,12 +798,11 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     function flexySimpleExpression(&$str)
     {
-        if ('#' == substr($str, 0, 1)) {
-
+        if (substr($str, 0, 1) == '#') {
             // find next #
             $pos = strpos($str, '#', 1);
 
-            if (false === $pos) {
+            if ($pos === false) {
                 $this->error('No closing #');
             }
 
@@ -809,12 +817,14 @@ class FlexyCompiler extends \XLite\Base\Singleton
         if (substr($str, 0, 1) == "%") {
             // find next %
             $pos = strpos($str, "%", 1);
-            if ($pos===false) $this->error("No closing %");
-            $result = substr($str, 1, $pos-1);
-            $str = substr($str, $pos+1);
+            if ($pos === false) {
+                $this->error("No closing %");
+            }
+            $result = substr($str, 1, $pos - 1);
+            $str = substr($str, $pos + 1);
             return $result;
         }
-        if (substr($str, 0, 1)>='0' && substr($str, 0, 1) <='9' || substr($str, 0, 1) == '-' || substr($str, 0, 1) == '.') { // numeric constant
+        if (substr($str, 0, 1) >= '0' && substr($str, 0, 1) <= '9' || substr($str, 0, 1) == '-' || substr($str, 0, 1) == '.') { // numeric constant
             $len = strspn($str, '0123456789-.');
             $result = substr($str, 0, $len);
             $str = substr($str, $len);
@@ -823,34 +833,35 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
         $len = strcspn($str, '=&|,)(:^');
         if ($len < strlen($str) && substr($str, $len, 1) == '(') { // method call
-
             $token  = substr($str, 0, $len);
-            $method = (false !== ($dotPos = strrpos($token, '.'))) ? substr($token, $dotPos + 1) : $token;
+            $method = (($dotPos = strrpos($token, '.')) !== false) ? substr($token, $dotPos + 1) : $token;
             $field  = substr($str, 0, $dotPos);
 
-            if (static::TAG_ARRAY === $method) {
+            if ($method === static::TAG_ARRAY) {
                 $result = 'array';
             } else {
-                $result = '$this->' . ((false === $dotPos) ? '' : 'get' . (strrpos($field, '.') ? 'Complex' : '') . '(\'' . $field . '\')->') . $method;
+                $result = '$this->' . (($dotPos === false) ? '' : 'get' . (strrpos($field, '.') ? 'Complex' : '') . '(\'' . $field . '\')->') . $method;
             }
 
             $str = substr($str, $len);
-            $params = array();
+            $params = [];
 
             if (substr($str, 1, 1) != ')') {
-    			while (substr($str, 0, 1) != ')') {
-        			$str = substr($str,1); // eat , or (
-            		if (strlen($str) == 0) $this->error("No closing )");
-                	$params[] = $this->flexyExpression($str);
-    			}
-  	    	    $str = substr($str,1); // eat )
+                while (substr($str, 0, 1) != ')') {
+                    $str = substr($str, 1); // eat , or (
+                    if (strlen($str) == 0) {
+                        $this->error("No closing )");
+                    }
+                    $params[] = $this->flexyExpression($str);
+                }
+                $str = substr($str, 1); // eat )
             } else {
-                $str = substr($str,2); // eat ()
+                $str = substr($str, 2); // eat ()
             }
             return $result . '(' . implode(',', $params) . ')';
         }
         if ($len) {
-    		// field
+            // field
             $field  = substr($str, 0, $len);
             $result = '$this->get' . (strpos($field, '.') ? 'Complex' : '') . '(\'' . $field . '\')';
         } else {
@@ -867,8 +878,8 @@ class FlexyCompiler extends \XLite\Base\Singleton
         }
         // find all {..} in $str and replace with flexyExpression()
         $result = "";
-        $find = array("'", '&quot;');
-        $replace = array("\'", '"');
+        $find = ["'", '&quot;'];
+        $replace = ["\'", '"'];
         while (strlen($str)) {
             if (substr($str, 0, 1) == "{") {
                 $pos = strpos($str, "}");
@@ -876,9 +887,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
                     $this->error("} not found");
                     return "";
                 }
-                $tmp = substr($str, 0, $pos+1);
+                $tmp = substr($str, 0, $pos + 1);
                 $s = $this->flexyExpression($tmp);
-                $str = substr($str, $pos+1);
+                $str = substr($str, $pos + 1);
             } else {
                 $pos = strpos($str, "{");
                 if ($pos === false) {
@@ -908,7 +919,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $str = substr($str, 1);
         $list = explode(",", $str);
         if (count($list) == 2) {
-            list ($k, $v) = $list;
+            [$k, $v] = $list;
             $forvar = $v;
             $key = '$this->' . $k . ' => $this->' . $forvar;
         } else {
@@ -916,20 +927,12 @@ class FlexyCompiler extends \XLite\Base\Singleton
             $key = '$this->' . $forvar;
         }
 
-        return array($expr, $key, $forvar);
+        return [$expr, $key, $forvar];
     }
 
     function removeBraces($str)
     {
-        if (substr($str, 0, 1) == '{') {
-            $str = substr($str, 1);
-        }
-
-        if ($str{strlen($str) - 1} == '}') {
-            $str = substr($str, 0, strlen($str) - 1);
-        }
-
-        return $str;
+        return rtrim(ltrim($str, '{'), '}');
     }
 
     protected function getXliteFormIDText()
@@ -945,19 +948,18 @@ class FlexyCompiler extends \XLite\Base\Singleton
     /**
      * @todo: remove since we do not use it anymore.
      * Use the Form classes instead
-     * 
+     *
      * @staticvar null $script_start
      * @param type $tokenIndex
      */
     protected function attachFormID($tokenIndex)
     {
         if (\XLite::isAdminZone()) {
-
             $token = $this->tokens[$tokenIndex];
             $token['name'] = empty($token['name']) ? '' : strtolower($token['name']);
 
             // sign each form with generated form_id
-            if ('tag' == $token['type'] && 'form' == $token['name']) {
+            if ($token['type'] == 'tag' && $token['name'] == 'form') {
                 $genFormId = $this->getXliteFormIDText();
                 $this->subst(
                     $token['end'],
@@ -967,20 +969,18 @@ class FlexyCompiler extends \XLite\Base\Singleton
             }
 
             // attach form_id to all links inside attributes (in case they contain javascript links)
-            if ('attribute-value' == $token['type']) {
+            if ($token['type'] == 'attribute-value') {
                 $str = $this->getTokenText($tokenIndex);
                 $this->_addFormIdToActions($str, $token['start']);
             }
 
             // attach form_id to all links inside scripts
             static $script_start = null;
-            if ('tag' == $token['type'] && 'script' == $token['name']) {
+            if ($token['type'] == 'tag' && $token['name'] == 'script') {
                 $script_start = $token['end'];
-
-            } elseif ('close-tag' == $token['type'] && 'script' == $token['name'] && isset($script_start)) {
-
+            } elseif ($token['type'] == 'close-tag' && $token['name'] == 'script' && isset($script_start)) {
                 $script_end = $token['start'];
-                $script_body = substr($this->source, $script_start, $script_end-$script_start);
+                $script_body = substr($this->source, $script_start, $script_end - $script_start);
                 $this->_addFormIdToActions($script_body, $script_start);
                 $script_start = null;
             }
@@ -989,15 +989,15 @@ class FlexyCompiler extends \XLite\Base\Singleton
 
     protected function _addFormIdToActions($text, $text_start)
     {
-        $blocks = array();
+        $blocks = [];
         $search_text = 'action=';
         $prev_pos = 0;
         while ($pos = strpos($text, $search_text, $prev_pos)) {
-            $blocks[] = array(
+            $blocks[] = [
                 'start' => $prev_pos,
                 'end'   => $pos + strlen($search_text),
                 'body'  => substr($text, $prev_pos, $pos + strlen($search_text) - $prev_pos),
-            );
+            ];
             $prev_pos = $pos + strlen($search_text);
         }
 
@@ -1017,7 +1017,8 @@ class FlexyCompiler extends \XLite\Base\Singleton
                 $genFormId = $this->getXliteFormIDText();
                 $echo = $link_symbol . \XLite::FORM_ID . '=' . $genFormId . '&action=';
                 $this->subst(
-                    $text_start + $block['start'] + $pos, $text_start + $block['start'] + $pos + strlen($action_text),
+                    $text_start + $block['start'] + $pos,
+                    $text_start + $block['start'] + $pos + strlen($action_text),
                     $echo
                 );
             }
@@ -1101,9 +1102,9 @@ class FlexyCompiler extends \XLite\Base\Singleton
         $this->file   = $file;
         $this->source = \Includes\Utils\FileManager::read($file);
 
-        $this->urlRewrite = array(
-            'images' => array($this, 'rewriteImageURL'),
-        );
+        $this->urlRewrite = [
+            'images' => [$this, 'rewriteImageURL'],
+        ];
     }
 
     /**
@@ -1118,7 +1119,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
     {
         if (!strcasecmp($token['name'], 'widget')) {
             $attrs = $this->parseTagAttrs($counter);
-            list($target, $module, $name) = $this->processWidgetAttrs($attrs);
+            [$target, $module, $name] = $this->processWidgetAttrs($attrs);
 
             $this->displayTag($token, $this->widgetDisplayCode($attrs, $target, $module, $name));
         }
@@ -1148,18 +1149,16 @@ class FlexyCompiler extends \XLite\Base\Singleton
      */
     protected function parseTagAttrs(&$counter)
     {
-        $attrs = array();
+        $attrs = [];
 
         while (++$counter < count($this->tokens)) {
             $current = $this->tokens[$counter];
 
-            if ('attribute' === $current['type']) {
+            if ($current['type'] === 'attribute') {
                 $attr = $current['name'];
                 $attrs[$attr] = true;
-
-            } elseif ('attribute-value' === $current['type']) {
+            } elseif ($current['type'] === 'attribute-value') {
                 $attrs[$attr] = $this->getTokenText($counter);
-
             } else {
                 $counter--;
                 break;
@@ -1196,8 +1195,8 @@ class FlexyCompiler extends \XLite\Base\Singleton
      */
     protected function processWidgetAttrs(array &$attrs)
     {
-        $result = array();
-        $names  = array('target', 'module', 'name');
+        $result = [];
+        $names  = ['target', 'module', 'name'];
 
         foreach ($names as $index) {
             $result[] = \Includes\Utils\ArrayManager::getIndex($attrs, $index);
@@ -1207,7 +1206,7 @@ class FlexyCompiler extends \XLite\Base\Singleton
             $attrs['IF'] = $attrs['if'];
         }
 
-        $this->unsetAttributes($attrs, array_merge($names, array('if')));
+        $this->unsetAttributes($attrs, array_merge($names, ['if']));
 
         return $result;
     }
@@ -1223,14 +1222,14 @@ class FlexyCompiler extends \XLite\Base\Singleton
     {
         $type = ucfirst(\Includes\Utils\ArrayManager::getIndex($attrs, 'type'));
         $name = \Includes\Utils\ArrayManager::getIndex($attrs, 'name');
-        $this->unsetAttributes($attrs, array('type', 'name'));
+        $this->unsetAttributes($attrs, ['type', 'name']);
 
         $args = '';
         if (!empty($attrs)) {
             $args .= ', ' . $this->getAttributesList($attrs);
         }
 
-        return '$this->display' . $type . 'ViewListContent(' . $this->flexyAttribute($name) . $args. ');';
+        return '$this->display' . $type . 'ViewListContent(' . $this->flexyAttribute($name) . $args . ');';
     }
 
     /**
@@ -1243,10 +1242,10 @@ class FlexyCompiler extends \XLite\Base\Singleton
         parent::__construct();
 
         $this->checkTemplateStatus = LC_DEVELOPER_MODE
-            || \XLite::getInstance()->getOptions(array('skin_details', 'check_templates_status'));
+            || \Includes\Utils\ConfigParser::getOptions(['skin_details', 'check_templates_status']);
 
         $this->rootDirLength = strlen(LC_DIR_ROOT);
 
-        $this->compileDir = \Includes\Decorator\Utils\CacheManager::getCompileDir();
+        $this->compileDir = LC_DIR_COMPILE;
     }
 }
