@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\Core;
 
+use XLite\Core\HTMLPurifierModules\Scripting;
+
 /**
  * HTML Purifier wrapper
  */
@@ -28,16 +29,15 @@ class HTMLPurifier extends \XLite\Base\Singleton
     public static function getPurifier($force = false)
     {
         if ($force || !isset(static::$purifier)) {
-            //require_once LC_DIR_LIB . 'htmlpurifier/library/HTMLPurifier.auto.php';
-            require_once LC_DIR_LIB . 'htmlpurifier/library/HTMLPurifier.safe-includes.php';
             $config = \HTMLPurifier_Config::createDefault();
             $config->set('Cache.SerializerPath', LC_DIR_DATACACHE);
             // Set some HTML5 properties
             $config->set('HTML.DefinitionID', 'html5-definitions'); // unqiue id
             $config->set('HTML.DefinitionRev', 1);
+            $config->set('Output.CommentScriptContents', 0);
 
-            // Get additional options from etc/config.php
-            $options = \XLite::getInstance()->getOptions('html_purifier');
+            // Get additional options from packages/x_cart.yaml
+            $options = \Includes\Utils\ConfigParser::getOptions(['html_purifier', 'options']);
 
             if (empty($options)) {
                 $options = static::getDefaultOptions();
@@ -47,6 +47,7 @@ class HTMLPurifier extends \XLite\Base\Singleton
 
             if (count(static::getAdditionalAttributes())) {
                 if ($def = $config->maybeGetRawHTMLDefinition()) {
+                    $def->manager->registerModule(new Scripting(), true);
                     $module = $def->getAnonymousModule();
 
                     foreach (static::getAdditionalAttributes() as $tag => $attributes) {
@@ -77,15 +78,13 @@ class HTMLPurifier extends \XLite\Base\Singleton
     public static function addConfigOptions($config, $options)
     {
         foreach ($options as $name => $value) {
-
-            if ('1' == $value) {
+            if ($value == '1') {
                 $value = true;
-
-            } elseif ('0' == $value) {
+            } elseif ($value == '0') {
                 $value = false;
             }
 
-            $method = 'prepareOptionValue' . \XLite\Core\Converter::convertToCamelCase(str_replace('.', '', $name));
+            $method = 'prepareOptionValue' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
             if (method_exists(static::getInstance(), $method)) {
                 $value = static::$method($value);
@@ -127,7 +126,6 @@ class HTMLPurifier extends \XLite\Base\Singleton
     protected static function prepareOptionValueURISafeIframeRegexp($value)
     {
         if (!empty($value)) {
-
             if (!is_array($value)) {
                 $value = [$value];
             }
@@ -141,7 +139,6 @@ class HTMLPurifier extends \XLite\Base\Singleton
             $value = array_unique($value);
 
             $value = '%^(http:|https:)?//(' . implode('|', $value) . ')%';
-
         } else {
             $value = null;
         }
@@ -158,7 +155,7 @@ class HTMLPurifier extends \XLite\Base\Singleton
     {
         $result = [];
 
-        $hostDetails = \XLite::getInstance()->getOptions('host_details');
+        $hostDetails = \Includes\Utils\ConfigParser::getOptions(['host_details']);
 
         $domains = explode(',', $hostDetails['domains']);
         $domains[] = $hostDetails['http_host'];
@@ -211,11 +208,11 @@ class HTMLPurifier extends \XLite\Base\Singleton
     {
         $result = [];
 
-        if (\Includes\Utils\ConfigParser::getOptions(['html_purifier_additional_attributes'])) {
-            foreach (\Includes\Utils\ConfigParser::getOptions(['html_purifier_additional_attributes']) as $tag => $attributes) {
+        if (\Includes\Utils\ConfigParser::getOptions(['html_purifier', 'attributes'])) {
+            foreach (\Includes\Utils\ConfigParser::getOptions(['html_purifier', 'attributes']) as $tag => $attributes) {
                 $result[$tag] = [];
                 foreach ($attributes as $attributeData) {
-                    list ($attribute, $definition) = array_pad(explode(':', $attributeData), 2, null);
+                    [$attribute, $definition] = array_pad(explode(':', $attributeData), 2, null);
                     if ($attribute && $definition) {
                         $result[$tag][$attribute] = $definition;
                     }
