@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -26,12 +25,15 @@ class Remote extends ADTO
             $this->setBody($body);
         }
 
-        $imageSize = @getimagesizefromstring($this->getBody());
-        if (is_array($imageSize)) {
-            $this->setName($remoteResource->getName());
-            $this->setWidth($imageSize[0]);
-            $this->setHeight($imageSize[1]);
-            $this->setType($imageSize['mime']);
+        if ($body = $this->getBody()) {
+            $imageSize = @getimagesizefromstring($body);
+
+            if (is_array($imageSize)) {
+                $this->setName($remoteResource->getName());
+                $this->setWidth($imageSize[0]);
+                $this->setHeight($imageSize[1]);
+                $this->setType($imageSize['mime']);
+            }
         }
     }
 }
