@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,7 +21,7 @@ class DefaultStepsProvider implements StepsProviderInterface
      */
     private $steps;
 
-    function __construct(\SeekableIterator $steps, $count = null)
+    public function __construct(\SeekableIterator $steps, $count = null)
     {
         $this->steps = $steps;
         $this->count = $count ?: iterator_count($steps);
@@ -42,13 +41,12 @@ class DefaultStepsProvider implements StepsProviderInterface
         $this->steps->seek($position);
 
         for ($i = 0; $i < $size; $i++) {
-            $result[]= $this->steps->current();
+            $result[] = $this->steps->current();
             $this->steps->next();
 
             if (!$this->steps->valid()) {
                 break;
             }
-
         }
 
         return $result;
