@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\Core;
 
-use Includes\Decorator\Utils\CacheManager;
 use XLite\Core\Cache\ExecuteCachedTrait;
 use XLite\Core\Less\ImportPathResolver;
 
@@ -19,7 +17,7 @@ class LessParser extends \XLite\Base\Singleton
 {
     use ExecuteCachedTrait;
 
-    const LESS_PARENT_CONDITION = '~parent';
+    public const LESS_PARENT_CONDITION = '~parent';
 
     /**
      * Less parser object
@@ -36,12 +34,12 @@ class LessParser extends \XLite\Base\Singleton
     protected $http = null;
 
     /**
-     * admin or default interface.
-     * If none is defined then interface will be detected via \XLite::isAdminZone() method
+     * admin or default zone.
+     * If none is defined then zone will be detected via \XLite::isAdminZone() method
      *
      * @var mixed
      */
-    protected $interface = null;
+    protected $zone = null;
 
     /**
      * LESS resource hash
@@ -70,26 +68,24 @@ class LessParser extends \XLite\Base\Singleton
      */
     protected function getCacheDir($media, $original = false)
     {
-        $interface = is_null($this->interface) ? (\XLite::isAdminZone() ? 'admin' : 'default') : $this->interface;
+        $zone = is_null($this->zone) ? (\XLite::isAdminZone() ? 'admin' : 'default') : $this->zone;
         $http = is_null($this->http) ? (Request::getInstance()->isHTTPS() ? 'https' : 'http') : $this->http;
 
-        return CacheManager::getResourcesDir($original)
-            . $interface . LC_DS
+        return LC_DIR_CACHE_RESOURCES
+            . $zone . LC_DS
             . $http . LC_DS
             . $media . LC_DS;
     }
 
     /**
-     * Interface setter
-     *
-     * @param string $interface The interface which will be used for less generation. Can be
+     * @param string $zone      The zone which will be used for less generation. Can be
      *                          'admin', 'default'.
      *
      * @return void
      */
-    public function setInterface($interface)
+    public function setZone($zone)
     {
-        $this->interface = $interface;
+        $this->zone = $zone;
     }
 
     /**
@@ -115,7 +111,7 @@ class LessParser extends \XLite\Base\Singleton
     {
         $file = $this->makeLESSResourcePath($lessFiles);
         $path = $this->getCSSResource($lessFiles);
-        $url = $this->getCSSResourceURL($path);
+        $url  = $this->getCSSResourceURL($path);
 
         $data = [
             'file'  => $path,
@@ -133,7 +129,6 @@ class LessParser extends \XLite\Base\Singleton
                     && \Includes\Utils\FileManager::isFileReadable($originalPath)
                 ) {
                     $content = \Includes\Utils\FileManager::read($originalPath);
-
                 } else {
                     // Need recreate parser for every parseFile
                     $this->parser = new \Less_Parser($this->getLessParserOptions());
@@ -146,7 +141,6 @@ class LessParser extends \XLite\Base\Singleton
 
                 \Includes\Utils\FileManager::mkdirRecursive(dirname($path));
                 \Includes\Utils\FileManager::write($path, $content);
-
             } catch (\Exception $e) {
                 \XLite\Logger::getInstance()->registerException($e);
                 $data = null;
@@ -165,11 +159,12 @@ class LessParser extends \XLite\Base\Singleton
      */
     protected function calcLESSResourceHash($lessFiles)
     {
-        $result = [];
+        $result         = [];
+        $additionalData = $this->getAdditionalLessData();
 
         if ($lessFiles && is_array($lessFiles)) {
             foreach ($lessFiles as $v) {
-                $result[$this->getShortName($v['file'])] = $this->calcLESSFileHash($v['file']);
+                $result[$this->getShortName($v['file'])] = md5(serialize([$this->calcLESSFileHash($v['file']), $additionalData]));
             }
         }
 
@@ -190,7 +185,7 @@ class LessParser extends \XLite\Base\Singleton
 
             if ($lessFile && file_exists($lessFile)) {
                 $content = file_get_contents($lessFile);
-                $offset = 0;
+                $offset  = 0;
 
                 while (($offset = strpos($content, '@import ', $offset)) !== false) {
                     $import = substr($content, $offset + 8, strpos($content, ';', $offset) - $offset - 8);
@@ -199,7 +194,7 @@ class LessParser extends \XLite\Base\Singleton
                     $import = trim($matches[2], "\n\r'\" ;@");
 
                     if ($import === static::LESS_PARENT_CONDITION) {
-                        @list($path, ) = $this->importPathResolver->getParentPathAndUri($lessFile, '');
+                        @[$path,] = $this->importPathResolver->getParentPathAndUri($lessFile, '');
                         $result .= $this->calcLESSFileHash($path);
                     } else {
                         $result .= $this->calcLESSFileHash(sprintf("%s/%s", dirname($lessFile), $import));
@@ -225,7 +220,7 @@ class LessParser extends \XLite\Base\Singleton
     protected function setLESSResourceHash($lessFiles)
     {
         $this->LESSResourceHash[$this->getCSSResource($lessFiles, false, true)] = $this->calcLESSResourceHash($lessFiles);
-        $this->LESSResourceHash[$this->getCSSResource($lessFiles, true, true)] = $this->calcLESSResourceHash($lessFiles);
+        $this->LESSResourceHash[$this->getCSSResource($lessFiles, true, true)]  = $this->calcLESSResourceHash($lessFiles);
         \Includes\Utils\FileManager::write(
             static::getHashFilePath(),
             '; <' . '?php /*' . PHP_EOL . serialize($this->LESSResourceHash) . '; */ ?' . '>'
@@ -247,7 +242,7 @@ class LessParser extends \XLite\Base\Singleton
 
             if ($data) {
                 $data = substr($data, strlen('; <' . '?php /*' . PHP_EOL), strlen('; */ ?' . '>') * -1);
-                $data = unserialize($data);
+                $data = unserialize($data, ['allowed_classes' => false]);
             }
 
             $this->LESSResourceHash = $data && is_array($data)
@@ -281,16 +276,17 @@ class LessParser extends \XLite\Base\Singleton
      */
     protected function getUniqueName($lessFiles)
     {
-        $list = [];
+        $list           = [];
+        $additionalData = $this->getAdditionalLessData();
 
-        foreach ($lessFiles as $id => $lessFile) {
+        foreach ($lessFiles as $lessFile) {
             unset($lessFile['file']);
             $list[$lessFile['original']] = $lessFile;
         }
 
         ksort($list);
 
-        return hash('md4', serialize($list));
+        return hash('md4', serialize($list) . serialize($additionalData));
     }
 
     /**
@@ -365,7 +361,7 @@ class LessParser extends \XLite\Base\Singleton
     protected function getCSSResourceURL($path)
     {
         return \XLite::getInstance()->getShopURL(
-            str_replace(LC_DS, '/', substr(dirname($path), strlen(LC_DIR_ROOT))) . '/' . basename($path)
+            str_replace(LC_DS, '/', substr(dirname($path), strlen(LC_DIR_PUBLIC))) . '/' . basename($path)
         );
     }
 
@@ -397,14 +393,14 @@ class LessParser extends \XLite\Base\Singleton
      */
     protected function prepareLESSContent($content, $path, array $data)
     {
-        $file = $data['file'];
+        $file    = $data['file'];
         $rootURL = \XLite::getInstance()->getShopURL('');
 
         $container = $this;
 
         return preg_replace_callback(
             '/url\(([^)]+)\)/Ss',
-            function (array $matches) use ($container, $file, $rootURL) {
+            static function (array $matches) use ($container, $file, $rootURL) {
                 return $container->processCSSURLHandler($matches, $file, $rootURL);
             },
             $content
@@ -421,10 +417,10 @@ class LessParser extends \XLite\Base\Singleton
      */
     public function processCSSURLHandler(array $matches, $file, $rootURL)
     {
-        $url = trim($matches[1]);
+        $url   = trim($matches[1]);
         $first = substr($url, 0, 1);
 
-        if ('"' == $first || '\'' == $first) {
+        if ($first == '"' || $first == '\'') {
             $url = stripslashes(substr($url, 1, -1));
         }
 
@@ -432,6 +428,16 @@ class LessParser extends \XLite\Base\Singleton
             $url = str_replace(LC_DS, '/', \Includes\Utils\FileManager::makeRelativePath($file, LC_DIR_ROOT . substr($url, strlen($rootURL))));
         }
 
+        if (strpos($url, '/modules/') !== false) {
+            $url = preg_replace('#modules/\w+/\w+/public#S', Layout::ASSETS_PATH, $url);
+        }
+
+        // Relative URI is calculated for a file located in a root assets folder,
+        // but it is required to use a file from public/assets, so we need to remove one path step back
+        if (strpos($url, '../') === 0) {
+            $url = substr($url, 3);
+        }
+
         return 'url("' . $url . '")';
     }
 
@@ -444,21 +450,27 @@ class LessParser extends \XLite\Base\Singleton
      */
     protected function getModifiedLESSVars($data)
     {
-        $xlite = \XLite::getInstance();
-        $layout = Layout::getInstance();
-
-        return [
+        $xlite              = \XLite::getInstance();
+        $layout             = Layout::getInstance();
+        $modified_less_vars = [
             // Defines the admin skin path
-            'admin-skin'    => '\'' . $xlite->getShopURL(
-                    dirname($layout->getResourceWebPath('body.twig', Layout::WEB_PATH_OUTPUT_URL, \XLite::ADMIN_INTERFACE))
-                ) . '\'',
-            'customer-skin' => '\'' . $xlite->getShopURL(
-                    dirname($layout->getResourceWebPath('body.twig', Layout::WEB_PATH_OUTPUT_URL, \XLite::CUSTOMER_INTERFACE))
-                ) . '\'',
-            'common-skin'   => '\'' . $xlite->getShopURL(
-                    $layout->getResourceWebPath('', Layout::WEB_PATH_OUTPUT_URL, \XLite::COMMON_INTERFACE)
-                ) . '\'',
+            'admin-skin'    => '\'' . $xlite->getShopURL(dirname($layout->getResourceWebPath('body.twig', Layout::WEB_PATH_OUTPUT_URL, \XLite::INTERFACE_WEB, \XLite::ZONE_ADMIN))) . '\'',
+            'customer-skin' => '\'' . $xlite->getShopURL(dirname($layout->getResourceWebPath('body.twig', Layout::WEB_PATH_OUTPUT_URL, \XLite::INTERFACE_WEB, \XLite::ZONE_CUSTOMER))) . '\'',
+            'common-skin'   => '\'' . $xlite->getShopURL($layout->getResourceWebPath('', Layout::WEB_PATH_OUTPUT_URL, \XLite::INTERFACE_WEB, \XLite::ZONE_COMMON)) . '\'',
         ];
+
+        return array_merge(
+            $modified_less_vars,
+            $this->getAdditionalLessData()
+        );
+    }
+
+    /**
+     * @return array
+     */
+    protected function getAdditionalLessData()
+    {
+        return [];
     }
 
     /**
@@ -470,7 +482,7 @@ class LessParser extends \XLite\Base\Singleton
     {
         return [
             'compress'        => true,
-            'cache_dir'       => LC_DIR_DATACACHE . '/less',
+            'cache_dir'       => LC_DIR_DATACACHE . 'less',
             'import_callback' => $this->getImportCallback(),
         ];
     }
@@ -481,8 +493,8 @@ class LessParser extends \XLite\Base\Singleton
     protected function getImportCallback()
     {
         return function (\Less_Tree_Import $import) {
-            $filePath = $import->currentFileInfo['filename'];
-            $entryDir = $import->currentFileInfo['entryPath'];
+            $filePath = $import->currentFileInfo['filename'] ?? null;
+            $entryDir = $import->currentFileInfo['entryPath'] ?? null;
 
             if (($path = $import->path) instanceof \Less_Tree_Quoted) {
                 $path = $path->value;
