@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,16 +7,15 @@
 
 namespace XLite\Core\Mail\Common;
 
-
 use XLite\Core\Converter;
 use XLite\Core\Mail\AMail;
 use XLite\Core\Mailer;
 
 class FailedLoginAdmin extends AMail
 {
-    public static function getInterface()
+    public static function getZone()
     {
-        return \XLite::ADMIN_INTERFACE;
+        return \XLite::ZONE_ADMIN;
     }
 
     public static function getDir()
@@ -59,4 +57,4 @@ class FailedLoginAdmin extends AMail
             'REMOTE_ADDR' => $ip,
         ]);
     }
-}
\ No newline at end of file
+}
