@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -14,15 +13,16 @@ use XLite\Model\Order;
 
 abstract class AAdmin extends \XLite\Core\Mail\Order\AOrder
 {
-    static function getInterface()
+    public static function getZone()
     {
-        return \XLite::ADMIN_INTERFACE;
+        return \XLite::ZONE_ADMIN;
     }
 
     protected static function defineVariables()
     {
         return [
                 'customer_name' => '',
+                'first_name'    => static::t('na_admin'),
                 'order_link'    => \XLite::getInstance()->getShopURL(),
             ] + parent::defineVariables();
     }
@@ -39,6 +39,7 @@ abstract class AAdmin extends \XLite\Core\Mail\Order\AOrder
 
         $this->populateVariables([
             'customer_name' => $order->getProfile()->getName(),
+            'first_name'    => static::t('na_admin'),
             'order_link'    => Converter::buildFullURL(
                 'order',
                 '',
@@ -47,4 +48,4 @@ abstract class AAdmin extends \XLite\Core\Mail\Order\AOrder
             ),
         ]);
     }
-}
\ No newline at end of file
+}
