@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,9 +12,9 @@ use XLite\Model\Order;
 
 abstract class ACustomer extends \XLite\Core\Mail\Order\AOrder
 {
-    static function getInterface()
+    public static function getZone()
     {
-        return \XLite::CUSTOMER_INTERFACE;
+        return \XLite::ZONE_CUSTOMER;
     }
 
     public function __construct(Order $order)
@@ -23,7 +22,7 @@ abstract class ACustomer extends \XLite\Core\Mail\Order\AOrder
         parent::__construct($order);
         $this->setFrom(Mailer::getOrdersDepartmentMail());
         $this->setReplyTo(Mailer::getOrdersDepartmentMails());
-        $this->setTo($order->getProfile()->getEmail());
+        $this->setTo(['email' => $order->getProfile()->getEmail(), 'name' => $order->getProfile()->getName(false)]);
         $this->tryToSetLanguageCode($order->getProfile()->getLanguage());
     }
-}
\ No newline at end of file
+}
