@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,12 +7,12 @@
 
 namespace XLite\Core\Mail\Order;
 
-
 use XLite\Model\Order;
+use XLite\Model\Product;
 
 class BackorderCreatedAdmin extends \XLite\Core\Mail\Order\AAdmin
 {
-    static function getDir()
+    public static function getDir()
     {
         return 'backorder_created';
     }
@@ -29,6 +28,25 @@ class BackorderCreatedAdmin extends \XLite\Core\Mail\Order\AAdmin
     {
         parent::__construct($order);
 
+        $backorderData = self::getBackorderData($order);
+
+        $this->populateVariables([
+            'backordered_item_names' => implode(', ', $backorderData['items']),
+        ]);
+
+        $this->appendData([
+            'backorderedProducts'   => $backorderData['products'],
+            'product_url_processor' => [static::class, 'productUrlProcessor'],
+        ]);
+    }
+
+    /**
+     * @param Order $order
+     *
+     * @return array
+     */
+    public static function getBackorderData(Order $order)
+    {
         $backorderedItems = [];
         $backorderedProducts = [];
 
@@ -39,13 +57,20 @@ class BackorderCreatedAdmin extends \XLite\Core\Mail\Order\AAdmin
             }
         }
 
-        $this->populateVariables([
-            'backordered_item_names' => implode(', ', $backorderedItems),
-        ]);
-
-        $this->appendData([
-            'items'               => $order->getItems(),
-            'backorderedProducts' => $backorderedProducts,
-        ]);
+        return ['items' => $backorderedItems, 'products' => $backorderedProducts];
     }
-}
\ No newline at end of file
+
+
+    /**
+     * @param Product $product
+     *
+     * @return string
+     */
+    public static function productUrlProcessor(Product $product)
+    {
+        return \XLite\Core\Converter::buildFullURL('product', '', [
+            'product_id' => $product->getProductId(),
+            'page'       => 'inventory'
+        ], \XLite::getAdminScript());
+    }
+}
