@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,9 @@
 
 namespace XLite\Core\Mail\Order;
 
-
 class FailedAdmin extends \XLite\Core\Mail\Order\AAdmin
 {
-    static function getDir()
+    public static function getDir()
     {
         return 'order_failed';
     }
@@ -35,4 +33,4 @@ class FailedAdmin extends \XLite\Core\Mail\Order\AAdmin
 
         return $result;
     }
-}
\ No newline at end of file
+}
