@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,8 +7,7 @@
 
 namespace XLite\Core;
 
-use XCart\Marketplace\Constant;
-use XCart\MarketplaceShop;
+use XLite\Core\Marketplace\Constant;
 use XLite\Core\Cache\ExecuteCached;
 
 /**
@@ -20,48 +18,36 @@ class Marketplace extends \XLite\Base\Singleton
     /**
      * Dedicated return code for the "performActionWithTTL" method
      */
-    const TTL_NOT_EXPIRED = '____TTL_NOT_EXPIRED____';
+    public const TTL_NOT_EXPIRED = '____TTL_NOT_EXPIRED____';
 
     /**
      * Some predefined TTLs
      */
-    const TTL_LONG  = 86400;
-    const TTL_SHORT = 3600;
+    public const TTL_LONG  = 86400;
+    public const TTL_SHORT = 3600;
 
     /**
      * HTTP request TTL for 'test_marketplace' action
      */
-    const TTL_TEST_MP = 300; // 5 minutes
+    public const TTL_TEST_MP = 300; // 5 minutes
 
     /**
      * PurchaseURL host
      */
-    const PURCHASE_URL_HOST = 'market.x-cart.com';
-
-    /**
-     * Last error code
-     *
-     * @var string
-     */
-    protected static $lastErrorCode;
-
-    /**
-     * Error message
-     *
-     * @var mixed
-     */
-    protected $error;
+    public const PURCHASE_URL_HOST = 'market.x-cart.com';
 
     protected $systemData;
 
+    protected $segmentData;
+
+    protected $serviceStorage = [];
+
     /**
      * @return string
      */
     public static function getBusinessPurchaseURL()
     {
-        $marketplaceShop = static::buildMarketplaceShop();
-
-        return $marketplaceShop->getPurchaseURL();
+        return static::getPurchaseURL();
     }
 
     /**
@@ -72,39 +58,28 @@ class Marketplace extends \XLite\Base\Singleton
      * @return string
      */
     public static function getPurchaseURL($id = 0, array $params = [], $ignoreId = false)
-    {
-        $marketplaceShop = static::buildMarketplaceShop();
-
-        return $marketplaceShop->getPurchaseURL($id, $params, $ignoreId);
-    }
-
-    /**
-     * @return MarketplaceShop
-     */
-    public static function buildMarketplaceShop()
     {
         $adminEmail = \XLite\Core\Auth::getInstance()->isAdmin()
             ? \XLite\Core\Auth::getInstance()->getProfile()->getLogin()
             : null;
 
-        $licenseKeyMD5 = '';
-        $licenseKey    = \XLite::getXCNLicenseKey();
-        if ($licenseKey) {
-            $licenseKeyMD5 = md5($licenseKey);
-        }
+        $controllerTarget = \XLite::isAdminZone() && \XLite::getController()
+            ? \XLite::getController()->getTarget()
+            : '';
 
-        $controller = '';
-        if (\XLite::isAdminZone() && \XLite::getController()) {
-            $controller = \XLite::getController()->getTarget();
-        }
+        $shopUrl = \XLite\Core\URLManager::getShopURL(
+            \XLite\Core\Converter::buildURL()
+        );
 
-        return MarketplaceShop::build(
-            \XLite\Core\URLManager::getShopURL(\XLite\Core\Converter::buildURL()),
-            $adminEmail,
-            $licenseKeyMD5,
+        return \Includes\Utils\URLManager::getPurchaseURL(
+            $shopUrl,
+            $controllerTarget,
             \XLite::getAffiliateId(),
-            $controller,
-            \XLite::getInstallationLng()
+            \XLite::getInstallationLng(),
+            $adminEmail,
+            $id,
+            $params,
+            $ignoreId
         );
     }
 
@@ -133,53 +108,15 @@ class Marketplace extends \XLite\Base\Singleton
      */
     public function getSystemData()
     {
-        if (!$this->systemData) {
-            $path = LC_DIR_FILES . 'service' . LC_DS . 'coreConfigStorage.data';
-            $content = \Includes\Utils\FileManager::read($path);
-            $systemData = @unserialize($content, ['allowed_classes' => false]);
-
-            $this->systemData = $systemData ?: [];
-        }
-
-        return $this->systemData;
+        return [];
     }
 
     /**
-     * @param array $systemData
+     * @return \Exception|null
      */
-    public function setSystemData($systemData)
+    public function getLastError()
     {
-        $content = @serialize($systemData);
-
-        $path = LC_DIR_FILES . 'service' . LC_DS . 'coreConfigStorage.data';
-
-        \Includes\Utils\FileManager::write($path, $content);
-    }
-
-    public function setFreshInstall()
-    {
-        $systemData = $this->getSystemData();
-        $systemData['freshInstall'] = true;
-
-        $this->setSystemData($systemData);
-    }
-
-    /**
-     * Check if cache was reset by service.php?/clear-cache
-     *
-     * @param $cell
-     * @param $serviceVar
-     *
-     * @return bool
-     */
-    protected function isServiceCacheReset($cell, $serviceVar)
-    {
-        $start = \XLite\Core\TmpVars::getInstance()->$cell;
-        $systemData = $this->getSystemData();
-
-        return isset($start)
-            && isset($systemData[$serviceVar])
-            && $start < $systemData[$serviceVar];
+        return Marketplace\Retriever::getInstance()->getLastError();
     }
 
     /**
@@ -187,9 +124,13 @@ class Marketplace extends \XLite\Base\Singleton
      */
     public function getPaymentMethods(string $countryCode = '')
     {
-        return Marketplace\Retriever::getInstance()->retrieve(
-            Marketplace\QueryRegistry::getQuery('payment_methods', ['countryCode' => $countryCode]),
-            new Marketplace\Normalizer\PaymentMethods()
+        $params = $countryCode
+            ? ['shopCountryCode' => $countryCode]
+            : [];
+
+        return MarketplaceClient::getInstance()->retrieve(
+            'get_payment_methods',
+            $params
         );
     }
 
@@ -201,7 +142,7 @@ class Marketplace extends \XLite\Base\Singleton
     public function updatePaymentMethods($countryCode, $ttl = null)
     {
         $countryCode = $countryCode ?: \XLite\Core\Config::getInstance()->Company->location_country;
-        list($cellTTL,) = $this->getActionCacheVars(Constant::REQUEST_PAYMENT_METHODS . '-' . $countryCode . '-');
+        [$cellTTL,] = $this->getActionCacheVars(Constant::REQUEST_PAYMENT_METHODS . '-' . $countryCode . '-');
 
         $ttl = $ttl ?? static::TTL_LONG;
 
@@ -219,10 +160,7 @@ class Marketplace extends \XLite\Base\Singleton
      */
     public function getShippingMethods()
     {
-        return Marketplace\Retriever::getInstance()->retrieve(
-            Marketplace\QueryRegistry::getQuery('shipping_methods'),
-            new Marketplace\Normalizer\ShippingMethods()
-        );
+        return MarketplaceClient::getInstance()->retrieve('get_shipping_methods');
     }
 
     /**
@@ -232,7 +170,7 @@ class Marketplace extends \XLite\Base\Singleton
      */
     public function updateShippingMethods($ttl = null)
     {
-        list($cellTTL,) = $this->getActionCacheVars(Constant::REQUEST_SHIPPING_METHODS);
+        [$cellTTL,] = $this->getActionCacheVars(Constant::REQUEST_SHIPPING_METHODS);
 
         $ttl = $ttl ?? static::TTL_LONG;
 
@@ -245,8 +183,6 @@ class Marketplace extends \XLite\Base\Singleton
         }
     }
 
-    // {{{ "Get dataset" request
-
     /**
      * Get actions list for 'get_dataset' request
      *
@@ -262,9 +198,11 @@ class Marketplace extends \XLite\Base\Singleton
             $actions = array_merge($actions, $scheduled);
         }
 
-        return array_map([$this, 'mapRequestNameToType'], array_keys($actions));
+        return $actions;
     }
 
+    // {{{ "Get dataset" request
+
     /**
      * Return true if action is active (non-empty and not expired)
      *
@@ -274,187 +212,20 @@ class Marketplace extends \XLite\Base\Singleton
      */
     public function isActionActive($action)
     {
-        list($cellTTL,) = $this->getActionCacheVars($action);
+        [$cellTTL,] = $this->getActionCacheVars($action);
 
         return !$this->checkTTL($cellTTL, $this->getActionTTL($action));
     }
 
-    /**
-     * Get installation data
-     *
-     * @return array
-     */
-    public function getInstallationData()
-    {
-        try {
-            $systemData = $this->getSystemData();
-
-            return $this->performRequestWithCache(
-                [Constant::REQUEST_INSTALLATION_DATA, $systemData['dataDate'] ?? 0],
-                function () {
-                    $result = Marketplace\Retriever::getInstance()->retrieve(
-                        Marketplace\QueryRegistry::getQuery('installation_data'),
-                        new Marketplace\Normalizer\InstallationData()
-                    );
-
-                    if ($result === null) {
-                        throw new \Exception();
-                    }
-
-                    return $result;
-                }
-            );
-        } catch (\Exception $e) {
-            return null;
-        }
-    }
-
-    /**
-     * Get installation data
-     *
-     * @return array
-     */
-    public function getCoreLicense()
-    {
-        $systemData = $this->getSystemData();
-
-        $result = $this->performRequestWithCache(
-            [Constant::REQUEST_CORE_LICENSE, $systemData['dataDate'] ?? 0],
-            function () {
-                return Marketplace\Retriever::getInstance()->retrieve(
-                    Marketplace\QueryRegistry::getQuery('core_license'),
-                    new Marketplace\Normalizer\CoreLicense()
-                );
-            }
-        );
-
-        return $result;
-    }
-
-    public function hasUnallowedModules($onlyEnabled = true)
-    {
-        $inactiveModules = $this->getInactiveContentData();
-
-        if (!$onlyEnabled) {
-            return 0 < count($inactiveModules);
-        }
-
-        foreach ($inactiveModules as $module) {
-            if (isset($module['enabled']) && true === $module['enabled']) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
-    /**
-     * Get installation data
-     *
-     * @return array
-     */
-    public function getWaves()
-    {
-        return Marketplace\Retriever::getInstance()->retrieve(
-            Marketplace\QueryRegistry::getQuery('waves'),
-            new Marketplace\Normalizer\Waves()
-        );
-    }
-
-    /**
-     * @param string $wave
-     *
-     * @return array
-     */
-    public function setWave($wave)
-    {
-        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
-            \XLite\Core\Marketplace\QueryRegistry::getMutation('setWave', [
-                'wave' => $wave
-            ]),
-            new \XLite\Core\Marketplace\Normalizer\Raw()
-        ) ?: [];
-    }
-
-    /**
-     * @param string $key
-     *
-     * @return array
-     */
-    public function registerLicense($key)
-    {
-        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
-            \XLite\Core\Marketplace\QueryRegistry::getMutation('registerLicenseKey', [
-                'key' => $key
-            ]),
-            new \XLite\Core\Marketplace\Normalizer\RegisterLicenseKey()
-        ) ?: [];
-    }
-
-    /**
-     * The certain request handler
-     *
-     * @return array
-     */
-    public function getAllBanners()
-    {
-        return $this->performRequestWithCache(
-            Constant::REQUEST_BANNERS,
-            function () {
-                return Marketplace\Retriever::getInstance()->retrieve(
-                    Marketplace\QueryRegistry::getQuery('banners'),
-                    new Marketplace\Normalizer\Banners()
-                );
-            }
-        );
-    }
-
     // }}}
 
-    /**
-     * @return array
-     */
-    public function getMarketplaceModule($moduleId)
-    {
-        $systemData = $this->getSystemData();
-
-        $cacheKeyData = [
-            'moduleId' => $moduleId,
-            'dataDate' => $systemData['dataDate'] ?? 0,
-        ];
-
-        return $this->performRequestWithCache($cacheKeyData, function () use ($moduleId) {
-            $result = \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
-                \XLite\Core\Marketplace\QueryRegistry::getQuery('marketplace_modules', ['includeIds' => [$moduleId]]),
-                new \XLite\Core\Marketplace\Normalizer\MarketplaceModules()
-            ) ?: [];
-
-            return $result[0] ?? [];
-        });
-    }
-
     /**
      * @return array
      */
     public function getAccountingModules()
     {
-        $criteria = [
-            'tag'       => 'Accounting',
-            'installed' => true,
-        ];
-
-        $systemData = $this->getSystemData();
-
-        $cacheKeyData = $criteria + [
-                'dataDate' => $systemData['dataDate'] ?? 0,
-            ];
-
-        return $this->performRequestWithCache($cacheKeyData, function () use ($criteria) {
-            return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
-                \XLite\Core\Marketplace\QueryRegistry::getQuery('marketplace_modules', $criteria),
-                new \XLite\Core\Marketplace\Normalizer\MarketplaceModules()
-            ) ?: [];
-        });
+        // todo: implement it on frontend
+        return [];
     }
 
     /**
@@ -463,117 +234,29 @@ class Marketplace extends \XLite\Base\Singleton
     public function hasAvailableNotInstalledMarketingModules()
     {
         $criteria = [
-            'installed' => false,
-            'canInstall' => true,
-            'system' => false,
-            'isSalesChannel' => true
+            'installed'      => false,
+            'canInstall'     => true,
+            'system'         => false,
+            'isSalesChannel' => true,
         ];
 
         $systemData = $this->getSystemData();
+        $dataDate   = $systemData['dataDate'] ?? 0;
 
         $cacheKeyData = $criteria + [
-                'dataDate' => $systemData['dataDate'] ?? 0,
+                'dataDate' => $dataDate,
             ];
 
-        return $this->performRequestWithCache($cacheKeyData, function () use ($criteria) {
+        return $this->performRequestWithCache($cacheKeyData, static function () use ($criteria) {
             $modules = \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
                 \XLite\Core\Marketplace\QueryRegistry::getQuery('marketplace_modules', $criteria),
                 new \XLite\Core\Marketplace\Normalizer\MarketplaceModules()
             );
+
             return !empty($modules);
         });
     }
 
-    /**
-     * @param $modules
-     *
-     * @return mixed
-     */
-    public function getAutomateShippingRoutineModules($modules)
-    {
-        $criteria = [
-            'includeIds' => $modules,
-        ];
-
-        $systemData = $this->getSystemData();
-
-        $cacheKeyData = $criteria + [
-                'dataDate' => $systemData['dataDate'] ?? 0,
-            ];
-
-        return $this->performRequestWithCache($cacheKeyData, function () use ($criteria) {
-            return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
-                \XLite\Core\Marketplace\QueryRegistry::getQuery('marketplace_modules', $criteria),
-                new \XLite\Core\Marketplace\Normalizer\MarketplaceModules()
-            ) ?: [];
-        });
-    }
-
-    /**
-     * The certain request handler
-     *
-     * @return array
-     */
-    public function getXC5Notifications()
-    {
-        $result = $this->performActionRequestWithCache(
-            Constant::REQUEST_NOTIFICATIONS,
-            function () {
-                return Marketplace\Retriever::getInstance()->retrieve(
-                    Marketplace\QueryRegistry::getQuery('notifications'),
-                    new Marketplace\Normalizer\Notifications()
-                );
-            }
-        );
-
-        return $result ?: [];
-    }
-
-    /**
-     * Unseen updates available hash
-     *
-     * @return string Hash of modules updates messages
-     */
-    public function unseenUpdatesHash()
-    {
-        $result   = [];
-        $messages = $this->getXC5Notifications();
-        // $coreVersion = \XLite\Upgrade\Cell::getInstance()->getCoreVersion();
-        // todo: use some other way through the BUS
-        $coreVersion = '';// \XLite\Upgrade\Cell::getInstance()->getCoreVersion();
-        if ($messages) {
-            foreach ($messages as $message) {
-                if ($message['type'] === 'module') {
-                    $result[] = $message;
-                }
-            }
-        }
-
-        return md5(serialize($result) . serialize($coreVersion));
-    }
-
-    /**
-     * Return true if system detected inactive license key
-     *
-     * @return array
-     */
-    public function getInactiveContentData()
-    {
-        $systemData = $this->getSystemData();
-
-        $result = $this->performRequestWithCache(
-            [Constant::REQUEST_OUTDATED_MODULE, $systemData['dataDate'] ?? 0],
-            function () {
-                return Marketplace\Retriever::getInstance()->retrieve(
-                    Marketplace\QueryRegistry::getQuery('inactive_content', ['licensed' => false]),
-                    new Marketplace\Normalizer\MarketplaceModules()
-                );
-            }
-        );
-
-        return $result ?: [];
-    }
-
     /**
      * @param bool $withCore
      *
@@ -593,15 +276,16 @@ class Marketplace extends \XLite\Base\Singleton
 
         $result = array_merge(
             [
-                'total' => 0,
-                'core-types' => []
+                'total'      => 0,
+                'core-types' => [],
             ],
             array_fill_keys($listToCheckInOrder, 0)
         );
 
         foreach ($listToCheckInOrder as $type) {
             $entriesByType = $entries[$type] ?? [];
-            if ((isset($entriesByType['CDev-Core']) && $entriesByType['CDev-Core']['type'] === $type)
+            if (
+                (isset($entriesByType['CDev-Core']) && $entriesByType['CDev-Core']['type'] === $type)
                 || (isset($entries['self']['XC-Service']) && $entries['self']['XC-Service']['type'] === $type)
             ) {
                 $result['core-types'][] = $type;
@@ -609,18 +293,16 @@ class Marketplace extends \XLite\Base\Singleton
 
             $entriesOfType = array_filter(
                 $entriesByType,
-                function ($entry) use ($withCore, $type) {
+                static function ($entry) use ($withCore, $type) {
                     return $entry['type'] === $type && ($withCore || $entry['id'] !== 'CDev-Core');
                 }
             );
 
             $previousTypeIndex = (int) $type - 1;
-            $previousTypeCount = isset($result[$previousTypeIndex])
-                ? $result[$previousTypeIndex]
-                : 0;
+            $previousTypeCount = $result[$previousTypeIndex] ?? 0;
             $countOnlyThisType = count($entriesOfType) - $previousTypeCount;
-            $result[$type] = $countOnlyThisType;
-            $result['total'] += $countOnlyThisType;
+            $result[$type]     = $countOnlyThisType;
+            $result['total']   += $countOnlyThisType;
         }
 
         return $result;
@@ -632,10 +314,11 @@ class Marketplace extends \XLite\Base\Singleton
     public function getUpgradeTypesEntries()
     {
         $systemData = $this->getSystemData();
+        $dataDate   = $systemData['dataDate'] ?? 0;
 
         return $this->performRequestWithCache(
-            ['getUpgradeTypesEntries', $systemData['dataDate'] ?? 0],
-            function () {
+            ['getUpgradeTypesEntries', $dataDate],
+            static function () {
                 $data = \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
                     \XLite\Core\Marketplace\QueryRegistry::getQuery('upgrade_entries'),
                     new \XLite\Core\Marketplace\Normalizer\Raw()
@@ -646,8 +329,8 @@ class Marketplace extends \XLite\Base\Singleton
                 }
 
                 foreach ($data as $key => $datum) {
-                    $datum = $datum ?: [];
-                    $keys = array_map(function ($type) {
+                    $datum      = $datum ?: [];
+                    $keys       = array_map(static function ($type) {
                         return $type['id'];
                     }, $datum);
                     $data[$key] = array_combine($keys, $datum);
@@ -658,6 +341,144 @@ class Marketplace extends \XLite\Base\Singleton
         );
     }
 
+    /**
+     * @return boolean
+     */
+    public function isFraud()
+    {
+        $systemData = $this->getSystemData();
+
+        return $systemData[Constant::FIELD_IS_CONFIRMED] ?? false;
+    }
+
+    /**
+     * @return array
+     */
+    public function dropRebuild()
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getMutation('dropRebuild'),
+            new \XLite\Core\Marketplace\Normalizer\Simple('dropRebuild')
+        ) ?: [];
+    }
+
+    /**
+     * @return array
+     */
+    public function clearCache()
+    {
+        $driver = \XLite\Core\Cache::getInstance()->getDriver();
+
+        $driver->delete(ExecuteCached::getCacheKey([Constant::REQUEST_CORE_LICENSE, 0]));
+        $driver->delete(ExecuteCached::getCacheKey([Constant::REQUEST_OUTDATED_MODULE, 0]));
+        $driver->delete(ExecuteCached::getCacheKey([Constant::REQUEST_INSTALLATION_DATA, 0]));
+        $driver->delete(ExecuteCached::getCacheKey(['getUpgradeTypesEntries', 0]));
+
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getMutation('clearCache'),
+            new \XLite\Core\Marketplace\Normalizer\Simple('clearCache')
+        ) ?: [];
+    }
+
+    /**
+     * @param string $type
+     *
+     * @return array
+     */
+    public function createScenario($type = 'common')
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getMutation('createScenario', [
+                'type' => $type,
+            ]),
+            new \XLite\Core\Marketplace\Normalizer\Simple('createScenario')
+        ) ?: [];
+    }
+
+    /**
+     * @param string $scenarioId
+     * @param array  $states
+     *
+     * @return array
+     */
+    public function changeModulesState($scenarioId, $states)
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getRaw('changeModulesState', null, [
+                'scenarioId' => $scenarioId,
+                'states'     => $states,
+            ]),
+            new \XLite\Core\Marketplace\Normalizer\Simple('changeModulesState')
+        ) ?: [];
+    }
+
+    /**
+     * @param string $id
+     *
+     * @return array
+     */
+    public function getRebuildState($id)
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getQuery('rebuildState', [
+                'id' => $id,
+            ]),
+            new \XLite\Core\Marketplace\Normalizer\Simple('rebuildState')
+        ) ?: [];
+    }
+
+    /**
+     * @param string $id
+     * @param array  $options OPTIONAL
+     *
+     * @return array
+     */
+    public function startRebuild($id, $options = [])
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getMutation(
+                'startRebuild',
+                array_merge($options, ['id' => $id])
+            ),
+            new \XLite\Core\Marketplace\Normalizer\Simple('startRebuild')
+        ) ?: [];
+    }
+
+    /**
+     * @param string $id
+     * @param string $action
+     *
+     * @return array
+     */
+    public function executeRebuild($id, $action = 'execute')
+    {
+        return \XLite\Core\Marketplace\Retriever::getInstance()->retrieve(
+            \XLite\Core\Marketplace\QueryRegistry::getMutation('executeRebuild', [
+                'id'     => $id,
+                'action' => $action,
+            ]),
+            new \XLite\Core\Marketplace\Normalizer\Simple('executeRebuild')
+        ) ?: [];
+    }
+
+    /**
+     * Check if cache was reset by service.php?/clear-cache
+     *
+     * @param $cell
+     * @param $serviceVar
+     *
+     * @return bool
+     */
+    protected function isServiceCacheReset($cell, $serviceVar)
+    {
+        $start      = \XLite\Core\TmpVars::getInstance()->$cell;
+        $systemData = $this->getSystemData();
+
+        return isset($start)
+            && isset($systemData[$serviceVar])
+            && $start < $systemData[$serviceVar];
+    }
+
     // {{{ "Get xc5 notifications" request
 
     /**
@@ -735,7 +556,7 @@ class Marketplace extends \XLite\Base\Singleton
         \XLite\Core\Lock\MarketplaceLocker::getInstance()->lock($requestName);
 
         if (!$this->isActionActive($requestName)) {
-            list(, $dataCell) = $this->getActionCacheVars($requestName);
+            [, $dataCell] = $this->getActionCacheVars($requestName);
             $result = \XLite\Core\TmpVars::getInstance()->$dataCell;
 
             $this->scheduleAction($requestName, []);
@@ -749,39 +570,6 @@ class Marketplace extends \XLite\Base\Singleton
         return $result;
     }
 
-    protected function getRequestTypeToNameAssociations()
-    {
-        return [
-            'banners'          => Constant::REQUEST_BANNERS,
-            'notifications'    => Constant::REQUEST_NOTIFICATIONS,
-        ];
-    }
-
-    protected function mapRequestTypeToName($type)
-    {
-        return isset($this->getRequestTypeToNameAssociations()[$type])
-            ? $this->getRequestTypeToNameAssociations()[$type]
-            : null;
-    }
-
-    protected function mapRequestNameToType($name)
-    {
-        return ($k = array_search($name, $this->getRequestTypeToNameAssociations(), true)) !== false
-            ? $k
-            : null;
-    }
-
-    protected function saveRequestInCache($requestType, $data)
-    {
-        if ($requestName = $this->mapRequestTypeToName($requestType)) {
-            $this->saveResultInCache($requestName, $data, true);
-
-            return true;
-        }
-
-        return false;
-    }
-
     /**
      * Return list of marketplace request types which are cached in tmp_vars
      *
@@ -794,15 +582,12 @@ class Marketplace extends \XLite\Base\Singleton
             Constant::REQUEST_CHECK_ADDON_KEY,
             Constant::REQUEST_CORES,
             Constant::REQUEST_ADDONS,
-            Constant::REQUEST_BANNERS,
             Constant::REQUEST_TAGS,
-            //    Constant::ACTION_GET_HOSTING_SCORE,
             Constant::REQUEST_LANDING,
             Constant::REQUEST_WAVES,
             Constant::INACTIVE_KEYS,
             Constant::REQUEST_PAYMENT_METHODS,
             Constant::REQUEST_SHIPPING_METHODS,
-            Constant::REQUEST_NOTIFICATIONS,
         ];
     }
 
@@ -818,12 +603,9 @@ class Marketplace extends \XLite\Base\Singleton
             Constant::REQUEST_CHECK_ADDON_KEY  => static::TTL_LONG,
             Constant::REQUEST_CORES            => static::TTL_LONG,
             Constant::REQUEST_ADDONS           => static::TTL_LONG,
-            Constant::REQUEST_BANNERS          => static::TTL_LONG,
             Constant::REQUEST_TAGS             => static::TTL_LONG,
-            //  Constant::ACTION_GET_HOSTING_SCORE     => static::TTL_LONG,
             Constant::REQUEST_LANDING          => static::TTL_LONG,
             Constant::REQUEST_WAVES            => static::TTL_LONG,
-            Constant::REQUEST_NOTIFICATIONS    => static::TTL_SHORT,
             Constant::REQUEST_PAYMENT_METHODS  => static::TTL_LONG,
             Constant::REQUEST_SHIPPING_METHODS => static::TTL_LONG,
 
@@ -842,7 +624,7 @@ class Marketplace extends \XLite\Base\Singleton
     {
         $ttls = $this->getMarketplaceActions();
 
-        return isset($ttls[$action]) ? $ttls[$action] : null;
+        return $ttls[$action] ?? null;
     }
 
     /**
@@ -869,7 +651,7 @@ class Marketplace extends \XLite\Base\Singleton
      */
     protected function saveResultInCache($action, $result, $saveInTmpVars)
     {
-        list($cellTTL, $cellData) = $this->getActionCacheVars($action);
+        [$cellTTL, $cellData] = $this->getActionCacheVars($action);
 
         if ($saveInTmpVars) {
             // Save in DB (if needed)
@@ -916,7 +698,6 @@ class Marketplace extends \XLite\Base\Singleton
             unset($current[$action]);
             \XLite\Core\TmpVars::getInstance()->marketplaceSchedule = $current ?: null;
         }
-
     }
 
     /**
