@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,15 +17,14 @@ abstract class Normalizer
      *
      * @return array
      */
-    protected function mapFields(array $entity, array $map) {
+    protected function mapFields(array $entity, array $map)
+    {
         $result = [];
 
         foreach ($map as $field => $replace) {
-            $result[$replace] = isset($entity[$field])
-                ? $entity[$field]
-                : null;
+            $result[$replace] = $entity[$field] ?? null;
         }
 
         return $result;
     }
-}
\ No newline at end of file
+}
