@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\Core\Marketplace\Normalizer;
 
-use \XCart\Marketplace\Constant;
+use XLite\Core\Marketplace\Constant;
 
 class Banners extends \XLite\Core\Marketplace\Normalizer
 {
@@ -34,4 +33,4 @@ class Banners extends \XLite\Core\Marketplace\Normalizer
 
         return $result;
     }
-}
\ No newline at end of file
+}
