@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\Core\Marketplace\Normalizer;
 
-
 class CoreLicense extends \XLite\Core\Marketplace\Normalizer
 {
     /**
@@ -18,7 +16,8 @@ class CoreLicense extends \XLite\Core\Marketplace\Normalizer
      */
     public function normalize($response)
     {
-        if(!empty($response['coreLicense'])
+        if (
+            !empty($response['coreLicense'])
             && empty($response['coreLicense']['keyData']['editionName'])
         ) {
             $response['coreLicense']['keyData']['editionName'] = 'Trial';
