@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\Core\Marketplace\Normalizer;
 
-use \XCart\Marketplace\Constant;
+use XLite\Core\Marketplace\Constant;
 
 class Notifications extends \XLite\Core\Marketplace\Normalizer
 {
@@ -20,6 +19,7 @@ class Notifications extends \XLite\Core\Marketplace\Normalizer
         'description' => Constant::FIELD_NOTIFICATION_DESCRIPTION,
         'link'        => Constant::FIELD_NOTIFICATION_LINK,
         'date'        => Constant::FIELD_NOTIFICATION_DATE,
+        'pageParams'  => Constant::FIELD_NOTIFICATION_PAGE_PARAMS,
     ];
 
     /**
@@ -37,5 +37,4 @@ class Notifications extends \XLite\Core\Marketplace\Normalizer
 
         return $result;
     }
-
-}
\ No newline at end of file
+}
