@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,48 +15,48 @@ class OrderHistory extends \XLite\Base\Singleton
     /**
      * Codes for registered events of order history
      */
-    const CODE_PLACE_ORDER                  = 'PLACE ORDER';
-    const CODE_USER_IP                      = 'USER IP';
-    const CODE_CHANGE_STATUS_ORDER          = 'CHANGE STATUS ORDER';
-    const CODE_CHANGE_PAYMENT_STATUS_ORDER  = 'CHANGE PAYMENT STATUS ORDER';
-    const CODE_CHANGE_SHIPPING_STATUS_ORDER = 'CHANGE SHIPPING STATUS ORDER';
-    const CODE_CHANGE_NOTES_ORDER           = 'CHANGE NOTES ORDER';
-    const CODE_CHANGE_CUSTOMER_NOTES_ORDER  = 'CHANGE CUSTOMER NOTES ORDER';
-    const CODE_CHANGE_AMOUNT                = 'CHANGE PRODUCT AMOUNT';
-    const CODE_CHANGE_AMOUNT_GROUPED        = 'CHANGE PRODUCT AMOUNT GROUPED';
-    const CODE_EMAIL_CUSTOMER_SENT          = 'EMAIL CUSTOMER SENT';
-    const CODE_EMAIL_CUSTOMER_FAILED        = 'EMAIL CUSTOMER FAILED';
-    const CODE_EMAIL_ADMIN_SENT             = 'EMAIL ADMIN SENT';
-    const CODE_EMAIL_ADMIN_FAILED           = 'EMAIL ADMIN FAILED';
-    const CODE_TRANSACTION                  = 'TRANSACTION';
-    const CODE_ORDER_PACKAGING              = 'ORDER PACKAGING';
-    const CODE_ORDER_TRACKING               = 'ORDER TRACKING';
-    const CODE_ORDER_EDITED                 = 'ORDER EDITED';
+    public const CODE_PLACE_ORDER                  = 'PLACE ORDER';
+    public const CODE_USER_IP                      = 'USER IP';
+    public const CODE_CHANGE_STATUS_ORDER          = 'CHANGE STATUS ORDER';
+    public const CODE_CHANGE_PAYMENT_STATUS_ORDER  = 'CHANGE PAYMENT STATUS ORDER';
+    public const CODE_CHANGE_SHIPPING_STATUS_ORDER = 'CHANGE SHIPPING STATUS ORDER';
+    public const CODE_CHANGE_NOTES_ORDER           = 'CHANGE NOTES ORDER';
+    public const CODE_CHANGE_CUSTOMER_NOTES_ORDER  = 'CHANGE CUSTOMER NOTES ORDER';
+    public const CODE_CHANGE_AMOUNT                = 'CHANGE PRODUCT AMOUNT';
+    public const CODE_CHANGE_AMOUNT_GROUPED        = 'CHANGE PRODUCT AMOUNT GROUPED';
+    public const CODE_EMAIL_CUSTOMER_SENT          = 'EMAIL CUSTOMER SENT';
+    public const CODE_EMAIL_CUSTOMER_FAILED        = 'EMAIL CUSTOMER FAILED';
+    public const CODE_EMAIL_ADMIN_SENT             = 'EMAIL ADMIN SENT';
+    public const CODE_EMAIL_ADMIN_FAILED           = 'EMAIL ADMIN FAILED';
+    public const CODE_TRANSACTION                  = 'TRANSACTION';
+    public const CODE_ORDER_PACKAGING              = 'ORDER PACKAGING';
+    public const CODE_ORDER_TRACKING               = 'ORDER TRACKING';
+    public const CODE_ORDER_EDITED                 = 'ORDER EDITED';
 
     /**
      * Texts for the order history event descriptions
      */
-    const TXT_PLACE_ORDER                   = 'Order placed';
-    const TXT_USER_IP                       = '{{ip}} IP address used';
-    const TXT_CHANGE_STATUS_ORDER           = 'Order status changed from {{oldStatus}} to {{newStatus}}';
-    const TXT_CHANGE_PAYMENT_STATUS_ORDER   = 'Order payment status changed from {{oldStatus}} to {{newStatus}}';
-    const TXT_CHANGE_SHIPPING_STATUS_ORDER  = 'Order shipping status changed from {{oldStatus}} to {{newStatus}}';
-    const TXT_CHANGE_NOTES_ORDER            = 'Order staff notes changed';
-    const TXT_CHANGE_CUSTOMER_NOTES_ORDER   = 'Order customer notes changed';
-    const TXT_CHANGE_AMOUNT_ADDED           = '[Inventory] Return back to stock: "{{product}}" product amount in stock changes from "{{oldInStock}}" to "{{newInStock}}" ({{qty}} items)';
-    const TXT_CHANGE_AMOUNT_REMOVED         = '[Inventory] Removed from stock: "{{product}}" product amount in stock changes from "{{oldInStock}}" to "{{newInStock}}" ({{qty}} items)';
-    const TXT_UNABLE_RESERVE_AMOUNT         = '[Inventory] Unable to reduce stock for product: "{{product}}", amount: "{{qty}}" items';
-    const TXT_TRACKING_INFO_UPDATE          = '[Tracking] Tracking information was updated';
-    const TXT_TRACKING_INFO_ADDED           = '"{{number}}" tracking number is added';
-    const TXT_TRACKING_INFO_REMOVED         = '"{{number}}" tracking number is removed';
-    const TXT_TRACKING_INFO_CHANGED         = 'Tracking number is changed from "{{old_number}}" to "{{new_number}}"';
-    const TXT_EMAIL_CUSTOMER_SENT           = 'Email sent to the customer';
-    const TXT_EMAIL_CUSTOMER_FAILED         = 'Failure sending email to the customer';
-    const TXT_EMAIL_ADMIN_SENT              = 'Email sent to the admin';
-    const TXT_EMAIL_ADMIN_FAILED            = 'Failure sending email to the admin';
-    const TXT_TRANSACTION                   = 'Transaction made';
-    const TXT_ORDER_PACKAGING               = 'Products have been split into parcels in order to estimate the shipping cost';
-    const TXT_ORDER_EDITED                  = 'Order has been edited';
+    public const TXT_PLACE_ORDER                   = 'Order placed';
+    public const TXT_USER_IP                       = '{{ip}} IP address used';
+    public const TXT_CHANGE_STATUS_ORDER           = 'Order status changed from {{oldStatus}} to {{newStatus}}';
+    public const TXT_CHANGE_PAYMENT_STATUS_ORDER   = 'Order payment status changed from {{oldStatus}} to {{newStatus}}';
+    public const TXT_CHANGE_SHIPPING_STATUS_ORDER  = 'Order shipping status changed from {{oldStatus}} to {{newStatus}}';
+    public const TXT_CHANGE_NOTES_ORDER            = 'Order staff notes changed';
+    public const TXT_CHANGE_CUSTOMER_NOTES_ORDER   = 'Order customer notes changed';
+    public const TXT_CHANGE_AMOUNT_ADDED           = '[Inventory] Return back to stock: "{{product}}" product amount in stock changes from "{{oldInStock}}" to "{{newInStock}}" ({{qty}} items)';
+    public const TXT_CHANGE_AMOUNT_REMOVED         = '[Inventory] Removed from stock: "{{product}}" product amount in stock changes from "{{oldInStock}}" to "{{newInStock}}" ({{qty}} items)';
+    public const TXT_UNABLE_RESERVE_AMOUNT         = '[Inventory] Unable to reduce stock for product: "{{product}}", amount: "{{qty}}" items';
+    public const TXT_TRACKING_INFO_UPDATE          = '[Tracking] Tracking information was updated';
+    public const TXT_TRACKING_INFO_ADDED           = '"{{number}}" tracking number is added';
+    public const TXT_TRACKING_INFO_REMOVED         = '"{{number}}" tracking number is removed';
+    public const TXT_TRACKING_INFO_CHANGED         = 'Tracking number is changed from "{{old_number}}" to "{{new_number}}"';
+    public const TXT_EMAIL_CUSTOMER_SENT           = 'Email sent to the customer';
+    public const TXT_EMAIL_CUSTOMER_FAILED         = 'Failure sending email to the customer';
+    public const TXT_EMAIL_ADMIN_SENT              = 'Email sent to the admin';
+    public const TXT_EMAIL_ADMIN_FAILED            = 'Failure sending email to the admin';
+    public const TXT_TRANSACTION                   = 'Transaction made';
+    public const TXT_ORDER_PACKAGING               = 'Products have been split into parcels in order to estimate the shipping cost';
+    public const TXT_ORDER_EDITED                  = 'Order has been edited';
 
     /**
      * Register event to the order history. Main point of action.
@@ -67,11 +66,11 @@ class OrderHistory extends \XLite\Base\Singleton
      * @param string  $description Event description
      * @param array   $data        Data for event description OPTIONAL
      * @param string  $comment     Event comment OPTIONAL
-     * @param string  $details     Event details OPTIONAL
+     * @param array   $details     Event details OPTIONAL
      *
      * @return void
      */
-    public function registerEvent($orderId, $code, $description, array $data = array(), $comment = '', $details = array())
+    public function registerEvent($orderId, $code, $description, array $data = [], $comment = '', $details = [])
     {
         \XLite\Core\Database::getRepo('XLite\Model\OrderHistoryEvents')
             ->registerEvent($orderId, $code, $description, $data, $comment, $details);
@@ -115,7 +114,7 @@ class OrderHistory extends \XLite\Base\Singleton
                 $orderId,
                 static::CODE_CHANGE_AMOUNT_GROUPED,
                 '[Inventory] Inventory changed',
-                array(),
+                [],
                 '',
                 $processedData
             );
@@ -132,13 +131,21 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function preprocessForGroupData($orderId, $data)
     {
-        $result = array();
+        $result = [];
 
-        foreach ($data as $key => $item) {
-            if ($item['item']->getProduct()
+        foreach ($data as $item) {
+            if (
+                $item['item']->getProduct()
                 && $item['item']->getProduct()->getInventoryEnabled()
             ) {
-                $result[] = $this->preprocessForGroupDataItem($orderId, $item);
+                $realDelta = $item['delta'] > 0 && $item['item']->getBackorderedAmount() > 0
+                    ? $item['delta'] - $item['item']->getBackorderedAmount()
+                    : $item['delta'];
+
+                if ($realDelta !== 0) {
+                    $item['delta'] = $realDelta;
+                    $result[] = $this->preprocessForGroupDataItem($orderId, $item);
+                }
             }
         }
 
@@ -171,15 +178,15 @@ class OrderHistory extends \XLite\Base\Singleton
         $partsOfText = explode(':', $textTranslated, 2);
         if (1 < count($partsOfText)) {
             $name = array_shift($partsOfText);
-            $value = join(';', $partsOfText);
+            $value = implode(';', $partsOfText);
         }
         $name = str_replace('[Inventory] ', '', $name);
 
-        return array(
+        return [
             'name'  => $name,
             'value' => $value,
             'label' => ''
-        );
+        ];
     }
 
     /**
@@ -218,15 +225,14 @@ class OrderHistory extends \XLite\Base\Singleton
     {
         $packages = ($modifier && $modifier->getMethod() && $modifier->getMethod()->getProcessorObject())
             ? $modifier->getMethod()->getProcessorObject()->getPackages($modifier)
-            : array();
+            : [];
 
         if (is_array($packages) && 1 < count($packages)) {
-
-            $result = array();
+            $result = [];
 
             // Correct package keys to improve appearance
             foreach ($packages as $packId => $pack) {
-                $result[$packId+1] = $pack;
+                $result[$packId + 1] = $pack;
             }
 
             // Register event
@@ -234,7 +240,7 @@ class OrderHistory extends \XLite\Base\Singleton
                 $orderId,
                 static::CODE_ORDER_PACKAGING,
                 $this->getOrderPackagingDescription($orderId),
-                array(),
+                [],
                 $this->getOrderPackagingComment($result)
             );
         }
@@ -311,8 +317,8 @@ class OrderHistory extends \XLite\Base\Singleton
     public function registerOrderChanges($orderId, array $changes)
     {
         foreach ($changes as $name => $change) {
-            if (method_exists($this, 'registerOrderChange' . ucfirst($name))) {
-                $this->{'registerOrderChange' . ucfirst($name)}($orderId, $change);
+            if (method_exists($this, 'registerOrderChange' . \Includes\Utils\Converter::convertToUpperCamelCase($name))) {
+                $this->{'registerOrderChange' . \Includes\Utils\Converter::convertToUpperCamelCase($name)}($orderId, $change);
             }
         }
     }
@@ -345,19 +351,19 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     public function registerOrderChangeCustomerNotes($orderId, $change)
     {
-        $comments = array();
+        $comments = [];
 
         if (!empty($change['old'])) {
-            $comments['Old customer note'][] = array(
+            $comments['Old customer note'][] = [
                 'old' => null,
                 'new' => $change['old'],
-            );
+            ];
         }
 
-        $comments['New customer note'][] = array(
+        $comments['New customer note'][] = [
             'old' => null,
             'new' => $change['new'],
-        );
+        ];
 
         $this->registerEvent(
             $orderId,
@@ -378,19 +384,19 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     public function registerOrderChangeAdminNotes($orderId, $change)
     {
-        $comments = array();
+        $comments = [];
 
         if (!empty($change['old'])) {
-            $comments['Old staff note'][] = array(
+            $comments['Old staff note'][] = [
                 'old' => null,
                 'new' => $change['old'],
-            );
+            ];
         }
 
-        $comments['New staff note'][] = array(
+        $comments['New staff note'][] = [
             'old' => null,
             'new' => $change['new'],
-        );
+        ];
 
         $this->registerEvent(
             $orderId,
@@ -481,7 +487,7 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getTrackingInfoData($orderId)
     {
-        return array();
+        return [];
     }
 
     /**
@@ -510,15 +516,15 @@ class OrderHistory extends \XLite\Base\Singleton
         $comment = [];
 
         foreach ($added as $value) {
-            $comment[] = static::t(static::TXT_TRACKING_INFO_ADDED, array('number' => $value));
+            $comment[] = static::t(static::TXT_TRACKING_INFO_ADDED, ['number' => $value]);
         }
 
         foreach ($removed as $value) {
-            $comment[] = static::t(static::TXT_TRACKING_INFO_REMOVED, array('number' => $value));
+            $comment[] = static::t(static::TXT_TRACKING_INFO_REMOVED, ['number' => $value]);
         }
 
         foreach ($changed as $value) {
-            $comment[] = static::t(static::TXT_TRACKING_INFO_CHANGED, array('old_number' => $value['old'], 'new_number' => $value['new']));
+            $comment[] = static::t(static::TXT_TRACKING_INFO_CHANGED, ['old_number' => $value['old'], 'new_number' => $value['new']]);
         }
 
         return $comment;
@@ -566,17 +572,19 @@ class OrderHistory extends \XLite\Base\Singleton
      * Register transaction data to the order history
      *
      * @param integer $orderId
-     * @param string  $transactionData
+     * @param string  $description
+     * @param array   $details OPTIONAL
+     * @param string  $comment OPTIONAL
      *
      * @return void
      */
-    public function registerTransaction($orderId, $description, $details = array(), $comment = '')
+    public function registerTransaction($orderId, $description, $details = [], $comment = '')
     {
         $this->registerEvent(
             $orderId,
             static::CODE_TRANSACTION,
             $description,
-            array(),
+            [],
             $comment,
             $details
         );
@@ -603,9 +611,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getPlaceOrderData($orderId)
     {
-        return array(
+        return [
             'orderId' => $orderId,
-        );
+        ];
     }
 
     /**
@@ -625,9 +633,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getUserIpData()
     {
-        return array(
+        return [
             'ip' => \XLite\Core\Request::getInstance()->getClientIp(),
-        );
+        ];
     }
 
     /**
@@ -647,50 +655,19 @@ class OrderHistory extends \XLite\Base\Singleton
      *
      * @param array $packages
      *
-     * @return array
+     * @return string
      */
     protected function getOrderPackagingComment($packages)
     {
-        // Switch interface to admin
-        $layout = \XLite\Core\Layout::getInstance();
+        return \XLite\Core\Layout::getInstance()->callInInterfaceZone(static function () use ($packages) {
+            $widget = new \XLite\View\Order\Details\Admin\Packaging(
+                [
+                    \XLite\View\Order\Details\Admin\Packaging::PARAM_PACKAGES => $packages,
+                ]
+            );
 
-        $baseSkin = $layout->getSkin();
-        $baseInterface = $layout->getInterface();
-        $baseInnerInterface = $layout->getInnerInterface();
-
-        $layout->setAdminSkin();
-
-        // Get compiled widget content
-        $widget = new \XLite\View\Order\Details\Admin\Packaging(
-            array(
-                \XLite\View\Order\Details\Admin\Packaging::PARAM_PACKAGES => $packages,
-            )
-        );
-
-        $result = $widget->getContent();
-
-        // Restore interface
-        switch ($baseInterface) {
-            case \XLite::ADMIN_INTERFACE:
-                $layout->setAdminSkin();
-                break;
-
-            case \XLite::CUSTOMER_INTERFACE:
-                $layout->setCustomerSkin();
-                break;
-
-            case \XLite::CONSOLE_INTERFACE:
-                $layout->setConsoleSkin();
-                break;
-
-            case \XLite::MAIL_INTERFACE:
-                $layout->setMailSkin($baseInnerInterface);
-                break;
-        }
-
-        $layout->setSkin($baseSkin);
-
-        return $result;
+            return $widget->getContent();
+        }, \XLite::INTERFACE_WEB, \XLite::ZONE_ADMIN);
     }
 
 
@@ -704,12 +681,13 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getOrderChangeStatusCode($orderId, array $change)
     {
-        return isset($change['type']) && $change['type']
-            ? (
-                'payment' === $change['type']
+        if (isset($change['type']) && $change['type']) {
+            return $change['type'] === 'payment'
                 ? static::CODE_CHANGE_PAYMENT_STATUS_ORDER
-                : static::CODE_CHANGE_SHIPPING_STATUS_ORDER
-            ) : static::CODE_CHANGE_STATUS_ORDER;
+                : static::CODE_CHANGE_SHIPPING_STATUS_ORDER;
+        }
+
+        return static::CODE_CHANGE_STATUS_ORDER;
     }
 
     /**
@@ -722,12 +700,13 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getOrderChangeStatusDescription($orderId, array $change)
     {
-        return isset($change['type']) && $change['type']
-            ? (
-                'payment' == $change['type']
+        if (isset($change['type']) && $change['type']) {
+            return $change['type'] === 'payment'
                 ? static::TXT_CHANGE_PAYMENT_STATUS_ORDER
-                : static::TXT_CHANGE_SHIPPING_STATUS_ORDER
-            ) : static::TXT_CHANGE_STATUS_ORDER;
+                : static::TXT_CHANGE_SHIPPING_STATUS_ORDER;
+        }
+
+        return static::TXT_CHANGE_STATUS_ORDER;
     }
 
     /**
@@ -740,11 +719,13 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getOrderChangeStatusData($orderId, array $change)
     {
-        return array(
-            'orderId'   => $orderId,
-            'newStatus' => $change['new']->getName(),
-            'oldStatus' => $change['old']->getName(),
-        );
+        return [
+            'orderId'       => $orderId,
+            'oldStatus'     => $change['old']->getName(),
+            'newStatus'     => $change['new']->getName(),
+            'oldStatusCode' => $change['old']->getCode(),
+            'newStatusCode' => $change['new']->getCode(),
+        ];
     }
 
     /**
@@ -758,9 +739,13 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getOrderChangeAmountDescription($orderId, $delta, $product)
     {
-        return $delta < 0
-            ? ($this->isAbleToReduceAmount($product, $delta) ? static::TXT_CHANGE_AMOUNT_REMOVED : static::TXT_UNABLE_RESERVE_AMOUNT)
-            : static::TXT_CHANGE_AMOUNT_ADDED;
+        if ($delta < 0) {
+            return $this->isAbleToReduceAmount($product, $delta)
+                ? static::TXT_CHANGE_AMOUNT_REMOVED
+                : static::TXT_UNABLE_RESERVE_AMOUNT;
+        }
+
+        return static::TXT_CHANGE_AMOUNT_ADDED;
     }
 
     /**
@@ -775,13 +760,13 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getOrderChangeAmountData($orderId, $productName, $oldAmount, $delta)
     {
-        return array(
+        return [
             'orderId'    => $orderId,
             'newInStock' => $oldAmount + $delta,
             'oldInStock' => $oldAmount,
             'product'    => $productName,
             'qty'        => abs($delta),
-        );
+        ];
     }
 
     /**
@@ -844,9 +829,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getCustomerEmailSentData($orderId)
     {
-        return array(
+        return [
             'orderId' => $orderId,
-        );
+        ];
     }
 
     /**
@@ -870,9 +855,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getCustomerEmailFailedData($orderId)
     {
-        return array(
+        return [
             'orderId' => $orderId,
-        );
+        ];
     }
 
     /**
@@ -896,9 +881,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getAdminEmailSentData($orderId)
     {
-        return array(
+        return [
             'orderId' => $orderId,
-        );
+        ];
     }
 
     /**
@@ -922,9 +907,9 @@ class OrderHistory extends \XLite\Base\Singleton
      */
     protected function getAdminEmailFailedData($orderId)
     {
-        return array(
+        return [
             'orderId' => $orderId,
-        );
+        ];
     }
 
     /**
