@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,11 +7,15 @@
 
 namespace XLite\Core;
 
+use XLite\InjectLoggerTrait;
+
 /**
  * Package operations
  */
 class Package extends \XLite\Base\Singleton
 {
+    use InjectLoggerTrait;
+
     /**
      * Minimum item weight
      *
@@ -39,7 +42,6 @@ class Package extends \XLite\Base\Singleton
         $packages = $this->getCachedPackages($key);
 
         if (!$packages) {
-
             // Generate packages
             $packages = $this->generatePackages($pendingItems, $limits);
 
@@ -61,33 +63,33 @@ class Package extends \XLite\Base\Singleton
      */
     protected function initPendingItems($items)
     {
-        $pendingItems = array();
+        $pendingItems = [];
 
         if (is_array($items)) {
             foreach ($items as $item) {
                 $product = $item->getProduct();
 
                 if ($product) {
-                    $weight = 0 === $item->getWeight()
+                    $weight = $item->getWeight() === 0
                         ? $this->getMinimumItemWeight()
                         : $item->getWeight() / $item->getAmount();
 
-                    $pendingItem = array(
+                    $pendingItem = [
                         'subtotal' => $item->getTotal(),
                         'price'    => $item->getItemNetPrice(),
                         'weight'   => $weight,
                         'qty'      => $item->getAmount(),
                         'id'       => $item->getItemId(),
                         'name'     => $product->getName(),
-                    );
+                    ];
 
                     if ($product->getUseSeparateBox()) {
-                        $pendingItem['separate_box'] = array(
+                        $pendingItem['separate_box'] = [
                             'length' => $product->getBoxLength() * 1,
                             'width'  => $product->getBoxWidth() * 1,
                             'height' => $product->getBoxHeight() * 1,
                             'maxQty' => $product->getItemsPerBox(),
-                        );
+                        ];
                     }
 
                     $pendingItems[] = $pendingItem;
@@ -123,23 +125,21 @@ class Package extends \XLite\Base\Singleton
         }
 
         if (!empty($pendingItems)) {
-            \XLite\Logger::getInstance()->log($this->getLogMessage($backupPendingItems, $errorMsg), $this->getLogLevel());
+            $this->getLogger()->warning($this->getLogMessage($backupPendingItems, $errorMsg));
         }
 
-        if (\Includes\Utils\ConfigParser::getOptions(['log_details', 'level']) >= LOG_DEBUG) {
-            // Log package details into var/log/PACKING-...
-            $data = array(
-                'pendingItems' => $pendingItems,
+        $this->getLogger('PACKING')->debug(
+            '',
+            $data = [
+                'pendingItems'     => $pendingItems,
                 'separatePackages' => $separatePackages,
-                'restPackages' => $restPackages,
-            );
-
-            \XLite\Logger::logCustom('PACKING', $data);
-        }
+                'restPackages'     => $restPackages,
+            ]
+        );
 
         // Return empty array on failure (if pending items list is not empty) or aggregated packages lists on success
         return $pendingItems
-            ? array()
+            ? []
             : $this->getAggregatedPackages($separatePackages, $restPackages);
     }
 
@@ -154,7 +154,7 @@ class Package extends \XLite\Base\Singleton
      */
     protected function getSeparatePackages(&$pendingItems, $limits, &$errorMsg)
     {
-        $packages = array();
+        $packages = [];
 
         $items = $pendingItems;
 
@@ -164,52 +164,41 @@ class Package extends \XLite\Base\Singleton
         $e = null;
 
         while (!$stop) {
-
             if (empty($items[$id])) {
                 $stop = true;
-
             } else {
-
                 if (!empty($items[$id]['separate_box']) && 0 < $items[$id]['qty']) {
-
                     // Process next item of product
-    
+
                     $item = $items[$id];
 
                     if (isset($packages[$packageId]['items'][$id])) {
-
                         // Product has already been partially packed
 
                         if ($packages[$packageId]['items'][$id]['qty'] < $item['separate_box']['maxQty']) {
-
                             $pack = $packages[$packageId];
                             $pack['items'][$id]['qty'] ++;
                             $pack['subtotal'] += $item['price'];
                             $pack['weight'] += $item['weight'];
 
                             if ($this->checkLimits($pack, $limits, $e)) {
-
                                 // Move one item of product to the package
                                 $packages[$packageId] = $pack;
 
                                 // Decrease quantity of unpacked items
                                 $items[$id]['qty'] --;
-
                             } else {
                                 // Package limits failed - try to place item to a new package
-                                $packageId ++;
+                                $packageId++;
                             }
-
                         } else {
                             // Package is full, add new
-                            $packageId ++;
+                            $packageId++;
                         }
-
                     } else {
-
                         // Create package and add first item of product
                         $item['qty'] = 1;
-                        $pack = array();
+                        $pack = [];
                         $pack['items'][$id] = $item;
                         $pack['subtotal'] = $item['price'];
                         $pack['weight'] = $item['weight'];
@@ -220,9 +209,7 @@ class Package extends \XLite\Base\Singleton
 
                             // Decrease quantity of unpacked items
                             $items[$id]['qty'] --;
-
                         } else {
-
                             // Package limits failed - it's impossible to pack item for delivery
 
                             $stop = true;
@@ -232,20 +219,17 @@ class Package extends \XLite\Base\Singleton
                             }
                         }
                     }
-
                 } else {
-
-                    if (0 == $items[$id]['qty']) {
-
+                    if ($items[$id]['qty'] == 0) {
                         // Remove completely packed product
                         unset($items[$id]);
 
                         // Create new package for the next product
-                        $packageId ++;
+                        $packageId++;
                     }
 
                     // Pass to the next product
-                    $id ++;
+                    $id++;
                 }
             }
         }
@@ -266,7 +250,7 @@ class Package extends \XLite\Base\Singleton
      */
     protected function packItems(&$pendingItems, $limits, &$errorMsg)
     {
-        $packages = array();
+        $packages = [];
 
         $items = $this->preprocessPendingItems($pendingItems);
 
@@ -279,22 +263,17 @@ class Package extends \XLite\Base\Singleton
         $e = null;
 
         while (!$stop) {
-
             if (empty($items) || $error) {
                 $stop = true;
-
             } else {
-
                 if (isset($items[$id]) && 0 < $items[$id]['qty']) {
-
                     // Process next item of product
-    
+
                     $item = $items[$id];
 
                     // Product item is satisfied to the package limits
-    
-                    if (isset($packages[$packageId]['items'][$id])) {
 
+                    if (isset($packages[$packageId]['items'][$id])) {
                         // Product has already been partially packed
                         // Add new item of product to the package
 
@@ -305,21 +284,16 @@ class Package extends \XLite\Base\Singleton
                         $pack['weight'] += $item['weight'];
 
                         if ($this->checkLimits($pack, $limits, $e)) {
-
-                            // Save package if it is satisfied to the limits 
+                            // Save package if it is satisfied to the limits
                             $packages[$packageId] = $pack;
 
                             // Decrease quantity of unpacked items
                             $items[$id]['qty'] --;
-
                         } else {
-
                             // Package limits failed - go to the next product
-                            $id ++;
+                            $id++;
                         }
-
                     } else {
-
                         // Create package and add first item of product
 
                         $item['qty'] = 1;
@@ -327,14 +301,13 @@ class Package extends \XLite\Base\Singleton
                         $isNewPackage = false;
 
                         if (!isset($packages[$packageId])) {
-                            $pack = array();
-                            $pack['items'] = array();
+                            $pack = [];
+                            $pack['items'] = [];
                             $pack['subtotal'] = 0;
                             $pack['weight'] = 0;
                             $pack['box'] = $limits;
 
                             $isNewPackage = true;
-
                         } else {
                             $pack = $packages[$packageId];
                         }
@@ -344,50 +317,42 @@ class Package extends \XLite\Base\Singleton
                         $pack['weight'] += $item['weight'];
 
                         if ($this->checkLimits($pack, $limits, $e)) {
-
-                            // Save package if it is satisfied to the limits 
+                            // Save package if it is satisfied to the limits
                             $packages[$packageId] = $pack;
 
                             // Decrease quantity of unpacked items
                             $items[$id]['qty'] --;
-
                         } else {
-
                             // Package limits failed
 
                             if ($isNewPackage) {
-
                                 // It's impossible to place item into new (empty) package - break operation
                                 $error = true;
 
                                 if ($e) {
                                     $errorMsg = $e;
                                 }
-
                             } else {
                                 // Go to the next product
-                                $id ++;
+                                $id++;
                             }
                         }
                     }
-
                 } else {
-
                     // Remove completely packed product
-                    if (isset($items[$id]) && 0 == $items[$id]['qty']) {
+                    if (isset($items[$id]) && $items[$id]['qty'] == 0) {
                         unset($items[$id]);
                     }
 
                     // Increase $id and pass to the next product
-                    $id ++;
+                    $id++;
                 }
 
                 if ($id > $maxItemId) {
-
                     $id = 0;
 
                     // Create new package if there are no items added in the last cycle
-                    $packageId ++;
+                    $packageId++;
                 }
             }
         }
@@ -444,10 +409,8 @@ class Package extends \XLite\Base\Singleton
     {
         if ($a['weight'] == $b['weight']) {
             $result = 0;
-
         } elseif ($a['weight'] > $b['weight']) {
             $result = -1;
-
         } else {
             $result = 1;
         }
@@ -471,9 +434,7 @@ class Package extends \XLite\Base\Singleton
         $error = null;
 
         if (!empty($limits) && is_array($limits)) {
-
             foreach ($limits as $key => $limit) {
-
                 if (isset($box[$key]) && $box[$key] > $limit) {
                     $result = false;
                     $error = sprintf('Limit failure: %s = %s (limit is %s)', $key, $box[$key], $limit);
@@ -497,10 +458,10 @@ class Package extends \XLite\Base\Singleton
      */
     protected function getCacheKey($pendingItems, $limits)
     {
-        $keyData = array(
+        $keyData = [
             'pendingItems' => $pendingItems,
             'limits'       => $limits,
-        );
+        ];
 
         return 'pack-' . md5(serialize($keyData));
     }
@@ -514,9 +475,9 @@ class Package extends \XLite\Base\Singleton
      */
     protected function getCachedPackages($key)
     {
-        $result = array();
+        $result = [];
 
-        $cacheDriver = \XLite\Core\Database::getCacheDriver();
+        $cacheDriver = \XLite\Core\Cache::getInstance()->getDriver();
 
         if ($cacheDriver->contains($key)) {
             $result = $cacheDriver->fetch($key);
@@ -535,7 +496,7 @@ class Package extends \XLite\Base\Singleton
      */
     protected function savePackagesInCache($key, $data)
     {
-        \XLite\Core\Database::getCacheDriver()->save($key, $data);
+        \XLite\Core\Cache::getInstance()->getDriver()->save($key, $data);
     }
 
     // }}}
@@ -550,9 +511,9 @@ class Package extends \XLite\Base\Singleton
      */
     protected function getLogMessage($pendingItems, $errorMsg)
     {
-        $items = array();
+        $items = [];
 
-        foreach ($pendingItems as $id => $item) {
+        foreach ($pendingItems as $item) {
             $items[] = sprintf('%s (weight: %0.2f, qty: %d)', $item['id'], $item['weight'], $item['qty']);
         }
 
@@ -561,16 +522,6 @@ class Package extends \XLite\Base\Singleton
         return $message;
     }
 
-    /**
-     * Return type of log messages
-     *
-     * @return integer
-     */
-    protected function getLogLevel()
-    {
-        return LOG_WARNING;
-    }
-
     // {{{ Minimum item weight
 
     /**
