@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\Core\RemoteResource;
 
-use PEAR2\HTTP\Request\Exception;
+use Exception;
 
 /**
  * Class DropBox
@@ -38,22 +37,19 @@ class DropBox extends AURL
         return $urlParts['scheme'] . '://' . $urlParts['host'] . $urlParts['path'] . '?raw=1';
     }
 
-    /**
-     * @return string
-     */
     public function getName()
     {
         try {
             $headers            = $this->getHeaders();
-            $contentDisposition = $headers->ContentDisposition;
+            $contentDisposition = $headers['content-disposition'][0] ?? '';
 
-            if (preg_match('/filename\*=(?:[^\']+)\'\'(\S+)/', $contentDisposition, $matches)
+            if (
+                preg_match('/filename\*=(?:[^\']+)\'\'(\S+)/', $contentDisposition, $matches)
                 || preg_match('/filename="(.*)(?(?=\\\\)[^\"]|\")/', $contentDisposition, $matches)
             ) {
-
                 return $matches[1];
             }
-        } catch (Exception $e) {
+        } catch (Exception) {
         }
 
         return parent::getName();
