@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -21,6 +20,10 @@ class RemoteResourceFactory
         /** @var IURL[] $resources */
         $resources = array_merge(static::getResources(), ['XLite\Core\RemoteResource\PlainURL']);
 
+        if (!\XLite\Core\Converter::isURL($url)) {
+            $url = \Includes\Utils\Operator::purifyLink($url);
+        }
+
         foreach ($resources as $resource) {
             if ($resource::isMatch($url)) {
                 return new $resource($url);
