@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,15 +7,22 @@
 
 namespace XLite\Core;
 
+use XCart\Container;
+use XCart\Service\BotDetector\BotDetector;
+use XCart\Service\BotDetector\BotDetectorInterface;
+use XLite\InjectLoggerTrait;
+
 /**
  * Request
  */
 class Request extends \XLite\Base\Singleton
 {
+    use InjectLoggerTrait;
+
     /**
      * Current method
      */
-    const METHOD_CLI = 'cli';
+    public const METHOD_CLI = 'cli';
 
     /**
      * Current request method
@@ -30,21 +36,21 @@ class Request extends \XLite\Base\Singleton
      *
      * @var array
      */
-    protected $data = array();
+    protected $data = [];
 
     /**
      * Request data (non-filtered)
      *
      * @var array
      */
-    protected $nonFilteredData = array();
+    protected $nonFilteredData = [];
 
     /**
      * Request raw data (parsed manually from php://input)
      *
      * @var array
      */
-    protected $rawData = array();
+    protected $rawData = [];
 
     /**
      * Cache for mobile device flag
@@ -65,6 +71,8 @@ class Request extends \XLite\Base\Singleton
      */
     protected $identifier;
 
+    protected BotDetectorInterface $botDetector;
+
     /**
      * Current request identifier
      *
@@ -72,7 +80,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function getUniqueIdentifier()
     {
-        if (null === $this->identifier) {
+        if ($this->identifier === null) {
             $this->identifier = hash('md5', uniqid('', true));
         }
 
@@ -107,7 +115,7 @@ class Request extends \XLite\Base\Singleton
      */
     public static function isMobileDevice()
     {
-        if (null === static::$isMobileDeviceFlag) {
+        if (static::$isMobileDeviceFlag === null) {
             static::$isMobileDeviceFlag = static::detectMobileDevice();
         }
 
@@ -141,7 +149,7 @@ class Request extends \XLite\Base\Singleton
      *
      * @return void
      */
-    public function mapRequest(array $data = array())
+    public function mapRequest(array $data = [])
     {
         if (empty($data)) {
             if ($this->isCLI()) {
@@ -149,7 +157,6 @@ class Request extends \XLite\Base\Singleton
                     $pair = explode('=', $_SERVER['argv'][$i], 2);
                     $data[preg_replace('/^-+/S', '', $pair[0])] = isset($pair[1]) ? trim($pair[1]) : true;
                 }
-
             } else {
                 $data = array_merge($this->getCookieData(false), $this->getGetData(false), $this->getPostData(false));
             }
@@ -186,10 +193,10 @@ class Request extends \XLite\Base\Singleton
     public function getRawPostData()
     {
         if (empty($this->rawData)) {
-            $this->rawData = array();
+            $this->rawData = [];
             $raw_post_array = explode('&', file_get_contents('php://input'));
             foreach ($raw_post_array as $keyval) {
-                $keyval = explode ('=', $keyval);
+                $keyval = explode('=', $keyval);
                 if (count($keyval) == 2) {
                     $name = urldecode($keyval[0]);
                     $value = urldecode($keyval[1]);
@@ -210,16 +217,15 @@ class Request extends \XLite\Base\Singleton
     public function getPostDataWithArrayValues()
     {
         $rawData = $this->getRawPostData();
-        $output  = array();
+        $output  = [];
         $pattern = '/(?>([\w]*)\[(\d)\]\.)(\w*?)$/';
 
         foreach ($rawData as $name => $value) {
             preg_match($pattern, $name, $matches);
 
             if (count($matches) > 3) {
-                list($full, $name, $index, $subname) = $matches;
+                [, $name, $index, $subname] = $matches;
                 $output[$name][$index][$subname] = $value;
-
             } else {
                 $output[$name] = $value;
             }
@@ -305,7 +311,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function isGet()
     {
-        return 'GET' === $this->requestMethod;
+        return $this->requestMethod === 'GET';
     }
 
     /**
@@ -315,7 +321,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function isPost()
     {
-        return 'POST' === $this->requestMethod;
+        return $this->requestMethod === 'POST';
     }
 
     /**
@@ -325,7 +331,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function isHead()
     {
-        return 'HEAD' === $this->requestMethod;
+        return $this->requestMethod === 'HEAD';
     }
 
     /**
@@ -343,9 +349,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function getAjaxRefererTarget()
     {
-        return isset($_SERVER['HTTP_AJAXREFERERTARGET'])
-            ? $_SERVER['HTTP_AJAXREFERERTARGET']
-            : null;
+        return $_SERVER['HTTP_AJAXREFERERTARGET'] ?? null;
     }
 
     /**
@@ -365,7 +369,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function isCLI()
     {
-        return 'cli' === PHP_SAPI;
+        return PHP_SAPI === 'cli';
     }
 
     /**
@@ -377,7 +381,7 @@ class Request extends \XLite\Base\Singleton
      */
     public function __get($name)
     {
-        return isset($this->data[$name]) ? $this->data[$name] : null;
+        return $this->data[$name] ?? null;
     }
 
     /**
@@ -422,7 +426,8 @@ class Request extends \XLite\Base\Singleton
      */
     protected function __construct()
     {
-        $this->requestMethod = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : self::METHOD_CLI;
+        $this->requestMethod = $_SERVER['REQUEST_METHOD'] ?? self::METHOD_CLI;
+        $this->botDetector = Container::getContainer()->get(BotDetector::class);
         $this->mapRequest();
     }
 
@@ -448,7 +453,7 @@ class Request extends \XLite\Base\Singleton
     protected function doUnescape($data)
     {
         return is_array($data)
-            ? array_map(array($this, __FUNCTION__), $data)
+            ? array_map([$this, __FUNCTION__], $data)
             : $this->doUnescapeSingle($data);
     }
 
@@ -508,9 +513,16 @@ class Request extends \XLite\Base\Singleton
             foreach ($data as $key => $value) {
                 if (is_array($value)) {
                     $value = $this->filterData($value);
-
                 } elseif (!empty($value) && !is_numeric($value)) {
                     $value = strip_tags($value);
+
+                    if (
+                        str_contains($key, \XLite\Core\View\DynamicWidgetRenderer::DYNAMIC_WIDGET_PLACEHOLDER)
+                        || str_contains($value, \XLite\Core\View\DynamicWidgetRenderer::DYNAMIC_WIDGET_PLACEHOLDER)
+                    ) {
+                        unset($data[$key]);
+                        continue;
+                    }
                 }
 
                 $data[$key] = $value;
@@ -533,11 +545,10 @@ class Request extends \XLite\Base\Singleton
         $result = true;
 
         if (!is_string($value)) {
-            \XLite\Logger::getInstance()->logPostponed($name . ' has a wrong type');
+            $this->logPostponed(LOG_DEBUG, $name . ' has a wrong type', ['trace' => debug_backtrace()]);
             $result = false;
-
         } elseif (!preg_match('/^[a-z0-9_]*$/Si', $value)) {
-            \XLite\Logger::getInstance()->logPostponed($name . ' has a wrong format');
+            $this->logPostponed(LOG_DEBUG, $name . ' has a wrong type', ['trace' => debug_backtrace()]);
             $result = false;
         }
 
@@ -564,7 +575,7 @@ class Request extends \XLite\Base\Singleton
 
         if ($secure) {
             $domain = $this->getCookieDomain(true);
-            $result = $this->_setcookie(
+            $result = $this->setcookieWrapper(
                 $name,
                 $value,
                 $ttl,
@@ -575,7 +586,7 @@ class Request extends \XLite\Base\Singleton
             );
         } else {
             $httpDomain = $this->getCookieDomain(false);
-            $result = $this->_setcookie(
+            $result = $this->setcookieWrapper(
                 $name,
                 $value,
                 $ttl,
@@ -588,7 +599,7 @@ class Request extends \XLite\Base\Singleton
             $httpsDomain = $this->getCookieDomain(true);
 
             if ($httpDomain != $httpsDomain) {
-                $result = $this->_setcookie(
+                $result = $this->setcookieWrapper(
                     $name,
                     $value,
                     $ttl,
@@ -613,7 +624,7 @@ class Request extends \XLite\Base\Singleton
 
         if ($secure) {
             $domain = $this->getCookieDomain(true);
-            $this->_setcookie(
+            $this->setcookieWrapper(
                 $name,
                 null,
                 -1,
@@ -624,7 +635,7 @@ class Request extends \XLite\Base\Singleton
             );
         } else {
             $httpDomain = $this->getCookieDomain(false);
-            $this->_setcookie(
+            $this->setcookieWrapper(
                 $name,
                 null,
                 -1,
@@ -636,7 +647,7 @@ class Request extends \XLite\Base\Singleton
 
             $httpsDomain = $this->getCookieDomain(true);
             if ($httpDomain != $httpsDomain) {
-                $this->_setcookie(
+                $this->setcookieWrapper(
                     $name,
                     null,
                     -1,
@@ -652,9 +663,10 @@ class Request extends \XLite\Base\Singleton
     /**
      * Wrapper for setcookie PHP function
      */
-    public function _setcookie($name, $value = '', $expires = 0, $path = '', $domain = '', $secure = false, $httponly = false, $samesite = null)
+    public function setcookieWrapper($name, $value = '', $expires = 0, $path = '', $domain = '', $secure = false, $httponly = false, $samesite = null)
     {
         $samesite = $samesite ?: $this->getCookieSameSiteOptionValue();
+        $domain = $this->getCookieHostOnlyOptionValue() ? '' : $domain;
 
         if (PHP_VERSION_ID >= 70300) {
             $options = [
@@ -669,10 +681,8 @@ class Request extends \XLite\Base\Singleton
                 $options['samesite'] = $samesite;
             }
 
-            @setcookie($name, $value, $options);
-
+            \XLite::getInstance()->saveCookie($name, (string)$value, $options);
         } else {
-
             if ($samesite) {
                 // Use a bug in PHP prior to v7.3.0 to pass 'samesite' option into cookie
                 $path .= '; samesite=' . $this->getCookieSameSiteOptionValue() . ';';
@@ -693,7 +703,7 @@ class Request extends \XLite\Base\Singleton
     {
         $url = $this->getCookieURL($secure);
 
-        return false === strpos($url['host'], '.') ? false : $url['host'];
+        return strpos($url['host'], '.') === false ? false : $url['host'];
     }
 
     /**
@@ -707,7 +717,7 @@ class Request extends \XLite\Base\Singleton
     {
         $url = $this->getCookieURL($secure);
 
-        return isset($url['path']) ? $url['path'] : '/';
+        return $url['path'] ?? '/';
     }
 
     /**
@@ -717,7 +727,17 @@ class Request extends \XLite\Base\Singleton
      */
     protected function getCookieSameSiteOptionValue()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('other', 'cookie_samesite'));
+        return \Includes\Utils\ConfigParser::getOptions(['other', 'cookie_samesite']);
+    }
+
+    /**
+     * Get hostonly option value
+     *
+     * @return string
+     */
+    protected function getCookieHostOnlyOptionValue()
+    {
+        return \Includes\Utils\ConfigParser::getOptions(['other', 'cookie_hostonly']);
     }
 
     /**
@@ -730,10 +750,10 @@ class Request extends \XLite\Base\Singleton
     protected function getCookieURL($secure = false)
     {
         $url = $secure
-            ? 'https://' .  \XLite::getInstance()->getOptions(array('host_details', 'https_host'))
-            : 'http://' . \XLite::getInstance()->getOptions(array('host_details', 'http_host'));
+            ? 'https://' .  \Includes\Utils\ConfigParser::getOptions(['host_details', 'https_host'])
+            : 'http://' . \Includes\Utils\ConfigParser::getOptions(['host_details', 'http_host']);
 
-        $url .= \XLite::getInstance()->getOptions(array('host_details', 'web_dir'));
+        $url .= \Includes\Utils\ConfigParser::getOptions(['host_details', 'web_dir']);
 
         return parse_url($url);
     }
@@ -742,7 +762,6 @@ class Request extends \XLite\Base\Singleton
     {
         if (\XLite::isAdminZone()) {
             return \XLite\Core\Config::getInstance()->Security->admin_security;
-
         } else {
             return \XLite\Core\Config::getInstance()->Security->customer_security;
         }
@@ -755,76 +774,13 @@ class Request extends \XLite\Base\Singleton
     /**
      * Cookie cell for robot mark
      */
-    const COOKIE_ROBOT = 'is_robot';
+    public const COOKIE_ROBOT = 'is_robot';
 
     /**
-     * Bot flag
-     *
-     * @var   boolean
+     * @var boolean
      */
     protected $botFlag;
 
-    /**
-     * Bot signatures
-     *
-     * @var array
-     */
-    protected $botSignatures = array (
-        'X-Cart info'    => array(
-            'X-Cart info',
-            'X-Cart Catalog Generator',
-        ),
-        'Google'        => array(
-            'Mediapartners-Google',
-            'Google Page Speed Insights',
-            'Google-Adwords-Instant',
-        ),
-        'Yandex'         => array(
-            'YandexImages',
-            'YandexMetrika',
-            'YandexImageResizer',
-            'YandexVideoParser',
-        ),
-        'Yahoo'            => array(
-            'Slurp',
-            'YahooSeeker',
-        ),
-        'Ask'            => array(
-            'Teoma',
-        ),
-        'Baidu'          => array(
-            'baiduspider',
-        ),
-        'Qihoo' => array(
-            'Qihoo',
-        ),
-        'Tencent' => array(
-            'Sosospider',
-        ),
-        'Entireweb.com' => array(
-            'Speedy Spider',
-        ),
-        'WuKong' => array(
-            'WukongSpider',
-        ),
-        'NHN Corporation' => array(
-            'Yeti',
-        ),
-        'other' => array(
-            'special_archiver',
-            'SEOkicks',
-            'idmarch',
-            'Qwantify',
-            'TagVisit',
-            'FastCrawler',
-            'Pandalytics',
-            'Veooz',
-            'Mappy',
-            'Nmap Scripting Engine',
-            'linkfluence.com',
-        ),
-    );
-
     /**
      * Check - current user is bot or not
      *
@@ -832,23 +788,19 @@ class Request extends \XLite\Base\Singleton
      */
     public function isBot()
     {
-        if (null === $this->botFlag) {
+        if ($this->botFlag === null) {
             $this->botFlag = false;
 
             if (!$this->isCLI() && !empty($_SERVER['HTTP_USER_AGENT'])) {
                 if (isset($_COOKIE[static::COOKIE_ROBOT])) {
-                    if (substr($_COOKIE[static::COOKIE_ROBOT], 0, -1) == hash('md4', $_SERVER['HTTP_USER_AGENT'])) {
-                        $this->botFlag = (bool)substr($_COOKIE[static::COOKIE_ROBOT], -1);
-
+                    if (substr($_COOKIE[static::COOKIE_ROBOT], 0, -1) === hash('md4', $_SERVER['HTTP_USER_AGENT'])) {
+                        $this->botFlag = (bool) substr($_COOKIE[static::COOKIE_ROBOT], -1);
                     } else {
                         $this->unsetCookie(static::COOKIE_ROBOT);
                     }
-
                 } else {
                     $this->botFlag = $this->detectBot();
-                    if ($this->botFlag) {
-                        $this->setCookie(static::COOKIE_ROBOT, hash('md4', $_SERVER['HTTP_USER_AGENT']) . ((int) $this->botFlag));
-                    }
+                    $this->setCookie(static::COOKIE_ROBOT, hash('md4', $_SERVER['HTTP_USER_AGENT']) . ((int) $this->botFlag));
                 }
             }
         }
@@ -857,117 +809,44 @@ class Request extends \XLite\Base\Singleton
     }
 
     /**
-     * Detect bot
-     *
      * @return boolean
      */
     protected function detectBot()
     {
-        $result = false;
-
-        if (false !== stristr($_SERVER['HTTP_USER_AGENT'], 'bot')) {
-            return true;
-        }
-
-        foreach ($this->botSignatures as $name => $signatures) {
-            foreach ($signatures as $signature) {
-                if (false !== stristr($_SERVER['HTTP_USER_AGENT'], $signature)) {
-                    $result = true;
-                    break;
-                }
-            }
-        }
-
-        return $result;
-    }
-
-    // }}}
-
-    // {{{ Browser detection
-
-    /**
-     * Browscap cache
-     *
-     * @var \stdClass|array
-     */
-    protected $browscap;
-
-    /**
-     * Get browser data
-     *
-     * @param boolean $override Override cache OPTIONAL
-     *
-     * @return \stdClass|array
-     */
-    public function getBrowserData($override = false)
-    {
-        if ((null === $this->browscap || $override)
-            && !$this->isCLI()
-            && !empty($_SERVER['HTTP_USER_AGENT'])
-        ) {
-            $this->browscap = $this->getBrowscapClient()->getBrowser($_SERVER['HTTP_USER_AGENT']);
-        }
-
-        return $this->browscap;
-    }
-
-    /**
-     * Get browscap client
-     *
-     * @return \phpbrowscap\Browscap
-     */
-    protected function getBrowscapClient()
-    {
-        require_once (LC_DIR_LIB . 'Browscap.php');
-
-        $cacheDir = LC_DIR_DATA . 'browscap';
-        if (!file_exists($cacheDir)) {
-            \Includes\Utils\FileManager::mkdirRecursive($cacheDir);
-            \Includes\Utils\FileManager::copy(
-                $this->getBrowsCapPath(),
-                $cacheDir . LC_DS . 'browscap.ini'
-            );
-        }
-
-        return new \phpbrowscap\Browscap($cacheDir);
-    }
-
-    /**
-     * Get browsCap file path
-     *
-     * @return string
-     */
-    protected function getBrowsCapPath()
-    {
-        return LC_DIR_LIB . 'browscap.ini';
+        return $this->botDetector->detectByHeader($_SERVER['HTTP_USER_AGENT']);
     }
 
     // }}}
 
     /**
      * Returns customer ip
+     * https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For
      *
      * @return string
      */
     public function getClientIp()
     {
-        if (isset($_SERVER['REMOTE_ADDR'])) {
-            $ipAddress = $_SERVER['REMOTE_ADDR'];
+        if (isset($_SERVER['HTTP_CF_CONNECTING_IP'])) {
+            $ipAddress = $_SERVER['HTTP_CF_CONNECTING_IP'];
         } elseif (isset($_SERVER['HTTP_CLIENT_IP'])) {
             $ipAddress = $_SERVER['HTTP_CLIENT_IP'];
-        } else if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
+        } elseif (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
             $ipAddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
-        } else if (isset($_SERVER['HTTP_X_FORWARDED'])) {
+        } elseif (isset($_SERVER['HTTP_X_FORWARDED'])) {
             $ipAddress = $_SERVER['HTTP_X_FORWARDED'];
-        } else if (isset($_SERVER['HTTP_FORWARDED_FOR'])) {
+        } elseif (isset($_SERVER['HTTP_FORWARDED_FOR'])) {
             $ipAddress = $_SERVER['HTTP_FORWARDED_FOR'];
-        } else if (isset($_SERVER['HTTP_FORWARDED'])) {
+        } elseif (isset($_SERVER['HTTP_FORWARDED'])) {
             $ipAddress = $_SERVER['HTTP_FORWARDED'];
+        } elseif (isset($_SERVER['REMOTE_ADDR'])) {
+            $ipAddress = $_SERVER['REMOTE_ADDR'];
         } else {
             $ipAddress = 'UNKNOWN';
         }
 
-        return $ipAddress;
+        $ipAddress = explode(',', $ipAddress);
+
+        return trim(reset($ipAddress));
     }
 
     /**
@@ -980,7 +859,7 @@ class Request extends \XLite\Base\Singleton
         $result = false;
 
         // Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; NP06; rv:11.0) like Gecko
-        $ua = htmlentities($_SERVER['HTTP_USER_AGENT'], ENT_QUOTES, 'UTF-8');
+        $ua = htmlentities($this->getClientUserAgent(), ENT_QUOTES, 'UTF-8');
         if (preg_match('~MSIE|Internet Explorer~i', $ua) || preg_match('~Trident/7\.0;(?:.*) rv:11\.0~i', $ua)) {
             $result = true;
         }
@@ -1001,4 +880,18 @@ class Request extends \XLite\Base\Singleton
 
         return 'UNKNOWN';
     }
+
+    public function verifyWidget(string $widget): bool
+    {
+        $widget = implode('\\', array_filter(explode('\\', $widget)));
+
+        return !in_array($widget, $this->getUnAllowedWidgets(), true);
+    }
+
+    protected function getUnAllowedWidgets(): array
+    {
+        return [
+            'XLite\View\FormField\Select\Profile\Admin',
+        ];
+    }
 }
