@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,20 +12,20 @@ namespace XLite\Core\Task\Base;
  */
 abstract class Periodic extends \XLite\Core\Task\ATask
 {
-    const INT_1_MIN     = 60;
-    const INT_5_MIN     = 300;
-    const INT_10_MIN    = 600;
-    const INT_15_MIN    = 900;
-    const INT_30_MIN    = 1800;
-    const INT_1_HOUR    = 3600;
-    const INT_2_HOURS   = 7200;
-    const INT_4_HOURS   = 14400;
-    const INT_6_HOURS   = 21600;
-    const INT_12_HOURS  = 43200;
-    const INT_1_DAY     = 86400;
-    const INT_2_DAYS    = 172800;
-    const INT_5_DAYS    = 432000;
-    const INT_1_WEEK    = 604800;
+    public const INT_1_MIN     = 60;
+    public const INT_5_MIN     = 300;
+    public const INT_10_MIN    = 600;
+    public const INT_15_MIN    = 900;
+    public const INT_30_MIN    = 1800;
+    public const INT_1_HOUR    = 3600;
+    public const INT_2_HOURS   = 7200;
+    public const INT_4_HOURS   = 14400;
+    public const INT_6_HOURS   = 21600;
+    public const INT_12_HOURS  = 43200;
+    public const INT_1_DAY     = 86400;
+    public const INT_2_DAYS    = 172800;
+    public const INT_5_DAYS    = 432000;
+    public const INT_1_WEEK    = 604800;
 
     /**
      * Get period (seconds)
@@ -37,7 +36,7 @@ abstract class Periodic extends \XLite\Core\Task\ATask
 
     /**
      * Mark task as running
-     * 
+     *
      * @return void
      */
     protected function markAsRunning()
@@ -59,7 +58,7 @@ abstract class Periodic extends \XLite\Core\Task\ATask
 
         $this->release();
 
-        $this->model->setTriggerTime(\XLite\Core\Converter::time() + $this->getPeriod());
+        $this->model = \XLite\Core\Database::getEM()->merge($this->model);
+        $this->model->setTriggerTime($this->startTime + $this->getPeriod());
     }
-
 }
