@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,7 +19,7 @@ class EventListener extends \XLite\Core\Task\Base\Periodic
      */
     public function getTitle()
     {
-        return 'Event listener (DB)';
+        return static::t('Event listener (DB)');
     }
 
     /**
@@ -47,5 +46,4 @@ class EventListener extends \XLite\Core\Task\Base\Periodic
     {
         return 1800;
     }
-
 }
