@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,8 +15,8 @@ abstract class APair extends \XLite\Core\Validator\AValidator
     /**
      * Modes
      */
-    const STRICT = 'strict';
-    const SOFT   = 'soft';
+    public const STRICT = 'strict';
+    public const SOFT   = 'soft';
 
     /**
      * Validation mode
