@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -25,7 +24,7 @@ class Switcher extends \XLite\Core\Validator\TypeString
     {
         parent::validate($data);
 
-        if ('0' !== $data && '1' !== $data && '' !== $data) {
+        if ($data !== '0' && $data !== '1' && $data !== '') {
             throw $this->throwError('Not a switcher');
         }
     }
@@ -39,6 +38,6 @@ class Switcher extends \XLite\Core\Validator\TypeString
      */
     public function sanitize($data)
     {
-        return '' === $data ? null : (bool) $data;
+        return $data === '' ? null : (bool) $data;
     }
 }
