@@ -1,19 +1,16 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
  * See https://www.x-cart.com/license-agreement.html for license details.
  */
 
-
 namespace XLite\Core\View;
 
 use RuntimeException;
 use XLite\Core\Layout;
 use XLite\Core\View\DTO\Assets;
 
-
 /**
  * Asset registrar allows widgets to register their css and js assets to be included into the generated html
  */
@@ -39,7 +36,7 @@ class AssetRegistrar implements AssetRegistrarInterface
                 $buffer[] = $assets;
             }
         } else {
-            $this->layout->registerResources($assets->assets, $assets->index, $assets->interface, $assets->group);
+            $this->layout->registerResources($assets->assets, $assets->index, $assets->interface, $assets->zone, $assets->group);
         }
     }
 
@@ -48,7 +45,7 @@ class AssetRegistrar implements AssetRegistrarInterface
      */
     public function startBuffering()
     {
-        array_push($this->assetBuffers, []);
+        $this->assetBuffers[] = [];
     }
 
     /**
@@ -62,4 +59,4 @@ class AssetRegistrar implements AssetRegistrarInterface
 
         return array_pop($this->assetBuffers);
     }
-}
\ No newline at end of file
+}
