@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,7 +17,7 @@ class AllInOneSolutionService extends \XLite\Base\Singleton
      *
      * @var array
      */
-    protected $solutions = array();
+    protected $solutions = [];
 
     /**
      * Add solution
