@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -23,9 +22,9 @@ class AttributeSurcharge extends \XLite\Logic\ALogic
      *
      * @return boolean
      */
-    static public function isApply(\XLite\Model\AEntity $model, $property, array $behaviors, $purpose)
+    public static function isApply(\XLite\Model\AEntity $model, $property, array $behaviors, $purpose)
     {
-        return $model instanceOf \XLite\Model\OrderItem || $model instanceOf \XLite\Model\Product;
+        return $model instanceof \XLite\Model\OrderItem || $model instanceof \XLite\Model\Product;
     }
 
     /**
@@ -39,11 +38,11 @@ class AttributeSurcharge extends \XLite\Logic\ALogic
      *
      * @return float
      */
-    static public function modifyMoney($value, \XLite\Model\AEntity $model, $property, array $behaviors, $purpose)
+    public static function modifyMoney($value, \XLite\Model\AEntity $model, $property, array $behaviors, $purpose)
     {
         foreach (static::getAttributeValues($model) as $attributeValue) {
             if (
-                $attributeValue instanceOf \XLite\Model\OrderItem\AttributeValue
+                $attributeValue instanceof \XLite\Model\OrderItem\AttributeValue
                 && $attributeValue->getAttributeValue()
             ) {
                 $attributeValue = $attributeValue->getAttributeValue();
@@ -67,9 +66,9 @@ class AttributeSurcharge extends \XLite\Logic\ALogic
      *
      * @return array
      */
-    static protected function getAttributeValues(\XLite\Model\AEntity $model)
+    protected static function getAttributeValues(\XLite\Model\AEntity $model)
     {
-        return $model instanceOf \XLite\Model\Product
+        return $model instanceof \XLite\Model\Product
             ? $model->getAttrValues()
             : $model->getAttributeValues();
     }
