@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,14 +12,14 @@ namespace XLite\Logic\Export\Step;
  */
 abstract class AStep extends \XLite\Logic\ARepoStep
 {
-    const COLUMN_GETTER    = 'getter';
-    const COLUMN_MULTIPLE  = 'multiple';
-    const COLUMN_FORMATTER = 'formatter';
-    const COLUMN_ID        = 'id';
+    public const COLUMN_GETTER    = 'getter';
+    public const COLUMN_MULTIPLE  = 'multiple';
+    public const COLUMN_FORMATTER = 'formatter';
+    public const COLUMN_ID        = 'id';
 
-    const SUBVALUE_DELIMITER = '&&';
+    public const SUBVALUE_DELIMITER = '&&';
 
-    const DEFAULT_CHARSET = 'UTF-8';
+    public const DEFAULT_CHARSET = 'UTF-8';
 
     /**
      * File pointer
@@ -70,7 +69,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      *
      * @return integer
      */
-    public function count()
+    public function count(): int
     {
         if (!isset($this->countCache)) {
             $this->countCache = $this->getRepository()->countForExport();
@@ -94,13 +93,13 @@ abstract class AStep extends \XLite\Logic\ARepoStep
 
         $this->generator->setInProgress(true);
 
-        if (0 == $this->position) {
+        if ($this->position === 0) {
             $this->buildHeader();
         }
 
         $row = $this->getItems()->current();
 
-        $this->processModel($row[0]);
+        $this->processModel($row);
         $this->generator->setInProgress(false);
 
         $this->generator->getOptions()->time += round(microtime(true) - $time, 3);
@@ -142,7 +141,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      */
     protected function buildModelRows(\XLite\Model\AEntity $model)
     {
-        $rows = array();
+        $rows = [];
         foreach ($this->getModelDatasets($model) as $i => $dataset) {
             $rows[] = $this->buildDatasetRow($dataset, $i);
         }
@@ -159,9 +158,9 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      */
     protected function getModelDatasets(\XLite\Model\AEntity $model)
     {
-        return array(
-            array('model' => $model),
-        );
+        return [
+            ['model' => $model],
+        ];
     }
 
     /**
@@ -178,9 +177,9 @@ abstract class AStep extends \XLite\Logic\ARepoStep
         $i = 0;
         foreach ($models as $model) {
             if (!isset($datasets[$i])) {
-                $datasets[$i] = array(
+                $datasets[$i] = [
                     'model' => $datasets[0]['model'],
-                );
+                ];
             }
 
             $datasets[$i][$name] = $model;
@@ -201,7 +200,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      */
     protected function buildDatasetRow(array $dataset, $i)
     {
-        return 0 == $i ? $this->buildPrimaryRow($dataset) : $this->buildSecondaryRow($dataset, $i);
+        return $i == 0 ? $this->buildPrimaryRow($dataset) : $this->buildSecondaryRow($dataset, $i);
     }
 
     /**
@@ -213,13 +212,12 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      */
     protected function buildPrimaryRow(array $dataset)
     {
-        $row = array();
+        $row = [];
 
         foreach ($this->getColumns() as $name => $info) {
             $row[$name] = $this->{$info[static::COLUMN_GETTER]}($dataset, $name, 0);
             if ($info[static::COLUMN_FORMATTER]) {
                 $row[$name] = $this->{$info[static::COLUMN_FORMATTER]}($row[$name], $dataset, $name);
-
             } else {
                 $row[$name] = $this->formatDefault($row[$name], $dataset, $name);
             }
@@ -238,14 +236,13 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      */
     protected function buildSecondaryRow(array $dataset, $i)
     {
-        $row = array();
+        $row = [];
 
         foreach ($this->getColumns() as $name => $info) {
             if ($this->isColumnMultiple($info, $dataset, $name) || $this->isColumnId($info, $dataset, $name)) {
                 $row[$name] = $this->{$info[static::COLUMN_GETTER]}($dataset, $name, $i);
                 if ($info[static::COLUMN_FORMATTER]) {
                     $row[$name] = $this->{$info[static::COLUMN_FORMATTER]}($row[$name], $dataset, $name);
-
                 } else {
                     $row[$name] = $this->formatDefault($row[$name], $dataset, $name);
                 }
@@ -315,22 +312,16 @@ abstract class AStep extends \XLite\Logic\ARepoStep
     {
         if ($value instanceof \XLite\Model\Membership) {
             $value = $this->formatMembershipModel($value);
-
         } elseif ($value instanceof \XLite\Model\ProductClass) {
             $value = $this->formatProductClassModel($value);
-
         } elseif ($value instanceof \XLite\Model\TaxClass) {
             $value = $this->formatTaxClassModel($value);
-
         } elseif ($value instanceof \XLite\Model\AttributeGroup) {
             $value = $this->formatAttributeGroupModel($value);
-
         } elseif ($value instanceof \XLite\Model\Base\Image) {
             $value = $this->formatImageModel($value);
-
         } elseif ($value instanceof \XLite\Model\Base\Storage) {
             $value = $this->formatStorageModel($value);
-
         } else {
             $value = serialize($value);
         }
@@ -452,10 +443,9 @@ abstract class AStep extends \XLite\Logic\ARepoStep
         $copyResources = !is_null($copyResources) ? $copyResources : $this->generator->getOptions()->copyResources;
 
         if ($storage) {
-
             $result = $copyResources
                 ? \Includes\Utils\FileManager::getRelativePath($storage->getStoragePath(), LC_DIR_ROOT)
-                : $storage->getFrontURL();
+                : $storage->getURL();
         }
 
         return $result;
@@ -505,7 +495,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
     {
         $columns = $this->getColumns();
 
-        return isset($columns[$name]) ? $columns[$name] : null;
+        return $columns[$name] ?? null;
     }
 
     /**
@@ -532,7 +522,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
     {
         $i = 0;
         foreach ($this->columns as $name => $column) {
-            $uname = ucfirst($name);
+            $uname = \Includes\Utils\Converter::convertToUpperCamelCase($name);
             if (empty($column[static::COLUMN_GETTER])) {
                 $column[static::COLUMN_GETTER] = 'get' . $uname . 'ColumnValue';
             }
@@ -542,7 +532,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
             }
 
             if (!isset($column[static::COLUMN_ID])) {
-                $column[static::COLUMN_ID] = 0 == $i;
+                $column[static::COLUMN_ID] = $i == 0;
             }
 
             if (!isset($column[static::COLUMN_FORMATTER])) {
@@ -626,10 +616,10 @@ abstract class AStep extends \XLite\Logic\ARepoStep
             $this->generator->getOptions()->enclosure
         );
 
-        if (false === $result) {
+        if ($result === false) {
             $this->generator->addError(
                 static::t('Failed write to file'),
-                static::t('Failed write to file X. There may not be enough disc-space. Please check if there is enough disc-space.', array('path' => $this->filePath))
+                static::t('Failed write to file X. There may not be enough disc-space. Please check if there is enough disc-space.', ['path' => $this->filePath])
             );
         }
 
@@ -645,45 +635,19 @@ abstract class AStep extends \XLite\Logic\ARepoStep
     {
         if (!isset($this->filePointer)) {
             $name = $this->getFilename();
-            if ('.csv' != substr($name, -4)) {
+            if (substr($name, -4) != '.csv') {
                 $name .= '.csv';
             }
             $name = preg_replace('/(\.[^\.]+)$/', '-' . date('Y-m-d') . '$1', $name);
 
             $dir = \Includes\Utils\FileManager::getRealPath(LC_DIR_VAR . $this->generator->getOptions()->dir);
             if (is_writable($dir)) {
-                if (!\Includes\Utils\FileManager::isExists($dir . LC_DS . '.htaccess')) {
-                    // Try to create .htaccess file to protect directory
-                    $out = <<<OUT
-Options -Indexes
-
-<Files "*.php">
-  Deny from all
-</Files>
-
-<Files "*.php3">
-  Deny from all
-</Files>
-
-<Files "*.pl">
-  Deny from all
-</Files>
-
-<Files "*.py">
-  Deny from all
-</Files>
-
-Allow from all
-OUT;
-                    \Includes\Utils\FileManager::write($dir . LC_DS . '.htaccess', $out);
-                }
                 $this->filePath = $dir . LC_DS . $name;
                 $this->filePointer = @fopen($dir . LC_DS . $name, 'ab');
-
             } else {
                 $this->generator->addError(
                     static::t('Directory does not have permissions to write'),
-                    static::t('Directory X does not have permissions to write. Please set necessary permissions to directory X.', array('path' => $dir))
+                    static::t('Directory X does not have permissions to write. Please set necessary permissions to directory X.', ['path' => $dir])
                 );
             }
         }
@@ -700,7 +664,7 @@ OUT;
      */
     protected function normalizeRow(array $row)
     {
-        $result = array();
+        $result = [];
 
         foreach (array_keys($this->getColumns()) as $name) {
             $result[] = isset($row[$name]) ? $this->filterCellValue($name, $row[$name]) : '';
@@ -733,7 +697,8 @@ OUT;
      */
     protected function convertCharset(array $row)
     {
-        if (static::DEFAULT_CHARSET != $this->generator->getOptions()->charset
+        if (
+            $this->generator->getOptions()->charset != static::DEFAULT_CHARSET
             && \XLite\Core\Iconv::getInstance()->isValid()
         ) {
             $iconv = \XLite\Core\Iconv::getInstance();
