@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -36,4 +35,27 @@ class AttributeValueSelect extends \XLite\Logic\Export\Step\AttributeValues\AAtt
     {
         return $dataset['model']->getPosition();
     }
+
+    /**
+     * Get column value for 'displayMode' column
+     *
+     * @param array   $dataset Dataset
+     * @param string  $name    Column name
+     * @param integer $i       Subcolumn index
+     *
+     * @return string
+     */
+    protected function getDisplayModeColumnValue(array $dataset, $name, $i)
+    {
+        $result = '';
+
+        if (!$this->isAttributePropertyExported('displayMode', $dataset['model'])) {
+            $result = $dataset['model']->getAttribute()->getDisplayMode(
+                $dataset['model']->getProduct()
+            );
+            $this->setAttributePropertyExported('displayMode', $dataset['model']);
+        }
+
+        return $result;
+    }
 }
