@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,12 +15,12 @@ class Orders extends \XLite\Logic\Export\Step\AStep
     /**
      * Prefixes names
      */
-    const CUSTOMER_PREFIX            = 'customer';
-    const ITEM_PREFIX                = 'item';
-    const SURCHARGE_PREFIX           = 'surcharge';
-    const PAYMENT_TRANSACTION_PREFIX = 'paymentTransaction';
-    const ADDRESS_FIELD_SUFFIX       = 'AddressField';
-    const TRACKING_NUMBER_SUFFIX     = 'TrackingNumber';
+    public const CUSTOMER_PREFIX            = 'customer';
+    public const ITEM_PREFIX                = 'item';
+    public const SURCHARGE_PREFIX           = 'surcharge';
+    public const PAYMENT_TRANSACTION_PREFIX = 'paymentTransaction';
+    public const ADDRESS_FIELD_SUFFIX       = 'AddressField';
+    public const TRACKING_NUMBER_SUFFIX     = 'TrackingNumber';
 
     // {{{ Data
 
@@ -85,8 +84,8 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             static::CUSTOMER_PREFIX . 'AddressSame' => [],
         ];
 
-        foreach(\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
-            $name = ucfirst(\XLite\Core\Converter::convertToCamelCase($field->getServiceName()));
+        foreach (\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
+            $name = \Includes\Utils\Converter::convertToUpperCamelCase($field->getServiceName());
             $columns[static::CUSTOMER_PREFIX . $name . 'Billing' . static::ADDRESS_FIELD_SUFFIX] = [
                 static::COLUMN_GETTER    => 'getBillingAddressFieldValue',
                 static::COLUMN_FORMATTER => 'formatBillingAddressFieldValue',
@@ -94,8 +93,8 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             ];
         }
 
-        foreach(\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
-            $name = ucfirst(\XLite\Core\Converter::convertToCamelCase($field->getServiceName()));
+        foreach (\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
+            $name = \Includes\Utils\Converter::convertToUpperCamelCase($field->getServiceName());
             $columns[static::CUSTOMER_PREFIX . $name . 'Shipping' . static::ADDRESS_FIELD_SUFFIX] = [
                 static::COLUMN_GETTER    => 'getShippingAddressFieldValue',
                 static::COLUMN_FORMATTER => 'formatShippingAddressFieldValue',
@@ -110,6 +109,7 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             static::ITEM_PREFIX . 'Price'           => [static::COLUMN_MULTIPLE => true],
             static::ITEM_PREFIX . 'Quantity'        => [static::COLUMN_MULTIPLE => true],
             static::ITEM_PREFIX . 'Subtotal'        => [static::COLUMN_MULTIPLE => true],
+            static::ITEM_PREFIX . 'BackorderedAmount' => [static::COLUMN_MULTIPLE => true]
         ];
 
         foreach ($this->getOrderItemSurchargeTypes() as $type) {
@@ -149,17 +149,20 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             'currency'                              => [],
             'shippingMethod'                        => [],
             'trackingNumber'                        => [],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Method' => [static::COLUMN_MULTIPLE => true],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Status' => [static::COLUMN_MULTIPLE => true],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Value'  => [static::COLUMN_MULTIPLE => true],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Note'   => [static::COLUMN_MULTIPLE => true],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Type'   => [static::COLUMN_MULTIPLE => true],
-            static::PAYMENT_TRANSACTION_PREFIX . 'Id'     => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Method'   => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Status'   => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Value'    => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Note'     => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Type'     => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'SystemId' => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Id'       => [static::COLUMN_MULTIPLE => true],
+            static::PAYMENT_TRANSACTION_PREFIX . 'Data'     => [static::COLUMN_MULTIPLE => true],
             static::PAYMENT_TRANSACTION_PREFIX . 'Currency' => [static::COLUMN_MULTIPLE => true],
             'date'                                  => [],
             'recent'                                => [],
             'paymentStatus'                         => [],
             'shippingStatus'                        => [],
+            'stockStatus'                           => [],
             'notes'                                 => [],
             'adminNotes'                            => [],
             'detailCode'                            => [static::COLUMN_MULTIPLE => true],
@@ -319,6 +322,20 @@ class Orders extends \XLite\Logic\Export\Step\AStep
         return $dataset['model']->getShippingStatusCode();
     }
 
+    /**
+     * Get column value for 'stockStatus' column
+     *
+     * @param array   $dataset Dataset
+     * @param string  $name    Column name
+     * @param integer $i       Subcolumn index
+     *
+     * @return string
+     */
+    protected function getStockStatusColumnValue(array $dataset, $name, $i)
+    {
+        return $this->getColumnValueByName($dataset['model'], 'stockStatus');
+    }
+
     /**
      * Get column value for 'notes' column
      *
@@ -405,13 +422,10 @@ class Orders extends \XLite\Logic\Export\Step\AStep
 
         if (empty($address)) {
             $result = '';
-
-        } elseif ('state_id' == $column['service_name'] || 'custom_state' == $column['service_name']) {
+        } elseif ($column['service_name'] == 'state_id' || $column['service_name'] == 'custom_state') {
             $result = $address->getStateName();
-
-        } elseif ('country_code' == $column['service_name']) {
+        } elseif ($column['service_name'] == 'country_code') {
             $result = $address->getCountryCode();
-
         } else {
             $result = $address->getterProperty($column['service_name']);
         }
@@ -449,13 +463,10 @@ class Orders extends \XLite\Logic\Export\Step\AStep
 
         if (empty($address)) {
             $result = '';
-
-        } elseif ('state_id' == $column['service_name'] || 'custom_state' == $column['service_name']) {
+        } elseif ($column['service_name'] == 'state_id' || $column['service_name'] == 'custom_state') {
             $result = $address->getStateName();
-
-        } elseif ('country_code' == $column['service_name']) {
+        } elseif ($column['service_name'] == 'country_code') {
             $result = $address->getCountryCode();
-
         } else {
             $result = $address->getterProperty($column['service_name']);
         }
@@ -610,7 +621,7 @@ class Orders extends \XLite\Logic\Export\Step\AStep
     {
         $result = [];
 
-        if (isset($dataset['item']) && $dataset['item'] ) {
+        if (isset($dataset['item']) && $dataset['item']) {
             foreach ($dataset['item']->getAttributeValues() as $av) {
                 $result[] = $av->getActualName() . '=' . $av->getActualValue();
             }
@@ -635,6 +646,22 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             : $this->getColumnValueByName($dataset['item'], 'subtotal');
     }
 
+    /**
+     * Get column value for 'itemBackorderedAmount' column
+     *
+     * @param array   $dataset Dataset
+     * @param string  $name    Column name
+     * @param integer $i       Subcolumn index
+     *
+     * @return string
+     */
+    protected function getItemBackorderedAmountColumnValue(array $dataset, $name, $i)
+    {
+        return empty($dataset['item'])
+            ? ''
+            : $this->getColumnValueByName($dataset['item'], 'BackorderedAmount');
+    }
+
     /**
      * Get column value for 'itemTotal' column
      *
@@ -818,6 +845,22 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             : $this->getColumnValueByName($dataset['paymentTransaction'], 'type');
     }
 
+    /**
+     * Get column value for 'paymentTransactionSystemId' column
+     *
+     * @param array   $dataset Dataset
+     * @param string  $name    Column name
+     * @param integer $i       Subcolumn index
+     *
+     * @return string
+     */
+    protected function getPaymentTransactionSystemIdColumnValue(array $dataset, $name, $i)
+    {
+        return empty($dataset['paymentTransaction'])
+            ? ''
+            : $this->getColumnValueByName($dataset['paymentTransaction'], 'publicTxnId');
+    }
+
     /**
      * Get column value for 'paymentTransactionId' column
      *
@@ -834,6 +877,32 @@ class Orders extends \XLite\Logic\Export\Step\AStep
             : $this->getColumnValueByName($dataset['paymentTransaction'], 'public_id');
     }
 
+    /**
+     * Get column value for 'paymentTransactionData' column
+     *
+     * @param array   $dataset Dataset
+     * @param string  $name    Column name
+     * @param integer $i       Subcolumn index
+     *
+     * @return string
+     */
+    protected function getPaymentTransactionDataColumnValue(array $dataset, $name, $i)
+    {
+        if (empty($dataset['paymentTransaction'])) {
+            return '';
+        }
+
+        $customerData = [];
+        $transactionData = $this->getColumnValueByName($dataset['paymentTransaction'], 'data');
+        foreach ($transactionData as $data) {
+            if ($data->getAccessLevel() === \XLite\Model\Payment\TransactionData::ACCESS_CUSTOMER) {
+                $customerData[$data->getName()] = $data->getValue();
+            }
+        }
+
+        return serialize($customerData);
+    }
+
     /**
      * Get column value for 'paymentTransactionCurrency' column
      *
