@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -101,17 +100,15 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getAttributesColumns()
     {
-        $columns = array();
-
-        if ('none' !== $this->generator->getOptions()->attrs) {
+        $columns = [];
 
+        if ($this->generator->getOptions()->attrs !== 'none') {
             $cnd = new \XLite\Core\CommonCell();
 
-            if ('global' === $this->generator->getOptions()->attrs) {
+            if ($this->generator->getOptions()->attrs === 'global') {
                 $cnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT} = null;
                 $cnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT_CLASS} = null;
-
-            } elseif ('global_n_classes' === $this->generator->getOptions()->attrs) {
+            } elseif ($this->generator->getOptions()->attrs === 'global_n_classes') {
                 $cnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT} = null;
             }
 
@@ -122,15 +119,14 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
                 $start = 0;
 
                 do {
-                    $cnd->{\XLite\Model\Repo\Attribute::P_LIMIT} = array($start, $limit);
+                    $cnd->{\XLite\Model\Repo\Attribute::P_LIMIT} = [$start, $limit];
                     foreach (\XLite\Core\Database::getRepo('XLite\Model\Attribute')->search($cnd) as $attribute) {
                         $name = $this->getUniqueFieldName($attribute);
                         $column = $this->getAttributeColumn($attribute);
-                        if (\XLite\Model\Attribute::TYPE_TEXT === $attribute->getType()) {
+                        if ($attribute->getType() === \XLite\Model\Attribute::TYPE_TEXT) {
                             foreach ($this->getRepository()->getTranslationRepository()->getUsedLanguageCodes() as $code) {
                                 $columns[$name . '_' . $code] = $column;
                             }
-
                         } else {
                             $columns[$name] = $column;
                         }
@@ -138,7 +134,6 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
 
                     $count -= $limit;
                     $start += $limit;
-
                 } while ($count > 0);
             }
         }
@@ -155,14 +150,14 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getAttributeColumn($attribute)
     {
-        return array(
+        return [
             static::COLUMN_GETTER => 'getAttributeColumnValue',
             'attributeId'         => $attribute->getId(),
             'attributeName'       => $attribute->getName(),
             'attributeGroup'      => $attribute->getAttributeGroup() ? $attribute->getAttributeGroup()->getName() : '',
             'attributeIsProduct'  => (bool) $attribute->getProduct(),
             'attributeIsClass'    => (bool) $attribute->getProductClass(),
-        );
+        ];
     }
 
     /**
@@ -176,18 +171,15 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
     {
         $result = $attribute->getName() . ' (field:';
 
-        $cnd = new \XLite\Core\CommonCell;
+        $cnd = new \XLite\Core\CommonCell();
         $cnd->name = $attribute->getName();
 
         if ($attribute->getProduct()) {
             $result .= 'product';
-
         } elseif ($attribute->getProductClass()) {
             $result .= 'class';
-
         } elseif ($attribute->isHidden()) {
             $result .= 'hidden';
-
         } else {
             $result .= 'global';
         }
@@ -258,7 +250,7 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getMembershipsColumnValue(array $dataset, $name, $i)
     {
-        $result = array();
+        $result = [];
 
         foreach ($dataset['model']->getMemberships() as $membership) {
             $result[] = $membership->getName();
@@ -334,10 +326,13 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getImagesColumnValue(array $dataset, $name, $i)
     {
-        $result = array();
+        $result = [];
 
         foreach ($dataset['model']->getImages() as $image) {
-            $result[] = $this->formatImageModel($image);
+            $value = $this->formatImageModel($image);
+            if ($value) {
+                $result[] = $value;
+            }
         }
 
         return $result;
@@ -354,7 +349,7 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getImagesAltColumnValue(array $dataset, $name, $i)
     {
-        $result = array();
+        $result = [];
 
         foreach ($dataset['model']->getImages() as $image) {
             $result[] = $image->getAlt();
@@ -458,9 +453,9 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getCategoriesColumnValue(array $dataset, $name, $i)
     {
-        $result = array();
+        $result = [];
         foreach ($dataset['model']->getCategories() as $category) {
-            $path = array();
+            $path = [];
             foreach ($category->getRepository()->getCategoryPath($category->getCategoryId()) as $c) {
                 $path[] = $c->getName();
             }
@@ -481,7 +476,7 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function getInCategoriesPositionColumnValue(array $dataset, $name, $i)
     {
-        $result = array();
+        $result = [];
 
         // N.B. There is no need to order this
         // because Model\Product#getCategories() method just wrapping Model\Product#getCategoryProducts()
@@ -660,14 +655,14 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
     {
         $columns = $this->getColumns();
         $column = $columns[$name];
-        $result = array();
+        $result = [];
         $attribute = !empty($dataset['attribute']) ? $dataset['attribute'] : null;
 
-        if (null === $attribute && $column['attributeIsProduct']) {
+        if ($attribute === null && $column['attributeIsProduct']) {
             $attribute = $this->findProductSpecifiedAttribute($dataset['model'], $column['attributeName']);
         }
 
-        if (null === $attribute && $column['attributeIsClass']) {
+        if ($attribute === null && $column['attributeIsClass']) {
             $attribute = $this->findProductClassAttribute(
                 $dataset['model'],
                 $column['attributeName'],
@@ -675,7 +670,7 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
             );
         }
 
-        if (null === $attribute) {
+        if ($attribute === null) {
             $attribute = \XLite\Core\Database::getRepo('XLite\Model\Attribute')->find($column['attributeId']);
         }
 
@@ -685,19 +680,18 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
             )
         );
 
-        if (\XLite\Model\Attribute::TYPE_TEXT === $attribute->getType()) {
-            $value = $repo->findOneBy(array('product' => $dataset['model'], 'attribute' => $attribute));
+        if ($attribute->getType() === \XLite\Model\Attribute::TYPE_TEXT) {
+            $value = $repo->findOneBy(['product' => $dataset['model'], 'attribute' => $attribute]);
             if ($value) {
                 $result[] = $value->getTranslation(substr($name, -2))->getValue();
             }
-
         } else {
-            $values = $repo->findBy(array('product' => $dataset['model'], 'attribute' => $attribute));
+            $values = $repo->findBy(['product' => $dataset['model'], 'attribute' => $attribute]);
 
             if ($values) {
                 $isMultiple = $attribute->isMultiple($dataset['model']);
                 foreach ($values as $value) {
-                    $modifiers = array();
+                    $modifiers = [];
                     if ($isMultiple) {
                         if ($value->getDefaultValue()) {
                             $modifiers[] = 'default';
@@ -710,7 +704,7 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
                         }
                     }
 
-                    $result[] = $value->asString() . ($modifiers ? '=' . implode('/', $modifiers)  : '');
+                    $result[] = $value->asString() . ($modifiers ? '==' . implode('/', $modifiers)  : '');
                 }
             }
         }
@@ -729,8 +723,8 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
     protected function findProductSpecifiedAttribute($model, $name)
     {
         /** @var \XLite\Model\Attribute $item */
-        return array_reduce($model->getAttributes()->toArray(), function ($carry, $item) use ($name) {
-            return null === $carry && $name === $item->getName()
+        return array_reduce($model->getAttributes()->toArray(), static function ($carry, $item) use ($name) {
+            return $carry === null && $name === $item->getName()
                 ? $item
                 : $carry;
         }, null);
@@ -747,11 +741,11 @@ class Products extends \XLite\Logic\Export\Step\Base\I18n
      */
     protected function findProductClassAttribute($model, $name, $group)
     {
-        $attributes = $model->getProductClass() ? $model->getProductClass()->getAttributes()->toArray() : array();
+        $attributes = $model->getProductClass() ? $model->getProductClass()->getAttributes()->toArray() : [];
 
         /** @var \XLite\Model\Attribute $item */
-        return array_reduce($attributes, function ($carry, $item) use ($name, $group) {
-            return null === $carry
+        return array_reduce($attributes, static function ($carry, $item) use ($name, $group) {
+            return $carry === null
             && $name === $item->getName()
             && $group === ($item->getAttributeGroup() ? $item->getAttributeGroup()->getName() : '')
                 ? $item
