@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -15,9 +14,9 @@ use XLite\Core\Skin;
  */
 class Generator extends \XLite\Logic\AGenerator
 {
-    const MODEL_PRODUCT  = 'XLite\Model\Image\Product\Image';
-    const MODEL_CATEGORY = 'XLite\Model\Image\Category\Image';
-    const MODEL_LOGO     = 'XLite\Model\Image\Common\Logo';
+    public const MODEL_PRODUCT  = 'XLite\Model\Image\Product\Image';
+    public const MODEL_CATEGORY = 'XLite\Model\Image\Category\Image';
+    public const MODEL_LOGO     = 'XLite\Model\Image\Common\Logo';
 
     /**
      * Image sizes
@@ -42,28 +41,29 @@ class Generator extends \XLite\Logic\AGenerator
     {
         return [
             static::MODEL_PRODUCT  => [
-                'XXSThumbnail'     => [40, 40],
-                'XSThumbnail2'     => [58, 58], // Items list (admin area)
+                'XXSThumbnail'     => [60, 60],
+                'XSThumbnail2'     => [60, 60], // Items list (admin area)
                 'XSThumbnail'      => [60, 60], // Product thumbnail in the list of detailed images (details page)
-                'SMThumbnail'      => [80, 80], // Product thumbnail on the cart items list
-                'MDThumbnail'      => [122, 122],
-                'CommonThumbnail'  => [110, 110], // Products list thumbnail (mainly for sidebar lists)
+                'SMThumbnail'      => [60, 60], // Product thumbnail on the cart items list
+                'MDThumbnail'      => [120, 120],
+                'CommonThumbnail'  => [120, 120], // Products list thumbnail (mainly for sidebar lists)
                 'SBSmallThumbnail' => [160, 160], // Sidebar products list small thumbnail
-                'SBBigThumbnail'   => [160, 160], // Sidebar products list big thumbnail
+                'SBBigThumbnail'   => [240, 240], // Sidebar products list big thumbnail
                 'LGThumbnailList'  => [160, 160], // Center products list thumbnail
                 'LGThumbnailGrid'  => [160, 160], // Center products grid thumbnail
                 'Default'          => [300, 300], // Product thumbnail on the details page
-                'LGDefault'        => [600, 600], // Product detailed image on the details page
             ],
             static::MODEL_CATEGORY => [
-                'XXSThumbnail' => [40, 40],
-                'XSThumbnail2' => [58, 58],
-                'MDThumbnail'  => [122, 122],
-                'LGThumbnail'  => [160, 160],
-                'Default'      => [160, 160], // Category thumbnail
+                'XXSThumbnail' => [60, 60],
+                'XSThumbnail'  => [60, 60],
+                'MDThumbnail'  => [120, 120],
+                'LGThumbnail'  => [240, 240],
+                'Default'      => [240, 240], // Category thumbnail
             ],
-            static::MODEL_LOGO => [
-                'Default' => [0, 0],
+            static::MODEL_LOGO     => [
+                'Default' => [221, 40],
+                'Mobile'  => [30, 30],
+                'Invoice' => [330, 180],
             ],
         ];
     }
@@ -86,6 +86,8 @@ class Generator extends \XLite\Logic\AGenerator
             ],
             static::MODEL_LOGO     => [
                 'Default',
+                'Mobile',
+                'Invoice'
             ],
         ];
     }
@@ -122,7 +124,6 @@ class Generator extends \XLite\Logic\AGenerator
 
                 if (is_numeric($name)) {
                     $baseSizes[$model][] = $size;
-
                 } else {
                     $baseSizes[$model][$name] = $size;
                 }
@@ -143,7 +144,7 @@ class Generator extends \XLite\Logic\AGenerator
     {
         $sizes = static::getImageSizes();
 
-        return isset($sizes[$class]) ? $sizes[$class] : [];
+        return $sizes[$class] ?? [];
     }
 
     /**
@@ -166,9 +167,8 @@ class Generator extends \XLite\Logic\AGenerator
             }
         }
 
-        if (null !== $model && null !== $code) {
-            $result = isset(static::$imageSizesCache[$model][$code]) ? static::$imageSizesCache[$model][$code] : null;
-
+        if ($model !== null && $code !== null) {
+            $result = static::$imageSizesCache[$model][$code] ?? null;
         } else {
             $result = static::$imageSizesCache;
         }
@@ -199,6 +199,14 @@ class Generator extends \XLite\Logic\AGenerator
         return $result;
     }
 
+    /**
+     * @return void
+     */
+    public static function clearImageSizesCache()
+    {
+        static::$imageSizesCache = null;
+    }
+
     // {{{ Steps
 
     /**
