@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,28 +7,33 @@
 
 namespace XLite\Logic\Import;
 
+use XLite\Core\Config;
+use XLite\Logic\Import\Processor\Attributes;
+use XLite\Logic\Import\Processor\AttributeValues\AttributeValueCheckbox;
+use XLite\Logic\Import\Processor\AttributeValues\AttributeValueHidden;
+use XLite\Logic\Import\Processor\AttributeValues\AttributeValueSelect;
+use XLite\Logic\Import\Processor\AttributeValues\AttributeValueText;
+use XLite\Logic\Import\Processor\Categories;
+use XLite\Logic\Import\Processor\Customers;
+use XLite\Logic\Import\Processor\Products;
+
 /**
  * Importer
  */
-class Importer extends \XLite\Base
+class Importer extends \XLite\Base implements ImporterInterface
 {
     /**
      * Default import directory
      */
-    const IMPORT_DIR = 'import';
+    public const IMPORT_DIR = 'import';
 
-    const DEFAULT_CHARSET = 'UTF-8';
+    public const DEFAULT_CHARSET = 'UTF-8';
 
-    const PART_IDENTIFIER = '.part-';
+    public const PART_IDENTIFIER = '.part-';
 
-    const MAX_FILE_SIZE = 500000;
+    public const MAX_FILE_SIZE = 500000;
 
-    /**
-     * Language code
-     *
-     * @var string
-     */
-    static protected $languageCode;
+    protected static ?string $languageCode = null;
 
     /**
      * Options
@@ -57,38 +61,37 @@ class Importer extends \XLite\Base
      *
      * @param array $options Options OPTIONAL
      */
-    public function __construct(array $options = array())
+    public function __construct(array $options = [])
     {
-        $this->options = array(
-            'step'             => isset($options['step']) ? (int)($options['step']) : 0,
-            'position'         => isset($options['position']) ? (int)($options['position']) : 0,
-            'charset'          => !empty($options['charset']) ? $options['charset'] : static::DEFAULT_CHARSET,
-            'delimiter'        => isset($options['delimiter']) ? $options['delimiter'] : ',',
-            'enclosure'        => isset($options['enclosure']) ? $options['enclosure'] : '"',
-            'files'            => isset($options['files']) ? $options['files'] : array(),
-            'linkedFiles'      => isset($options['linkedFiles']) ? $options['linkedFiles'] : array(),
-            'deltaFiles'       => isset($options['deltaFiles']) ? $options['deltaFiles'] : array(),
-            'clearImportDir'     => isset($options['clearImportDir']) ? $options['clearImportDir'] : false,
-            'ignoreFileChecking' => isset($options['ignoreFileChecking']) ? $options['ignoreFileChecking'] : false,
-            'dir'              => isset($options['dir']) ? $options['dir'] : static::getImportDir(),
-            'time'             => isset($options['time']) ? (int)($options['time']) : 0,
-            'columnsMetaData'  => isset($options['columnsMetaData']) ? $options['columnsMetaData'] : array(),
-            'errorsCount'      => isset($options['errorsCount']) ? $options['errorsCount'] : 0,
-            'warningsCount'    => isset($options['warningsCount']) ? $options['warningsCount'] : 0,
-            'rowsCount'        => isset($options['rowsCount']) ? $options['rowsCount'] : 0,
-            'warningsAccepted' => isset($options['warningsAccepted']) ? $options['warningsAccepted'] : false,
-            'target'           => isset($options['target']) ? $options['target'] : static::getDefaultTarget(),
-            'importMode'       => isset($options['importMode']) ? $options['importMode'] : \XLite\View\Import\Begin::MODE_UPDATE_AND_CREATE,
-            // 'calculateAllQuickData' => isset($options['calculateAllQuickData']) ? $options['calculateAllQuickData'] : false,
-        ) + $options;
+        $this->options = [
+                'step'               => isset($options['step']) ? (int) ($options['step']) : 0,
+                'position'           => isset($options['position']) ? (int) ($options['position']) : 0,
+                'progressPosition'   => $options['progressPosition'] ?? 0,
+                'charset'            => !empty($options['charset']) ? $options['charset'] : static::DEFAULT_CHARSET,
+                'delimiter'          => $options['delimiter'] ?? ',',
+                'enclosure'          => $options['enclosure'] ?? '"',
+                'files'              => $options['files'] ?? [],
+                'linkedFiles'        => $options['linkedFiles'] ?? [],
+                'deltaFiles'         => $options['deltaFiles'] ?? [],
+                'clearImportDir'     => $options['clearImportDir'] ?? false,
+                'ignoreFileChecking' => $options['ignoreFileChecking'] ?? false,
+                'dir'                => $options['dir'] ?? static::getImportDir(),
+                'time'               => isset($options['time']) ? (int) ($options['time']) : 0,
+                'columnsMetaData'    => $options['columnsMetaData'] ?? [],
+                'errorsCount'        => $options['errorsCount'] ?? 0,
+                'warningsCount'      => $options['warningsCount'] ?? 0,
+                'rowsCount'          => $options['rowsCount'] ?? 0,
+                'progressRowsCount'  => $options['progressRowsCount'] ?? 0,
+                'warningsAccepted'   => $options['warningsAccepted'] ?? false,
+                'target'             => $options['target'] ?? static::getDefaultTarget(),
+                'importMode'         => $options['importMode'] ?? \XLite\View\Import\Begin::MODE_UPDATE_AND_CREATE,
+            ] + $options;
 
-        static::$languageCode = isset($options['languageCode'])
-            ? $options['languageCode']
-            : \XLite\Core\Config::getInstance()->General->default_admin_language;
+        static::$languageCode = $options['languageCode'] ?? \XLite\Core\Config::getInstance()->General->default_admin_language;
 
         $this->options = new \ArrayObject($this->options, \ArrayObject::ARRAY_AS_PROPS);
 
-        if ($options && 0 == $this->getOptions()->step && 0 == $this->getOptions()->position && !isset($this->getOptions()->initialized)) {
+        if ($options && $this->getOptions()->step == 0 && $this->getOptions()->position == 0 && !isset($this->getOptions()->initialized)) {
             $this->initialize();
         }
     }
@@ -103,26 +106,13 @@ class Importer extends \XLite\Base
         return 'import';
     }
 
-    /**
-     * Get language code
-     *
-     * @return string
-     */
-    public static function getLanguageCode()
+    public static function getLanguageCode(): ?string
     {
         return static::$languageCode;
     }
 
-    /**
-     * Set language code
-     *
-     * @param string $code Code
-     *
-     * @return void
-     */
-    public static function setLanguageCode($code)
+    public static function setLanguageCode(string $code): void
     {
-
         static::$languageCode = $code;
     }
 
@@ -135,14 +125,14 @@ class Importer extends \XLite\Base
      */
     public static function run(array $options)
     {
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setVar(static::getImportCancelFlagVarName(), false);
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setVar(static::getImportUserBreakFlagVarName(), false);
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->initializeEventState(
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setVar(static::getImportCancelFlagVarName(), false);
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setVar(static::getImportUserBreakFlagVarName(), false);
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->initializeEventState(
             static::getEventName(),
-            array('options' => $options)
+            ['options' => $options]
         );
         \XLite\Core\EventTask::import();
-        call_user_func(array('\XLite\Core\EventTask', static::getEventName()));
+        call_user_func(['\XLite\Core\EventTask', static::getEventName()]);
     }
 
     /**
@@ -152,13 +142,13 @@ class Importer extends \XLite\Base
      */
     public static function cancel()
     {
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setVar(static::getImportCancelFlagVarName(), true);
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setVar(static::getImportUserBreakFlagVarName(), false);
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setVar(static::getImportCancelFlagVarName(), true);
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setVar(static::getImportUserBreakFlagVarName(), false);
 
-        $state = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState(static::getEventName());
+        $state = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState(static::getEventName());
         \XLite\Core\Session::getInstance()->lastCancelledEventState = $state;
 
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->removeEventState(static::getEventName());
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->removeEventState(static::getEventName());
     }
 
     /**
@@ -192,7 +182,7 @@ class Importer extends \XLite\Base
      */
     public static function userBreak()
     {
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setVar(static::getImportUserBreakFlagVarName(), true);
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setVar(static::getImportUserBreakFlagVarName(), true);
     }
 
     /**
@@ -202,7 +192,7 @@ class Importer extends \XLite\Base
      */
     public function getAvailableEntityKeys()
     {
-        $result = array();
+        $result = [];
 
         foreach ($this->getProcessors() as $processor) {
             $keys = $processor->getAvailableEntityKeys();
@@ -222,7 +212,7 @@ class Importer extends \XLite\Base
     public function finalize()
     {
         if (!isset($this->getOptions()->commonData)) {
-            $this->getOptions()->commonData = array();
+            $this->getOptions()->commonData = [];
         }
         $this->getOptions()->commonData['finalize'] = true;
     }
@@ -241,7 +231,7 @@ class Importer extends \XLite\Base
         \XLite\Core\Database::getRepo('XLite\Model\ImportLog')->clearAll();
 
         // Convert charsets
-        if (static::DEFAULT_CHARSET != $this->getOptions()->charset) {
+        if ($this->getOptions()->charset != static::DEFAULT_CHARSET) {
             $iconv = \XLite\Core\Iconv::getInstance();
             foreach ($this->getCSVList() as $file) {
                 $iconv->convertFile(
@@ -253,18 +243,17 @@ class Importer extends \XLite\Base
         }
 
         // Preprocess import data
-        $rowsCount = $this->preprocessImport();
+        [$rowsCount, $progressRowsCount] = $this->preprocessImport();
 
         $this->getOptions()->rowsCount = $rowsCount;
+        $this->getOptions()->progressRowsCount = $progressRowsCount;
 
         // Save import options if they were changed
-        $record = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState('import');
+        $record = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->getEventState('import');
         // $record['state'] = \XLite\Core\EventTask::STATE_IN_PROGRESS;
         $record['options'] = $this->getOptions()->getArrayCopy();
         $record['options']['initialized'] = true;
-        \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->setEventState('import', $record);
-
-        \XLite\Core\Session::getInstance()->importedProductSkus = array();
+        \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class)->setEventState('import', $record);
     }
 
     /**
@@ -290,33 +279,48 @@ class Importer extends \XLite\Base
      * Check size limit of CSV files and divide them on several small parts.
      * Returns total count or rows
      *
-     * @return int
+     * @return array
      */
     protected function preprocessImport()
     {
-        $newFiles = array();
+        $newFiles = [];
 
         $totalRows = 0;
+        $totalProgressRows = 0;
 
         foreach ($this->getProcessors() as $processor) {
             $files = $processor->getFiles(true);
+            $totalRowsAreCounted = false;
+
             foreach ($files as $file) {
                 $fileSize = $file->getSize();
                 $fileName = $file->getBasename();
 
-                if (false === strpos($fileName, static::PART_IDENTIFIER) && $fileSize > static::MAX_FILE_SIZE) {
+                if (strpos($fileName, static::PART_IDENTIFIER) === false && $fileSize > static::MAX_FILE_SIZE) {
                     $dividedFiles = $processor->divideCSVFile($file);
                     $newFiles[$file->getRealPath()] = $dividedFiles;
 
-                    $totalRows += array_reduce($dividedFiles, static function ($carry, $item) {
-                        return $carry + $item['rowsCount'];
-                    }, 0);
+                    if ($processor->allowDividedRowsCalculate()) {
+                        $rows = array_reduce($dividedFiles, static function ($carry, $item) {
+                            return $carry + $item['rowsCount'];
+                        }, 0);
+                    } else {
+                        $rows = $processor->count();
+                    }
 
+                    $totalRows += $rows;
+                    $totalProgressRows += $rows * $processor->getProgressPositionIncrement();
                 } elseif (0 < $fileSize) {
                     // Add empty line at the end to avoid problems in some environments (see BUG-2636)
                     $this->correctLastNewline($file);
 
-                    $totalRows += $processor->count();
+                    if (!$totalRowsAreCounted) {
+                        $rows = $processor->count();
+
+                        $totalRows  += $rows;
+                        $totalProgressRows += $rows * $processor->getProgressPositionIncrement();
+                        $totalRowsAreCounted = true;
+                    }
                 }
             }
         }
@@ -329,16 +333,16 @@ class Importer extends \XLite\Base
                     foreach ($dstFiles as $fileData) {
                         $moveTo = $dir . LC_DS . basename($fileData['file']);
                         \Includes\Utils\FileManager::move($fileData['file'], $moveTo);
-                        $this->options->deltaFiles[basename($moveTo)] = array(
+                        $this->options->deltaFiles[basename($moveTo)] = [
                             'delta' => $fileData['delta'],
                             'file'  => basename($srcFile),
-                        );
+                        ];
                     }
                 }
             }
         }
 
-        return $totalRows;
+        return [$totalRows, $totalProgressRows];
     }
 
     /**
@@ -425,7 +429,7 @@ class Importer extends \XLite\Base
      *
      * @return boolean
      */
-    public function switchToNextStep(array $options = array())
+    public function switchToNextStep(array $options = [])
     {
         $result = false;
 
@@ -460,7 +464,6 @@ class Importer extends \XLite\Base
             $step = (isset($steps[$index]) && $steps[$index]->isAllowed())
                 ? $index
                 : null;
-
         } while ($index < $length && !$step);
 
         return $step;
@@ -475,12 +478,12 @@ class Importer extends \XLite\Base
      */
     public static function getImportOptionsList()
     {
-        return array(
+        return [
             'ignoreFileChecking',
             'charset',
             'delimiter',
             'importMode',
-        );
+        ];
     }
 
     /**
@@ -490,12 +493,12 @@ class Importer extends \XLite\Base
      */
     public static function getCommonImportOptionsList()
     {
-        return array(
-            'commonData'       => array(),
-            'columnsMetaData'  => array(),
+        return [
+            'commonData'       => [],
+            'columnsMetaData'  => [],
             'warningsAccepted' => false,
             'target'           => 'import',
-        );
+        ];
     }
 
     /**
@@ -505,16 +508,14 @@ class Importer extends \XLite\Base
      *
      * @return array
      */
-    public static function assembleImportOptions(array $options = array())
+    public static function assembleImportOptions(array $options = [])
     {
-        $result = array();
+        $result = [];
 
-        $importOptions = \XLite\Core\Config::getInstance()->Import;
+        $importOptions = Config::getInstance()->Import;
 
         foreach (static::getImportOptionsList() as $key) {
-            $result[$key] = isset($options[$key])
-                ? $options[$key]
-                : ($importOptions ? $importOptions->$key : null);
+            $result[$key] = $options[$key] ?? $importOptions ? $importOptions->$key : null;
         }
 
         return $result;
@@ -527,14 +528,12 @@ class Importer extends \XLite\Base
      *
      * @return array
      */
-    public static function assembleCommonImportOptions(array $options = array())
+    public static function assembleCommonImportOptions(array $options = [])
     {
-        $result = array();
+        $result = [];
 
         foreach (static::getCommonImportOptionsList() as $key => $default) {
-            $result[$key] = isset($options[$key])
-                ? $options[$key]
-                : $default;
+            $result[$key] = $options[$key] ?? $default;
         }
 
         return $result;
@@ -553,7 +552,7 @@ class Importer extends \XLite\Base
     {
         $steps = $this->getSteps();
 
-        return isset($steps[$this->getOptions()->step]) ? $steps[$this->getOptions()->step] : null;
+        return $steps[$this->getOptions()->step] ?? null;
     }
 
     /**
@@ -586,10 +585,8 @@ class Importer extends \XLite\Base
 
         if ($aw > $bw) {
             $result = 1;
-
         } elseif ($aw < $bw) {
             $result = -1;
-
         } else {
             $result = 0;
         }
@@ -604,13 +601,13 @@ class Importer extends \XLite\Base
      */
     protected function defineSteps()
     {
-        return array(
+        return [
             'XLite\Logic\Import\Step\Verification',
             'XLite\Logic\Import\Step\Import',
             'XLite\Logic\Import\Step\QuickData',
             'XLite\Logic\Import\Step\CategoriesStructure',
             'XLite\Logic\Import\Step\ImageResize',
-        );
+        ];
     }
 
     /**
@@ -625,7 +622,7 @@ class Importer extends \XLite\Base
             $this->steps[$i]->setDefaultWeight(($i + 1) * 100);
         }
 
-        usort($this->steps, array($this, 'sortSteps'));
+        usort($this->steps, [$this, 'sortSteps']);
 
         $this->steps = array_values($this->steps);
     }
@@ -656,16 +653,16 @@ class Importer extends \XLite\Base
      */
     public static function getProcessorList()
     {
-        return array(
-            'XLite\Logic\Import\Processor\Categories',
-            'XLite\Logic\Import\Processor\Products',
-            'XLite\Logic\Import\Processor\Attributes',
-            'XLite\Logic\Import\Processor\AttributeValues\AttributeValueCheckbox',
-            'XLite\Logic\Import\Processor\AttributeValues\AttributeValueSelect',
-            'XLite\Logic\Import\Processor\AttributeValues\AttributeValueText',
-            'XLite\Logic\Import\Processor\AttributeValues\AttributeValueHidden',
-            'XLite\Logic\Import\Processor\Customers',
-        );
+        return [
+            Categories::class,
+            Products::class,
+            Attributes::class,
+            AttributeValueCheckbox::class,
+            AttributeValueSelect::class,
+            AttributeValueText::class,
+            AttributeValueHidden::class,
+            Customers::class,
+        ];
     }
 
     /**
@@ -673,10 +670,10 @@ class Importer extends \XLite\Base
      */
     protected function prepareProcessors()
     {
+        /** @var string $processor */
         foreach ($this->processors as $i => $processor) {
-            if (\XLite\Core\Operator::isClassExists($processor)) {
+            if (class_exists($processor)) {
                 $this->processors[$i] = new $processor($this);
-
             } else {
                 unset($this->processors[$i]);
             }
@@ -697,7 +694,7 @@ class Importer extends \XLite\Base
     public static function hasWarnings()
     {
         return 0 < \XLite\Core\Database::getRepo('XLite\Model\ImportLog')
-            ->countBy(array('type' => \XLite\Model\ImportLog::TYPE_WARNING));
+            ->countBy(['type' => \XLite\Model\ImportLog::TYPE_WARNING]);
     }
 
     /**
@@ -708,7 +705,7 @@ class Importer extends \XLite\Base
     public static function hasErrors()
     {
         return 0 < \XLite\Core\Database::getRepo('XLite\Model\ImportLog')
-            ->countBy(array('type' => \XLite\Model\ImportLog::TYPE_ERROR));
+            ->countBy(['type' => \XLite\Model\ImportLog::TYPE_ERROR]);
     }
 
     // }}}
@@ -718,7 +715,7 @@ class Importer extends \XLite\Base
     /**
      * Get CSV files list
      *
-     * @return \Includes\Utils\FileFilter\FilterIterator
+     * @return \Includes\Utils\FileFilter
      */
     public function getCSVList()
     {
@@ -733,23 +730,23 @@ class Importer extends \XLite\Base
 
     /**
      * Delete all files
-     *
-     * @return void
      */
     public function deleteAllFiles()
     {
         $dir = \Includes\Utils\FileManager::getRealPath(LC_DIR_VAR . $this->getOptions()->dir);
+        if (empty($dir)) {
+            return; # XCB-1853
+        }
 
         if (!\Includes\Utils\FileManager::isExists($dir)) {
             \Includes\Utils\FileManager::mkdir($dir);
         }
 
-        $list = glob($dir . LC_DS . '*');
+        $list = glob($dir . '/*');
         if ($list) {
             foreach ($list as $path) {
                 if (is_file($path)) {
                     \Includes\Utils\FileManager::deleteFile($path);
-
                 } else {
                     \Includes\Utils\FileManager::unlinkRecursive($path);
                 }
