@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -27,35 +26,35 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      *
      * @var array
      */
-    protected $classesCache = array();
+    protected $classesCache = [];
 
     /**
      * Attribute groups cache
      *
      * @var array
      */
-    protected $groupsCache = array();
+    protected $groupsCache = [];
 
     /**
      * Attributes cache
      *
      * @var array
      */
-    protected $attributesCache = array();
+    protected $attributesCache = [];
 
     /**
      * Products cache
      *
      * @var array
      */
-    protected $productsCache = array();
+    protected $productsCache = [];
 
     /**
      * Products cache
      *
      * @var array
      */
-    protected $attrsCache = array();
+    protected $attrsCache = [];
 
 
     /**
@@ -63,7 +62,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      *
      * @return string
      */
-    static public function getTitle()
+    public static function getTitle()
     {
         return static::t('Product attributes values has been imported');
     }
@@ -118,6 +117,8 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
             'editable'          => [],
             'attributePosition' => [],
             'valuePosition'     => [],
+            'displayMode'       => [],
+            'displayAbove'      => [],
         ];
     }
 
@@ -131,10 +132,10 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     public static function getMessages()
     {
         return parent::getMessages()
-            + array(
+            + [
                 'ATTRS-PRODUCT-SKU-FMT'     => 'ProductSKU is empty',
                 'ATTRS-PRODUCT-NOT-EXISTS'  => 'Product with SKU "{{value}}" does not exists',
-                'ATTRS-TYPE-FMT'            => 'Wrong "type" value ({{value}}). This should be "C", "S" or "T"',
+                'ATTRS-TYPE-FMT'            => 'Wrong "type" value ({{value}}). This should be "C", "S", "H" or "T"',
                 'ATTRS-NAME-FMT'            => 'Name is empty',
                 'ATTRS-OWNER-FMT'           => 'Wrong "owner" format ({{value}}). Value should be one of "Yes" or "No"',
                 'ATTRS-DEFAULT-FMT'         => 'Wrong "default" format ({{value}}). Value should be one of "Yes" or "No"',
@@ -143,7 +144,10 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
                 'ATTRS-CLASS-WRN'           => 'Product class {{value}} does not exists and will be created',
                 'ATTRS-GROUP-WRN'           => 'Group {{value}} does not exists and will be created',
                 'ATTRS-EDITABLE-FMT'        => 'Wrong "owner" format ({{value}}). Value should be one of "Yes" or "No" or empty',
-            );
+                'ATTR-MODE-S-FMT'           => 'Wrong display mode format for selector',
+                'ATTR-MODE-NOT-S-FMT'       => 'Wrong display mode format for not selector',
+                'ATTR-DISPLAY-ABOVE-FMT'    => 'Wrong display above price format',
+            ];
     }
 
     /**
@@ -153,7 +157,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     public static function getCSVFormatManualURL()
     {
-        return static::t('https://kb.x-cart.com/import-export/csv_format_by_x-cart_data_type/csv_import_product_attribute_values.html');
+        return static::t('https://support.x-cart.com/en/articles/5387445-csv-import-product-attribute-values');
     }
 
     /**
@@ -165,7 +169,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function isImportedFile(\SplFileInfo $file)
     {
-        return 0 === strpos($file->getFilename(), 'product-attributes');
+        return strpos($file->getFilename(), 'product-attributes') === 0;
     }
 
     /**
@@ -175,26 +179,27 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      *
      * @return array
      */
-    protected function assembleColumnsData(array $rows)
+    public function assembleColumnsData(array $rows, ?bool $normalize = null)
     {
         $typeRaw = $this->getColumn('type');
         $typeProcessed = $this->processColumn('type', $typeRaw);
         $type = $this->assembleColumnData($typeProcessed, $rows);
 
         return !$type || $this->attributeType != $type
-            ? array()
+            ? []
             : parent::assembleColumnsData($rows);
     }
 
     /**
      * Check if product will be added
+     *
+     * @param string $sku
+     *
+     * @return boolean
      */
-    protected function isProductWillBeAdded($sku){
-        $products = \XLite\Core\Session::getInstance()->importedProductSkus;
-
-        return null !== $products
-            ? in_array($sku, $products)
-            : false;
+    protected function isProductWillBeAdded($sku)
+    {
+        return \XLite\Core\Database::getRepo('XLite\Model\ImportLog')->isSkuWillBeAdded($sku);
     }
 
     /**
@@ -208,13 +213,12 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyProductSKU($value, array $column)
     {
         if ($this->verifyValueAsEmpty($value)) {
-            $this->addError('ATTRS-PRODUCT-SKU-FMT', array('column' => $column, 'value' => $value));
-
+            $this->addError('ATTRS-PRODUCT-SKU-FMT', ['column' => $column, 'value' => $value]);
         } elseif (!$this->isUpdateMode()) {
-            $product = \XLite\Core\Database::getRepo('XLite\Model\Product')->findOneBy(array('sku' => $value));
+            $product = \XLite\Core\Database::getRepo('XLite\Model\Product')->findOneBy(['sku' => $value]);
 
             if (!$product && !$this->isProductWillBeAdded($value)) {
-                $this->addError('ATTRS-PRODUCT-NOT-EXISTS', array('column' => $column, 'value' => $value));
+                $this->addError('ATTRS-PRODUCT-NOT-EXISTS', ['column' => $column, 'value' => $value]);
             }
         }
     }
@@ -229,8 +233,8 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function verifyType($value, array $column)
     {
-        if (!$this->verifyValueAsSet($value, array('C', 'S', 'T'))) {
-            $this->addError('ATTRS-TYPE-FMT', array('column' => $column, 'value' => $value));
+        if (!$this->verifyValueAsSet($value, ['C', 'S', 'T', 'H'])) {
+            $this->addError('ATTRS-TYPE-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -245,7 +249,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyName($value, array $column)
     {
         if ($this->verifyValueAsEmpty($value)) {
-            $this->addError('ATTRS-NAME-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('ATTRS-NAME-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -259,8 +263,8 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function verifyOwner($value, array $column)
     {
-        if (!$this->verifyValueAsBoolean($value)) {
-            $this->addError('ATTRS-OWNER-FMT', array('column' => $column, 'value' => $value));
+        if ($this->verificationRequired($value) && !$this->verifyValueAsBoolean($value)) {
+            $this->addError('ATTRS-OWNER-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -274,8 +278,8 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function verifyDefault($value, array $column)
     {
-        if (!$this->verifyValueAsBoolean($value)) {
-            $this->addError('ATTRS-DEFAULT-FMT', array('column' => $column, 'value' => $value));
+        if ($this->verificationRequired($value) && !$this->verifyValueAsBoolean($value)) {
+            $this->addError('ATTRS-DEFAULT-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -290,7 +294,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyPriceModifier($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->checkModifierFormat($value)) {
-            $this->addError('ATTRS-PRICE-MODIFIER-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('ATTRS-PRICE-MODIFIER-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -305,10 +309,21 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyWeightModifier($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->checkModifierFormat($value)) {
-            $this->addError('ATTRS-WEIGHT-MODIFIER-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('ATTRS-WEIGHT-MODIFIER-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
+    /**
+     * Allow to skip missing values in the update mode
+     * @param $value
+     *
+     * @return bool
+     */
+    protected function verificationRequired($value)
+    {
+        return isset($value) || !$this->isUpdateMode();
+    }
+
     protected function checkModifierFormat($value)
     {
         return true;
@@ -325,11 +340,10 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyClass($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value)) {
-
             $entity = \XLite\Core\Database::getRepo('XLite\Model\ProductClass')->findOneByName($value);
 
             if (!$entity) {
-                $this->addWarning('ATTRS-CLASS-WRN', array('column' => $column, 'value' => $value));
+                $this->addWarning('ATTRS-CLASS-WRN', ['column' => $column, 'value' => $value]);
             }
         }
     }
@@ -345,11 +359,10 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyGroup($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value)) {
-
             $entity = \XLite\Core\Database::getRepo('XLite\Model\AttributeGroup')->findOneByName($value);
 
             if (!$entity) {
-                $this->addWarning('ATTRS-GROUP-WRN', array('column' => $column, 'value' => $value));
+                $this->addWarning('ATTRS-GROUP-WRN', ['column' => $column, 'value' => $value]);
             }
         }
     }
@@ -365,14 +378,100 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyEditable($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
-            $this->addError('ATTRS-EDITABLE-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('ATTRS-EDITABLE-FMT', ['column' => $column, 'value' => $value]);
+        }
+    }
+
+    /**
+     * Verify 'displayMode' value
+     *
+     * @param mixed $value  Value
+     * @param array $column Column info
+     *
+     * @return void
+     */
+    protected function verifyDisplayMode($value, array $column)
+    {
+        if ($this->isDisplayModeVerified($this->currentRowData)) {
+            return;
+        }
+
+        if ($this->currentRowData['type'] === \XLite\Model\Attribute::TYPE_SELECT) {
+            $availableDisplayModes = \XLite\Model\Attribute::getDisplayModes();
+            if ($this->verificationRequired($value) && !isset($availableDisplayModes[$value])) {
+                $this->addError('ATTR-MODE-S-FMT', ['column' => $column, 'value' => $value]);
+            }
+        } elseif (!$this->verifyValueAsEmpty($value)) {
+            $this->addError('ATTR-MODE-NOT-S-FMT', ['column' => $column, 'value' => $value]);
+        }
+
+        $this->setDisplayModeVerified($this->currentRowData);
+    }
+
+    /**
+     * @param array $rowData
+     *
+     * @return bool
+     */
+    protected function isDisplayModeVerified(array $rowData)
+    {
+        $options = $this->importer->getOptions();
+
+        $key = $this->getDisplayModeVerifiedKey($rowData);
+
+        return isset($options[$key]) && $options[$key] === true;
+    }
+
+    /**
+     * @param array $rowData
+     */
+    protected function setDisplayModeVerified(array $rowData)
+    {
+        $options = $this->importer->getOptions();
+
+        $key = $this->getDisplayModeVerifiedKey($rowData);
+
+        $options[$key] = true;
+        $this->importer->setOptions($options);
+    }
+
+    /**
+     * @param array $rowData
+     *
+     * @return string
+     */
+    protected function getDisplayModeVerifiedKey(array $rowData)
+    {
+        return implode('.', [
+            'displayModeVerify',
+            $rowData['productSKU'],
+            $rowData['type'],
+            $rowData['name'],
+            $rowData['class'] ?? '',
+            $rowData['group'] ?? '',
+            $rowData['owner'] ?? '',
+        ]);
+    }
+
+    /**
+     * Verify 'displayAbove' value
+     *
+     * @param mixed $value  Value
+     * @param array $column Column info
+     *
+     * @return void
+     */
+    protected function verifyDisplayAbove($value, array $column)
+    {
+        if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
+            $this->addError('ATTR-DISPLAY-ABOVE-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
     /**
      * Normalize 'owner' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return boolean
      */
@@ -494,7 +593,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function importEditableColumn($model, $value, array $column)
     {
-        if (\XLite\Model\Attribute::TYPE_TEXT == $model->getAttribute()->getType()) {
+        if ($model->getAttribute()->getType() == \XLite\Model\Attribute::TYPE_TEXT) {
             $model->setEditable($this->normalizeValueAsBoolean($value));
         }
     }
@@ -528,7 +627,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
         }
 
         if ($create && !empty($name) && !$this->classesCache[$name]) {
-            $entity = new \XLite\Model\ProductClass;
+            $entity = new \XLite\Model\ProductClass();
             $entity->setName($name);
             $productClass = \XLite\Core\Database::getRepo('XLite\Model\ProductClass')->insert($entity);
 
@@ -557,7 +656,7 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
         }
 
         if ($create && !empty($name) && $productClass && !$this->groupsCache[$cacheKey]) {
-            $entity = new \XLite\Model\AttributeGroup;
+            $entity = new \XLite\Model\AttributeGroup();
             $entity->setName($name);
             $entity->setProductClass($productClass);
             $group = \XLite\Core\Database::getRepo('XLite\Model\AttributeGroup')->insert($entity);
@@ -579,14 +678,18 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function getAttribute($data)
     {
-        $keyData = array(
+        $keyData = [
             'p:' . $data['productSKU'],
             't:' . $data['type'],
             'c:' . $data['class'],
             'g:' . $data['group'],
             'o:' . $data['owner'],
             'n:' . $data['name'],
-        );
+        ];
+
+        if (isset($data['productVendor'])) {
+            $keyData[] = 'v:' . $data['productVendor'];
+        }
 
         $key = implode(';', $keyData);
 
@@ -594,10 +697,9 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
             $cnd = new \XLite\Core\CommonCell();
 
             if ($data['owner']) {
-                $cnd->product        = $this->getProduct($data['productSKU']);
+                $cnd->product        = $this->getProductByData($data);
                 $cnd->productClass   = null;
                 $cnd->attributeGroup = null;
-
             } else {
                 $cnd->product        = null;
                 $cnd->productClass   = $this->getProductClass($data['class']);
@@ -611,7 +713,6 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
 
             if ($attribute) {
                 $attribute = $attribute[0];
-
             } else {
                 $attribute = null;
             }
@@ -623,21 +724,34 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     }
 
     /**
-     * Get cached attribute group by its name
+     * Get cached product by SKU
      *
-     * @param string $name Attribute group name
+     * @param string $sku Product SKU
      *
-     * @return \XLite\Model\AttributeGroup Attribute group object
+     * @return \XLite\Model\Product|null
      */
     protected function getProduct($sku)
     {
         if (!isset($this->productsCache[$sku])) {
-            $this->productsCache[$sku] = \XLite\Core\Database::getRepo('XLite\Model\Product')->findOneBy(array('sku' => $sku));
+            $this->productsCache[$sku] = \XLite\Core\Database::getRepo('XLite\Model\Product')->findOneBy(['sku' => $sku]);
         }
 
         return $this->productsCache[$sku];
     }
 
+    /**
+     * Get product by row data
+     *
+     * @param array $data
+     * @return \XLite\Model\Product|null
+     */
+    protected function getProductByData(array $data)
+    {
+        $sku = $data['productSKU'] ?? '';
+
+        return $sku ? $this->getProduct($sku) : null;
+    }
+
     /**
      * Create model
      *
@@ -647,21 +761,25 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function createModel(array $data)
     {
+        $model = null;
+
         $data['owner'] = $this->normalizeValueAsBoolean($data['owner']);
 
-        $product = $this->getProduct($data['productSKU']);
+        $product = $this->getProductByData($data);
 
-        $attribute = $this->getAttribute($data);
+        if ($product) {
+            $attribute = $this->getAttribute($data);
 
-        if (!$attribute) {
-            $attribute = $this->createAttribute($data);
+            if (!$attribute) {
+                $attribute = $this->createAttribute($data);
+            }
+
+            $model = $this->getRepository()->insert($this->getAttributeValueData($data, $attribute));
+
+            $model->setAttribute($attribute);
+            $model->setProduct($product);
         }
 
-        $model = $this->getRepository()->insert($this->getAttributeValueData($data, $attribute));
-
-        $model->setAttribute($attribute);
-        $model->setProduct($product);
-
         return $model;
     }
 
@@ -675,9 +793,9 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function getAttributeValueData($data, $attribute)
     {
-        return array(
+        return [
             'value' => $data['value'],
-        );
+        ];
     }
 
     /**
@@ -697,28 +815,27 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      *
      * @param array $data Import row data
      *
-     * @return array 
+     * @return array
      */
     protected function getAttributeData($data)
     {
-        if ($data['owner']) {
-            $product        = $this->getProduct($data['productSKU']);
+        if (!empty($data['owner'])) {
+            $product        = $this->getProductByData($data);
             $productClass   = null;
             $attributeGroup = null;
-
         } else {
             $product        = null;
             $productClass   = $this->getProductClass($data['class'], true);
             $attributeGroup = $this->getAttributeGroup($data['group'], $productClass, true);
         }
 
-        return array(
+        return [
             'name'           => $data['name'],
             'productClass'   => $productClass,
             'attributeGroup' => $attributeGroup,
             'product'        => $product,
             'type'           => $data['type'],
-        );
+        ];
     }
 
 
@@ -733,12 +850,56 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function importAttributePositionColumn($model, $value, array $column)
     {
-        if ($value && !$this->isAttributePositionImported($model)) {
+        if ($value && !$this->isAttributePropertyImported('attributePosition', $model)) {
             $model->getAttribute()->setPosition([
                 'product'  => $model->getProduct(),
                 'position' => $value
             ]);
-            $this->setAttributePositionImported($model);
+            $this->setAttributePropertyImported('attributePosition', $model);
+        }
+    }
+
+    /**
+     * Import 'displayMode' value
+     *
+     * @param \XLite\Model\AttributeValue\AttributeValueSelect $model  Attribute value object
+     * @param mixed                                            $value  Value
+     * @param array                                            $column Column info
+     *
+     * @return void
+     */
+    protected function importDisplayModeColumn($model, $value, array $column)
+    {
+        if ($value && !$this->isAttributePropertyImported('displayMode', $model)) {
+            $model->getAttribute()
+                ->getProperty($model->getProduct())
+                ->setDisplayMode($value);
+
+            $this->setAttributePropertyImported('displayMode', $model);
+        }
+    }
+
+    /**
+     * Import 'displayAbove' value
+     *
+     * @param AttributeValue\AAttributeValue $model  Attribute value object
+     * @param mixed                          $value  Value
+     * @param array                          $column Column info
+     *
+     * @return void
+     */
+    protected function importDisplayAboveColumn($model, $value, array $column)
+    {
+        if (
+            !$this->verifyValueAsEmpty($value)
+            && $this->verifyValueAsBoolean($value)
+            && !$this->isAttributePropertyImported('displayAbove', $model)
+        ) {
+            $model->getAttribute()
+                ->getProperty($model->getProduct())
+                ->setDisplayAbove($this->normalizeValueAsBoolean($value));
+
+            $this->setAttributePropertyImported('displayAbove', $model);
         }
     }
 
@@ -756,40 +917,44 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
     }
 
     /**
+     * @param string                         $property
      * @param AttributeValue\AAttributeValue $attributeValue
      *
      * @return bool
      */
-    protected function isAttributePositionImported(AttributeValue\AAttributeValue $attributeValue)
+    protected function isAttributePropertyImported($property, AttributeValue\AAttributeValue $attributeValue)
     {
         $options = $this->importer->getOptions();
 
-        $key = $this->getAttributePositionImportedKey($attributeValue);
+        $key = $this->getAttributePropertyImportedKey($property, $attributeValue);
 
         return isset($options[$key]) && $options[$key] === true;
     }
 
     /**
+     * @param string                         $property
      * @param AttributeValue\AAttributeValue $attributeValue
      */
-    protected function setAttributePositionImported(AttributeValue\AAttributeValue $attributeValue)
+    protected function setAttributePropertyImported($property, AttributeValue\AAttributeValue $attributeValue)
     {
         $options = $this->importer->getOptions();
 
-        $key = $this->getAttributePositionImportedKey($attributeValue);
+        $key = $this->getAttributePropertyImportedKey($property, $attributeValue);
 
         $options[$key] = true;
         $this->importer->setOptions($options);
     }
 
     /**
+     * @param string                         $property
      * @param AttributeValue\AAttributeValue $attributeValue
      *
      * @return string
      */
-    protected function getAttributePositionImportedKey(AttributeValue\AAttributeValue $attributeValue)
+    protected function getAttributePropertyImportedKey($property, AttributeValue\AAttributeValue $attributeValue)
     {
         return implode('.', [
+            $property,
             $attributeValue->getProduct()
                 ? $attributeValue->getProduct()->getProductId()
                 : 'none',
@@ -798,4 +963,14 @@ abstract class AAttributeValue extends \XLite\Logic\Import\Processor\AProcessor
                 : 'none',
         ]);
     }
+
+    /**
+     * Get increment value for position in lines imported label
+     *
+     * @return float
+     */
+    public function getProgressPositionIncrement()
+    {
+        return 0.25;
+    }
 }
