@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\Logic\Import\Processor;
 
+use XLite\Logic\Import\Console\ConsoleImporterInterface;
+
 /**
  * Categories import processor
  */
@@ -49,7 +50,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
      *
      * @return void
      */
-    protected function initialize()
+    public function initialize()
     {
         parent::initialize();
 
@@ -129,6 +130,26 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
 
     // }}}
 
+    // {{{ Column metadata
+
+    /**
+     * Get value for default language, allow to get non-default value right from file
+     *
+     * @param mixed $value Value
+     *
+     * @return mixed
+     */
+    protected function getDefLangValue($value)
+    {
+        $parent_value = parent::getDefLangValue($value);
+        if (is_null($parent_value) && is_array($value) && !empty($value)) {
+            $parent_value = array_values($value)[0];
+        }
+
+        return $parent_value;
+    }
+    // }}}
+
     // {{{ Verification
 
     /**
@@ -166,7 +187,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
      */
     public static function getCSVFormatManualURL()
     {
-        return static::t('https://kb.x-cart.com/import-export/csv_format_by_x-cart_data_type/csv_import_categories.html');
+        return static::t('https://support.x-cart.com/en/articles/5370878-csv-import-categories');
     }
 
     /**
@@ -178,8 +199,8 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyIdentity($value, array $column)
     {
         if (!empty($value['categoryId'])) {
-            if (!$this->getRepository()->find((integer)$value['categoryId'])) {
-                $this->addWarning('CATEGORY-CATEGORY-ID-NF', ['column' => $column, 'value' => (integer)$value['categoryId']]);
+            if (!$this->getRepository()->find((int)$value['categoryId'])) {
+                $this->addWarning('CATEGORY-CATEGORY-ID-NF', ['column' => $column, 'value' => (int)$value['categoryId']]);
             }
         } elseif (isset($value['path'])) {
             $model = $this->getCategoryByPath($value['path'], false);
@@ -333,7 +354,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
 
         if ($this->verifyValueAsEmpty($value)) {
             $this->addError('CATEGORY-NAME-FMT', ['column' => $column, 'value' => $value]);
-        } else if (!$this->verifyValueAsUtf8mb3($value)) {
+        } elseif (!$this->verifyValueAsUtf8mb3($value)) {
             $this->addError('CATEGORY-NAME-COLLATION', ['column' => $column]);
         }
     }
@@ -408,7 +429,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'enabled' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return boolean
      */
@@ -420,7 +441,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'show title' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return boolean
      */
@@ -432,7 +453,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'position' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return integer
      */
@@ -445,20 +466,6 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
 
     // {{{ Import
 
-    /**
-     * Import data
-     *
-     * @param array $data Row set Data
-     *
-     * @return boolean
-     */
-    protected function importData(array $data)
-    {
-        \Xlite\Core\Database::getRepo('XLite\Model\Product')->setBlockQuickDataFlag(true);
-
-        return parent::importData($data);
-    }
-
     /**
      * Detect model
      *
@@ -469,11 +476,11 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     protected function detectModel(array $data)
     {
         if (!empty($data['categoryId'])) {
-            $model = $this->getRepository()->find((integer)$data['categoryId']);
+            $model = $this->getRepository()->find((int)$data['categoryId']);
         }
 
         if (!isset($model) || !$model) {
-            $path = isset($data['path']) ? $data['path'] : '';
+            $path = $data['path'] ?? '';
             $model = $this->getCategoryByPath($path, false);
         }
 
@@ -489,7 +496,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function createModel(array $data)
     {
-        $path = isset($data['path']) ? $data['path'] : '';
+        $path = $data['path'] ?? '';
         $path = explode('>>>', $path);
         $lastElement = count($path) ? trim(array_pop($path)) : '';
         $name = trim($this->getDefLangValue($data['name']));
@@ -501,6 +508,16 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
         return parent::createModel($data);
     }
 
+    protected function updateModel(\XLite\Model\AEntity $model, array $data)
+    {
+        if (!$model->isPersistent()) {
+            \XLite\Core\Database::getEM()->persist($model);
+            \XLite\Core\Database::getEM()->flush();
+        }
+
+        return parent::updateModel($model, $data);
+    }
+
     /**
      * Import 'categoryId' value
      *
@@ -536,6 +553,13 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
         $cacheKey = implode('/', $path);
         $model->setName(array_pop($path));
         $model->setParent($this->addCategoryByPath($path));
+        if (!$model->isPersistent()) {
+            \XLite\Core\Database::getEM()->persist($model);
+            if (!($this->importer instanceof ConsoleImporterInterface)) {
+                \XLite\Core\Database::getEM()->flush();
+            }
+        }
+
         $this->setCategoryByPathCache($cacheKey, $model);
     }
 
@@ -552,9 +576,6 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
     {
         if ($value) {
             if ($model->getMemberships()) {
-                foreach ($model->getMemberships() as $membership) {
-                    $membership->getCategories()->removeElement($model);
-                }
                 $model->getMemberships()->clear();
             }
 
@@ -563,7 +584,6 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
                     $membership = $this->normalizeValueAsMembership($membership);
                     if ($membership) {
                         $model->addMemberships($membership);
-                        $membership->addCategory($model);
                     }
                 }
             }
@@ -596,7 +616,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
             $image = $model->getImage();
 
             if (!$image) {
-                $image = new \XLite\Model\Image\Category\Image;
+                $image = new \XLite\Model\Image\Category\Image();
             }
 
             $success = $image->loadFromPath($value);
@@ -613,6 +633,11 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
                         'column' => $column,
                         'value'  => $this->verifyValueAsURL($file) ? $value : LC_DIR_ROOT . $file
                     ]);
+                } elseif ($image->getLoadError() === 'undownloadable') {
+                    $this->addWarning('CATEGORY-IMG-URL-LOAD-FAILED', [
+                        'column' => $column,
+                        'value'  => $this->verifyValueAsURL($file) ? $value : LC_DIR_ROOT . $file
+                    ]);
                 } elseif ($image->getLoadError() === 'nonexistent') {
                     $this->addWarning('CATEGORY-IMG-FILE-LOAD-FAILED', [
                         'column' => $column,
@@ -659,7 +684,7 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
             $file = $this->verifyValueAsLocalURL($path) ? $this->getLocalPathFromURL($path) : $path;
 
             if (!$image) {
-                $image = new \XLite\Model\Image\Category\Banner;
+                $image = new \XLite\Model\Image\Category\Banner();
             }
 
             $success = $image->loadFromPath($path);
@@ -675,6 +700,11 @@ class Categories extends \XLite\Logic\Import\Processor\AProcessor
                         'column' => $column,
                         'value'  => $this->verifyValueAsURL($file) ? $path : LC_DIR_ROOT . $file
                     ]);
+                } elseif ($image->getLoadError() === 'undownloadable') {
+                    $this->addWarning('CATEGORY-BANNER-URL-LOAD-FAILED', [
+                        'column' => $column,
+                        'value'  => $this->verifyValueAsURL($file) ? $path : LC_DIR_ROOT . $file
+                    ]);
                 } elseif ($image->getLoadError() === 'nonexistent') {
                     $this->addWarning('CATEGORY-BANNER-FILE-LOAD-FAILED', [
                         'column' => $column,
