@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,13 +7,14 @@
 
 namespace XLite\Logic\Import\Processor;
 
+use XLite\Core\Request;
+
 /**
  * Customers import processor
  */
 class Customers extends \XLite\Logic\Import\Processor\AProcessor
 {
-
-    const ADDRESS_FIELD_SUFFIX = 'AddressField';
+    public const ADDRESS_FIELD_SUFFIX = 'AddressField';
 
     /**
      * Runtime cache
@@ -44,6 +44,11 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected $isIgnoreRow = false;
 
+    /**
+     * @var bool
+     */
+    protected $isNewModel = false;
+
     /**
      * Get title
      *
@@ -73,36 +78,36 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function defineColumns()
     {
-        $columns = array(
-            'login'           => array(
+        $columns = [
+            'login'           => [
                 static::COLUMN_IS_KEY => true,
                 static::COLUMN_LENGTH => 128,
-            ),
-            'added'           => array(),
-            'firstLogin'      => array(),
-            'lastLogin'       => array(),
-            'status'          => array(),
-            'referer'         => array(
+            ],
+            'added'           => [],
+            'firstLogin'      => [],
+            'lastLogin'       => [],
+            'status'          => [],
+            'referer'         => [
                 static::COLUMN_LENGTH => 255,
-            ),
-            'language'        => array(
+            ],
+            'language'        => [
                 static::COLUMN_LENGTH => 2,
-            ),
-            'membership'      => array(),
-            'addressField'    => array(
+            ],
+            'membership'      => [],
+            'addressField'    => [
                 static::COLUMN_IS_MULTICOLUMN  => true,
                 static::COLUMN_IS_MULTIROW     => true,
                 static::COLUMN_HEADER_DETECTOR => true,
-            ),
-            'password'        => array(
+            ],
+            'password'        => [
                 static::COLUMN_LENGTH => 128,
-            ),
-            'forceChangePassword' => array(),
-            'access_level' => array(),
-            'roles' => array(
+            ],
+            'forceChangePassword' => [],
+            'access_level' => [],
+            'roles' => [
                 static::COLUMN_IS_MULTIPLE => true,
-            ),
-        );
+            ],
+        ];
 
         return $columns;
     }
@@ -114,6 +119,10 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function isAdminProfilesManager()
     {
+        if (Request::getInstance()->isCLI()) {
+            return true;
+        }
+
         if (!isset($this->isAdminProfilesManager)) {
             $this->isAdminProfilesManager = \XLite\Core\Auth::getInstance()->isAdminProfilesManager();
         }
@@ -153,7 +162,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     public static function getMessages()
     {
         return parent::getMessages()
-            + array(
+            + [
                 'USER-LOGIN-FMT'      => 'Wrong login format',
                 'USER-ADDED-FMT'      => 'Wrong added format',
                 'USER-FLOGIN-FMT'     => 'Wrong first login date format',
@@ -173,7 +182,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
                 'USER-ACCESSLEV-CHANGE' => 'Access level cannot be changed (from {{prevValue}} to {{value}}) for existing profile ({{login}})',
                 'USER-ADMIN-IGN'      => 'You cannot update administrator profile ({{value}}). Row will be skipped',
                 'USER-ADMIN-IMP-IGN'  => 'You cannot update administrator profile ({{value}}). Row is skipped',
-            );
+            ];
     }
 
     /**
@@ -183,7 +192,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     public static function getCSVFormatManualURL()
     {
-        return static::t('https://kb.x-cart.com/import-export/csv_format_by_x-cart_data_type/csv_import_customers.html');
+        return static::t('https://support.x-cart.com/en/articles/5387451-csv-import-customers');
     }
 
     /**
@@ -226,7 +235,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyLogin($value, array $column)
     {
         if (!$this->verifyValueAsEmail($value)) {
-            $this->addError('USER-LOGIN-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('USER-LOGIN-FMT', ['column' => $column, 'value' => $value]);
         }
 
         $this->login = $value;
@@ -236,10 +245,10 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
         if (!$this->isAdminProfilesManager()) {
             $profile = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findByLogin($this->login);
 
-           if ($profile && $profile->isAdmin()) {
-               $this->addWarning('USER-ADMIN-IGN', array('column' => $column, 'value' => $value));
-               $this->isIgnoreRow = true;
-           }
+            if ($profile && $profile->isAdmin()) {
+                $this->addWarning('USER-ADMIN-IGN', ['column' => $column, 'value' => $value]);
+                $this->isIgnoreRow = true;
+            }
         }
     }
 
@@ -270,7 +279,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyAdded($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsDate($value)) {
-            $this->addWarning('USER-ADDED-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('USER-ADDED-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -285,7 +294,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyFirstLogin($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsDate($value)) {
-            $this->addWarning('USER-FLOGIN-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('USER-FLOGIN-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -300,7 +309,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyLastLogin($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsDate($value)) {
-            $this->addWarning('USER-LLOGIN-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('USER-LLOGIN-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -314,13 +323,14 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function verifyStatus($value, array $column)
     {
-        if (!$this->verifyValueAsEmpty($value)
+        if (
+            !$this->verifyValueAsEmpty($value)
             && !$this->verifyValueAsSet(
                 $value,
-                array(\XLite\Model\Profile::STATUS_ENABLED, \XLite\Model\Profile::STATUS_DISABLED)
+                [\XLite\Model\Profile::STATUS_ENABLED, \XLite\Model\Profile::STATUS_DISABLED]
             )
         ) {
-            $this->addError('USER-STATUS-FMT', array('column' => $column, 'value' => $value));
+            $this->addError('USER-STATUS-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -335,7 +345,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyLanguage($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsLanguageCode($value)) {
-            $this->addWarning('USER-LANGUAGE-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('USER-LANGUAGE-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -351,7 +361,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyShippingAddress($value, array $column, $index)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
-            $this->addWarning('USER-SHPADDR-FMT', array('column' => $column, 'value' => $value), $index);
+            $this->addWarning('USER-SHPADDR-FMT', ['column' => $column, 'value' => $value], $index);
         }
     }
 
@@ -367,7 +377,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyBillingAddress($value, array $column, $index)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
-            $this->addWarning('USER-BILADDR-FMT', array('column' => $column, 'value' => $value), $index);
+            $this->addWarning('USER-BILADDR-FMT', ['column' => $column, 'value' => $value], $index);
         }
     }
 
@@ -386,14 +396,12 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
                 $method = null;
                 if ($this->isColumnHeaderEqual('shippingAddress', $name)) {
                     $method = 'verifyShippingAddress';
-
                 } elseif ($this->isColumnHeaderEqual('billingAddress', $name)) {
                     $method = 'verifyBillingAddress';
-
                 } else {
                     $serviceName = $this->normalizeColumnHeader('(\w+)' . static::ADDRESS_FIELD_SUFFIX, $name);
                     if ($serviceName) {
-                        $method = 'verifyAddressField' . \XLite\Core\Converter::convertToCamelCase($serviceName);
+                        $method = 'verifyAddressField' . \Includes\Utils\Converter::convertToUpperCamelCase($serviceName);
                         if (!method_exists($this, $method)) {
                             $method = null;
                         }
@@ -421,7 +429,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyAddressFieldCountryCode($value, array $column, $index)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsCountryCode($value)) {
-            $this->addWarning('USER-CCODE-FMT', array('column' => $column, 'value' => $value), $index);
+            $this->addWarning('USER-CCODE-FMT', ['column' => $column, 'value' => $value], $index);
         }
     }
 
@@ -437,7 +445,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyAddressFieldStateId($value, array $column, $index)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsStateId($value)) {
-            $this->addWarning('USER-SID-FMT', array('column' => $column, 'value' => $value), $index);
+            $this->addWarning('USER-SID-FMT', ['column' => $column, 'value' => $value], $index);
         }
     }
 
@@ -452,7 +460,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyMembership($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsMembership($value)) {
-            $this->addWarning('GLOBAL-MEMBERSHIP-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('GLOBAL-MEMBERSHIP-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -467,7 +475,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyForceChangePassword($value, array $column)
     {
         if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
-            $this->addWarning('USER-FORDER-CHANGE-PASSWORD-FMT', array('column' => $column, 'value' => $value));
+            $this->addWarning('USER-FORDER-CHANGE-PASSWORD-FMT', ['column' => $column, 'value' => $value]);
         }
     }
 
@@ -478,26 +486,37 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      * @param array $column Column info
      *
      * @return void
+     * @throws \Exception
      */
     protected function verifyAccessLevel($value, array $column)
     {
-        if (!$this->verifyValueAsEmpty($value)) {
-
+        if (!$this->verifyValueAsEmpty($value) && !Request::getInstance()->isCLI()) {
             if (!$this->isAdminProfilesManager()) {
                 // Administrator hasn't permissions to change access level
-                $this->addError('USER-ACCESSLEV-PERM', array('column' => $column));
-
-            } elseif (!in_array($value, array(\XLite\Core\Auth::getInstance()->getAdminAccessLevel(), \XLite\Core\Auth::getInstance()->getCustomerAccessLevel()))) {
+                $this->addError('USER-ACCESSLEV-PERM', ['column' => $column]);
+            } elseif (
+                !in_array(
+                    (int) $value,
+                    [
+                        \XLite\Core\Auth::getInstance()->getAdminAccessLevel(),
+                        \XLite\Core\Auth::getInstance()->getCustomerAccessLevel()
+                    ],
+                    true
+                )
+            ) {
                 // Wrong value of access level
-                $this->addError('USER-ACCESSLEV-FMT', array('column' => $column, 'value' => $value));
-
+                $this->addError('USER-ACCESSLEV-FMT', ['column' => $column, 'value' => $value]);
             } else {
-
                 $profile = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findByLogin($this->login);
 
-                if ($profile && (int)$value != (int)$profile->getAccessLevel()) {
+                if ($profile && (int) $value !== (int) $profile->getAccessLevel()) {
                     // It's impossible to change access level of an existing profile
-                    $this->addWarning('USER-ACCESSLEV-CHANGE', array('column' => $column, 'value' => $value, 'prevValue' => $profile->getAccessLevel(), 'login' => $profile->getLogin()));
+                    $this->addWarning('USER-ACCESSLEV-CHANGE', [
+                        'column' => $column,
+                        'value' => $value,
+                        'prevValue' => $profile->getAccessLevel(),
+                        'login' => $profile->getLogin()
+                    ]);
                 }
             }
         }
@@ -514,20 +533,17 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function verifyRoles($value, array $column)
     {
         if (!empty($value)) {
-
             if (!$this->isAdminProfilesManager()) {
                 // Administrator hasn't permissions to change access level
-                $this->addError('USER-ROLES-PERM', array('column' => $column));
-
+                $this->addError('USER-ROLES-PERM', ['column' => $column]);
             } elseif ($this->isCurrentUser) {
                 // Admin cannot change its own roles via import
-                $this->addWarning('USER-ROLES-SELF', array('column' => $column));
-
+                $this->addWarning('USER-ROLES-SELF', ['column' => $column]);
             } elseif (is_array($value)) {
                 foreach ($value as $role) {
                     if (!$this->verifyValueAsEmpty($role) && !$this->verifyValueAsRole($role)) {
                         // Wrong role name
-                        $this->addError('USER-ROLE-FMT', array('column' => $column, 'value' => $role));
+                        $this->addError('USER-ROLE-FMT', ['column' => $column, 'value' => $role]);
                     }
                 }
             }
@@ -556,20 +572,6 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
 
     // {{{ Import
 
-    /**
-     * Import data
-     *
-     * @param array $data Row set Data
-     *
-     * @return boolean
-     */
-    protected function importData(array $data)
-    {
-        \Xlite\Core\Database::getRepo('XLite\Model\Product')->setBlockQuickDataFlag(true);
-
-        return parent::importData($data);
-    }
-
     /**
      * Import password
      *
@@ -600,25 +602,22 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     protected function importAddressFieldColumn(\XLite\Model\Profile $model, array $value, array $column)
     {
         if ($value && !$this->verifyValueAsNull($value)) {
-            $data = array();
+            $data = [];
+            $addressFields = \XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled();
             foreach ($value as $name => $rows) {
-                $method = null;
                 if ($this->isColumnHeaderEqual('shippingAddress', $name)) {
                     $data['is_shipping'] = $rows;
-
                 } elseif ($this->isColumnHeaderEqual('billingAddress', $name)) {
                     $data['is_billing'] = $rows;
-
                 } else {
                     $serviceName = $this->normalizeColumnHeader('(\w+)' . static::ADDRESS_FIELD_SUFFIX, $name);
                     if ($serviceName) {
-                        if ('state' == $serviceName) {
+                        if ($serviceName === 'state') {
                             $data['state'] = $rows;
-
                         } else {
-                            foreach (\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
-                                $fname = lcfirst(\XLite\Core\Converter::convertToCamelCase($field->getServiceName()));
-                                if ($fname == $serviceName) {
+                            foreach ($addressFields as $field) {
+                                $fieldName = \Includes\Utils\Converter::convertToLowerCamelCase($field->getServiceName());
+                                if ($fieldName === $serviceName) {
                                     $data[$field->getServiceName()] = $rows;
                                 }
                             }
@@ -627,45 +626,39 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
                 }
             }
 
+            $this->removeAllAddresses($model);
             $addresses = $this->assembleSubmodelsData($data, $column);
 
-            $i = 0;
             foreach ($addresses as $address) {
-                $this->importAddress($model, $address, $i);
-                $i++;
-            }
-
-            // Remove
-            while (count($model->getAddresses()) > count($addresses)) {
-                $address = $model->getAddresses()->last();
-                \XLite\Core\Database::getRepo('XLite\Model\Address')->delete($address, false);
-                $model->getAddresses()->removeElement($address);
+                $this->importAddress($model, $address);
             }
         } elseif ($value && $this->verifyValueAsNull($value)) {
-            foreach ($model->getAddresses() as $address) {
-                \XLite\Core\Database::getEM()->remove($address);
-            }
-            $model->getAddresses()->clear();
+            $this->removeAllAddresses($model);
         }
     }
 
+    protected function removeAllAddresses(\XLite\Model\Profile $model): void
+    {
+        foreach ($model->getAddresses() as $address) {
+            \XLite\Core\Database::getEM()->remove($address);
+        }
+
+        $model->getAddresses()->clear();
+    }
+
     /**
      * Import address
      *
      * @param \XLite\Model\Profile $model   Profile
      * @param array                $address Address
-     * @param integer              $index   Index
      *
      * @return void
      */
-    protected function importAddress(\XLite\Model\Profile $model, array $address, $index)
+    protected function importAddress(\XLite\Model\Profile $model, array $address)
     {
-        $addr = $model->getAddresses()->get($index);
-        if (!$addr) {
-            $addr = $this->createAddress();
-            $model->addAddresses($addr);
-            $addr->setProfile($model);
-        }
+        $addr = $this->createAddress();
+        $model->addAddresses($addr);
+        $addr->setProfile($model);
 
         if (isset($address['is_shipping'])) {
             $address['is_shipping'] = $this->normalizeValueAsBoolean($address['is_shipping']);
@@ -693,12 +686,13 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
      */
     protected function importAccessLevelColumn(\XLite\Model\Profile $model, $value, array $column)
     {
-        if (!$this->verifyValueAsEmpty($value)
+        if (
+            $this->isNewModel
+            && !$this->verifyValueAsEmpty($value)
             && $this->isAdminProfilesManager()
-            && $model->getLogin() != \XLite\Core\Auth::getInstance()->getProfile()->getLogin()
-            && $this->isNewModel
+            && $model->getLogin() !== \XLite\Core\Auth::getInstance()->getProfile()?->getLogin()
         ) {
-            $model->setAccessLevel($value);
+            $model->setAccessLevel((int) $value);
         }
     }
 
@@ -718,7 +712,6 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
             && $this->isAdminProfilesManager()
             && $model->getLogin() != \XLite\Core\Auth::getInstance()->getProfile()->getLogin()
         ) {
-
             if ($model->getRoles()) {
                 foreach ($model->getRoles() as $role) {
                     $role->getProfiles()->removeElement($model);
@@ -768,7 +761,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'login' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return string
      */
@@ -780,7 +773,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'added' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return integer
      */
@@ -792,7 +785,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'first login' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return integer
      */
@@ -804,7 +797,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'last login' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return intger
      */
@@ -816,7 +809,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'status' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return string
      */
@@ -828,7 +821,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'language' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return string
      */
@@ -840,7 +833,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
     /**
      * Normalize 'membership' value
      *
-     * @param mixed @value Value
+     * @param mixed $value Value
      *
      * @return \XLite\Model\Membership
      */
@@ -886,7 +879,7 @@ class Customers extends \XLite\Logic\Import\Processor\AProcessor
             && $entity->isAdmin();
 
         if ($this->isIgnoreRow) {
-            $this->addWarning('USER-ADMIN-IMP-IGN', array('value' => $entity->getLogin()));
+            $this->addWarning('USER-ADMIN-IMP-IGN', ['value' => $entity->getLogin()]);
             $this->setMetaData('updateCount', ((int) $this->getMetaData('updateCount')) - 1);
         }
 
