@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,7 +17,7 @@ abstract class AStep extends \XLite\Logic\ARepoStep
      *
      * @return integer
      */
-    public function count()
+    public function count(): int
     {
         if (!isset($this->countCache)) {
             $this->countCache = $this->getRepository()->countForQuickData();
