@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\Logic\Order\Modifier;
 
+use XLite\Core\Database;
 use XLite\Model\Shipping\Rate;
 
 /**
@@ -18,7 +18,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     /**
      * Modifier code
      */
-    const MODIFIER_CODE = 'SHIPPING';
+    public const MODIFIER_CODE = 'SHIPPING';
 
     /**
      * Modifier unique code
@@ -30,7 +30,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     /**
      * Selected rate (cache)
      *
-     * @var \XLite\Model\Shipping\Rate
+     * @var Rate
      */
     protected $selectedRate;
 
@@ -38,14 +38,14 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
      * Runtime cache
      * @var array
      */
-    protected $rates;
+    protected $rates = [];
 
     /**
      * @inheritdoc
      */
     public function initialize(\XLite\Model\Order $order, \XLite\DataSet\Collection\OrderModifier $list)
     {
-        $this->rates = null;
+        $this->rates = [];
         parent::initialize($order, $list);
     }
 
@@ -74,7 +74,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
             if (!$this->isCart() || !$this->order->isIgnoreLongCalculations()) {
                 $rate = $this->getSelectedRate();
 
-                if (null !== $rate) {
+                if ($rate !== null) {
                     $cost = $this->getOrder()->getCurrency()->roundValue($rate->getTotalRate());
                 } else {
                     $this->resetOrderSurcharges();
@@ -105,7 +105,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
         foreach ($this->order->getSurcharges() as $s) {
             if ($s->getType() === $this->type && $s->getCode() === $this->code) {
                 $this->getOrder()->removeSurcharge($s);
-                \XLite\Core\Database::getEM()->remove($s);
+                Database::getEM()->remove($s);
             }
         }
     }
@@ -122,20 +122,21 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
 
     /**
      * Get shipping rates
-     * todo: add checking if rates should be recalculated else get rates from cache
      *
      * @return array(\XLite\Model\Shipping\Rate)
      */
     public function getRates()
     {
-        if (!isset($this->rates) || \XLite\Core\Request::getInstance()->isAJAX()) {
+        $hash = \XLite\Model\Shipping::getInstance()->getHash($this);
+
+        if (!isset($this->rates[$hash])) {
             if ($this->isCart()) {
-                $this->rates = $this->calculateRates();
+                $this->rates[$hash] = $this->calculateRates();
             } else {
                 $restored = $this->restoreRates();
                 $rates = array_merge($restored, array_filter(
                     $this->calculateRates(),
-                    function (Rate $rate) use ($restored) {
+                    static function (Rate $rate) use ($restored) {
                         foreach ($restored as $restoredRate) {
                             if ($restoredRate->getMethod() === $rate->getMethod()) {
                                 return false;
@@ -146,11 +147,15 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
                     }
                 ));
 
-                $this->rates = $rates;
+                $this->rates[$hash] = $rates;
+            }
+
+            if (!\XLite::isAdminZone()) {
+                $this->order->renewShippingMethod();
             }
         }
 
-        return $this->rates;
+        return $this->rates[$hash];
     }
 
     /**
@@ -175,19 +180,22 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     // {{{ Shipping rates
 
     /**
-     * Calculate shipping rates
-     *
-     * @return \XLite\Model\Shipping\Rate[]
+     * @return Rate[]
      */
     protected function calculateRates()
     {
-        $rates = array();
-
-        if ($this->isShippable()) {
-            $rates = $this->retrieveRates();
-            uasort($rates, array($this, 'compareRates'));
+        if (!$this->isShippable()) {
+            return [];
         }
 
+        $rates = $this->retrieveRates();
+        uasort(
+            $rates,
+            static function (Rate $rateLeft, Rate $rateRight) {
+                return $rateLeft->getMethod()->getPosition() <=> $rateRight->getMethod()->getPosition();
+            }
+        );
+
         return $rates;
     }
 
@@ -204,18 +212,18 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     /**
      * Restore rates
      *
-     * @return \XLite\Model\Shipping\Rate[]
+     * @return Rate[]
      */
     protected function restoreRates()
     {
-        $rates = array();
+        $rates = [];
 
         if ($this->order->getShippingId()) {
             /** @var \XLite\Model\Shipping\Method $method */
-            $method = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method')->find($this->order->getShippingId());
+            $method = Database::getRepo('XLite\Model\Shipping\Method')->find($this->order->getShippingId());
 
             if ($method) {
-                $rate = new \XLite\Model\Shipping\Rate();
+                $rate = new Rate();
                 $rate->setMethod($method);
                 $rate->setBaseRate(0);
                 $rate->setMarkupRate($this->order->getSurchargeSumByType($this->type));
@@ -227,37 +235,6 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
         return $rates;
     }
 
-    /**
-     * Shipping rates sorting callback
-     *
-     * @param \XLite\Model\Shipping\Rate $a First shipping rate
-     * @param \XLite\Model\Shipping\Rate $b Second shipping rate
-     *
-     * @return integer
-     */
-    protected function compareRates(\XLite\Model\Shipping\Rate $a, \XLite\Model\Shipping\Rate $b)
-    {
-        $aMethod = $a->getMethod();
-        $bMethod = $b->getMethod();
-
-        $aPosition = $aMethod->getPosition();
-        $bPosition = $bMethod->getPosition();
-
-        if ('offline' !== $aMethod->getProcessor() && 'offline' !== $bMethod->getProcessor()) {
-            if ($aMethod->getProcessor() !== $bMethod->getProcessor()) {
-                $aPosition = $aMethod->getParentMethod()->getPosition();
-                $bPosition = $bMethod->getParentMethod()->getPosition();
-            }
-        } elseif ('offline' !== $aMethod->getProcessor()) {
-            $aPosition = $aMethod->getParentMethod()->getPosition();
-
-        } elseif ('offline' !== $bMethod->getProcessor()) {
-            $bPosition = $bMethod->getParentMethod()->getPosition();
-        }
-
-        return $aPosition === $bPosition ? 0 : ($aPosition < $bPosition ? -1 : 1);
-    }
-
     // }}}
 
     // {{{ Current shipping method and rate
@@ -265,32 +242,20 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     /**
      * Get selected shipping rate
      *
-     * @return \XLite\Model\Shipping\Rate
+     * @return Rate
      */
     public function getSelectedRate()
     {
-        if ($this->order instanceof \XLite\Model\Cart
-            && !$this->order->getShippingId()
-            && $this->order->getProfile()
-            && $this->order->getLastShippingId()
-        ) {
-            // Remember last shipping id
-            $this->order->setShippingId($this->order->getLastShippingId());
-        }
+        $selectedRate = null;
+        $shippingId = (int)$this->order->getShippingId();
 
         // Get shipping rates
-        $rates = $this->getRates();
+        $rates = $shippingId > 0 ? $this->getRates() : [];
 
-        $selectedRate = null;
-
-        if (!empty($rates) && 0 < (int) $this->order->getShippingId()) {
-            // Set selected rate from the rates list if shipping_id is already assigned
-
-            foreach ($rates as $rate) {
-                if ($this->order->getShippingId() == $rate->getMethodId()) {
-                    $selectedRate = $rate;
-                    break;
-                }
+        foreach ($rates as $rate) {
+            if ($shippingId === (int)$rate->getMethodId()) {
+                $selectedRate = $rate;
+                break;
             }
         }
 
@@ -302,19 +267,18 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     /**
      * Set shipping rate and shipping method id
      *
-     * @param \XLite\Model\Shipping\Rate $rate Shipping rate object OPTIONAL
+     * @param Rate $rate Shipping rate object OPTIONAL
      *
      * @return void
      */
-    public function setSelectedRate(\XLite\Model\Shipping\Rate $rate = null)
+    public function setSelectedRate(Rate $rate = null)
     {
-
         $this->selectedRate = $rate;
-        $newShippingId = $rate ? $rate->getMethodId() : 0;
+        $newShippingId = $rate ? (int)$rate->getMethodId() : 0;
 
-        if ($this->order->getShippingId() != $newShippingId) {
+        if ((int)$this->order->getShippingId() !== $newShippingId) {
             $this->order->setShippingId($newShippingId);
-            \XLite\Core\Database::getEM()->flush();
+            Database::getEM()->flush();
         }
     }
 
@@ -337,9 +301,19 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     {
         $result = null;
 
-        $rate = $this->getSelectedRate();
-        if (null !== $rate) {
-            $result = $rate->getMethod();
+        if (
+            !$this->isCart()
+            && $this->order->getShippingId()
+        ) {
+            /** @var \XLite\Model\Shipping\Method $result */
+            $result = Database::getRepo('XLite\Model\Shipping\Method')->find($this->order->getShippingId());
+        }
+
+        if (!$result) {
+            $rate = $this->getSelectedRate();
+            if ($rate !== null) {
+                $result = $rate->getMethod();
+            }
         }
 
         return $result;
@@ -374,7 +348,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
      */
     public function getItems()
     {
-        $result = array();
+        $result = [];
 
         foreach ($this->order->getItems() as $item) {
             if ($item->isShippable()) {
@@ -474,21 +448,11 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
     }
 
     /**
-     * Get shipped items for check condition
-     *
      * @return array
      */
     public function getItemsCondition()
     {
-        $result = array();
-
-        foreach ($this->order->getItems() as $item) {
-            if ($item->isShippable()) {
-                $result[] = $item;
-            }
-        }
-
-        return $result;
+        return $this->order->getItems();
     }
 
     /**
@@ -571,7 +535,7 @@ class Shipping extends \XLite\Logic\Order\Modifier\AShipping
      */
     public function getSurchargeInfo(\XLite\Model\Base\Surcharge $surcharge)
     {
-        $info = new \XLite\DataSet\Transport\Order\Surcharge;
+        $info = new \XLite\DataSet\Transport\Order\Surcharge();
 
         $info->name = \XLite\Core\Translation::lbl('Shipping cost');
         $info->notAvailableReason = \XLite\Core\Translation::lbl('Shipping address is not defined');
