@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\Logic\RemoveData;
 
+use XLite\Logic\RemoveData\Step\DemoProducts;
 
 /**
  * Generator
@@ -41,6 +41,7 @@ class Generator extends \XLite\Logic\AGenerator
     protected function getStepsList()
     {
         return [
+            DemoProducts::class,
             'XLite\Logic\RemoveData\Step\Products',
             'XLite\Logic\RemoveData\Step\Categories',
             'XLite\Logic\RemoveData\Step\Orders',
@@ -81,9 +82,9 @@ class Generator extends \XLite\Logic\AGenerator
     // {{{ SeekableIterator, Countable
 
     /**
-     * @inheritdoc
+     * @return int
      */
-    public function count()
+    public function count(): int
     {
         if (!isset($this->countCache)) {
             if (!isset($this->options['count'])) {
