@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,70 +7,157 @@
 
 namespace XLite\Model;
 
+use ApiPlatform\Core\Annotation as ApiPlatform;
+use Doctrine\ORM\Mapping as ORM;
+use XLite\API\Endpoint\ProfileAddress\DTO\ProfileAddressInput as Input;
+use XLite\API\Endpoint\ProfileAddress\DTO\ProfileAddressOutput as Output;
+
 /**
- * Address model
- *
- * @Entity
- * @Table  (name="profile_addresses",
- *      indexes={
- *          @Index (name="is_billing", columns={"is_billing"}),
- *          @Index (name="is_shipping", columns={"is_shipping"})
- *      }
+ * @ORM\Entity
+ * @ORM\Table (
+ *     name="profile_addresses",
+ *     indexes={
+ *         @ORM\Index (name="is_billing", columns={"is_billing"}),
+ *         @ORM\Index (name="is_shipping", columns={"is_shipping"})
+ *     }
  * )
- * @HasLifecycleCallbacks
+ * @ApiPlatform\ApiResource(
+ *     input=Input::class,
+ *     output=Output::class,
+ *     itemOperations={
+ *          "get"={
+ *              "method"="GET",
+ *              "path"="/profiles/{profile_id}/addresses/{address_id}.{_format}",
+ *              "identifiers"={"profile_id", "address_id"},
+ *              "requirements"={"profile_id"="\d+", "address_id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Retrieve an address from a profile",
+ *                  "parameters"={
+ *                      {"name"="profile_id", "in"="path", "required"=true, "schema"={"type"="integer"}},
+ *                      {"name"="address_id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  }
+ *              }
+ *          },
+ *          "put"={
+ *              "method"="PUT",
+ *              "path"="/profiles/{profile_id}/addresses/{address_id}.{_format}",
+ *              "identifiers"={"profile_id", "address_id"},
+ *              "requirements"={"profile_id"="\d+", "address_id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Update an address of a profile",
+ *                  "parameters"={
+ *                      {"name"="profile_id", "in"="path", "required"=true, "schema"={"type"="integer"}},
+ *                      {"name"="address_id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  }
+ *              }
+ *          },
+ *          "delete"={
+ *              "method"="DELETE",
+ *              "path"="/profiles/{profile_id}/addresses/{address_id}.{_format}",
+ *              "identifiers"={"profile_id", "address_id"},
+ *              "requirements"={"profile_id"="\d+", "address_id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Delete an address from a profile",
+ *                  "parameters"={
+ *                      {"name"="profile_id", "in"="path", "required"=true, "schema"={"type"="integer"}},
+ *                      {"name"="address_id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  }
+ *              }
+ *          }
+ *     },
+ *     collectionOperations={
+ *          "get"={
+ *              "method"="GET",
+ *              "path"="/profiles/{profile_id}/addresses.{_format}",
+ *              "identifiers"={"profile_id", "address_id"},
+ *              "requirements"={"profile_id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Retrieve a list of addresses from a profile",
+ *                  "parameters"={
+ *                      {"name"="profile_id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  },
+ *              }
+ *          },
+ *          "post"={
+ *              "method"="POST",
+ *              "path"="/profiles/{profile_id}/addresses.{_format}",
+ *              "controller"="xcart.api.profile_address.controller",
+ *              "identifiers"={"profile_id", "address_id"},
+ *              "requirements"={"profile_id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Add an address to a profile",
+ *                  "parameters"={
+ *                      {"name"="profile_id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  }
+ *              }
+ *          }
+ *     }
+ * )
+ *
+ * @method string getFirstname
+ * @method string setFirstname
+ * @method string getLastname
+ * @method string setLastname
+ * @method string getAddress1
+ * @method string getAddress2
+ * @method string getAddress3
+ * @method string setAddress1
+ * @method string setAddress2
+ * @method string setAddress3
+ * @method string getZipcode
+ * @method string setZipcode
+ * @method string getCity
+ * @method string setCity
  */
 class Address extends \XLite\Model\Base\PersonalAddress
 {
-
     /**
      * Address type codes
      */
-    const BILLING  = 'b';
-    const SHIPPING = 's';
+    public const BILLING  = 'b';
+    public const SHIPPING = 's';
 
     /**
      * Address fields collection
      *
      * @var \Doctrine\Common\Collections\ArrayCollection
      *
-     * @OneToMany (targetEntity="XLite\Model\AddressFieldValue", mappedBy="address", cascade={"all"})
+     * @ORM\OneToMany (targetEntity="XLite\Model\AddressFieldValue", mappedBy="address", cascade={"all"})
      */
     protected $addressFields;
 
     /**
      * Flag: is it a billing address
      *
-     * @var boolean
+     * @var bool
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $is_billing = false;
 
     /**
      * Flag: is it a shipping address
      *
-     * @var boolean
+     * @var bool
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $is_shipping = false;
 
     /**
      * Flag: is it a work address
      *
-     * @var boolean
+     * @var bool
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $isWork = false;
 
     /**
-     * Profile: many-to-one relation with profile entity
-     *
      * @var \XLite\Model\Profile
      *
-     * @ManyToOne (targetEntity="XLite\Model\Profile", inversedBy="addresses", cascade={"persist","merge","detach"})
-     * @JoinColumn (name="profile_id", referencedColumnName="profile_id", onDelete="CASCADE")
+     * @ORM\ManyToOne (targetEntity="XLite\Model\Profile", inversedBy="addresses", cascade={"persist","merge","detach"})
+     * @ORM\JoinColumn (name="profile_id", referencedColumnName="profile_id", onDelete="CASCADE")
      */
     protected $profile;
 
@@ -99,7 +185,7 @@ class Address extends \XLite\Model\Base\PersonalAddress
     {
         $result = parent::setterProperty($property, $value);
 
-        if (null === $result) {
+        if ($result === null) {
             $addressField = \XLite\Core\Database::getRepo('XLite\Model\AddressField')
                 ->findOneBy(['serviceName' => $property]);
 
@@ -113,7 +199,6 @@ class Address extends \XLite\Model\Base\PersonalAddress
                     if ($this->isPersistent()) {
                         $repo->update($addressFieldValue);
                     }
-
                 } else {
                     $addressFieldValue = new \XLite\Model\AddressFieldValue();
                     $addressFieldValue->map([
@@ -128,7 +213,6 @@ class Address extends \XLite\Model\Base\PersonalAddress
                 }
 
                 $result = true;
-
             } else {
                 // Log wrong access to property
                 $this->logWrongAddressPropertyAccess($property, false);
@@ -150,6 +234,7 @@ class Address extends \XLite\Model\Base\PersonalAddress
         if ($this->getProfile()) {
             \XLite\Core\Database::getEM()->refresh($this->getProfile());
             $this->getProfile()->updateSearchFakeField();
+            \XLite\Core\Database::getEM()->flush();
         }
 
         return $result;
@@ -205,7 +290,7 @@ class Address extends \XLite\Model\Base\PersonalAddress
     {
         $result = parent::getterProperty($property);
 
-        if (null === $result) {
+        if ($result === null) {
             $addressField = static::getAddressFieldByServiceName($property);
 
             if ($addressField) {
@@ -214,7 +299,6 @@ class Address extends \XLite\Model\Base\PersonalAddress
                 $result = $addressFieldValue
                     ? $addressFieldValue->getValue()
                     : static::getDefaultFieldPlainValue($property);
-
             } else {
                 // Log wrong access to property
                 $this->logWrongAddressPropertyAccess($property);
@@ -277,7 +361,8 @@ class Address extends \XLite\Model\Base\PersonalAddress
 
         if ($addressField) {
             foreach ($this->getAddressFields() as $field) {
-                if ($field->getAddressField()
+                if (
+                    $field->getAddressField()
                     && (int)$field->getAddressField()->getId() === (int)$addressField->getId()
                 ) {
                     $addressFieldValue = $field;
@@ -433,7 +518,7 @@ class Address extends \XLite\Model\Base\PersonalAddress
         $result = [];
 
         if ($fields) {
-            $result = array_reduce($fields->toArray(), function ($acc, $item) {
+            $result = array_reduce($fields->toArray(), static function ($acc, $item) {
                 if ($item->getAddressField()) {
                     $acc[$item->getAddressField()->getServiceName()] = $item->getValue();
                     return $acc;
@@ -498,7 +583,9 @@ class Address extends \XLite\Model\Base\PersonalAddress
     {
         return [
             'name'         => trim($this->getFirstname() . ' ' . $this->getLastname()),
-            'address'      => $this->getStreet(),
+            'address1'     => $this->getAddress1(),
+            'address2'     => $this->getAddress2(),
+            'address3'     => $this->getAddress3(),
             'city'         => $this->getCity(),
             'state'        => $this->getState() ? $this->getState()->getCode() : '',
             'custom_state' => $this->getCustomState(),
@@ -655,4 +742,87 @@ class Address extends \XLite\Model\Base\PersonalAddress
     {
         return $this->profile;
     }
+
+    public function getAddressLinesList(): array
+    {
+        $result = [];
+
+        for ($i = 1; $i <= 3; $i++) {
+            $method = "getAddress{$i}";
+            $result[] = $this->$method();
+        }
+
+        return $result;
+    }
+
+    public function getAddressLineConcat(): string
+    {
+        return trim(
+            implode(' ', array_filter($this->getAddressLinesList()))
+        );
+    }
+
+    public function getAddressLineConcat23(): string
+    {
+        return $this->getAddress2() . ' ' . $this->getAddress3();
+    }
+
+    /**
+     * @deprecated since CDev-Core 5.5.1, use \XLite\Model\Address::getAddress1() instead
+     */
+    public function getStreet(): string
+    {
+        trigger_deprecation('CDev-Core', '5.5.1', '"%s" is deprecated, use \XLite\Model\Address::getAddress1() instead.', __METHOD__);
+
+        return $this->getAddress1();
+    }
+
+    public static function prepareAddressLines(string $address1 = '', string $address2 = '', string $address3 = ''): array
+    {
+        $result = [
+            'address1' => $address1,
+            'address2' => $address2,
+            'address3' => $address3,
+        ];
+
+        if (static::line3Disabled()) {
+            $result['address2'] .= ' ' . $result['address3'];
+            $result['address3'] = '';
+        }
+        if (static::line2Disabled()) {
+            $result['address1'] .= ' ' . $result['address2'];
+            $result['address2'] = '';
+        }
+
+        return $result;
+    }
+
+    public static function line2Disabled(): bool
+    {
+        return !static::getAddressFieldByServiceName('address2')->getEnabled();
+    }
+
+    public static function line3Disabled(): bool
+    {
+        return !static::getAddressFieldByServiceName('address3')->getEnabled();
+    }
+
+    public function getAddressLineConcatCommaDivided(): string
+    {
+        $fields = [];
+
+        foreach (['address1', 'address2', 'address3'] as $line) {
+            $method = 'get' . ucfirst($line);
+
+            if (
+                ($fieldValue = $this->getFieldValue($line))
+                && $fieldValue->getAddressField()->getEnabled()
+                && !empty($this->$method())
+            ) {
+                $fields[] = $this->$method();
+            }
+        }
+
+        return implode(', ', $fields);
+    }
 }
