@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,25 +7,33 @@
 
 namespace XLite\Model\AttributeValue;
 
+use Doctrine\ORM\Mapping as ORM;
+
 /**
  * Attribute value (hidden) multilingual data
  *
- * @Entity
- *
- * @Table  (name="attribute_values_hidden_translations",
+ * @ORM\Entity
+ * @ORM\Table  (name="attribute_values_hidden_translations",
  *         indexes={
- *              @Index (name="ci", columns={"code","id"}),
- *              @Index (name="id", columns={"id"})
+ *              @ORM\Index (name="ci", columns={"code","id"}),
+ *              @ORM\Index (name="id", columns={"id"})
  *         }
  * )
  */
 class AttributeValueHiddenTranslation extends \XLite\Model\Base\Translation
 {
+    /**
+     * @var \XLite\Model\AttributeValue\AttributeValueHidden
+     *
+     * @ORM\ManyToOne (targetEntity="XLite\Model\AttributeValue\AttributeValueHidden", inversedBy="translations")
+     * @ORM\JoinColumn (name="id", referencedColumnName="id", onDelete="CASCADE")
+     */
+    protected $owner;
 
     /**
      * Get label_id
      *
-     * @return integer 
+     * @return integer
      */
     public function getLabelId()
     {
@@ -48,7 +55,7 @@ class AttributeValueHiddenTranslation extends \XLite\Model\Base\Translation
     /**
      * Get code
      *
-     * @return string 
+     * @return string
      */
     public function getCode()
     {
