@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,20 +7,21 @@
 
 namespace XLite\Model\Base;
 
+use Doctrine\ORM\Mapping as ORM;
+
 /**
  * Abstract catalog model
  *
- * @MappedSuperclass
- * @HasLifecycleCallbacks
+ * @ORM\MappedSuperclass
  */
 abstract class Catalog extends \XLite\Model\Base\I18n
 {
-    const CLEAN_URL_HISTORY_LENGTH = 10;
+    public const CLEAN_URL_HISTORY_LENGTH = 10;
 
     /**
      * WEB LC root postprocessing constant
      */
-    const WEB_LC_ROOT = '{{WEB_LC_ROOT}}';
+    public const WEB_LC_ROOT = '{{WEB_LC_ROOT}}';
 
     /**
      * Clean URLs
@@ -48,7 +48,7 @@ abstract class Catalog extends \XLite\Model\Base\I18n
      *
      * @param array $data Entity properties OPTIONAL
      */
-    public function __construct(array $data = array())
+    public function __construct(array $data = [])
     {
         $this->cleanURLs = new \Doctrine\Common\Collections\ArrayCollection();
 
@@ -68,7 +68,6 @@ abstract class Catalog extends \XLite\Model\Base\I18n
             if ($cleanURLs) {
                 $this->setCleanURL($cleanURLs);
             }
-
         } else {
             $this->cleanURLs = $cleanURLs;
         }
@@ -130,22 +129,6 @@ abstract class Catalog extends \XLite\Model\Base\I18n
             : '';
     }
 
-    /**
-     * Lifecycle callback
-     *
-     * @return void
-     *
-     * @PrePersist
-     * @PreUpdate
-     */
-    public function prepareBeforeSave()
-    {
-        //TODO PreUpdate doesn't help here http://docs.doctrine-project.org/projects/doctrine-orm/en/latest/reference/events.html#preupdate
-        if (\XLite\Core\Converter::isEmptyString($this->getCleanURL())) {
-            $this->setCleanURL($this->generateCleanURL());
-        }
-    }
-
     /**
      * Remove duplicates from clean url history
      *
@@ -153,12 +136,11 @@ abstract class Catalog extends \XLite\Model\Base\I18n
      */
     protected function filterCleanURLDuplicates()
     {
-        $cleanURLs = array();
+        $cleanURLs = [];
         foreach (array_reverse($this->getCleanURLs()->toArray()) as $cleanURLObject) {
             if (in_array($cleanURLObject->getCleanURL(), $cleanURLs)) {
                 \XLite\Core\Database::getEM()->remove($cleanURLObject);
                 $this->getCleanURLs()->removeElement($cleanURLObject);
-
             } else {
                 $cleanURLs[] = $cleanURLObject->getCleanURL();
             }
@@ -206,9 +188,9 @@ abstract class Catalog extends \XLite\Model\Base\I18n
      */
     protected static function getWebPreprocessingTags()
     {
-        return array(
+        return [
             static::WEB_LC_ROOT,
-        );
+        ];
     }
 
     /**
@@ -222,7 +204,7 @@ abstract class Catalog extends \XLite\Model\Base\I18n
         $url = \XLite\Core\URLManager::getShopURL(
             null,
             \XLite\Core\Request::getInstance()->isHTTPS(),
-            array(),
+            [],
             null,
             false
         );
@@ -230,9 +212,9 @@ abstract class Catalog extends \XLite\Model\Base\I18n
         // We are cleaning URL from unnecessary here <xid> construction
         $url = preg_replace('/(\?.*)/', '', $url);
 
-        return array(
+        return [
             $url,
-        );
+        ];
     }
 
     /**
