@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,18 +7,28 @@
 
 namespace XLite\Model\Base;
 
+use Doctrine\ORM\Mapping as ORM;
 use XLite\Core\ImageOperator;
-use XLite\Core\Skin;
+use XLite\Core\Request;
+use XLite\Core\TopMessage;
+use XLite\InjectLoggerTrait;
 
 /**
  * Image abstract store
  *
- * @MappedSuperclass
- * @HasLifecycleCallbacks
+ * @ORM\MappedSuperclass
  */
 abstract class Image extends \XLite\Model\Base\Storage
 {
-    const RETINA_RATIO = 2;
+    use InjectLoggerTrait;
+
+    public const RETINA_RATIO = 2;
+
+    public const WEBP_MIME_TYPE = 'image/webp';
+
+    public const WEBP_EXTENSION = 'webp';
+
+    public const SVG_EXTENSION = 'svg';
 
     /**
      * MIME type to extension translation table
@@ -38,6 +47,37 @@ abstract class Image extends \XLite\Model\Base\Storage
         'image/x-ms-bmp'      => 'bmp',
         'image/x-windows-bmp' => 'bmp',
         'image/png'           => 'png',
+        'image/svg+xml'       => self::SVG_EXTENSION,
+        self::WEBP_MIME_TYPE  => self::WEBP_EXTENSION
+    ];
+
+    /**
+     * Extended MIME types
+     *
+     * @var array
+     */
+    protected static $extendedTypes = [
+        'application/ico'          => 'ico',
+        'image/ico'                => 'ico',
+        'image/icon'               => 'ico',
+        'image/vnd.microsoft.icon' => 'ico',
+        'image/x-ico'              => 'ico',
+        'image/x-icon'             => 'ico',
+        'text/ico'                 => 'ico',
+    ];
+
+    protected const DEFAULT_FONT_SIZE_PIXELS = 16;
+
+    /** @var array<string, float|int> $svgMeasurements */
+    protected static array $svgMeasurements = [
+        'px' => 1,
+        'em' => self::DEFAULT_FONT_SIZE_PIXELS,
+        'ex' => self::DEFAULT_FONT_SIZE_PIXELS / 2,
+        'pt' => self::DEFAULT_FONT_SIZE_PIXELS / 12,
+        'pc' => self::DEFAULT_FONT_SIZE_PIXELS,
+        'in' => self::DEFAULT_FONT_SIZE_PIXELS * 6,
+        'cm' => self::DEFAULT_FONT_SIZE_PIXELS / (2.54 / 6),
+        'mm' => self::DEFAULT_FONT_SIZE_PIXELS / (25.4 / 6),
     ];
 
     /**
@@ -45,7 +85,7 @@ abstract class Image extends \XLite\Model\Base\Storage
      *
      * @var integer
      *
-     * @Column (type="integer")
+     * @ORM\Column (type="integer")
      */
     protected $width = 0;
 
@@ -54,7 +94,7 @@ abstract class Image extends \XLite\Model\Base\Storage
      *
      * @var integer
      *
-     * @Column (type="integer")
+     * @ORM\Column (type="integer")
      */
     protected $height = 0;
 
@@ -63,7 +103,7 @@ abstract class Image extends \XLite\Model\Base\Storage
      *
      * @var string
      *
-     * @Column (type="string", options={ "fixed": true }, length=32, nullable=true)
+     * @ORM\Column (type="string", options={ "fixed": true }, length=32, nullable=true)
      */
     protected $hash;
 
@@ -72,7 +112,7 @@ abstract class Image extends \XLite\Model\Base\Storage
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $needProcess = true;
 
@@ -111,7 +151,7 @@ abstract class Image extends \XLite\Model\Base\Storage
         $result = true;
 
         if ($this->getHash()) {
-            list($path, $isTempFile) = $this->getLocalPath();
+            [$path, $isTempFile] = $this->getLocalPath();
 
             $hash = \Includes\Utils\FileManager::getHash($path, false, $this->includeFilenameInHash);
 
@@ -154,19 +194,46 @@ abstract class Image extends \XLite\Model\Base\Storage
     {
         $newEntity = parent::cloneEntity();
 
-        $newEntity->setPath('');
+        return $this->processClonnedEntity($newEntity);
+    }
 
-        if (static::STORAGE_URL == $this->getStorageType()) {
-            $newEntity->loadFromURL($this->getURL(), true);
-
-        } else {
+    /**
+     * @param \XLite\Model\AEntity $newEntity
+     *
+     * @return \XLite\Model\AEntity
+     */
+    protected function processClonnedEntity($newEntity)
+    {
+        if ($this->getStorageType() !== static::STORAGE_URL) {
+            $newEntity->setPath('');
             // Clone local image (will be created new file with unique name)
-            $newEntity->loadFromLocalFile($this->getStoragePath(), null, true);
+            $newEntity->loadFromLocalFile($this->getStoragePath(), null, false);
         }
 
         return $newEntity;
     }
 
+    public function getExtensionByMIME()
+    {
+        if (
+            $this->getMime() === static::WEBP_MIME_TYPE
+            && !ImageOperator::isWebpSupported()
+        ) {
+            $imageOperatorEngineType = ImageOperator::getEngineType();
+
+            if ($imageOperatorEngineType !== ImageOperator::ENGINE_SIMPLE) {
+                TopMessage::addWarning(
+                    'Your image processing library does not support WebP format.',
+                    [
+                        'name' => ImageOperator::getEngineName()
+                    ]
+                );
+            }
+        }
+
+        return parent::getExtensionByMIME();
+    }
+
     /**
      * Update file path - change file extension taken from MIME information.
      *
@@ -177,7 +244,7 @@ abstract class Image extends \XLite\Model\Base\Storage
         $result = parent::updatePathByMIME();
 
         if ($result && !$this->isURL()) {
-            list($path,) = $this->getLocalPath();
+            [$path,] = $this->getLocalPath();
 
             $newExtension = $this->getExtensionByMIME();
             $pathinfo = pathinfo($path);
@@ -191,7 +258,7 @@ abstract class Image extends \XLite\Model\Base\Storage
                 return false;
             }
 
-            $extension = isset($pathinfo['extension']) ? $pathinfo['extension'] : '';
+            $extension = $pathinfo['extension'] ?? '';
 
             // HARDCODE for BUG-2520
             if (strtolower($extension) === 'jpg' && $newExtension === 'jpeg') {
@@ -237,7 +304,6 @@ abstract class Image extends \XLite\Model\Base\Storage
                 if ($hash) {
                     $this->setHash($hash);
                 }
-
             } else {
                 $result = false;
             }
@@ -280,7 +346,39 @@ abstract class Image extends \XLite\Model\Base\Storage
      */
     protected function getSystemImageData($path)
     {
-        return @getimagesize($path) ?: [];
+        $publicDir = 'public/';
+        if (substr($path, 0, strlen($publicDir)) === $publicDir) {
+            $path = substr($path, strlen($publicDir));
+            $path = LC_DIR_PUBLIC . $path;
+        }
+
+        if (!file_exists($path)) {
+            return [];
+        }
+
+        $result = @getimagesize($path) ?: [];
+
+        if (
+            !$result
+            && strtolower(pathinfo($path, PATHINFO_EXTENSION)) === static::SVG_EXTENSION
+            && (
+                Request::getInstance()->svg_allowed
+                || $this->isSvgAllowed()
+            )
+        ) {
+            $request = Request::getInstance();
+
+            $result = ($request->svgWidth || $request->svgHeight)
+                ? [
+                    (int) $request->svgWidth,
+                    (int) $request->svgHeight
+                ]
+                : $this->getSvgSizes($path);
+
+            $result['mime'] = 'image/svg+xml';
+        }
+
+        return $result;
     }
 
     /**
@@ -308,6 +406,18 @@ abstract class Image extends \XLite\Model\Base\Storage
         return parent::loadFromLocalFile($path, $basename, $makeUnique);
     }
 
+    /**
+     * Get name
+     *
+     * @return string
+     */
+    public function getName(): string
+    {
+        return $this->getStorageType() === static::STORAGE_ABSOLUTE
+            ? basename($this->getPath())
+            : $this->getPath();
+    }
+
     // {{{ Resized icons
 
     /**
@@ -315,30 +425,38 @@ abstract class Image extends \XLite\Model\Base\Storage
      *
      * @param integer $width  Width limit OPTIONAL
      * @param integer $height Height limit OPTIONAL
+     * @param integer $basewidth Base Width OPTIONAL
+     * @param integer $baseheight Base Height OPTIONAL
      *
      * @return array (new width, new height, URL)
      */
-    public function getResizedURL($width = null, $height = null)
+    public function getResizedURL($width = null, $height = null, $basewidth = null, $baseheight = null)
     {
-        if ($this->isUseDynamicImageResizing()) {
-            $result = $this->doResize($width, $height, false);
-
+        if (strtolower(pathinfo($this->getURL(), PATHINFO_EXTENSION)) === static::SVG_EXTENSION) {
+            $result = [$this->getWidth(), $this->getHeight(), $this->getURL(), $this->getURL()];
+        } elseif ($this->isUseDynamicImageResizing()) {
+            $result = $this->doResize($width, $height, false, $basewidth, $baseheight);
         } else {
-            list($newWidth, $newHeight) = ImageOperator::getCroppedDimensions(
-                $this->getWidth(),
-                $this->getHeight(),
-                $width,
-                $height
-            );
+            $newWidth = $this->getWidth();
+            $newHeight = $this->getHeight();
+
+            if ($newWidth && $newHeight) {
+                $useBaseSizes = ($basewidth && $baseheight);
+
+                [$newWidth, $newHeight] = ImageOperator::getCroppedDimensions(
+                    $newWidth,
+                    $newHeight,
+                    ($useBaseSizes ? $basewidth : $width),
+                    ($useBaseSizes ? $baseheight : $height)
+                );
+            } else {
+                $newWidth = $newHeight = null;
+            }
 
             if ($this->isURL()) {
                 $url = $retinaURL = $this->getURL();
-
             } else {
-                $name = $this->getStorageType()===static::STORAGE_ABSOLUTE
-                    ? basename($this->getPath())
-                    : $this->getPath();
-
+                $name = $this->getName();
                 $size = ($width ?: 'x') . '.' . ($height ?: 'x');
                 $path = $retinaPath = $this->getResizedPath($size, $name);
 
@@ -389,46 +507,160 @@ abstract class Image extends \XLite\Model\Base\Storage
         );
     }
 
+    protected function getResizeableTypes(): array
+    {
+        return array_filter(
+            static::$types,
+            static fn(string $ext): bool => (strtolower($ext) !== static::SVG_EXTENSION)
+        );
+    }
+
     /**
-     * Do resize
+     * Do resize multiple
      *
-     * @param array   $sizes     Sizes
+     * @param array $sizes
      * @param boolean $doRewrite Rewrite flag OPTIONAL
      *
      * @return array
      */
     public function doResizeAll($sizes, $doRewrite = false)
     {
+        $sizesData = $this->prepareSizesData($sizes, $doRewrite);
+        $type = $this->getExtension();
         $result = [];
 
-        foreach ($sizes as $size) {
-            list($width, $height) = $size;
+        if (in_array($type, $this->getResizeableTypes(), true)) {
+            $operator = new ImageOperator($this);
+            $result = $operator->resizeBulk($sizesData);
 
-            $result[] = $this->doResize($width, $height, $doRewrite);
+            foreach ($result as $size) {
+                if (isset($size['tmp'])) {
+                    \Includes\Utils\FileManager::write($size['path'], $size['tmp']->getBody());
+                }
+            }
         }
 
         return $result;
     }
 
+    /**
+     * Prepare sizes array
+     *
+     * @param array $sizes
+     * @param boolean $doRewrite
+     *
+     * @return array
+     */
+    protected function prepareSizesData($sizes, $doRewrite = false)
+    {
+        $sizesData = [];
+
+        foreach ($sizes as $size) {
+            [$width, $height] = $size;
+
+            if (
+                $width < 0
+                || $height < 0
+                || ($width === 0 && $height === 0)
+            ) {
+                if ($width < 0 || $height < 0) {
+                    $this->getLogger()->debug(
+                        sprintf(
+                            'To resize, image width and height must be not less than zero, got: width=%s, height=%s',
+                            $width,
+                            $height
+                        )
+                    );
+                } else {
+                    $this->getLogger()->debug(
+                        'To resize, image width or height must be greater than zero, got: width=0, height=0'
+                    );
+                }
+
+                continue;
+            }
+
+            $sizeValue = $this->checkSizeExists($width, $height, $doRewrite);
+
+            if ($sizeValue) {
+                $sizesData[] = $sizeValue;
+            }
+
+            if (
+                \Includes\Utils\ConfigParser::getOptions(['images', 'generate_retina_images'])
+                && ($width * static::RETINA_RATIO) <= $this->getWidth()
+                && ($height * static::RETINA_RATIO) <= $this->getHeight()
+            ) {
+                $sizeValue = $this->checkSizeExists(
+                    $width * static::RETINA_RATIO,
+                    $height * static::RETINA_RATIO,
+                    $doRewrite
+                );
+                if ($sizeValue) {
+                    $sizesData[] = $sizeValue;
+                }
+            }
+        }
+
+        return array_unique($sizesData, SORT_REGULAR);
+    }
+
+    /**
+     * @param integer $width
+     * @param integer $height
+     * @param boolean $doRewrite
+     *
+     * @return array|null
+     */
+    protected function checkSizeExists($width, $height, $doRewrite)
+    {
+        $sizeValue = null;
+
+        [$newWidth, $newHeight] = $this->getCropDimensions($width, $height);
+
+        $name = $this->getName();
+        $size = ($width ?: 'x') . '.' . ($height ?: 'x');
+        $path = $this->getResizedPath($size, $name);
+        $url = $this->getResizedPublicURL($size, $name);
+
+        if (!$this->isResizedIconAvailable($path) || $doRewrite) {
+            $sizeValue = [
+                'width' => $newWidth,
+                'height' => $newHeight,
+                'path' => $path,
+                'url' => $url
+            ];
+        }
+
+        return $sizeValue;
+    }
+
     /**
      * Resize image by constraints
      *
      * @param integer $width     Width limit OPTIONAL
      * @param integer $height    Height limit OPTIONAL
      * @param boolean $doRewrite Force rewrite OPTIONAL
+     * @param integer $basewidth Base width OPTIONAL
+     * @param integer $baseheight Base height OPTIONAL
      *
      * @return array of [actualWidth, actualHeight, resizedPath, retinaResizedPath]
      */
-    public function doResize($width = null, $height = null, $doRewrite = false)
+    public function doResize($width = null, $height = null, $doRewrite = false, $basewidth = null, $baseheight = null)
     {
-        list($newWidth, $newHeight) = $this->getCropDimensions($width, $height);
+        [$newWidth, $newHeight] = $this->getCropDimensions($width, $height);
+
+        if ($basewidth && $baseheight) {
+            [$newWidth, $newHeight] = $this->getCropDimensions($basewidth, $baseheight);
+        }
+
         $resizedPath = $retinaResizedPath = $this->resizeImage($width, $height, $doRewrite) ?: $this->getURL();
 
-        if (\XLite\Core\ConfigParser::getOptions(['images', 'generate_retina_images'])
+        if (
+            \Includes\Utils\ConfigParser::getOptions(['images', 'generate_retina_images'])
             && ($width * static::RETINA_RATIO) <= $this->getWidth()
             && ($height * static::RETINA_RATIO) <= $this->getHeight()
         ) {
-
             $retinaResizedPath = $this->resizeImage(
                 $width * static::RETINA_RATIO,
                 $height * static::RETINA_RATIO,
@@ -454,16 +686,17 @@ abstract class Image extends \XLite\Model\Base\Storage
             return null;
         }
 
-        list($newWidth, $newHeight) = $this->getCropDimensions($width, $height);
+        [$newWidth, $newHeight] = $this->getCropDimensions($width, $height);
 
-        $name = $this->getStorageType()===static::STORAGE_ABSOLUTE
-            ? basename($this->getPath())
-            : $this->getPath();
+        $name = $this->getName();
         $size = ($width ?: 'x') . '.' . ($height ?: 'x');
         $path = $this->getResizedPath($size, $name);
         $url = $this->getResizedPublicURL($size, $name);
+        $type = $this->getExtension();
 
-        if (!$this->isResizedIconAvailable($path) || $doRewrite) {
+        if (!in_array($type, static::$types, true)) {
+            $url = null;
+        } elseif (!$this->isResizedIconAvailable($path) || $doRewrite) {
             $result = $this->resizeIcon($newWidth, $newHeight, $path);
 
             if (!$result) {
@@ -547,9 +780,9 @@ abstract class Image extends \XLite\Model\Base\Storage
     protected function resizeIcon($width, $height, $path)
     {
         $operator = new ImageOperator($this);
-        list($newWidth, $newHeight, $result) = $operator->resize($width, $height);
+        [$newWidth, $newHeight, $result] = $operator->resize($width, $height);
 
-        return false !== $result && \Includes\Utils\FileManager::write($path, $operator->getImage()->getBody())
+        return $result !== false && \Includes\Utils\FileManager::write($path, $operator->getImage()->getBody())
             ? [$newWidth, $newHeight]
             : null;
     }
@@ -606,17 +839,14 @@ abstract class Image extends \XLite\Model\Base\Storage
         }
 
         $sizes = $this->getAllSizes();
-        foreach ($sizes as $size) {
-            list($width, $height) = $size;
+        $sizesData = $this->prepareSizesData($sizes, true);
 
-            $size = ($width ?: 'x') . '.' . ($height ?: 'x');
-            $path = $this->getResizedPath($size, $name);
-
-            if (\Includes\Utils\FileManager::isExists($path)) {
-                $isDeleted = \Includes\Utils\FileManager::deleteFile($path);
+        foreach ($sizesData as $size) {
+            if (\Includes\Utils\FileManager::isExists($size['path'])) {
+                $isDeleted = \Includes\Utils\FileManager::deleteFile($size['path']);
 
                 if (!$isDeleted) {
-                    \XLite\Logger::getInstance()->log('Can\'t delete resized image ' . $path, LOG_DEBUG);
+                    $this->getLogger()->debug('Can\'t delete resized image ' . $size['path']);
                 }
             }
         }
@@ -713,4 +943,88 @@ abstract class Image extends \XLite\Model\Base\Storage
     {
         return $this->needProcess;
     }
+
+
+    public function allowExtendedTypes()
+    {
+        static::$types = array_merge(static::$types, static::$extendedTypes);
+    }
+
+    /**
+     * @return string[]
+     */
+    public static function getAllowedExtensions(): array
+    {
+        return array_unique(array_values(static::$types));
+    }
+
+    public static function getAllowedTypes(): array
+    {
+        return static::$types;
+    }
+
+    protected static function convertSvgSizeToPixels(string $size): int
+    {
+        $size = trim($size);
+        $value = substr($size, 0, -2);
+        $unit = substr($size, -2);
+
+        if (is_numeric($value) && isset(static::$svgMeasurements[$unit])) {
+            $pixelValue = ((float) $value) * static::$svgMeasurements[$unit];
+        } elseif (is_numeric($size)) {
+            $pixelValue = (float) $size;
+        } else {
+            $pixelValue = 0;
+        }
+
+        return (int) round($pixelValue);
+    }
+
+    /**
+     * @param string $filePath
+     *
+     * @return array{int, int}
+     */
+    protected function getSvgSizes(string $filePath): array
+    {
+        $result = [0, 0];
+
+        $xml = simplexml_load_file($filePath);
+
+        if ($xml) {
+            $attributes = $xml->attributes();
+
+            $width = static::convertSvgSizeToPixels($attributes->width);
+            $height = static::convertSvgSizeToPixels($attributes->height);
+
+            // Absolute dimensions
+            if ($width && $height) {
+                $result = [$width, $height];
+            }
+
+            $viewBox = preg_split('/[\s,]+/', (string)$xml->attributes->viewBox);
+            $viewBoxWidth = (float) ($viewBox[2] ?? 0);
+            $viewBoxHeight = (float) ($viewBox[3] ?? 0);
+
+            // Missing width/height and viewBox
+            if ($viewBoxWidth > 0 && $viewBoxHeight > 0) {
+                // Fixed width and viewBox
+                if ($result[0] && !$result[1]) {
+                    $result[1] = (int) round($result[0] / $viewBoxWidth * $viewBoxHeight);
+                }
+
+                // Fixed height and viewBox
+                if ($result[1] && !$result[0]) {
+                    $result[0] = (int) round($result[1] / $viewBoxHeight * $viewBoxWidth);
+                }
+            }
+        }
+
+        return $result;
+    }
+
+    protected function isSvgAllowed(): bool
+    {
+        return false;
+    }
 }
