@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,25 +7,52 @@
 
 namespace XLite\Model;
 
+use Doctrine\ORM\Mapping as ORM;
+use ApiPlatform\Core\Annotation as ApiPlatform;
+use XLite\API\Endpoint\Cart\DTO\CartOutput as Output;
+
 /**
  * Cart
  *
- * @Entity
- * @HasLifecycleCallbacks
+ * @ORM\Entity
+ * @ApiPlatform\ApiResource(
+ *     output=Output::class,
+ *     itemOperations={
+ *          "get"={
+ *              "method"="GET",
+ *              "path"="/carts/{id}.{_format}",
+ *              "identifiers"={"id"},
+ *              "requirements"={"id"="\d+"},
+ *              "openapi_context"={
+ *                  "summary"="Retrieve a cart by id",
+ *                  "parameters"={
+ *                      {"name"="id", "in"="path", "required"=true, "schema"={"type"="integer"}}
+ *                  }
+ *             },
+ *          }
+ *     },
+ *     collectionOperations={
+ *          "get"={
+ *              "method"="GET",
+ *              "path"="/carts.{_format}",
+ *              "identifiers"={"id"}
+ *          }
+ *     }
+ * )
  */
 class Cart extends \XLite\Model\Order
 {
     /**
      * Cart renew period
      */
-    const RENEW_PERIOD = 3600;
+    public const RENEW_PERIOD = 3600;
 
     /**
      * Array of instances for all derived classes
      *
      * @var array
      */
-    protected static $instances = array();
+    protected static $instances = [];
 
     /**
      * Flag to ignore long calculation for speed up purposes
@@ -61,7 +87,8 @@ class Cart extends \XLite\Model\Order
             static::$instances[$className] = $cart;
 
             if ($doCalculate) {
-                if ($auth->isLogged()
+                if (
+                    $auth->isLogged()
                     && (!$cart->getProfile()
                         || $auth->getProfile()->getProfileId() != $cart->getProfile()->getProfileId()
                     )
@@ -71,12 +98,13 @@ class Cart extends \XLite\Model\Order
                 }
 
                 // Check login state
-                if (\XLite\Core\Session::getInstance()->lastLoginUnique === null
+                if (
+                    \XLite\Core\Session::getInstance()->lastLoginUnique === null
                     && $cart->getProfile()
                     && $cart->getProfile()->getAnonymous()
                     && $cart->getProfile()->getLogin()
                 ) {
-                    $tmpProfile = new \XLite\Model\Profile;
+                    $tmpProfile = new \XLite\Model\Profile();
                     $tmpProfile->setProfileId(0);
                     $tmpProfile->setLogin($cart->getProfile()->getLogin());
 
@@ -87,11 +115,11 @@ class Cart extends \XLite\Model\Order
                 }
 
                 if ($cart->isPersistent()) {
-                    if ($cart instanceof \XLite\Model\Cart
+                    if (
+                        $cart instanceof \XLite\Model\Cart
                         || (\XLite\Core\Converter::time() - static::RENEW_PERIOD) > $cart->getLastRenewDate()
                     ) {
                         $cart->renew();
-
                     } else {
                         $cart->calculate();
                     }
@@ -119,10 +147,64 @@ class Cart extends \XLite\Model\Order
      */
     public function addItem(\XLite\Model\OrderItem $newItem)
     {
+        if (\XLite\Core\Request::getInstance()->addLastUpdatedItem === 'true') {
+            $suitableItems = $this->getItemsByProductId($newItem->getProductId());
+
+            if ($suitableItems) {
+                /** @var \XLite\Model\OrderItem $lastUpdatedItem */
+                $lastUpdatedItem = $this->getLastUpdatedOrderItem($suitableItems);
+
+                $newItem = $lastUpdatedItem->cloneEntity();
+                $newItem->setAmount(1);
+            }
+        }
+
         $this->renewUpdatedTime();
+
         return parent::addItem($newItem);
     }
 
+    /**
+     * Remove item from cart
+     *
+     * @param \XLite\Model\OrderItem $item
+     *
+     * @return boolean
+     */
+    public function removeItem(\XLite\Model\OrderItem $item)
+    {
+        $suitableItems = $this->getItemsByProductId($item->getProductId());
+
+        if (
+            $suitableItems
+            && $lastUpdatedItem = $this->getLastUpdatedOrderItem($suitableItems)
+        ) {
+            $this->renewUpdatedTime();
+
+            return parent::removeItem($lastUpdatedItem);
+        }
+    }
+
+    /**
+     * @param \XLite\Model\OrderItem[] $orderItems
+     *
+     * @return boolean
+     */
+    protected function getLastUpdatedOrderItem($orderItems)
+    {
+        $maxUpdateDate        = 0;
+        $lastUpdatedOrderItem = null;
+
+        foreach ($orderItems as $item) {
+            if ($item->getUpdateDate() >= $maxUpdateDate) {
+                $maxUpdateDate        = $item->getUpdateDate();
+                $lastUpdatedOrderItem = $item;
+            }
+        }
+
+        return $lastUpdatedOrderItem;
+    }
+
     /**
      * Check if recently updated
      *
@@ -135,7 +217,7 @@ class Cart extends \XLite\Model\Order
 
     /**
      * Check if given payment method can be applied to the order
-     * 
+     *
      * @param  \XLite\Model\Payment\Method  $method
      * @return boolean
      */
@@ -315,31 +397,6 @@ class Cart extends \XLite\Model\Order
         $this->reinitializeCurrency();
     }
 
-    /**
-     * Prepare order before save data operation
-     *
-     * @PrePersist
-     * @PreUpdate
-     */
-    public function prepareBeforeSave()
-    {
-        parent::prepareBeforeSave();
-
-        $this->setDate(\XLite\Core\Converter::time());
-    }
-
-    /**
-     * Prepare order before create entity
-     *
-     * @return void
-     *
-     * @PrePersist
-     */
-    public function prepareBeforeCreate()
-    {
-        $this->setLastRenewDate(\XLite\Core\Converter::time());
-    }
-
     /**
      * Clear cart (remove cart items)
      *
@@ -403,7 +460,6 @@ class Cart extends \XLite\Model\Order
      * Prepare order before remove operation
      *
      * @return void
-     * @PreRemove
      */
     public function prepareBeforeRemove()
     {
@@ -424,6 +480,7 @@ class Cart extends \XLite\Model\Order
         }
 
         $this->getRepository()->markAsOrder($this->getOrderId());
+        $this->setJustClosed(true);
     }
 
     /**
@@ -466,7 +523,6 @@ class Cart extends \XLite\Model\Order
             }
 
             \XLite\Core\Database::getEM()->remove($this);
-
         } else {
             $this->mergeWithProfile($profile);
 
@@ -563,7 +619,6 @@ class Cart extends \XLite\Model\Order
                     if ($profile->getShippingAddress()->getIsWork()) {
                         \XLite\Core\Database::getEM()->remove($profile->getShippingAddress());
                         $profile->getAddresses()->removeElement($profile->getShippingAddress());
-
                     } else {
                         $profile->getShippingAddress()->setisShipping(false);
                     }
@@ -575,17 +630,18 @@ class Cart extends \XLite\Model\Order
             }
 
             // Merge billing address
-            if ($this->getProfile()->getBillingAddress()
+            if (
+                $this->getProfile()->getBillingAddress()
                 && $this->getProfile()->getBillingAddress()->getIsWork()
             ) {
                 $address = $this->getProfile()->getBillingAddress();
                 if ($profile->getBillingAddress()) {
-                    if ($profile->getBillingAddress()->getIsWork()
+                    if (
+                        $profile->getBillingAddress()->getIsWork()
                         && !$profile->getBillingAddress()->getIsShipping()
                     ) {
                         \XLite\Core\Database::getEM()->remove($profile->getBillingAddress());
                         $profile->getAddresses()->removeElement($profile->getBillingAddress());
-
                     } else {
                         $profile->getBillingAddress()->setIsBilling(false);
                     }
@@ -595,9 +651,7 @@ class Cart extends \XLite\Model\Order
                 $this->getProfile()->getAddresses()->removeElement($address);
                 $profile->addAddresses($address);
             }
-
         }
-
     }
 
     /**
