@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,13 +21,17 @@ class Info extends \XLite\Model\DTO\Base\ADTO
     public static function validate($dto, ExecutionContextInterface $context)
     {
         if (!empty($dto->default->sku) && !static::isSKUValid($dto)) {
-            static::addViolation($context, 'default.sku', Translation::lbl('SKU must be unique'));
+            static::addViolation($context, 'default.sku', Translation::lbl('This product SKU already exists'));
         }
 
-        if ($dto->marketing->meta_description_type === 'C' && '' === trim($dto->marketing->meta_description)) {
+        if ($dto->marketing->meta_description_type === 'C' && trim($dto->marketing->meta_description) === '') {
             static::addViolation($context, 'marketing.meta_description', Translation::lbl('This field is required'));
         }
 
+        if (!static::isQtyValid($dto)) {
+            static::addViolation($context, 'prices_and_inventory.inventory_tracking.quantity', Translation::lbl('Product quantity has changed'));
+        }
+
         if (!$dto->marketing->clean_url->autogenerate) {
             $repo  = \XLite\Core\Database::getRepo('XLite\Model\CleanURL');
             if (!preg_match('/^' . $repo->getPattern('XLite\Model\Product') . '$/Sui', $dto->marketing->clean_url->clean_url)) {
@@ -43,6 +46,8 @@ class Info extends \XLite\Model\DTO\Base\ADTO
                     $conflict = $repo->getConflict($value, 'XLite\Model\Product', $dto->default->identity);
                     if ($conflict instanceof \XLite\Model\TargetCleanUrl) {
                         static::addViolation($context, 'marketing.clean_url.clean_url', Translation::lbl('The Clean URL entered is already in use by target alias.'));
+                    } elseif ($conflict instanceof \XLite\Model\RootDirCleanUrl) {
+                        static::addViolation($context, 'marketing.clean_url.clean_url', Translation::lbl('The Clean URL you have specified matches the name of a folder on your server.'));
                     } else {
                         static::addViolation($context, 'marketing.clean_url.clean_url', Translation::lbl('The Clean URL entered is already in use.', ['entityURL' => $repo->buildEditURL($conflict)]));
                     }
@@ -61,9 +66,29 @@ class Info extends \XLite\Model\DTO\Base\ADTO
         $sku      = $dto->default->sku;
         $identity = $dto->default->identity;
 
-        $entity = \XLite\Core\Database::getRepo('XLite\Model\Product')->findOneBySku($sku);
+        $entitiesWithSameSku = \XLite\Core\Database::getRepo('XLite\Model\Product')->findBySku($sku);
 
-        return !$entity || (int) $entity->getProductId() === (int) $identity;
+        return $entitiesWithSameSku
+            ? count($entitiesWithSameSku) === 1 && (int) $entitiesWithSameSku[0]->getProductId() === (int) $identity
+            : true;
+    }
+
+    /**
+     * @param Info $dto
+     *
+     * @return boolean
+     */
+    protected static function isQtyValid($dto)
+    {
+        $origin = $dto->prices_and_inventory->inventory_tracking->quantity_origin;
+        if ($origin !== $dto->prices_and_inventory->inventory_tracking->quantity) {
+            $current = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($dto->default->identity);
+            if ($current && $origin != $current->getAmount()) {
+                return false;
+            }
+        }
+
+        return true;
     }
 
     /**
@@ -112,10 +137,12 @@ class Info extends \XLite\Model\DTO\Base\ADTO
             $memberships[] = $membership->getMembershipId();
         }
 
-        $taxClass                   = $object->getTaxClass();
-        $inventoryTracking          = new CommonCell([
+        $taxClass          = $object->getTaxClass();
+        $qty               = $object->getAmount();
+        $inventoryTracking = new CommonCell([
             'inventory_tracking' => $object->getInventoryEnabled(),
-            'quantity'           => $object->getAmount(),
+            'quantity'           => $qty,
+            'quantity_origin'    => $qty,
         ]);
 
         $date = new \DateTime('now', \XLite\Core\Converter::getTimeZone());
@@ -135,15 +162,16 @@ class Info extends \XLite\Model\DTO\Base\ADTO
 
         $shippingBox    = new CommonCell([
             'separate_box' => $object->getUseSeparateBox(),
-            'dimensions'   => [
+            'items_in_box' => $object->getItemsPerBox(),
+        ]);
+        $shipping       = [
+            'requires_shipping_status' => $object->getShippable(),
+            'weight'                   => $object->getWeight(),
+            'dimensions'               => [
                 'length' => $object->getBoxLength(),
                 'width'  => $object->getBoxWidth(),
                 'height' => $object->getBoxHeight(),
             ],
-            'items_in_box' => $object->getItemsPerBox(),
-        ]);
-        $shipping       = [
-            'weight'            => $object->getWeight(),
             'requires_shipping' => $object->getShippable(),
         ];
         $this->shipping = new CommonCell($shipping);
@@ -160,7 +188,8 @@ class Info extends \XLite\Model\DTO\Base\ADTO
         );
 
         $cleanUrlExt = \XLite\Model\Repo\CleanURL::isProductUrlHasExt() ? '.html' : '';
-        if ($object->getCleanURL()
+        if (
+            $object->getCleanURL()
             && \XLite\Model\Repo\CleanURL::isProductUrlHasExt()
             && !preg_match('/.html$/', $object->getCleanURL())
         ) {
@@ -168,7 +197,7 @@ class Info extends \XLite\Model\DTO\Base\ADTO
         }
 
         $cleanURL = new CommonCell([
-            'autogenerate' => !(boolean) $object->getCleanURL(),
+            'autogenerate' => !(bool) $object->getCleanURL(),
             'clean_url'    => \XLite\Model\Repo\CleanURL::isProductUrlHasExt()
                 ? preg_replace('/.html$/', '', $object->getCleanURL())
                 : $object->getCleanURL(),
@@ -235,7 +264,7 @@ class Info extends \XLite\Model\DTO\Base\ADTO
         $object->setBriefDescription($description);
         $object->setDescription($full_description);
 
-        $object->setEnabled((boolean) $default->available_for_sale);
+        $object->setEnabled((bool) $default->available_for_sale);
 
         $priceAndInventory = $this->prices_and_inventory;
         $memberships       = \XLite\Core\Database::getRepo('XLite\Model\Membership')->findByIds($priceAndInventory->memberships);
@@ -254,19 +283,23 @@ class Info extends \XLite\Model\DTO\Base\ADTO
             $object->setArrivalDate($date->getTimestamp());
         }
 
-        $object->setInventoryEnabled((boolean) $priceAndInventory->inventory_tracking->inventory_tracking);
-        $object->setAmount((int) $priceAndInventory->inventory_tracking->quantity);
+        $object->setInventoryEnabled((bool) $priceAndInventory->inventory_tracking->inventory_tracking);
+
+        $qty = $priceAndInventory->inventory_tracking->quantity;
+        if ($priceAndInventory->inventory_tracking->quantity_origin !== $qty) {
+            $object->setAmount((int) $qty);
+        }
 
         $shipping = $this->shipping;
         $object->setWeight((float) $shipping->weight);
-        $object->setShippable((boolean) $shipping->requires_shipping->requires_shipping);
+        $object->setShippable((bool) $shipping->requires_shipping_status);
 
         $shippingBox = $shipping->requires_shipping->shipping_box;
-        $object->setUseSeparateBox((boolean) $shippingBox->separate_box);
+        $object->setUseSeparateBox((bool) $shippingBox->separate_box);
 
-        $object->setBoxLength($shippingBox->dimensions['length']);
-        $object->setBoxWidth($shippingBox->dimensions['width']);
-        $object->setBoxHeight($shippingBox->dimensions['height']);
+        $object->setBoxLength($shipping->dimensions['length']);
+        $object->setBoxWidth($shipping->dimensions['width']);
+        $object->setBoxHeight($shipping->dimensions['height']);
 
         $object->setItemsPerBox($shipping->requires_shipping->shipping_box->items_in_box);
 
@@ -282,11 +315,11 @@ class Info extends \XLite\Model\DTO\Base\ADTO
         $object->setMetaTags((string)$marketing->meta_keywords);
         $object->setMetaTitle((string)$marketing->product_page_title);
 
-        if ($marketing->clean_url->autogenerate
+        if (
+            $marketing->clean_url->autogenerate
             || empty($marketing->clean_url->clean_url)
         ) {
             $object->setCleanURL(\XLite\Core\Database::getRepo('XLite\Model\CleanURL')->generateCleanURL($object));
-
         } else {
             $cleanUrlExt = $marketing->clean_url->clean_url_ext ?: '';
             $value = $marketing->clean_url->clean_url . $cleanUrlExt;
@@ -312,12 +345,17 @@ class Info extends \XLite\Model\DTO\Base\ADTO
                     }
                 }
 
-                $object->setCleanURL((string) $value, !$conflictEntity || !($conflictEntity instanceof \XLite\Model\TargetCleanUrl));
-
+                $object->setCleanURL(
+                    (string) $value,
+                    !$conflictEntity
+                    || !(
+                        $conflictEntity instanceof \XLite\Model\TargetCleanUrl
+                        || $conflictEntity instanceof \XLite\Model\RootDirCleanUrl
+                    )
+                );
             } else {
                 $object->setCleanURL((string) $value);
             }
-
         }
     }
 
@@ -327,6 +365,9 @@ class Info extends \XLite\Model\DTO\Base\ADTO
      */
     public function afterUpdate($object, $rawData = null)
     {
+        if ($object->isDemoProduct()) {
+            $object->setIsDemoProduct(false);
+        }
     }
 
     /**
@@ -335,7 +376,6 @@ class Info extends \XLite\Model\DTO\Base\ADTO
      */
     public function afterPopulate($object, $rawData = null)
     {
-        $object->updateQuickData();
     }
 
     /**
