@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,14 +7,16 @@
 
 namespace XLite\Model;
 
+use Doctrine\ORM\Mapping as ORM;
+
 /**
  * Language label translations
  *
- * @Entity
- * @Table (name="language_label_translations",
+ * @ORM\Entity
+ * @ORM\Table (name="language_label_translations",
  *      indexes={
- *          @Index (name="ci", columns={"code","id"}),
- *          @Index (name="id", columns={"id"})
+ *          @ORM\Index (name="ci", columns={"code","id"}),
+ *          @ORM\Index (name="id", columns={"id"})
  *      }
  * )
  */
@@ -26,14 +27,22 @@ class LanguageLabelTranslation extends \XLite\Model\Base\Translation
      *
      * @var string
      *
-     * @Column (type="text")
+     * @ORM\Column (type="text")
      */
     protected $label;
 
+    /**
+     * @var \XLite\Model\LanguageLabel
+     *
+     * @ORM\ManyToOne (targetEntity="XLite\Model\LanguageLabel", inversedBy="translations")
+     * @ORM\JoinColumn (name="id", referencedColumnName="label_id", onDelete="CASCADE")
+     */
+    protected $owner;
+
     /**
      * Set label
      *
-     * @param text $label
+     * @param string $label
      * @return LanguageLabelTranslation
      */
     public function setLabel($label)
@@ -45,7 +54,7 @@ class LanguageLabelTranslation extends \XLite\Model\Base\Translation
     /**
      * Get label
      *
-     * @return text 
+     * @return string
      */
     public function getLabel()
     {
@@ -55,7 +64,7 @@ class LanguageLabelTranslation extends \XLite\Model\Base\Translation
     /**
      * Get label_id
      *
-     * @return integer 
+     * @return integer
      */
     public function getLabelId()
     {
@@ -77,7 +86,7 @@ class LanguageLabelTranslation extends \XLite\Model\Base\Translation
     /**
      * Get code
      *
-     * @return string 
+     * @return string
      */
     public function getCode()
     {
