@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,21 +7,23 @@
 
 namespace XLite\Model;
 
+use Doctrine\ORM\Mapping as ORM;
+
 /**
  * Membership
  *
- * @Entity
- * @Table (name="notifications")
+ * @ORM\Entity
+ * @ORM\Table (name="notifications")
  */
-class Notification extends \XLite\Model\Base\I18n
+class Notification extends \XLite\Model\Base\I18n implements \XLite\Model\Base\IModuleRelatedEntity
 {
     /**
      * Notification templates directory
      *
      * @var string
      *
-     * @Id
-     * @Column (type="string", length=255, unique=true)
+     * @ORM\Id
+     * @ORM\Column (type="string", length=255, unique=true)
      */
     protected $templatesDirectory = '';
 
@@ -31,7 +32,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $availableForAdmin = false;
 
@@ -40,7 +41,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $availableForCustomer = false;
 
@@ -49,7 +50,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $enabledForAdmin = false;
 
@@ -58,7 +59,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $enabledForCustomer = false;
 
@@ -67,7 +68,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $adminHeaderEnabled = true;
 
@@ -76,7 +77,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $adminGreetingEnabled = true;
 
@@ -85,7 +86,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $adminSignatureEnabled = true;
 
@@ -94,7 +95,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $customerHeaderEnabled = true;
 
@@ -103,7 +104,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $customerGreetingEnabled = true;
 
@@ -112,7 +113,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $customerSignatureEnabled = true;
 
@@ -121,7 +122,7 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var integer
      *
-     * @Column (type="integer", options={"default" : 0})
+     * @ORM\Column (type="integer", options={"default" : 0})
      */
     protected $position = 0;
 
@@ -130,10 +131,29 @@ class Notification extends \XLite\Model\Base\I18n
      *
      * @var boolean
      *
-     * @Column (type="boolean")
+     * @ORM\Column (type="boolean")
      */
     protected $editable = false;
 
+    /**
+     * @ORM\Column (type="string", nullable=true)
+     */
+    protected ?string $module;
+
+    /**
+     * @var bool
+     *
+     * @ORM\Column (type="boolean")
+     */
+    protected $available = true;
+
+    /**
+     * @var \Doctrine\Common\Collections\Collection
+     *
+     * @ORM\OneToMany (targetEntity="XLite\Model\NotificationTranslation", mappedBy="owner", cascade={"all"})
+     */
+    protected $translations;
+
     /**
      * Set templatesDirectory
      *
@@ -387,7 +407,127 @@ class Notification extends \XLite\Model\Base\I18n
      */
     public function setEditable($editable)
     {
-        $this->editable = (boolean)$editable;
+        $this->editable = (bool)$editable;
         return $this;
     }
+
+    public function getModule(): ?string
+    {
+        return $this->module;
+    }
+
+    public function setModule(string $module): void
+    {
+        $this->module = $module;
+    }
+
+    /**
+     * @return bool
+     */
+    public function isAvailable(): bool
+    {
+        return $this->available;
+    }
+
+    /**
+     * @param bool $available
+     */
+    public function setAvailable(bool $available): void
+    {
+        $this->available = $available;
+    }
+
+    // {{{ Translation Getters / setters
+
+    /**
+     * @return string
+     */
+    public function getDescription()
+    {
+        return $this->getTranslationField(__FUNCTION__);
+    }
+
+    /**
+     * @param string $description
+     *
+     * @return \XLite\Model\Base\Translation
+     */
+    public function setDescription($description)
+    {
+        return $this->setTranslationField(__FUNCTION__, $description);
+    }
+
+    /**
+     * @return string
+     */
+    public function getCustomerSubject()
+    {
+        return $this->getTranslationField(__FUNCTION__);
+    }
+
+    /**
+     * @param string $customerSubject
+     *
+     * @return \XLite\Model\Base\Translation
+     */
+    public function setCustomerSubject($customerSubject)
+    {
+        return $this->setTranslationField(__FUNCTION__, $customerSubject);
+    }
+
+    /**
+     * @return string
+     */
+    public function getCustomerText()
+    {
+        return $this->getTranslationField(__FUNCTION__);
+    }
+
+    /**
+     * @param string $customerText
+     *
+     * @return \XLite\Model\Base\Translation
+     */
+    public function setCustomerText($customerText)
+    {
+        return $this->setTranslationField(__FUNCTION__, $customerText);
+    }
+
+    /**
+     * @return string
+     */
+    public function getAdminSubject()
+    {
+        return $this->getTranslationField(__FUNCTION__);
+    }
+
+    /**
+     * @param string $adminSubject
+     *
+     * @return \XLite\Model\Base\Translation
+     */
+    public function setAdminSubject($adminSubject)
+    {
+        return $this->setTranslationField(__FUNCTION__, $adminSubject);
+    }
+
+    /**
+     * @return string
+     */
+    public function getAdminText()
+    {
+        return $this->getTranslationField(__FUNCTION__);
+    }
+
+    /**
+     * @param string $adminText
+     *
+     * @return \XLite\Model\Base\Translation
+     */
+    public function setAdminText($adminText)
+    {
+        return $this->setTranslationField(__FUNCTION__, $adminText);
+    }
+
+    // }}}
 }
