@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,9 +17,9 @@ class AccessControlZoneType extends \XLite\Model\Repo\ARepo
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('name'),
-    );
+    protected $alternativeIdentifier = [
+        ['name'],
+    ];
 
     /**
      * @param $name
@@ -48,4 +47,4 @@ class AccessControlZoneType extends \XLite\Model\Repo\ARepo
         $cnd = new \XLite\Core\CommonCell();
         return $this->search($cnd);
     }
-}
\ No newline at end of file
+}
