@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -10,12 +9,6 @@ namespace XLite\Model\Repo;
 
 /**
  * The Address model repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Address", summary="Add new address")
- * @Api\Operation\Read(modelClass="XLite\Model\Address", summary="Retrieve address by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Address", summary="Retrieve addresses by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Address", summary="Update address by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Address", summary="Delete address by id")
  */
 class Address extends \XLite\Model\Repo\ARepo
 {
@@ -35,7 +28,7 @@ class Address extends \XLite\Model\Repo\ARepo
     {
         $result = $this->defineFindAllCities()->getResult();
 
-        $cities = array();
+        $cities = [];
 
         foreach ($result as $res) {
             $cities[] = $res->getCity();
@@ -56,5 +49,4 @@ class Address extends \XLite\Model\Repo\ARepo
             ->addGroupBy('a.city')
             ->addOrderBy('a.city');
     }
-
 }
