@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,25 +7,24 @@
 
 namespace XLite\Model\Repo;
 
+use XLite\Model\AttributeTranslation;
+
 /**
  * Attributes repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Attribute", summary="Add new product attribute")
- * @Api\Operation\Read(modelClass="XLite\Model\Attribute", summary="Retrieve product attribute by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Attribute", summary="Retrieve product attributes by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Attribute", summary="Update product attribute by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Attribute", summary="Delete product attribute by id")
  */
 class Attribute extends \XLite\Model\Repo\Base\I18n
 {
+    use ModelRepoTranslationTrait;
+
     /**
      * Allowable search params
      */
-    const SEARCH_PRODUCT          = 'product';
-    const SEARCH_PRODUCT_CLASS    = 'productClass';
-    const SEARCH_ATTRIBUTE_GROUP  = 'attributeGroup';
-    const SEARCH_TYPE             = 'type';
-    const SEARCH_NAME             = 'name';
+    public const SEARCH_PRODUCT          = 'product';
+    public const SEARCH_PRODUCT_CLASS    = 'productClass';
+    public const SEARCH_ATTRIBUTE_GROUP  = 'attributeGroup';
+    public const SEARCH_TYPE             = 'type';
+    public const SEARCH_NAME             = 'name';
+    public const SEARCH_EXCLUDING_ID     = 'excludingId';
 
     /**
      * Default 'order by' field name
@@ -47,15 +45,15 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
     {
         return $ids
             ? $this->defineFindMultipleAttributesQuery($product, $ids)->getResult()
-            : array();
+            : [];
     }
 
     /**
      * Define query for findMultipleAttributes() method
-     * 
+     *
      * @param \XLite\Model\Product $product Product
      * @param array                $ids     Attribute ID list
-     *  
+     *
      * @return \XLite\Model\QueryBuilder\AQueryBuilder
      */
     protected function defineFindMultipleAttributesQuery(\XLite\Model\Product $product, array $ids)
@@ -63,7 +61,7 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         $qb = $this->createQueryBuilder('a');
 
         return $qb->leftJoin('a.attribute_properties', 'ap', 'WITH', 'ap.product = :product')
-            ->addSelect('ap.position')
+            ->addSelect('MAX(ap.position) position')
             ->addInCondition('a.id', $ids)
             ->addGroupBy('a.id')
             ->setParameter('product', $product);
@@ -92,7 +90,7 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
      */
     protected function defineRemoveGlobalAttributesDataQueryBuilder($position)
     {
-        $qb = parent::defineRemoveDataQueryBuilder($position);
+        $qb = $this->defineRemoveDataQueryBuilder($position);
 
         return $qb->andWhere($qb->getMainAlias() . '.product IS NULL');
     }
@@ -114,7 +112,7 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
      */
     protected function defineCountForRemoveGlobalAttributesDataQuery()
     {
-        $qb = parent::defineCountForRemoveDataQuery();
+        $qb = $this->defineCountForRemoveDataQuery();
 
         return $qb->andWhere($qb->getMainAlias() . '.product IS NULL');
     }
@@ -122,8 +120,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters attributes by certain product id (leave empty to search attributes without product)", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
      *
@@ -134,7 +130,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         if ($value) {
             $queryBuilder->andWhere('a.product = :attributeProduct')
                 ->setParameter('attributeProduct', $value);
-
         } else {
             $queryBuilder->andWhere('a.product is null');
         }
@@ -143,8 +138,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters attributes by product class ids", type="array", collectionFormat="multi", items=@Swg\Items(type="integer"))
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
      *
@@ -152,16 +145,13 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
      */
     protected function prepareCndProductClass(\Doctrine\ORM\QueryBuilder $queryBuilder, $value = null)
     {
-        if (is_null($value)) {
+        if ($value === null) {
             $queryBuilder->andWhere('a.productClass is null');
-
-        } elseif (is_object($value) && 'Doctrine\ORM\PersistentCollection' != get_class($value)) {
+        } elseif (is_object($value) && get_class($value) != 'Doctrine\ORM\PersistentCollection') {
             $queryBuilder->andWhere('a.productClass = :productClass')
                 ->setParameter('productClass', $value);
-
         } elseif ($value) {
-
-            $ids = array();
+            $ids = [];
             foreach ($value as $id) {
                 if ($id) {
                     $ids[] = is_object($id) ? $id->getId() : $id;
@@ -178,8 +168,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters attributes by attribute group id (leave empty to search attributes without group)", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
      *
@@ -190,7 +178,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         if ($value) {
             $queryBuilder->andWhere('a.attributeGroup = :attributeGroup')
                 ->setParameter('attributeGroup', $value);
-
         } else {
             $queryBuilder->andWhere('a.attributeGroup is null');
         }
@@ -198,7 +185,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters attributes by type", type="string", enum={"S", "T", "C", "H"})
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
@@ -210,7 +196,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         if ($value) {
             if (is_array($value)) {
                 $queryBuilder->andWhere('a.type IN (\'' . implode("','", $value) . '\')');
-
             } else {
                 $queryBuilder->andWhere('a.type = :type')
                     ->setParameter('type', $value);
@@ -220,7 +205,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters attributes by exluding type", type="string", enum={"S", "T", "C", "H"})
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
@@ -232,7 +216,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         if ($value) {
             if (is_array($value)) {
                 $queryBuilder->andWhere('a.type NOT IN (\'' . implode("','", $value) . '\')');
-
             } else {
                 $queryBuilder->andWhere('a.type != :type')
                     ->setParameter('type', $value);
@@ -242,7 +225,6 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters attributes by name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
@@ -264,7 +246,7 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
 
             $condition->add('translations.name = :name');
             $condition->add('defaults.name = :name');
-            if (\XLite\Core\Translation::DEFAULT_LANGUAGE !== \XLite::getDefaultLanguage()) {
+            if (\XLite::getDefaultLanguage() !== \XLite\Core\Translation::DEFAULT_LANGUAGE) {
                 // Add additional join to translations with default-default ('en' at the moment) language code
                 $this->addDefaultTranslationJoins(
                     $queryBuilder,
@@ -280,6 +262,22 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
         }
     }
 
+    /**
+     * Prepare certain search condition
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
+     * @param array                      $value        Condition data
+     *
+     * @return void
+     */
+    protected function prepareCndExcludingId(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if ($value) {
+            $queryBuilder->andWhere('a.id <> :id')
+                ->setParameter('id', $value);
+        }
+    }
+
     // }}}
 
     // {{{ Export routines
@@ -324,15 +322,16 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
      */
     public function generateAttributeValues(\XLite\Model\Product $product, $useProductClass = null)
     {
-        $cnd = new \XLite\Core\CommonCell;
+        $cnd = new \XLite\Core\CommonCell();
         $cnd->productClass = $useProductClass ? $product->getProductClass() : null;
         $cnd->product = null;
-        $cnd->type = array(
+        $cnd->type = [
             \XLite\Model\Attribute::TYPE_CHECKBOX,
             \XLite\Model\Attribute::TYPE_SELECT,
             \XLite\Model\Attribute::TYPE_TEXT,
             \XLite\Model\Attribute::TYPE_HIDDEN,
-        );
+        ];
+        /** @var \XLite\Model\Attribute $a */
         foreach ($this->search($cnd) as $a) {
             $a->addToNewProduct($product);
         }
@@ -349,20 +348,18 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
      */
     protected function addImportCondition(\Doctrine\ORM\QueryBuilder $qb, $name, $value)
     {
-        if ('productClass' == $name && is_string($value)) {
+        if ($name == 'productClass' && is_string($value)) {
             $alias = $qb->getMainAlias();
             $qb->linkInner($alias . '.productClass')
                 ->linkInner('productClass.translations', 'productClassTranslations')
                 ->andWhere('productClassTranslations.name = :productClass')
                 ->setParameter('productClass', $value);
-
         } else {
             parent::addImportCondition($qb, $name, $value);
         }
     }
 
     /**
-     * @param \XLite\Model\Attribute $attribute
      * @return int
      */
     public function countProductsWithValues(\XLite\Model\Attribute $attribute)
@@ -374,6 +371,155 @@ class Attribute extends \XLite\Model\Repo\Base\I18n
             ->where($alias . '.attribute = :attribute')
             ->setParameter('attribute', $attribute);
 
-        return intval($qb->getSingleScalarResult());
+        return (int) $qb->getQuery()->getSingleScalarResult();
+    }
+
+    // {{{ findDuplicateNames
+
+    /**
+     * Find duplicate names
+     *
+     * @param \XLite\Model\ProductClass   $productClass
+     * @param \XLite\Model\AttributeGroup $attrGroup
+     *
+     * @return array
+     */
+    public function findDuplicateNames($productClass, $attrGroup)
+    {
+        return $this->defineFindDuplicateNames($productClass, $attrGroup)->getResult();
+    }
+
+    /**
+     * Define query builder for findDuplicateNames() method
+     *
+     * @param \XLite\Model\ProductClass $productClass
+     * @param \XLite\Model\AttributeGroup $attrGroup
+     *
+     * @return \XLite\Model\QueryBuilder\AQueryBuilder
+     */
+    protected function defineFindDuplicateNames($productClass, $attrGroup)
+    {
+        $qb = $this->createQueryBuilder()
+            ->select('translations.name')
+            ->groupBy('translations.name')
+            ->having('COUNT(translations.name) > :count')
+            ->setParameter('count', 1);
+
+        if ($productClass) {
+            $qb->andWhere('a.productClass = :productClass')
+                ->setParameter('productClass', $productClass);
+        } else {
+            $qb->andWhere('a.productClass is null');
+        }
+
+        if ($attrGroup) {
+            $qb->andWhere('a.attributeGroup = :attrGroup')
+                ->setParameter('attrGroup', $attrGroup);
+        } else {
+            $qb->andWhere('a.attributeGroup is null');
+        }
+
+        return $qb;
+    }
+
+    // }}}
+
+    /**
+     * Find entity by name (any language), product class and attribute group
+     *
+     * @param string                      $name
+     * @param \XLite\Model\ProductClass   $productClass
+     * @param \XLite\Model\AttributeGroup $attrGroup
+     *
+     * @return \XLite\Model\AttributeGroup|integer
+     */
+    public function findByNameAndProductClassAndAttrGroup($name, $productClass, $attrGroup)
+    {
+        return $this->defineFindByNameAndProductClassAndAttrGroupQuery($name, $productClass, $attrGroup)
+            ->getResult();
+    }
+
+    /**
+     * Define query builder for findByNameAndProductClassAndAttrGroup() method
+     *
+     * @param string                      $name
+     * @param \XLite\Model\ProductClass   $productClass
+     * @param \XLite\Model\AttributeGroup $attrGroup
+     *
+     * @return \Doctrine\ORM\QueryBuilder
+     */
+    protected function defineFindByNameAndProductClassAndAttrGroupQuery($name, $productClass, $attrGroup)
+    {
+        $qb = $this->createQueryBuilder()
+            ->andWhere('translations.name = :name')
+            ->setParameter('name', $name);
+
+        if ($productClass) {
+            $qb->andWhere('a.productClass = :productClass')
+                ->setParameter('productClass', $productClass);
+        } else {
+            $qb->andWhere('a.productClass is null');
+        }
+
+        if ($attrGroup) {
+            $qb->andWhere('a.attributeGroup = :attrGroup')
+                ->setParameter('attrGroup', $attrGroup);
+        } else {
+            $qb->andWhere('a.attributeGroup is null');
+        }
+
+        return $qb;
+    }
+
+    public function getAttributesWithValues(\XLite\Model\Product $product, $type)
+    {
+        $attributeValueClass = \XLite\Model\Attribute::getAttributeValueClass($type);
+
+        if (class_exists($attributeValueClass)) {
+            $qb = $this->createQueryBuilder();
+            $alias = $qb->getMainAlias();
+            $qb->join(
+                $attributeValueClass,
+                'av',
+                \Doctrine\ORM\Query\Expr\Join::WITH,
+                'av.attribute = ' . $alias
+            );
+            $qb->andWhere('av.product = :product')
+                ->setParameter('product', $product);
+
+            if (is_a($attributeValueClass, \XLite\Model\AttributeValue\AttributeValueText::class, true)) {
+                $qb->linkLeft('av.translations', 'av_translations')
+                    ->andWhere('av.editable = :true OR av_translations.value != :empty')
+                    ->setParameter('true', true)
+                    ->setParameter('empty', '');
+            }
+
+            $data = $qb->getResult();
+
+            return $data;
+        }
+
+        return [];
+    }
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+            && !empty($result['name'])
+        ) {
+            return [
+                $result['name']
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(AttributeTranslation $translation): ?array
+    {
+        return [
+            $translation->getName()
+        ];
     }
 }
