@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,22 +7,20 @@
 
 namespace XLite\Model\Repo;
 
+use XLite\Model\AttributeOptionTranslation;
+
 /**
  * Attribute options repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\AttributeOption", summary="Add new attribute option")
- * @Api\Operation\Read(modelClass="XLite\Model\AttributeOption", summary="Retrieve attribute option by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\AttributeOption", summary="Retrieve attribute options by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\AttributeOption", summary="Update attribute option by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\AttributeOption", summary="Delete attribute option by id")
  */
 class AttributeOption extends \XLite\Model\Repo\Base\I18n
 {
+    use ModelRepoTranslationTrait;
+
     /**
      * Allowable search params
      */
-    const SEARCH_ATTRIBUTE = 'attribute';
-    const SEARCH_NAME      = 'name';
+    public const SEARCH_ATTRIBUTE = 'attribute';
+    public const SEARCH_NAME      = 'name';
 
     /**
      * Find one option by name and attribute
@@ -35,7 +32,8 @@ class AttributeOption extends \XLite\Model\Repo\Base\I18n
      */
     public function findOneByNameAndAttribute($name, \XLite\Model\Attribute $attribute)
     {
-        return $this->createQueryBuilder('a')
+        return $this->createPureQueryBuilder('a')
+            ->linkLeft('a.translations', 'translations')
             ->andWhere('translations.name = :name')
             ->andWhere('a.attribute = :attribute')
             ->setParameter('name', $name)
@@ -46,7 +44,6 @@ class AttributeOption extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters attribute options by attribute id", type="integer")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
@@ -58,7 +55,6 @@ class AttributeOption extends \XLite\Model\Repo\Base\I18n
         if ($value) {
             if (is_object($value)) {
                 $queryBuilder->andWhere('a.attribute = :attribute');
-
             } else {
                 $queryBuilder->linkInner('a.attribute')->andWhere('attribute.id = :attribute');
             }
@@ -68,7 +64,6 @@ class AttributeOption extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters attribute options by name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition OPTIONAL
@@ -96,4 +91,39 @@ class AttributeOption extends \XLite\Model\Repo\Base\I18n
         $qb->execute();
     }
 
+    public function getOptionNamesByAttribute(\XLite\Model\Attribute $attribute): array
+    {
+        $names = $this->createQueryBuilder()
+            ->select('translations.name')
+            ->linkLeft('a.attribute', 'attr')
+            ->where('attr = :attribute')
+            ->setParameter('attribute', $attribute)
+            ->getQuery()->getResult();
+
+        return array_map(
+            static fn ($item) => $item['name'],
+            $names
+        );
+    }
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+            && !empty($result['name'])
+        ) {
+            return [
+                $result['name']
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(AttributeOptionTranslation $translation): ?array
+    {
+        return [
+            $translation->getName()
+        ];
+    }
 }
