@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -31,7 +30,7 @@ abstract class Searchable extends \XLite\Base\SuperClass
             $cnd = new \XLite\Core\CommonCell();
         }
         // TODO - must be "self::P_LIMIT"
-        $cnd->{\XLite\Model\Repo\Product::P_LIMIT} = array($start, $count);
+        $cnd->{\XLite\Model\Repo\Product::P_LIMIT} = [$start, $count];
 
         return $cnd;
     }
