@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -14,23 +13,23 @@ namespace XLite\Model\Repo\Base;
 abstract class Surcharge extends \XLite\Model\Repo\ARepo
 {
     /**
-     * Get exists types 
-     * 
+     * Get exists types
+     *
      * @return array
      */
     public function getExistsTypes()
     {
-        $result = array();
+        $result = [];
 
         foreach ($this->defineGetExistsTypesQuery()->getResult() as $surcharge) {
             $info = $surcharge->getInfo();
             if ($info) {
-                $result[] = array(
+                $result[] = [
                     'name'    => $info->name,
                     'code'    => $surcharge->getCode(),
                     'type'    => $surcharge->getType(),
                     'include' => $surcharge->getInclude(),
-                );
+                ];
             }
         }
 
@@ -49,6 +48,4 @@ abstract class Surcharge extends \XLite\Model\Repo\ARepo
 
         return $qb->groupBy($alias . '.type, ' . $alias . '.code');
     }
-
 }
-
