@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -43,19 +42,19 @@ class Translation extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * Get used language codes 
-     * 
+     * Get used language codes
+     *
      * @return array
      */
     public function getUsedLanguageCodes()
     {
-        $result = array();
+        $result = [];
 
         $activeLanguagesCodes = [];
         foreach (\XLite\Core\Database::getRepo('XLite\Model\Language')->findActiveLanguages() as $language) {
             $activeLanguagesCodes[] = $language->code;
         }
-        
+
         foreach ($this->defineGetUsedLanguageCodesQuery()->getResult() as $row) {
             if (in_array($row['code'], $activeLanguagesCodes)) {
                 $result[] = $row['code'];
@@ -67,7 +66,7 @@ class Translation extends \XLite\Model\Repo\ARepo
 
     /**
      * Define query for getUsedLanguageCodes() methods
-     * 
+     *
      * @return \Doctrine\ORM\QueryBuilder
      */
     protected function defineGetUsedLanguageCodesQuery()
