@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -11,34 +10,32 @@ namespace XLite\Model\Repo;
 use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\Tools\Pagination\Paginator;
 use XLite\Core\Cache\ExecuteCachedTrait;
+use XLite\InjectLoggerTrait;
+use XLite\Model\CategoryTranslation;
 
 /**
  * Category repository class
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Category", summary="Add new category")
- * @Api\Operation\Read(modelClass="XLite\Model\Category", summary="Retrieve category by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Category", summary="Retrieve categories by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Category", summary="Update category by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Category", summary="Delete category by id")
  */
 class Category extends \XLite\Model\Repo\Base\I18n
 {
     use ExecuteCachedTrait;
+    use InjectLoggerTrait;
+    use ModelRepoTranslationTrait;
 
     /**
      * Allowable search params
      */
-    const SEARCH_PARENT  = 'parent';
-    const SEARCH_SUBTREE = 'subTree';
+    public const SEARCH_PARENT  = 'parent';
+    public const SEARCH_SUBTREE = 'subTree';
 
-    const ROOT_LPOS = 1;
+    public const ROOT_LPOS = 1;
 
     /**
      * Index for subtree param names
      *
      * @var integer
      */
-    static protected $subTreeConditionIndex = 0;
+    protected static $subTreeConditionIndex = 0;
 
     /**
      * Maximum value of the "rpos" field in all records
@@ -242,7 +239,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
      */
     public function getSubtree($categoryId)
     {
-        return $category = $this->getCategory($categoryId)
+        return $this->getCategory($categoryId)
             ? $this->defineSubtreeQuery($categoryId)->getResult()
             : [];
     }
@@ -252,11 +249,11 @@ class Category extends \XLite\Model\Repo\Base\I18n
      *
      * @param integer $categoryId Category Id
      *
-     * @return array
+     * @return \XLite\Model\Category[]
      */
     public function getCategoryPath($categoryId)
     {
-        return $category = $this->getCategory($categoryId)
+        return $this->getCategory($categoryId)
             ? $this->defineCategoryPathQuery($categoryId)->getResult()
             : [];
     }
@@ -294,7 +291,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
      */
     public function getCategoryDepth($categoryId)
     {
-        return $category = $this->getCategory($categoryId)
+        return $this->getCategory($categoryId)
             ? $this->defineCategoryDepthQuery($categoryId)->getSingleScalarResult()
             : 0;
     }
@@ -343,7 +340,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 }
 
                 if (1 < count($names)) {
-
                     $orCnd = new \Doctrine\ORM\Query\Expr\Orx();
 
                     foreach ($names as $k => $v) {
@@ -352,14 +348,12 @@ class Category extends \XLite\Model\Repo\Base\I18n
                     }
 
                     $qb->andWhere($orCnd);
-
                 } else {
                     $qb->andWhere('translations.name = :name')
                         ->setParameter('name', $name);
                 }
 
                 $result = $qb->getSingleResult();
-
             } while ($result && $path);
         }
 
@@ -383,7 +377,12 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $completeResult = [];
         } else {
             $result = $this->getRootCategory();
-            $completeResult = [$result->getCategoryId() => $result];
+            $completeResult = [
+                $result->getCategoryId() => [
+                    'name' => $result->getCategoryId(),
+                    'category' => $result,
+                ]
+            ];
         }
 
         if (!empty($path)) {
@@ -416,7 +415,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 }
 
                 if (1 < count($names)) {
-
                     $orCnd = new \Doctrine\ORM\Query\Expr\Orx();
 
                     foreach ($names as $k => $v) {
@@ -431,7 +429,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
                     }
 
                     $qb->andWhere($orCnd);
-
                 } else {
                     if ($this->getTranslationCode() !== $defaultLanguage) {
                         $qb->andWhere('(CASE WHEN translations.name IS NOT NULL
@@ -446,9 +443,11 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 $result = $qb->getSingleResult();
 
                 if ($result) {
-                    $completeResult[$result->getCategoryId()] = $result;
+                    $completeResult[$result->getCategoryId()] = [
+                        'name' => $name,
+                        'category' => $result,
+                    ];
                 }
-
             } while ($result && $path);
         }
 
@@ -469,21 +468,12 @@ class Category extends \XLite\Model\Repo\Base\I18n
     {
         $qb = $this->createQueryBuilder();
 
-        $defaultLanguage = 'en';
+        $qb->linkLeft(
+            $this->getMainAlias($qb) . '.translations',
+            'translationsAll'
+        );
 
-        if ($this->getTranslationCode() !== $defaultLanguage) {
-            // Add additional join to translations with default language code (en)
-            $this->addDefaultTranslationJoins(
-                $qb,
-                $this->getMainAlias($qb),
-                'default',
-                $defaultLanguage
-            );
-
-            $qb->andWhere('IF (translations.name IS NOT NULL, translations.name, default.name) LIKE :namePart');
-        } else {
-            $qb->andWhere('translations.name LIKE :namePart');
-        }
+        $qb->andWhere('translationsAll.name LIKE :namePart');
 
         if ($excludeCategoryId) {
             $excludeCategory = $this->getCategory($excludeCategoryId);
@@ -496,7 +486,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $qb->setParameter('exRpos', $exRpos);
         }
 
-        $qb->setParameter('namePart', '%'.$namePart.'%');
+        $qb->setParameter('namePart', '%' . $namePart . '%');
         $qb->orderBy('c.lpos', 'ASC');
         $qb->setFirstResult($countPerPage * ($page - 1));
         $qb->setMaxResults($countPerPage);
@@ -531,7 +521,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
             if ($excludeCat && $category['lpos'] >= $exLpos && $category['rpos'] <= $exRpos) {
                 // Category should be excluded
                 continue;
-
             } else {
                 // Add category to the result
                 $list[] = [
@@ -579,8 +568,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
         $field = 'lpos',
         $lpos = null,
         $rpos = null
-    )
-    {
+    ) {
         $category = $this->getCategory($categoryId);
 
         if ($category) {
@@ -681,7 +669,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $queryBuilder->innerJoin('c.parent', 'cparent')
                 ->andWhere('cparent.category_id = :parentId')
                 ->setParameter('parentId', $categoryId);
-
         } else {
             $queryBuilder->andWhere('c.parent IS NULL');
         }
@@ -765,7 +752,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
             );
 
             $queryBuilder->orderBy('c.lpos', 'ASC');
-
         } else {
             // :TODO: - throw exception
         }
@@ -859,7 +845,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 $queryBuilder->leftJoin($alias . '.memberships', 'membership')
                     ->andWhere('membership.membership_id = :membershipId OR membership.membership_id IS NULL')
                     ->setParameter('membershipId', \XLite\Core\Auth::getInstance()->getMembershipId());
-
             } else {
                 $queryBuilder->leftJoin($alias . '.memberships', 'membership')
                     ->andWhere('membership.membership_id IS NULL');
@@ -947,7 +932,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $entity->setLpos($parent->getLpos() + 1);
             $entity->setRpos($parent->getLpos() + 2);
             $entity->setDepth($parent->getDepth() + 1);
-
         } else {
             // :TODO: - rework - add support last root category
             $entity->setLpos(1);
@@ -1005,7 +989,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
         }
 
         foreach ($flags as $name => $delta) {
-            $name = \Includes\Utils\Converter::convertToPascalCase($name);
+            $name = \Includes\Utils\Converter::convertToUpperCamelCase($name);
             $quickFlags->{'set' . $name}($quickFlags->{'get' . $name}() + $delta);
         }
     }
@@ -1040,7 +1024,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
         if (empty($parentID)) {
             // Insert root category
             $this->prepareNewCategoryData($entity);
-
         } else {
             // Get parent for non-root category
             $parent = $this->getCategory($parentID);
@@ -1056,14 +1039,13 @@ class Category extends \XLite\Model\Repo\Base\I18n
 
                 // Create record in DB
                 $this->prepareNewCategoryData($entity, $parent);
-
             } else {
-                \Includes\ErrorHandler::fireError(__METHOD__ . ': category #' . $parentID . ' not found');
+                throw new \Exception(__METHOD__ . ': category #' . $parentID . ' not found');
             }
         }
 
         // Update quick flags
-        if (isset($parent) && null == $entity->getCategoryId()) {
+        if (isset($parent) && $entity->getCategoryId() == null) {
             $this->updateQuickFlags($parent, $this->prepareQuickFlags(1, $entity->getEnabled() ? 1 : -1));
         }
 
@@ -1084,26 +1066,26 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $changeset = [
                 'enabled' => [
                     $entity->getEnabled(),
-                    isset($data['enabled']) ? $data['enabled'] : null
+                    $data['enabled'] ?? null
                 ]
             ];
-
         } else {
             $uow = \XLite\Core\Database::getEM()->getUnitOfWork();
             $uow->computeChangeSets();
             $changeset = $uow->getEntityChangeSet($entity);
         }
 
-        if (!$changeset && $entity->_getPreviousState()->enabled !== null) {
+        if (!$changeset && $entity->getPreviousState()->enabled !== null) {
             $changeset = [
                 'enabled' => [
-                    (bool)$entity->_getPreviousState()->enabled,
+                    (bool)$entity->getPreviousState()->enabled,
                     $entity->getEnabled(),
                 ]
             ];
         }
 
-        if (isset($changeset['enabled'][0], $changeset['enabled'][1])
+        if (
+            isset($changeset['enabled'][0], $changeset['enabled'][1])
             && $entity->getParent()
             && ($changeset['enabled'][0] xor ((bool)$changeset['enabled'][1]))
         ) {
@@ -1144,7 +1126,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
 
         if ($onlySubtree) {
             $this->deleteInBatch($this->getSubtree($entity->getCategoryId()), false);
-
         } else {
             parent::performDelete($entity);
         }
@@ -1167,12 +1148,10 @@ class Category extends \XLite\Model\Repo\Base\I18n
         array $record,
         array $regular = [],
         array $assocs = []
-    )
-    {
+    ) {
         /** @var \XLite\Model\Category $entity */
         if ($entity->isPersistent() && $this->find($entity->getCategoryId())) {
             $this->performUpdate($entity);
-
         } else {
             $this->performInsert($entity);
         }
@@ -1215,8 +1194,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters categories by parent id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -1237,8 +1214,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Retrieve categories subtree by parent id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Parent category id
      *
@@ -1263,7 +1238,11 @@ class Category extends \XLite\Model\Repo\Base\I18n
     {
         $queryBuilder = parent::defineExportIteratorQueryBuilder($position);
 
-        $this->addSubTreeCondition($queryBuilder, $this->getRootCategoryId());
+        $field = 'lpos';
+        $categoryExists = $this->addSubTreeCondition($queryBuilder, $this->getRootCategoryId(), $field);
+        if ($categoryExists) {
+            $queryBuilder->addOrderBy('c.' . $field);
+        }
 
         return $queryBuilder;
     }
@@ -1284,21 +1263,19 @@ class Category extends \XLite\Model\Repo\Base\I18n
         );
 
         try {
-            list($data, $quickFlags) = $nestedSetCorrector->recalculateStructure();
+            [$data, $quickFlags] = $nestedSetCorrector->recalculateStructure();
         } catch (\Exception $exception) {
-            \XLite\Logger::getInstance()->log(
-                'Something is wrong categories in nestedSet recalculation: ' . $exception->getMessage(),
-                LOG_ERR
-            );
+            $this->getLogger()->error('Something is wrong categories in nestedSet recalculation: ' . $exception->getMessage());
+
             return;
         }
 
         if ($data) {
             foreach ($data as $catId => $d) {
                 $query = 'UPDATE ' . $this->getTableName()
-                         . ' SET ' . implode(', ', array_map(function ($v) {
-                        return $v . ' = ?';
-                    }, array_keys($d)))
+                         . ' SET ' . implode(', ', array_map(static function ($v) {
+                            return $v . ' = ?';
+                         }, array_keys($d)))
                          . ' WHERE category_id = ?';
                 $d[] = $catId;
                 \XLite\Core\Database::getEM()->getConnection()->executeUpdate($query, array_values($d));
@@ -1346,7 +1323,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
                  . ' qf ON c.category_id = qf.category_id '
                  . ' ORDER BY c.pos';
 
-        return \Includes\Utils\Database::fetchAll($query);
+        return $this->getEntityManager()->getConnection()->fetchAllAssociative($query);
     }
 
     // }}}
@@ -1437,7 +1414,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
         $rootId = $this->getRootCategoryId();
         $separator = ' / ';
 
-        array_walk($categories, function (array &$category) use ($categories, $rootId, $separator) {
+        array_walk($categories, static function (array &$category) use ($categories, $rootId, $separator) {
             $result = [$category['name']];
             $idsPath = [$category['id']];
             $parentId = (int)$category['parent_id'];
@@ -1497,7 +1474,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 $count = count($result);
                 if ($result) {
                     $tmpResult = [];
-                    foreach ($result as $key => $category) {
+                    foreach ($result as $category) {
                         $tmpResult[] = $category;
                         if (!isset($collected[$category['id']])) {
                             $tmpResult = array_merge($tmpResult, $this->sortCategoriesTreeForParent($list, $category['id']));
@@ -1527,12 +1504,12 @@ class Category extends \XLite\Model\Repo\Base\I18n
         foreach ($list as $category) {
             if ($identity && $category['parent_id'] == $identity) {
                 $categories[] = $category;
-            } else if (!$identity && $category['depth'] == 0) {
+            } elseif (!$identity && $category['depth'] == 0) {
                 $categories[] = $category;
             }
         }
 
-        usort($categories, function ($cat1, $cat2) {
+        usort($categories, static function ($cat1, $cat2) {
             $pos1 = $cat1['pos'];
             $pos2 = $cat2['pos'];
 
@@ -1559,6 +1536,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
         $this->addExcludeRootCondition($queryBuilder, 'c');
 
         $queryBuilder->select('c.category_id as id');
+        $queryBuilder->addGroupBy('c.category_id');
 
         if ($this->getTranslationCode() !== \XLite::getDefaultLanguage()) {
             // Add additional join to translations with default language code
@@ -1571,6 +1549,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $queryBuilder->addSelect('(CASE WHEN translations.name IS NOT NULL THEN translations.name ELSE defaults.name END) as name');
         } else {
             $queryBuilder->addSelect('translations.name');
+            $queryBuilder->addGroupBy('translations.name');
         }
 
         $queryBuilder->addSelect('IDENTITY(c.parent) as parent_id');
@@ -1588,7 +1567,6 @@ class Category extends \XLite\Model\Repo\Base\I18n
         );
         $queryBuilder->addSelect('cleanURLs.cleanURL as cleanURL');
 
-        $queryBuilder->addGroupBy('c.category_id');
         $queryBuilder->orderBy('c.lpos');
 
         return $queryBuilder;
@@ -1608,7 +1586,7 @@ class Category extends \XLite\Model\Repo\Base\I18n
         return $this->executeCachedRuntime(function () use ($term) {
             $categories = $this->getAllCategoriesAsDTO();
 
-            return array_filter($categories, function($item) use ($term) {
+            return array_filter($categories, static function ($item) use ($term) {
                 return stripos($item['fullName'], $term) !== false;
             });
         });
@@ -1617,25 +1595,30 @@ class Category extends \XLite\Model\Repo\Base\I18n
     /**
      * Get categories as dtos with runtime cache
      *
+     * @param boolean $excludeRoot Do not include root category into the search result OPTIONAL
+     *
      * @return array
      */
-    public function getCategoriesAsDTO()
+    public function getCategoriesAsDTO($excludeRoot = true)
     {
-        return $this->executeCachedRuntime(function () {
-            return $this->getCategoriesAsDTOQueryBuilder()->getResult();
-        });
+        return $this->executeCachedRuntime(function () use ($excludeRoot) {
+            return $this->getCategoriesAsDTOQueryBuilder($excludeRoot)->getResult();
+        }, [__METHOD__, $excludeRoot]);
     }
 
     /**
      * Get categories as dtos queryBuilder
      *
+     * @param boolean $excludeRoot Do not include root category into the search result OPTIONAL
+     *
      * @return \XLite\Model\QueryBuilder\AQueryBuilder
      */
-    public function getCategoriesAsDTOQueryBuilder()
+    public function getCategoriesAsDTOQueryBuilder($excludeRoot = true)
     {
-        $queryBuilder = $this->createQueryBuilder();
+        $queryBuilder = $this->createQueryBuilder(null, null, null, $excludeRoot);
 
         $queryBuilder->select('c.category_id as id');
+        $queryBuilder->addGroupBy('c.category_id');
 
         if ($this->getTranslationCode() !== \XLite::getDefaultLanguage()) {
             // Add additional join to translations with default language code
@@ -1648,28 +1631,79 @@ class Category extends \XLite\Model\Repo\Base\I18n
             $queryBuilder->addSelect('(CASE WHEN translations.name IS NOT NULL THEN translations.name ELSE defaults.name END) as name');
         } else {
             $queryBuilder->addSelect('translations.name');
+            $queryBuilder->addGroupBy('translations.name');
         }
 
         $queryBuilder->addSelect('IDENTITY(c.parent) as parent_id');
         $queryBuilder->addSelect('c.depth as depth');
         $queryBuilder->addSelect('count(conditional_children) as subcategoriesCount');
 
-        $queryBuilder->linkLeft('c.children', 'conditional_children',
+        $queryBuilder->linkLeft(
+            'c.children',
+            'conditional_children',
             'WITH',
             'conditional_children.enabled = true AND (:membership MEMBER OF conditional_children.memberships OR conditional_children.memberships IS EMPTY)'
         );
 
         $queryBuilder->setParameter('membership', \XLite\Core\Auth::getInstance()->getMembershipId());
 
-        $queryBuilder->addGroupBy('c.category_id');
+        if (LC_USE_CLEAN_URLS) {
+            $queryBuilder->linkLeft(
+                'c.cleanURLs',
+                'cleanURLs',
+                'WITH',
+                'cleanURLs.id = (SELECT MAX(cl.id) FROM XLite\Model\CleanURL cl WHERE cl.category = c.category_id)'
+            );
+            $queryBuilder->addSelect('cleanURLs.cleanURL as cleanURL');
+        }
 
         return $queryBuilder;
     }
 
     /**
-     * Prepare certain search condition
+     * @param  array $category current category
+     * @param  array $params
      *
-     * @Api\Condition(description="Search by term", type="string")
+     * @return string
+     */
+    public function getUrlByDTO($category, $params = [])
+    {
+        $defaultFormat = \XLite\Core\Converter::buildURL('category', '', ['category_id' => $category['id']], null, false, false);
+
+        if (!LC_USE_CLEAN_URLS || empty($category['cleanURL'])) {
+            return $defaultFormat;
+        }
+
+        $result   = [];
+        $dtos     = $this->getCategoriesAsDTO();
+        $result[] = $category['cleanURL'];
+
+        if (!\XLite\Model\Repo\CleanURL::isCategoryUrlCanonical()) {
+            while ($category['depth'] > 0) {
+                $parent = array_search($category['parent_id'], array_column($dtos, 'id'));
+
+                if ($parent === false) {
+                    return '';
+                }
+
+                $parent = $dtos[$parent];
+
+                if (empty($parent['cleanURL'])) {
+                    return $defaultFormat;
+                }
+
+                $result[] = $parent['cleanURL'];
+                $category = $parent;
+            }
+        }
+
+        $result = \XLite\Core\Database::getRepo('XLite\Model\CleanURL')->buildUrlByData('category', $result, $params);
+
+        return $result;
+    }
+
+    /**
+     * Prepare certain search condition
      *
      * @param \XLite\Model\QueryBuilder\AQueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                                   $value        Condition data
@@ -1699,13 +1733,12 @@ class Category extends \XLite\Model\Repo\Base\I18n
                 )
                     ->setParameter('searchTerm', '%' . (string)$value . '%');
 
-                $qb->addSelect('if(locate(\'' . $value . '\', translations.name)=1,0,1) termLocate');
-
+                $qb->addSelect('IFELSE(locate(\'' . $value . '\', translations.name)=1,0,1) termLocate');
             } else {
                 $qb->andWhere($qb->expr()->like('translations.name', ':searchTerm'))
                     ->setParameter('searchTerm', '%' . (string)$value . '%');
 
-                $qb->addSelect('if(locate(\'' . $value . '\', translations.name)=1,0,1) termLocate');
+                $qb->addSelect('IFELSE(locate(\'' . $value . '\', translations.name)=1,0,1) termLocate');
             }
         }
     }
@@ -1757,10 +1790,11 @@ class Category extends \XLite\Model\Repo\Base\I18n
     public function checkForInternalCategoryProducts($identifiers)
     {
         if (!empty($identifiers) && is_array($identifiers)) {
-            $tablePrefix = \XLite::getInstance()->getOptions(['database_details', 'table_prefix']);
-            $productsTable = $tablePrefix . 'products';
-            $categoriesTable = $tablePrefix . 'categories';
-            $categoryProductsTable = $tablePrefix . 'category_products';
+            $entityManager = \XLite\Core\Database::getEM();
+
+            $productsTable = $entityManager->getClassMetadata(\XLite\Model\Product::class)->getTableName();
+            $categoriesTable = $entityManager->getClassMetadata(\XLite\Model\Category::class)->getTableName();
+            $categoryProductsTable = $entityManager->getClassMetadata(\XLite\Model\CategoryProducts::class)->getTableName();
 
             $categoriesQuery =
                 "SELECT ct.category_id "
@@ -1808,4 +1842,33 @@ class Category extends \XLite\Model\Repo\Base\I18n
 
         return false;
     }
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+            && !empty($result['name'])
+        ) {
+            return [
+                $result['name'],
+                $result['description'] ?? '',
+                $result['metaTags'] ?? '',
+                $result['metaDesc'] ?? '',
+                $result['metaTitle'] ?? ''
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(CategoryTranslation $translation): ?array
+    {
+        return [
+            $translation->getName(),
+            $translation->getDescription(),
+            $translation->getMetaTags(),
+            $translation->getMetaDesc(),
+            $translation->getMetaTitle()
+        ];
+    }
 }
