@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -12,43 +11,37 @@ use XLite\Core\Cache\ExecuteCachedTrait;
 
 /**
  * Clean URL repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\CleanURL", summary="Add new clean url")
- * @Api\Operation\Read(modelClass="XLite\Model\CleanURL", summary="Retrieve clean url by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\CleanURL", summary="Retrieve all clean urls")
- * @Api\Operation\Update(modelClass="XLite\Model\CleanURL", summary="Update clean url by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\CleanURL", summary="Delete clean url by id")
  */
 class CleanURL extends \XLite\Model\Repo\ARepo
 {
     use ExecuteCachedTrait;
 
-    const CATEGORY_URL_FORMAT_NON_CANONICAL_NO_EXT = 'domain/parent/goalcategory/';
-    const CATEGORY_URL_FORMAT_CANONICAL_NO_EXT = 'domain/goalcategory/';
-    const CATEGORY_URL_FORMAT_NON_CANONICAL_EXT = 'domain/parent/goalcategory.html';
-    const CATEGORY_URL_FORMAT_CANONICAL_EXT = 'domain/goalcategory.html';
+    public const CATEGORY_URL_FORMAT_NON_CANONICAL_NO_EXT = 'domain/parent/goalcategory/';
+    public const CATEGORY_URL_FORMAT_CANONICAL_NO_EXT = 'domain/goalcategory/';
+    public const CATEGORY_URL_FORMAT_NON_CANONICAL_EXT = 'domain/parent/goalcategory.html';
+    public const CATEGORY_URL_FORMAT_CANONICAL_EXT = 'domain/goalcategory.html';
 
-    const PRODUCT_URL_FORMAT_NO_EXT = 'domain/goalproduct';
-    const PRODUCT_URL_FORMAT_EXT = 'domain/goalproduct.html';
+    public const PRODUCT_URL_FORMAT_NO_EXT = 'domain/goalproduct';
+    public const PRODUCT_URL_FORMAT_EXT = 'domain/goalproduct.html';
 
-    const PRODUCT_URL_CANONICAL_WITH_CATEGORY = 'domain/main_category_clean_url/product_clean_url';
+    public const PRODUCT_URL_CANONICAL_WITH_CATEGORY = 'domain/main_category_clean_url/product_clean_url';
 
     /**
      * Limit of iterations to generate clean URL
      */
-    const CLEAN_URL_CHECK_LIMIT = 1000;
+    public const CLEAN_URL_CHECK_LIMIT = 1000;
 
     /**
      * Use this char as separator, if the default one is not set in the config
      */
-    const CLEAN_URL_DEFAULT_SEPARATOR = '-';
+    public const CLEAN_URL_DEFAULT_SEPARATOR = '-';
 
     /**
      * Default extension
      */
-    const CLEAN_URL_DEFAULT_EXTENSION = 'html';
+    public const CLEAN_URL_DEFAULT_EXTENSION = 'html';
 
-    const PLACEHOLDER = '#PLACEHOLDER#';
+    public const PLACEHOLDER = '#PLACEHOLDER#';
 
     /**
      * Returns available entities types
@@ -77,9 +70,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             ? \Doctrine\Common\Util\ClassUtils::getClass($entity)
             : \Doctrine\Common\Util\ClassUtils::getRealClass($entity);
 
-        return isset($types[$className])
-            ? $types[$className]
-            : null;
+        return $types[$className] ?? null;
     }
 
     // {{{ Check clean url
@@ -96,7 +87,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         return method_exists($this, $method)
@@ -130,14 +121,15 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         $result = method_exists($this, $method)
             ? $this->{$method}($entity)
             : $this->getCommonSeparator();
 
-        if (empty($result)
+        if (
+            empty($result)
             || !preg_match('/' . $this->getPattern($entity) . '/S', $result)
         ) {
             $result = static::CLEAN_URL_DEFAULT_SEPARATOR;
@@ -153,7 +145,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public function getCommonSeparator()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'default_separator'));
+        return \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'default_separator']);
     }
 
     // }}}
@@ -172,7 +164,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         return method_exists($this, $method)
@@ -187,7 +179,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function isCommonCapitalizeWords()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'capitalize_words'));
+        return \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'capitalize_words']);
     }
 
     // }}}
@@ -206,7 +198,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $result = '';
 
-        if (null === $base) {
+        if ($base === null) {
             $base = $this->getURLBase($entity);
         }
 
@@ -221,7 +213,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
 
             if ($this->isCapitalizeWords($entity)) {
                 $result = implode($separator, array_map(
-                    function ($word) {
+                    static function ($word) {
                         return mb_strtoupper(mb_substr($word, 0, 1)) . mb_substr($word, 1);
                     },
                     explode($separator, $result)
@@ -237,7 +229,8 @@ class CleanURL extends \XLite\Model\Repo\ARepo
                 255 - mb_strlen($separator . (string) static::CLEAN_URL_CHECK_LIMIT . $this->postProcessURL('', $entity))
             );
 
-            while (!$this->isURLUnique($this->postProcessURL($result . $suffix, $entity), $entity)
+            while (
+                !$this->isURLUnique($this->postProcessURL($result . $suffix, $entity), $entity)
                 && static::CLEAN_URL_CHECK_LIMIT > $increment
             ) {
                 $suffix = $separator . $increment++;
@@ -276,7 +269,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public function isUseUnicode()
     {
-        return \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'use_unicode'));
+        return \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'use_unicode']);
     }
 
     // }}}
@@ -295,7 +288,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         return method_exists($this, $method)
@@ -315,16 +308,14 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         $result = method_exists($this, $method)
             ? $this->{$method}($entity)
             : null;
 
-        return null === $result
-            ? $entity->{$this->getBaseFieldName($entity)}
-            : $result;
+        return $result ?? $entity->{$this->getBaseFieldName($entity)};
     }
 
     // }}}
@@ -345,17 +336,20 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         if (method_exists($this, $method)) {
             $result = $this->{$method}($cleanURL, $entity, $id);
-
         } else {
             if (in_array($cleanURL, static::getConfigCleanUrlAliases())) {
                 return $this->getCleanUrlTargetEntity($cleanURL);
             }
 
+            if (static::isRootDirExists($cleanURL)) {
+                return $this->getCleanUrlRootDirEntity($cleanURL);
+            }
+
             /** @var \XLite\Model\CleanURL $cleanURLObject */
             $cleanURLObject = $this->findConflictByCleanURL($cleanURL, $entity, $id);
             $tmpEntity = $cleanURLObject
@@ -368,7 +362,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         }
 
         return $result;
-
     }
 
     /**
@@ -382,20 +375,23 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public function isURLUnique($cleanURL, $entity, $id = null)
     {
-        $result = null;
         $conflict = $this->getConflict($cleanURL, $entity, $id);
 
         if (is_object($entity)) {
-            $result = empty($conflict) || $conflict->getUniqueIdentifier() == $entity->getUniqueIdentifier();
+            $entityIdentifier = $entity->getUniqueIdentifier();
 
+            $result = $conflict === null
+                || (
+                    $entityIdentifier !== null
+                    && $conflict->getUniqueIdentifier() === $entityIdentifier
+                );
         } elseif ($id) {
-            $result = empty($conflict)
-                || (\Doctrine\Common\Util\ClassUtils::getClass($conflict) == $entity
+            $result = $conflict === null
+                || (\Doctrine\Common\Util\ClassUtils::getClass($conflict) === $entity
                     && $conflict->getUniqueIdentifier() == $id
                 );
-
         } else {
-            $result = empty($conflict);
+            $result = $conflict === null;
         }
 
         return $result;
@@ -408,7 +404,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      * @param \XLite\Model\AEntity|string $entity   Entity or class name
      * @param mixed                       $id       Entity identifier OPTIONAL
      *
-     * @return boolean
+     * @return \XLite\Model\AEntity
      */
     protected function getConflictCategory($cleanURL, $entity, $id = null)
     {
@@ -424,12 +420,22 @@ class CleanURL extends \XLite\Model\Repo\ARepo
                 if (in_array($cleanURL, static::getConfigCleanUrlAliases())) {
                     return $this->getCleanUrlTargetEntity($cleanURL);
                 }
+
+                if (static::isRootDirExists($cleanURL)) {
+                    return $this->getCleanUrlRootDirEntity($cleanURL);
+                }
+
                 $tmpEntity = $this->findEntityByURL('category', $cleanURL);
             } else {
-                if ($entity->getDepth() === 0 && in_array($cleanURL, static::getConfigCleanUrlAliases())) {
+                if ($entity->getDepth() <= 0 && in_array($cleanURL, static::getConfigCleanUrlAliases())) {
                     return $this->getCleanUrlTargetEntity($cleanURL);
                 }
 
+                $noExtCleanURL = str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $cleanURL);
+                if ($entity->getDepth() <= 0 && static::isRootDirExists($noExtCleanURL)) {
+                    return $this->getCleanUrlRootDirEntity($cleanURL);
+                }
+
                 $tmpEntity = $this->findCategoryByURL($cleanURL, $entity->getParent());
                 if (!$tmpEntity && static::isCategoryUrlHasExt()) {
                     $tmpEntity = $this->findCategoryByURL(str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $cleanURL), $entity->getParent());
@@ -439,9 +445,8 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             if (!$tmpEntity) {
                 $tmpEntity = $this->findCategoryConflictWithOtherTypes($cleanURL);
             }
-            
-            $result = $tmpEntity ?: null;
 
+            $result = $tmpEntity ?: null;
         }
 
         return $result;
@@ -510,7 +515,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         return method_exists($this, $method)
@@ -564,28 +569,28 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     public function parseURL($url, $last = '', $rest = '', $ext = '')
     {
         $target = null;
-        $params = array();
+        $params = [];
 
-        foreach (static::getEntityTypes() as $model => $entityType) {
+        foreach (static::getEntityTypes() as $entityType) {
             $method = $entityType
-                ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+                ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
                 : null;
 
             $result = method_exists($this, $method)
                 ? $this->{$method}($url, $last, $rest, $ext)
-                : array();
+                : [];
 
             if ($result) {
-                list($target, $params) = $result;
+                [$target, $params] = $result;
                 break;
             }
         }
 
-        if (null === $target) {
+        if ($target === null) {
             $result = $this->parseURLConfig($url, $last, $rest, $ext);
 
             if ($result) {
-                list($target, $params) = $result;
+                [$target, $params] = $result;
             }
         }
 
@@ -597,7 +602,16 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public static function getConfigCleanUrlAliases()
     {
-        return (array) \Includes\Utils\ConfigParser::getOptions(array('clean_urls_aliases'));
+        return (array) \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'aliases']);
+    }
+
+    /**
+     * @param $name
+     * @return bool
+     */
+    public static function isRootDirExists($name)
+    {
+        return \Includes\Utils\FileManager::isDir(LC_DIR_ROOT . $name);
     }
 
     /**
@@ -615,6 +629,10 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $aliases = static::getConfigCleanUrlAliases();
 
+        if ($ext) {
+            $url .= $ext;
+        }
+
         if (($key = array_search($url, $aliases)) !== false) {
             return [$key, []];
         }
@@ -638,15 +656,15 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         if ($query) {
             parse_str($query, $params);
 
-            $target = isset($params['target']) ? $params['target'] : '';
-            $action = isset($params['action']) ? $params['action'] : '';
+            $target = $params['target'] ?? '';
+            $action = $params['action'] ?? '';
 
             $result = \XLite\Core\Converter::buildCleanURL($target, $action, $params);
         }
-        
+
         return $result;
     }
-    
+
     /**
      * Hook for modules
      *
@@ -661,16 +679,17 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function prepareParseURL($url, $last, $rest, $ext, $target, $params)
     {
-        if ('product' === $target) {
+        if ($target === 'product') {
             if (!empty($last)) {
                 $path = explode('/', $rest);
                 $path[] = $last;
 
-                $entity = $this->findCategoryByPath($path);
+                $entity = static::isCategoryUrlCanonical()
+                    ? $this->findEntityByURL('category', $last)
+                    : $this->findCategoryByPath($path);
 
                 if ($entity && $entity->hasProduct($params['product_id'])) {
                     $params['category_id'] = $entity->getCategoryId();
-
                 }
             } elseif (!empty(\XLite\Core\Request::getInstance()->category_id)) {
                 $params['category_id'] = \XLite\Core\Request::getInstance()->category_id;
@@ -719,7 +738,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             if (static::isCategoryUrlCanonical()) {
                 $result = $this->findByURL('category', $url . $ext);
             } else {
-                $path = explode('/', $rest);
+                $path = explode('/', (string) $rest);
                 $path[] = $last;
 
                 if (static::isCategoryUrlHasExt()) {
@@ -736,7 +755,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
                     $target = 'category';
                     $params[$entity->getUniqueIdentifierName()] = $entity->getUniqueIdentifier();
 
-                    $result = array($target, $params);
+                    $result = [$target, $params];
                 }
             }
         }
@@ -755,7 +774,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     protected function findByURL($entityType, $url)
     {
         $target = null;
-        $params = array();
+        $params = [];
 
         $entity = $this->findEntityByURL($entityType, $url);
 
@@ -765,7 +784,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         }
 
         return $target
-            ? array($target, $params)
+            ? [$target, $params]
             : null;
     }
 
@@ -782,7 +801,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entity = $this->defineFindEntityByURL($entityType, $url)->getSingleResult();
 
         $method = $entityType
-            ? 'get' . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         return $entity && method_exists($entity, $method)
@@ -837,7 +856,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             $parent = $entity;
         }
 
-        return isset($entity) ? $entity : null;
+        return $entity ?? null;
     }
 
     /**
@@ -875,19 +894,12 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $queryBuilder = $this->defineFindEntityByURL('category', $url);
 
-        if ($parent) {
-            $queryBuilder->linkInner('c.category')
-                ->andWhere('category.lpos > :parentLpos')
-                ->andWhere('category.rpos < :parentRpos')
-                ->setParameter('parentLpos', $parent->getLpos())
-                ->setParameter('parentRpos', $parent->getRpos())
-                ->orderBy('c.id', 'DESC');
-        } else {
-            $queryBuilder->linkInner('c.category')
-                ->andWhere('category.parent = :parent')
-                ->setParameter('parent', null)
-                ->orderBy('c.id', 'DESC');
-        }
+        $queryBuilder->linkInner('c.category')
+            ->andWhere('category.parent = :parent')
+            ->setParameter('parent', $parent
+                ? $parent->getCategoryId()
+                : null)
+            ->orderBy('c.id', 'DESC');
 
         return $queryBuilder;
     }
@@ -904,46 +916,32 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @return string
      */
-    public function buildURL($target = '', array $params = array())
+    public function buildURL($target = '', array $params = [])
     {
         $result = null;
 
-        if (\XLite\Core\Operator::isClassExists($target)) {
+        if (class_exists($target)) {
             $target = static::getEntityType($target);
         }
 
         $method = $target
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($target)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($target)
             : null;
 
-        $data = method_exists($this, $method)
+        $data = isset($method) && method_exists($this, $method)
             ? $this->{$method}($params)
-            : array();
+            : [];
 
         if ($data) {
-            list($urlParts, $params) = $data;
-
-            if ($urlParts) {
-                list($urlParts, $params) = $this->prepareBuildURL($target, $params, $urlParts);
-            }
-
-            if ($urlParts) {
-                unset($params['target']);
-                $result = implode('/', array_reverse($urlParts));
-
-                if ($target == 'category' && !static::isCategoryUrlHasExt()) {
-                    $result .= '/';
-                }
-
-                if (!empty($params)) {
-                    $result .= '?' . http_build_query($params, null, '&');
-                }
-            }
+            [$urlParts, $params] = $data;
+            $result = $this->buildUrlByData($target, $urlParts, $params);
         } else {
             $aliases = static::getConfigCleanUrlAliases();
 
             if (isset($aliases[$target])) {
-                return (substr($aliases[$target], -4) == '.' . static::CLEAN_URL_DEFAULT_EXTENSION)
+                $extLength = strlen('.' . static::CLEAN_URL_DEFAULT_EXTENSION);
+
+                return (substr($aliases[$target], -$extLength) === '.' . static::CLEAN_URL_DEFAULT_EXTENSION)
                     ? $aliases[$target]
                     : $aliases[$target] . '/';
             }
@@ -952,6 +950,39 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return $result;
     }
 
+    /**
+     * Build url string by array
+     *
+     * @param string $target
+     * @param array  $urlParts
+     * @param array  $params
+     *
+     * @return string
+     */
+    public function buildUrlByData($target, $urlParts, $params)
+    {
+        $result = null;
+
+        if ($urlParts) {
+            [$urlParts, $params] = $this->prepareBuildURL($target, $params, $urlParts);
+        }
+
+        if ($urlParts) {
+            unset($params['target']);
+            $result = implode('/', array_reverse($urlParts));
+
+            if ($target == 'category' && !static::isCategoryUrlHasExt()) {
+                $result .= '/';
+            }
+
+            if (!empty($params)) {
+                $result .= '?' . http_build_query($params, '', '&');
+            }
+        }
+
+        return $result;
+    }
+
     /**
      * Returns 'category_clean_urls_format' option value
      *
@@ -959,7 +990,8 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public static function getCategoryCleanUrlFormat()
     {
-        $format = \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'category_clean_urls_format'));
+        $formats = \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'formats']);
+        $format = $formats['category'];
 
         return in_array($format, [
             static::CATEGORY_URL_FORMAT_NON_CANONICAL_NO_EXT,
@@ -978,7 +1010,9 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public function isUseCanonicalProductURLWithCategory()
     {
-        return static::PRODUCT_URL_CANONICAL_WITH_CATEGORY === \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'canonical_product_clean_urls_format'));
+        $formats = \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'formats']);
+
+        return $formats['canonical_product'] === static::PRODUCT_URL_CANONICAL_WITH_CATEGORY;
     }
 
     /**
@@ -996,7 +1030,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
 
     /**
      * Is use extension for categories
-     * 
+     *
      * @return boolean
      */
     public static function isCategoryUrlHasExt()
@@ -1014,7 +1048,8 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public static function getProductCleanUrlFormat()
     {
-        $format = \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'product_clean_urls_format'));
+        $formats = \Includes\Utils\ConfigParser::getOptions(['clean_urls', 'formats']);
+        $format = $formats['product'];
 
         return in_array($format, [
             static::PRODUCT_URL_FORMAT_EXT,
@@ -1034,34 +1069,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return static::getProductCleanUrlFormat() === static::PRODUCT_URL_FORMAT_EXT;
     }
 
-    /**
-     * Analyze current target and request params and get a canonical redirect URL or null if redirect is not needed
-     *
-     * @param string $target
-     *
-     * @return string
-     */
-    public function getRedirectCanonicalURL($target)
-    {
-        $result = null;
-
-        return $result;
-    }
-
-    /**
-     * Check if redirect to canonical url required
-     *
-     * @param string $target
-     * @param string $url
-     * @param string $last
-     * @param string $rest
-     * @param string $ext
-     * @return bool
-     */
-    protected function isRedirectToCanonicalRequired($target, $url, $last, $rest, $ext) {
-        return 'product' === $target && !empty($last);
-    }
-
     /**
      * Hook for modules
      *
@@ -1073,7 +1080,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function prepareBuildURL($target, $params, $urlParts)
     {
-        if ('product' === $target) {
+        if ($target === 'product') {
             /** @var \XLite\Model\Repo\Category $repo */
             $repo = \XLite\Core\Database::getRepo('XLite\Model\Category');
 
@@ -1092,7 +1099,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
 
                         unset($params['category_id']);
                     }
-
                 } else {
                     unset($params['category_id']);
                 }
@@ -1113,13 +1119,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function buildURLProduct($params)
     {
-        $urlParts = array();
+        $urlParts = [];
 
         if (!empty($params['product_id'])) {
             /** @var \XLite\Model\Product $product */
             $product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($params['product_id']);
 
-            if (null !== $product && $product->getCleanURL()) {
+            if ($product !== null && $product->getCleanURL()) {
                 $urlParts[] = $product->getCleanURL();
             }
         }
@@ -1136,7 +1142,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     public function buildURLProductCanonical($params)
     {
-        list($urlParts, $params) = $this->buildURLProduct($params);
+        [$urlParts, $params] = $this->buildURLProduct($params);
 
         if ($this->isUseCanonicalProductURLWithCategory()) {
             if ($product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($params['product_id'])) {
@@ -1171,11 +1177,9 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function buildURLCategory($params)
     {
-        $urlParts = array();
+        $urlParts = [];
 
-        $id = isset($params['category_id'])
-            ? $params['category_id']
-            : (isset($params['id']) ? $params['id'] : null);
+        $id = $params['category_id'] ?? ($params['id'] ?? null);
         if ($id) {
             $urlParts = $this->getCategoryURLPath($id);
 
@@ -1188,6 +1192,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return [$urlParts, $params];
     }
 
+    public function buildCategoryCleanUrl(int $categoryId): string
+    {
+        [$urlParts, $params] = $this->buildURLCategory(['category_id' => $categoryId]);
+
+        return $this->buildUrlByData('category', $urlParts, $params);
+    }
+
     protected function buildURLMain($params)
     {
         return [[''], $params];
@@ -1204,10 +1215,12 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $category = \XLite\Core\Database::getRepo('XLite\Model\Category')->getCategory($categoryId);
 
+        if (!$category) {
+            return null;
+        }
+
         if (static::isCategoryUrlCanonical()) {
-            return $category
-                ? [$category->getCleanURL()]
-                : null;
+            return [$category->getCleanURL()];
         } else {
             $result = [];
             $hasExt = static::isCategoryUrlHasExt();
@@ -1242,23 +1255,23 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @return string
      */
-    public function buildFakeURL($entity, array $params = array(), $ignoreExtension = false)
+    public function buildFakeURL($entity, array $params = [], $ignoreExtension = false)
     {
         $result = '';
 
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
-        $data = method_exists($this, $method)
+        $data = $method && method_exists($this, $method)
             ? $this->{$method}($entity, $params, $ignoreExtension)
-            : array();
+            : [];
 
         if ($data) {
-            list($urlParts, $params) = $data;
-            list($urlParts, $params) = $this->prepareBuildURL($entityType, $params, $urlParts);
+            [$urlParts, $params] = $data;
+            [$urlParts, $params] = $this->prepareBuildURL($entityType, $params, $urlParts);
 
             if ($urlParts) {
                 unset($params['target']);
@@ -1288,7 +1301,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function buildFakeURLProduct($entity, $params, $ignoreExtension = false)
     {
-        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension));
+        $urlParts = [$this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension)];
 
         /** @var \XLite\Model\Product $entity */
 //        if (is_object($entity) && $entity->getCategoryId()) {
@@ -1305,15 +1318,20 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      * @param array                       $params Params
      * @param boolean                     $ignoreExtension Ignore default extension
      *
-     * @return string
+     * @return array
      */
     protected function buildFakeURLCategory($entity, $params, $ignoreExtension = false)
     {
-        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension));
+        $urlParts = [$this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension)];
 
         /** @var \XLite\Model\Category $entity */
-        if (is_object($entity) && $entity->getParentId() && !static::isCategoryUrlCanonical()) {
-            $urlParts = array_merge($urlParts, $this->getCategoryURLPath($entity->getParentId()));
+        if (
+            is_object($entity)
+            && $entity->getParentId()
+            && !static::isCategoryUrlCanonical()
+            && ($parentUrlPart = $this->getCategoryURLPath($entity->getParentId()))
+        ) {
+            $urlParts = array_merge($urlParts, $parentUrlPart);
         }
 
         return [$urlParts, $params];
@@ -1337,18 +1355,18 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         $entityType = static::getEntityType($entity);
 
         $method = $entityType
-            ? __FUNCTION__ . \XLite\Core\Converter::convertToCamelCase($entityType)
+            ? __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($entityType)
             : null;
 
         $data = method_exists($this, $method)
             ? $this->{$method}($entity)
-            : array(
-                \XLite\Core\Converter::convertFromCamelCase($entityType),
-                array($entity->getUniqueIdentifierName() => $entity->getUniqueIdentifier())
-            );
+            : [
+                \Includes\Utils\Converter::convertFromCamelCase($entityType),
+                [$entity->getUniqueIdentifierName() => $entity->getUniqueIdentifier()]
+            ];
 
         if ($data) {
-            list($target, $params) = $data;
+            [$target, $params] = $data;
 
             if ($target) {
                 $result = \XLite\Core\Converter::buildURL($target, '', $params);
@@ -1383,5 +1401,18 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return $entity;
     }
 
+    /**
+     * @param $cleanURL
+     *
+     * @return \XLite\Model\RootDirCleanUrl
+     */
+    public function getCleanUrlRootDirEntity($cleanURL)
+    {
+        $entity = new \XLite\Model\RootDirCleanUrl();
+        $entity->setCleanURL($cleanURL);
+
+        return $entity;
+    }
+
     // }}}
 }
