@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,13 +15,13 @@ class EventTask extends \XLite\Model\Repo\ARepo
     /**
      * Query limit
      */
-    const QUERY_LIMIT = 10;
+    public const QUERY_LIMIT = 10;
 
     /**
-     * Find query 
+     * Find query
      *
      * @param integer $limit Tasks limit OPTIONAL
-     * 
+     *
      * @return array
      */
     public function findQuery($limit = self::QUERY_LIMIT)
@@ -53,7 +52,7 @@ class EventTask extends \XLite\Model\Repo\ARepo
      * Define query for findQuery() method
      *
      * @param integer $limit Tasks limit
-     * 
+     *
      * @return \XLite\Model\QueryBuilder\AQueryBuilder
      */
     protected function defineFindQuery($limit)
