@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,70 +8,72 @@
 namespace XLite\Model\Repo;
 
 use Doctrine\ORM\QueryBuilder;
+use XLite\InjectLoggerTrait;
 
 /**
  * Order repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Order", summary="Add new order")
- * @Api\Operation\Read(modelClass="XLite\Model\Order", summary="Retrieve order by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Order", summary="Retrieve orders by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Order", summary="Update order by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Order", summary="Delete order by id")
  */
 class Order extends \XLite\Model\Repo\ARepo
 {
+    use InjectLoggerTrait;
+
     /**
      * Additional search mode
      */
-    const SEARCH_MODE_TOTALS  = 'totals';
-    const SEARCH_MODE_PREV_ORDER  = 'prev';
-    const SEARCH_MODE_NEXT_ORDER  = 'next';
+    public const SEARCH_MODE_TOTALS  = 'totals';
+    public const SEARCH_MODE_PREV_ORDER  = 'prev';
+    public const SEARCH_MODE_NEXT_ORDER  = 'next';
 
     /**
      * Cart TTL (in seconds)
      */
-    const ORDER_TTL = 86400;
+    public const ORDER_TTL = 86400;
 
     /**
      * In progress orders TTL (in seconds)
      */
-    const IN_PROGRESS_ORDER_TTL = 3600;
+    public const IN_PROGRESS_ORDER_TTL = 3600;
 
     /**
      * Allowable search params
      */
-    const P_ORDER_ID          = 'orderId';
-    const P_PROFILE_ID        = 'profileId';
-    const P_PROFILE           = 'profile';
-    const P_EMAIL             = 'email';
-    const P_PAYMENT_STATUS    = 'paymentStatus';
-    const P_SHIPPING_STATUS   = 'shippingStatus';
-    const P_DATE              = 'date';
-    const P_CURRENCY          = 'currency';
+    public const P_ORDER_ID          = 'orderId';
+    public const P_PROFILE_ID        = 'profileId';
+    public const P_PROFILE           = 'profile';
+    public const P_EMAIL             = 'email';
+    public const P_PAYMENT_STATUS    = 'paymentStatus';
+    public const P_SHIPPING_STATUS   = 'shippingStatus';
+    public const P_DATE              = 'date';
+    public const P_CURRENCY          = 'currency';
 
-    const P_ORDER_NUMBER      = 'orderNumber';
-    const P_SHIPPING_METHOD_NAME = 'shippingMethodName';
-    const P_PAYMENT_METHOD_NAME  = 'paymentMethodName';
-    const P_RECENT            = 'recent';
-    const SEARCH_DATE_RANGE   = 'dateRange';
-    const SEARCH_SUBSTRING    = 'substring';
-    const SEARCH_ACCESS_LEVEL = 'accessLevel';
-    const SEARCH_ZIPCODE      = 'zipcode';
-    const SEARCH_CUSTOMER_NAME = 'customerName';
-    const SEARCH_TRANS_ID     = 'transactionID';
-    const SEARCH_SKU          = 'sku';
+    public const P_ORDER_NUMBER      = 'orderNumber';
+    public const P_SHIPPING_METHOD_NAME = 'shippingMethodName';
+    public const P_PAYMENT_METHOD_NAME  = 'paymentMethodName';
+    public const P_RECENT            = 'recent';
+    public const SEARCH_DATE_RANGE   = 'dateRange';
+    public const SEARCH_SUBSTRING    = 'substring';
+    public const SEARCH_ACCESS_LEVEL = 'accessLevel';
+    public const SEARCH_ZIPCODE      = 'zipcode';
+    public const SEARCH_CUSTOMER_NAME = 'customerName';
+    public const SEARCH_TRANS_ID     = 'transactionID';
+    public const SEARCH_SKU          = 'sku';
+    public const SEARCH_COUNTRY      = 'country';
+    public const SEARCH_STATE        = 'state';
+    public const SEARCH_CUSTOM_STATE = 'customState';
+    public const SEARCH_CITY         = 'city';
+    public const SEARCH_TYPE_ADDRESS = 'address';
 
-    const NEXT_PREVIOUS_CRITERIA_ORDER_NUMBER = 'orderNumber';
-    const NEXT_PREVIOUS_CRITERIA_DATE         = 'date';
+    public const NEXT_PREVIOUS_CRITERIA_ORDER_NUMBER = 'orderNumber';
+    public const NEXT_PREVIOUS_CRITERIA_DATE         = 'date';
 
     /**
      * Alternative record identifiers
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('orderNumber'),
-    );
+    protected $alternativeIdentifier = [
+        ['orderNumber'],
+    ];
 
     /**
      * Get condition to search recent orders
@@ -126,7 +127,26 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     public function getOrderStats($startDate, $endDate = 0)
     {
-        $result = $this->defineGetOrderStatsQuery($startDate, $endDate)->getSingleResult();
+        $result = $this->defineGetOrderStatsQuery($startDate, $endDate)->getQuery()->getSingleResult();
+
+        return $result;
+    }
+
+    /**
+     * @param     $startDate
+     * @param int $endDate
+     * @param int $groupPeriod
+     *
+     * @return array
+     */
+    public function getGroupedOrderStats($startDate, $endDate = 0, $groupPeriod = 86400)
+    {
+        $result = $this->defineGetOrderStatsQuery($startDate, $endDate)
+            ->addSelect('(:start + (FLOOR((o.date - :start) / :group_period) * :group_period)) as group_timestamp')
+            ->groupBy('group_timestamp')
+            ->setParameter('group_period', $groupPeriod)
+            ->orderBy('group_timestamp')
+            ->getResult();
 
         return $result;
     }
@@ -197,9 +217,7 @@ class Order extends \XLite\Model\Repo\ARepo
         if ($result) {
             $count = 0;
 
-            foreach ($result as $item) {
-                $order = $item[0];
-
+            foreach ($result as $order) {
                 \XLite\Core\Database::getEM()->remove($order);
                 $count++;
 
@@ -212,11 +230,9 @@ class Order extends \XLite\Model\Repo\ARepo
                 \XLite\Core\Database::getEM()->flush();
 
                 // Log operation only in debug mode
-                \XLite\Logger::getInstance()->log(
-                    \XLite\Core\Translation::getInstance()->translate(
-                        'X expired shopping cart(s) have been successfully removed',
-                        array('count' => $count)
-                    )
+                $this->getLogger()->debug(
+                    'Some expired shopping cart(s) have been successfully removed',
+                    ['count' => $count]
                 );
             }
         }
@@ -236,7 +252,6 @@ class Order extends \XLite\Model\Repo\ARepo
             && is_numeric($cnd->{static::P_PROFILE_ID})
         ) {
             unset($cnd->{static::SEARCH_CUSTOMER_NAME});
-
         } else {
             unset($cnd->{static::P_PROFILE_ID});
         }
@@ -355,7 +370,7 @@ class Order extends \XLite\Model\Repo\ARepo
             ->addGroupBy('o.order_id');
 
         foreach ($cnd as $key => $value) {
-            if (static::P_LIMIT !== $key && static::P_ORDER_BY !== $key) {
+            if ($key !== static::P_LIMIT && $key !== static::P_ORDER_BY) {
                 $this->callSearchConditionHandler($value, $key);
             }
         }
@@ -373,11 +388,11 @@ class Order extends \XLite\Model\Repo\ARepo
     public function initializeNextOrderNumber()
     {
         \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-            array(
+            [
                 'category'  => 'General',
                 'name'      => 'order_number_counter',
                 'value'     => $this->getMaxOrderNumber() + 1,
-            )
+            ]
         );
     }
 
@@ -388,9 +403,7 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     public function getMaxOrderNumber()
     {
-        $result = $this->defineMaxOrderNumberQuery()->getSingleResult();
-
-        return empty($result) ? 0 : array_pop($result);
+        return (int) $this->defineMaxOrderNumberQuery()->getSingleScalarResult();
     }
 
     /**
@@ -463,7 +476,7 @@ class Order extends \XLite\Model\Repo\ARepo
 
     protected function getNextPreviousOrderCriteria()
     {
-        $criteria = \XLite\Core\ConfigParser::getOptions(['other', 'next_previous_order_criteria']);
+        $criteria = \Includes\Utils\ConfigParser::getOptions(['other', 'next_previous_order_criteria']);
 
         return in_array($criteria, [
             static::NEXT_PREVIOUS_CRITERIA_ORDER_NUMBER,
@@ -478,8 +491,8 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     public function searchNextOrder()
     {
-        $qb = $this->searchState['queryBuilder'];
-        $order = $this->searchState['currentSearchCnd']->np_order;
+        $qb    = $this->searchState['queryBuilder'];
+        $order = $this->searchState['currentSearchCnd']->order;
         return $order
             ? $this->defineFindNextOrder($qb, $order)->getSingleResult()
             : null;
@@ -501,19 +514,19 @@ class Order extends \XLite\Model\Repo\ARepo
                 $qb->expr()->not(
                     $qb->expr()->andX(
                         $qb->expr()->eq('o.date', ':date'),
-                        $qb->expr()->lt('INTVAL(o.orderNumber)', $qb->expr()->literal(
-                            (integer)$order->getOrderNumber()
+                        $qb->expr()->lt('CAST(o.orderNumber AS UNSIGNED)', $qb->expr()->literal(
+                            (int)$order->getOrderNumber()
                         ))
                     )
                 )
             ))
-                ->setParameter('date', (integer)$order->getDate())
+                ->setParameter('date', (int)$order->getDate())
                 ->orderBy('o.date', 'ASC')
-                ->addOrderBy('INTVAL(o.orderNumber)', 'ASC');
+                ->addOrderBy('CAST(o.orderNumber AS UNSIGNED)', 'ASC');
         } else {
-            $qb->andWhere('INTVAL(o.orderNumber) > :orderNumber')
-                ->setParameter('orderNumber', (integer)$order->getOrderNumber())
-                ->orderBy('INTVAL(o.orderNumber)', 'ASC');
+            $qb->andWhere('CAST(o.orderNumber AS UNSIGNED) > :orderNumber')
+                ->setParameter('orderNumber', (int)$order->getOrderNumber())
+                ->orderBy('CAST(o.orderNumber AS UNSIGNED)', 'ASC');
         }
 
         return $qb;
@@ -524,8 +537,8 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     public function searchPrevOrder()
     {
-        $qb = $this->searchState['queryBuilder'];
-        $order = $this->searchState['currentSearchCnd']->np_order;
+        $qb    = $this->searchState['queryBuilder'];
+        $order = $this->searchState['currentSearchCnd']->order;
         return $order
             ? $this->defineFindPreviousOrder($qb, $order)->getSingleResult()
             : null;
@@ -547,19 +560,19 @@ class Order extends \XLite\Model\Repo\ARepo
                 $qb->expr()->not(
                     $qb->expr()->andX(
                         $qb->expr()->eq('o.date', ':date'),
-                        $qb->expr()->gt('INTVAL(o.orderNumber)', $qb->expr()->literal(
-                            (integer)$order->getOrderNumber()
+                        $qb->expr()->gt('CAST(o.orderNumber AS UNSIGNED)', $qb->expr()->literal(
+                            (int)$order->getOrderNumber()
                         ))
                     )
                 )
             ))
-                ->setParameter('date', (integer)$order->getDate())
+                ->setParameter('date', (int)$order->getDate())
                 ->orderBy('o.date', 'DESC')
-                ->addOrderBy('INTVAL(o.orderNumber)', 'DESC');
+                ->addOrderBy('CAST(o.orderNumber AS UNSIGNED)', 'DESC');
         } else {
-            $qb->andWhere('INTVAL(o.orderNumber) < :orderNumber')
-                ->setParameter('orderNumber', (integer)$order->getOrderNumber())
-                ->orderBy('INTVAL(o.orderNumber)', 'DESC');
+            $qb->andWhere('CAST(o.orderNumber AS UNSIGNED) < :orderNumber')
+                ->setParameter('orderNumber', (int)$order->getOrderNumber())
+                ->orderBy('CAST(o.orderNumber AS UNSIGNED)', 'DESC');
         }
 
         return $qb;
@@ -581,8 +594,8 @@ class Order extends \XLite\Model\Repo\ARepo
             ->andWhere('o.currency = :currency')
             ->setParameter('currency', \XLite::getInstance()->getCurrency());
 
-        $this->prepareCndDate($qb, array($startDate, $endDate));
-        $this->prepareCndPaymentStatus($qb, \XLite\Model\Order\Status\Payment::getOpenStatuses());
+        $this->prepareCndDate($qb, [$startDate, $endDate]);
+        $this->prepareCndPaymentStatus($qb, \XLite\Model\Order\Status\Payment::getPaidStatuses());
 
         return $qb;
     }
@@ -597,7 +610,7 @@ class Order extends \XLite\Model\Repo\ARepo
         $qb = $this->createQueryBuilder()
             ->select('MIN(o.date) as order_date');
 
-        $this->prepareCndPaymentStatus($qb, \XLite\Model\Order\Status\Payment::getOpenStatuses());
+        $this->prepareCndPaymentStatus($qb, \XLite\Model\Order\Status\Payment::getPaidStatuses());
 
         return $qb;
     }
@@ -620,7 +633,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve order by its number", type="integer")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -637,7 +649,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve order by user access level", type="string", enum={"anonymous", "registered"})
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -664,7 +675,7 @@ class Order extends \XLite\Model\Repo\ARepo
                     break;
             }
 
-            if ('' !== $anonymous) {
+            if ($anonymous !== '') {
                 $cnd = new \Doctrine\ORM\Query\Expr\Orx();
 
                 $anonymousCnd = new \Doctrine\ORM\Query\Expr\Andx();
@@ -681,13 +692,11 @@ class Order extends \XLite\Model\Repo\ARepo
                 $queryBuilder->andWhere($cnd)
                     ->setParameter('accessLevel', $anonymous);
             }
-
         }
     }
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters order by date (timestamp) arranged in two-value array [start, end]", type="array", collectionFormat="multi", @Swg\Items(type="integer"))
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -696,8 +705,8 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndDateRange(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        if ($value && is_array($value)) {
-            list($start, $end) = $value;
+        if (!empty($value)) {
+            [$start, $end] = is_array($value) ? $value : \XLite\View\FormField\Input\Text\DateRange::convertToArray($value);
 
             if ($start) {
                 $queryBuilder->andWhere('o.date >= :start')
@@ -713,7 +722,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve order by user login or order number substring", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -722,7 +730,7 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndSubstring(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        $value = trim($value);
+        $value = trim((string) $value);
 
         if (!empty($value)) {
             $queryBuilder->linkInner('o.profile', 'p');
@@ -743,19 +751,19 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function defineSubstringOrCnd(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        $orCnd = $queryBuilder->expr()->orX();;
+        $orCnd = $queryBuilder->expr()->orX();
+        ;
         $orCnd->add('p.login LIKE :substringLike');
 
         $queryBuilder->setParameter('substringLike', '%' . $value . '%');
 
         if (preg_match('/^\d+\s*?\-\s*?\d+$/S', $value)) {
-            list($min, $max) = explode('-', $value);
+            [$min, $max] = explode('-', $value);
 
             $orCnd->add('o.orderNumber BETWEEN :orderNumMin and :orderNumMax');
 
             $queryBuilder->setParameter('orderNumMin', (int) trim($min));
             $queryBuilder->setParameter('orderNumMax', (int) trim($max));
-
         } elseif (preg_match('/^\d+$/S', $value)) {
             $orCnd->add('o.orderNumber = :substring');
             $queryBuilder->setParameter('substring', (int) $value);
@@ -766,7 +774,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve order by product sku", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -775,20 +782,17 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndSku(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        $value = trim($value);
+        $value = trim((string) $value);
 
         if (!empty($value)) {
-
             $multiple = array_filter(array_map('trim', explode(',', $value)), 'strlen');
 
             if (0 < count($multiple)) {
-
                 $queryBuilder->linkLeft('o.items', 'oi');
 
                 if (1 < count($multiple)) {
                     // Detectd several values separated with comma: search for exact match
                     $queryBuilder->andWhere($queryBuilder->expr()->in('oi.sku', $multiple));
-
                 } else {
                     // Detected single SKU value
                     $queryBuilder->andWhere('oi.sku LIKE :sku')
@@ -800,7 +804,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve only recent (unprocessed) orders", type="boolean")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -849,7 +852,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve orders by profile id", type="integer")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -867,7 +869,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Retrieve orders by user login", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
@@ -887,9 +888,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(
-     *     description="Retrieve orders in certain payment status",
-     *     type="string", enum={"A", "PP", "P", "D", "C", "Q", "R"})
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
@@ -903,9 +901,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(
-     *     description="Retrieve orders in certain shipping status",
-     *     type="string", enum={"N", "P", "S", "D", "WND", "R", "WFA"})
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
@@ -932,9 +927,10 @@ class Order extends \XLite\Model\Repo\ARepo
             $alias = $status . 'Alias';
 
             if (is_array($value)) {
-                if (1 !== count($value)
+                if (
+                    count($value) !== 1
                     || !isset($value[0])
-                    || '' !== $value[0]
+                    || $value[0] !== ''
                 ) {
                     $field = 'id';
                     foreach ($value as $val) {
@@ -946,12 +942,11 @@ class Order extends \XLite\Model\Repo\ARepo
                     $queryBuilder->innerJoin('o.' . $status, $alias)
                         ->andWhere($queryBuilder->expr()->in($alias . '.' . $field, $value));
                 }
-
             } elseif (is_object($value)) {
                 $queryBuilder->andWhere('o.' . $status . ' = :' . $status)
                     ->setParameter($status, $value);
-
-            } elseif (is_int($value)
+            } elseif (
+                is_int($value)
                 || (is_string($value)
                     && preg_match('/^[\d]+$/', $value)
                 )
@@ -959,7 +954,6 @@ class Order extends \XLite\Model\Repo\ARepo
                 $queryBuilder->innerJoin('o.' . $status, $alias)
                     ->andWhere($alias . '.id = :' . $status)
                     ->setParameter($status, $value);
-
             } elseif (is_string($value)) {
                 $queryBuilder->innerJoin('o.' . $status, $alias)
                     ->andWhere($alias . '.code = :' . $status)
@@ -997,7 +991,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters order by currency id", type="integer")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data OPTIONAL
@@ -1029,17 +1022,20 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function defineAllExpiredTemporaryOrdersQuery()
     {
-        return $this->createQueryBuilder(null, null, false)
+        return $this->createPureQueryBuilder(null, false)
+            ->distinct()
             ->leftJoin('o.orig_profile', 'op')
+            ->leftJoin('o.payment_transactions', 'pt')
             ->andWhere('o INSTANCE OF XLite\Model\Cart')
             ->andWhere('op.profile_id IS NULL')
+            ->andWhere('pt.status <> :inProgress')
             ->andWhere('o.date < :time')
+            ->setParameter('inProgress', \XLite\Model\Payment\Transaction::STATUS_INPROGRESS)
             ->setParameter('time', \XLite\Core\Converter::time() - $this->getOrderTTL());
     }
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters order by payment transaction public_id", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -1057,7 +1053,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters orders by user zipcode", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -1081,7 +1076,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters orders by customer name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param integer                    $value        Condition data
@@ -1102,7 +1096,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Generate fullname by firstname and lastname values
-     * @Api\Condition(description="Filters orders by customer firstname-lastname pair", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      *
@@ -1136,7 +1129,7 @@ class Order extends \XLite\Model\Repo\ARepo
         $addressFieldName = 'address_field_value_' . $fieldName;
 
         $addressField = \XLite\Core\Database::getRepo('XLite\Model\AddressField')
-            ->findOneBy(array('serviceName' => $fieldName));
+            ->findOneBy(['serviceName' => $fieldName]);
 
         $queryBuilder->linkLeft(
             'addresses.addressFields',
@@ -1156,18 +1149,17 @@ class Order extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndOrderBy(\Doctrine\ORM\QueryBuilder $queryBuilder, array $value)
     {
-        list($sort, $order) = $this->getSortOrderValue($value);
+        [$sort, $order] = $this->getSortOrderValue($value);
         if (!is_array($sort)) {
-            $sort = array($sort);
-            $order = array($order);
+            $sort = [$sort];
+            $order = [$order];
         }
-        $queryBuilder->addSelect('INTVAL(o.orderNumber) AS HIDDEN int_order_number');
+        $queryBuilder->addSelect('CAST(o.orderNumber AS UNSIGNED) AS HIDDEN int_order_number');
 
         foreach ($sort as $key => $sortItem) {
-            if (\XLite\View\ItemsList\Model\Order\Admin\Search::SORT_BY_MODE_ID === $sortItem) {
+            if ($sortItem === \XLite\View\ItemsList\Model\Order\Admin\Search::SORT_BY_MODE_ID) {
                 $sortItem = 'int_order_number';
-
-            } elseif (\XLite\View\ItemsList\Model\Order\Admin\Search::SORT_BY_MODE_CUSTOMER === $sortItem) {
+            } elseif ($sortItem === \XLite\View\ItemsList\Model\Order\Admin\Search::SORT_BY_MODE_CUSTOMER) {
                 $this->prepareCndOrderByFullname($queryBuilder);
                 $queryBuilder->addOrderBy('fullname', $order[$key]);
             }
@@ -1178,7 +1170,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters orders by shipping method name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
@@ -1195,7 +1186,6 @@ class Order extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters orders by payment method name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
@@ -1210,6 +1200,87 @@ class Order extends \XLite\Model\Repo\ARepo
         }
     }
 
+    /**
+     * @param QueryBuilder $queryBuilder
+     * @param              $serviceName
+     * @param              $value
+     *
+     * @return void
+     */
+    protected function prepareCndByAddressField(\Doctrine\ORM\QueryBuilder $queryBuilder, $serviceName, $value)
+    {
+        if ($value) {
+            $queryBuilder->linkInner('o.profile', 'p');
+            $addressType = $this->searchState['currentSearchCnd']->address;
+
+            if ($addressType === \XLite\Model\Address::SHIPPING) {
+                $queryBuilder->linkLeft('p.addresses', 'addresses', 'WITH', 'addresses.is_shipping=1');
+            } elseif ($addressType === \XLite\Model\Address::BILLING) {
+                $queryBuilder->linkLeft('p.addresses', 'addresses', 'WITH', 'addresses.is_billing=1');
+            } else {
+                $queryBuilder->linkLeft('p.addresses', 'addresses');
+            }
+
+            $this->prepareOrderByAddressField($queryBuilder, $serviceName);
+
+            $queryBuilder->andWhere('address_field_value_' . $serviceName . '.value LIKE :' . $serviceName . 'Value')
+                ->setParameter($serviceName . 'Value', '%' . $value . '%');
+        }
+    }
+
+    /**
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
+     * @param mixed                      $value        Searchable value
+     *
+     * @return void
+     */
+    protected function prepareCndCountry(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if ($value) {
+            $this->prepareCndByAddressField($queryBuilder, 'country_code', $value);
+        }
+    }
+
+    /**
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
+     * @param mixed                      $value        Searchable value
+     *
+     * @return void
+     */
+    protected function prepareCndState(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if (!empty($this->searchState['currentSearchCnd']->{static::SEARCH_COUNTRY}) && $value) {
+            $this->prepareCndByAddressField($queryBuilder, 'state_id', $value);
+        }
+    }
+
+
+    /**
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
+     * @param mixed                      $value        Searchable value
+     *
+     * @return void
+     */
+    protected function prepareCndCustomState(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if (!empty($this->searchState['currentSearchCnd']->{static::SEARCH_COUNTRY}) && $value) {
+            $this->prepareCndByAddressField($queryBuilder, 'custom_state', $value);
+        }
+    }
+
+    /**
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
+     * @param mixed                      $value        Searchable value
+     *
+     * @return void
+     */
+    protected function prepareCndCity(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if (!empty($this->searchState['currentSearchCnd']->{static::SEARCH_COUNTRY}) && $value) {
+            $this->prepareCndByAddressField($queryBuilder, 'city', $value);
+        }
+    }
+
     // {{{ Export routines
 
     /**
@@ -1240,7 +1311,7 @@ class Order extends \XLite\Model\Repo\ARepo
     {
         $stmt = $this->defineMarkAsCartQuery($orderId);
 
-        return $stmt && $stmt->execute() && 0 < $stmt->rowCount();
+        return $stmt && $stmt->executeQuery()->rowCount() > 0;
     }
 
     /**
@@ -1261,7 +1332,6 @@ class Order extends \XLite\Model\Repo\ARepo
         if ($stmt) {
             $stmt->bindValue(':flag', 0);
             $stmt->bindValue(':id', $orderId);
-
         } else {
             $stmt = null;
         }
@@ -1363,18 +1433,19 @@ class Order extends \XLite\Model\Repo\ARepo
      *
      * @return array
      */
-    protected function assembleRegularFieldsFromRecord(array $record, array $regular = array())
+    protected function assembleRegularFieldsFromRecord(array $record, array $regular = [])
     {
         $shippingMethod = null;
 
-        if (isset($record['shipping']['processor'])
+        if (
+            isset($record['shipping']['processor'])
             && isset($record['shipping']['code'])
         ) {
             $shippingMethod = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method')->findOneBy(
-                array(
+                [
                     'processor' => $record['shipping']['processor'],
                     'code'      => $record['shipping']['code']
-                )
+                ]
             );
         }
 
@@ -1407,13 +1478,13 @@ class Order extends \XLite\Model\Repo\ARepo
         if ($this->getNextPreviousOrderCriteria() === static::NEXT_PREVIOUS_CRITERIA_DATE) {
             $qb->andWhere($e->lt('o.date', $e->literal($item->getOrder()->getDate())))
                 ->orderBy('o.date', 'DESC')
-                ->addOrderBy('INTVAL(o.orderNumber)', 'ASC');
+                ->addOrderBy('CAST(o.orderNumber AS UNSIGNED)', 'ASC');
         } else {
-            $qb->andWhere($e->lt('INTVAL(o.orderNumber)', $e->literal((integer)$item->getOrder()->getOrderNumber())))
-                ->orderBy('INTVAL(o.orderNumber)', 'DESC');
+            $qb->andWhere($e->lt('CAST(o.orderNumber AS UNSIGNED)', $e->literal((int)$item->getOrder()->getOrderNumber())))
+                ->orderBy('CAST(o.orderNumber AS UNSIGNED)', 'DESC');
         }
 
-        $qb->andWhere($e->gt('o.date', $e->literal($item->getOrder()->getDate() - (15*60))));
+        $qb->andWhere($e->gt('o.date', $e->literal($item->getOrder()->getDate() - (15 * 60))));
 
         return $qb;
     }
@@ -1431,7 +1502,6 @@ class Order extends \XLite\Model\Repo\ARepo
             return $this->defineBackorderCompetitorsByOrderQB($item)
                 ->getQuery()
                 ->getSingleResult();
-
         } catch (\Doctrine\ORM\NoResultException $noResultException) {
             return null;
         }
