@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -10,12 +9,6 @@ namespace XLite\Model\Repo\Order;
 
 /**
  * Order modifier repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Order\Modifier", summary="Add new order modifier")
- * @Api\Operation\Read(modelClass="XLite\Model\Order\Modifier", summary="Retrieve order modifier by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Order\Modifier", summary="Retrieve all order modifiers")
- * @Api\Operation\Update(modelClass="XLite\Model\Order\Modifier", summary="Update order modifier by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Order\Modifier", summary="Delete order modifier by id")
  */
 class Modifier extends \XLite\Model\Repo\ARepo
 {
@@ -31,9 +24,9 @@ class Modifier extends \XLite\Model\Repo\ARepo
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('class'),
-    );
+    protected $alternativeIdentifier = [
+        ['class'],
+    ];
 
     /**
      * Find all active modifiers
@@ -48,7 +41,7 @@ class Modifier extends \XLite\Model\Repo\ARepo
 
         if ($list) {
             foreach ($list as $i => $item) {
-                if (!\XLite\Core\Operator::isClassExists($item->getClass())) {
+                if (!class_exists($item->getClass())) {
                     unset($list[$i]);
                 }
             }
