@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,40 +8,40 @@
 namespace XLite\Model\Repo\Payment;
 
 use Includes\Utils\Module\Manager;
-use Includes\Utils\Module\Module;
+use XCart\Doctrine\FixtureLoader;
+use XLite\Core\Database;
+use XLite\Model\Payment\MethodTranslation;
 use XLite\Model\QueryBuilder\AQueryBuilder;
+use XLite\Model\Repo\ModelRepoTranslationTrait;
 
 /**
  * Payment method repository
- *
- * @Api\Operation\Read(modelClass="XLite\Model\Payment\Method", summary="Retrieve payment method by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Payment\Method", summary="Retrieve payment methods by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Payment\Method", summary="Update payment method by id")
  */
 class Method extends \XLite\Model\Repo\Base\I18n
 {
+    use ModelRepoTranslationTrait;
+
     /**
      * Names of fields that are used in search
      */
-    const P_ENABLED             = 'enabled';
-    const P_MODULE_ENABLED      = 'moduleEnabled';
-    const P_ADDED               = 'added';
-    const P_ONLY_PURE_OFFLINE   = 'onlyPureOffline';
-    const P_ONLY_MODULE_OFFLINE = 'onlyModuleOffline';
-    const P_POSITION            = 'position';
-    const P_TYPE                = 'type';
+    public const P_ENABLED             = 'enabled';
+    public const P_MODULE_ENABLED      = 'moduleEnabled';
+    public const P_ADDED               = 'added';
+    public const P_POSITION            = 'position';
+    public const P_TYPE                = 'type';
+    public const P_PREDEFINED          = 'predefined';
 
-     // Use the Force, Luke
-    const P_ORDER_BY_FORCE       = 'orderByForce';
+    // Use the Force, Luke
+    public const P_ORDER_BY_FORCE = 'orderByForce';
 
-    const P_NAME                = 'name';
-    const P_COUNTRY             = 'country';
-    const P_EX_COUNTRY          = 'exCountry';
+    public const P_NAME       = 'name';
+    public const P_COUNTRY    = 'country';
+    public const P_EX_COUNTRY = 'exCountry';
 
     /**
      * Name of the field which is used for default sorting (ordering)
      */
-    const FIELD_DEFAULT_POSITION = 'orderby';
+    public const FIELD_DEFAULT_POSITION = 'orderby';
 
     /**
      * Repository type
@@ -63,17 +62,25 @@ class Method extends \XLite\Model\Repo\Base\I18n
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('service_name'),
-    );
+    protected $alternativeIdentifier = [
+        ['service_name'],
+    ];
+
+    /**
+     * @return FixtureLoader
+     */
+    protected function getFixtureLoader()
+    {
+        return \XCart\Container::getContainer()->get(FixtureLoader::class);
+    }
 
     /**
      * Add the specific joints with the translation table
      *
      * @param AQueryBuilder $queryBuilder
-     * @param string                     $alias
-     * @param string                     $translationsAlias
-     * @param string                     $code
+     * @param string        $alias
+     * @param string        $translationsAlias
+     * @param string        $code
      *
      * @return AQueryBuilder
      */
@@ -101,7 +108,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      *
      * @return void
      */
-    public function update(\XLite\Model\AEntity $entity, array $data = array(), $flush = self::FLUSH_BY_DEFAULT)
+    public function update(\XLite\Model\AEntity $entity, array $data = [], $flush = self::FLUSH_BY_DEFAULT)
     {
         $name = null;
         foreach ($entity->getTranslations() as $translation) {
@@ -124,7 +131,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition for module name
-     * @Api\Condition(description="Retrieve payment method by its name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -134,7 +140,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     protected function prepareCndName(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
     {
-        if ('' !== $value) {
+        if ($value !== '') {
             $queryBuilder
                 ->andWhere('translations.name LIKE :name')
                 ->setParameter('name', "%" . $value . "%");
@@ -143,7 +149,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition for module name
-     * @Api\Condition(description="Retrieve payment method by country", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -161,15 +166,14 @@ class Method extends \XLite\Model\Repo\Base\I18n
         $queryBuilder->addSelect('(CASE WHEN countryPosition.adminPosition IS NULL THEN 1 ELSE 0 END) AS HIDDEN adminPosition');
 
         if (!empty($value)) {
-
             $queryBuilder->andWhere(
-                    $queryBuilder->expr()->orX(
-                        $alias . '.countries LIKE :country',
-                        $alias . '.countries = :emptyArray',
-                        $alias . '.countries = :undefinedValue',
-                        $alias . '.countries = :emptyValue'
-                    )
+                $queryBuilder->expr()->orX(
+                    $alias . '.countries LIKE :country',
+                    $alias . '.countries = :emptyArray',
+                    $alias . '.countries = :undefinedValue',
+                    $alias . '.countries = :emptyValue'
                 )
+            )
                 ->setParameter('country', '%"' . $value . '"%')
                 ->setParameter('emptyArray', 'a:0:{}')
                 ->setParameter('undefinedValue', 'N;')
@@ -179,7 +183,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition for module name
-     * @Api\Condition(description="Retrieve payment method by excluded country name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -193,17 +196,16 @@ class Method extends \XLite\Model\Repo\Base\I18n
             $alias = $this->getMainAlias($queryBuilder);
 
             $queryBuilder->andWhere(
-                    $queryBuilder->expr()->not(
-                        $alias . '.exCountries LIKE :country'
-                    )
+                $queryBuilder->expr()->not(
+                    $alias . '.exCountries LIKE :country'
                 )
+            )
                 ->setParameter('country', '%"' . $value . '"%');
         }
     }
 
     /**
      * Prepare certain search condition for enabled flag
-     * @Api\Condition(description="Retrieve payment method by its enabled state", type="boolean")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -220,7 +222,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition for moduleEnabled flag
-     * @Api\Condition(description="Retrieve payment method by module enabled state", type="boolean")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -231,11 +232,15 @@ class Method extends \XLite\Model\Repo\Base\I18n
     protected function prepareCndModuleEnabled(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
     {
         $enabledModules = array_map(
-            function ($module) {
-                /** @var Module $module */
-                return $module->author . '_' . $module->name;
+            static function ($moduleId) {
+                [$author, $name] = explode('-', $moduleId);
+
+                return "{$author}_{$name}";
             },
-            Manager::getRegistry()->getEnabledPaymentModules()
+            array_merge(
+                Manager::getRegistry()->getEnabledPaymentModuleIds(),
+                Manager::getRegistry()->getEnabledShippingModuleIds()
+            )
         );
 
         $enabledModules[] = '';
@@ -246,7 +251,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition for added flag
-     * @Api\Condition(description="Retrieve payment method by its added\not added state", type="boolean")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -256,7 +260,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     protected function prepareCndAdded(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
     {
-        if (isset($value)) {
+        if ($value !== null) {
             $queryBuilder
                 ->andWhere($this->getMainAlias($queryBuilder) . '.added = :added_value')
                 ->setParameter('added_value', $value);
@@ -264,8 +268,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
     }
 
     /**
-     * Prepare certain search condition for onlyModuleOffline flag
-     * @Api\Condition(description="Get only offline methods", type="boolean")
+     * Prepare certain search condition for predefined flag
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param boolean                    $value        Condition data
@@ -273,35 +276,12 @@ class Method extends \XLite\Model\Repo\Base\I18n
      *
      * @return void
      */
-    protected function prepareCndOnlyPureOffline(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
+    protected function prepareCndPredefined(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
     {
-        if ($value) {
-            $alias = $this->getMainAlias($queryBuilder);
+        if ($value !== null) {
             $queryBuilder
-                ->andWhere($alias . '.class = :class AND ' . $alias . '.type = :offlineType')
-                ->setParameter('class', 'Model\Payment\Processor\Offline')
-                ->setParameter('offlineType', \XLite\Model\Payment\Method::TYPE_OFFLINE);
-        }
-    }
-
-    /**
-     * Prepare certain search condition for onlyModuleOffline flag
-     * @Api\Condition(description="Get only offline methods (added by module)", type="boolean")
-     *
-     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
-     * @param boolean                    $value        Condition data
-     * @param boolean                    $countOnly    "Count only" flag
-     *
-     * @return void
-     */
-    protected function prepareCndOnlyModuleOffline(\Doctrine\ORM\QueryBuilder $queryBuilder, $value, $countOnly)
-    {
-        if ($value) {
-            $alias = $this->getMainAlias($queryBuilder);
-            $queryBuilder
-                ->andWhere($alias . '.class != :class AND ' . $alias . '.type = :offlineType')
-                ->setParameter('class', 'Model\Payment\Processor\Offline')
-                ->setParameter('offlineType', \XLite\Model\Payment\Method::TYPE_OFFLINE);
+                ->andWhere($this->getMainAlias($queryBuilder) . '.predefined = :predefined')
+                ->setParameter('predefined', $value);
         }
     }
 
@@ -317,15 +297,13 @@ class Method extends \XLite\Model\Repo\Base\I18n
     protected function prepareCndPosition(\Doctrine\ORM\QueryBuilder $queryBuilder, array $value, $countOnly)
     {
         if (!$countOnly) {
-            list($sort, $order) = $value;
+            [$sort, $order] = $value;
 
             $queryBuilder->addOrderBy($this->getMainAlias($queryBuilder) . '.' . $sort, $order);
         }
     }
 
     /**
-     * @Api\Condition(description="Filter methods by type", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
      * @param boolean                    $countOnly    "Count only" flag
@@ -338,7 +316,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
             $alias = $this->getMainAlias($queryBuilder);
             if (is_array($value)) {
                 $queryBuilder->addInCondition($alias . '.type', $value);
-
             } else {
                 $queryBuilder->andWhere($alias . '.type = :type')
                     ->setParameter('type', $value);
@@ -358,7 +335,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
     protected function prepareCndOrderByForce(\Doctrine\ORM\QueryBuilder $queryBuilder, array $value, $countOnly)
     {
         if (!$countOnly) {
-            list($sort, $order) = $this->getSortOrderValue($value);
+            [$sort, $order] = $this->getSortOrderValue($value);
 
             $queryBuilder->orderBy($sort, $order);
             $this->assignDefaultOrderBy($queryBuilder);
@@ -396,8 +373,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     public function hasActivePaymentModules()
     {
-        return (bool) \count(Manager::getRegistry()->getEnabledPaymentModules());
-        // return 0 < $this->defineHasActivePaymentModulesQuery()->getSingleScalarResult();
+        return (bool) \count(Manager::getRegistry()->getEnabledPaymentModuleIds());
     }
 
     /**
@@ -407,10 +383,10 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     public function findOffline()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->defineFindOfflineQuery()->getResult() as $method) {
-            if (!preg_match('/\\\Module\\\/Ss', $method->getClass())) {
+            if (strpos('XLite', $method->getClass()) === 0) {
                 $list[] = $method;
             }
         }
@@ -425,7 +401,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     public function findOfflineModules()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->defineFindOfflineQuery()->getResult() as $method) {
             if (preg_match('/\\\Module\\\/Ss', $method->getClass())) {
@@ -460,7 +436,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
         $qb = $this->createPureQueryBuilder('m');
 
         $this->prepareCndType($qb, $type, false);
-        $this->prepareCndOrderBy($qb, array('m.adminOrderby'), false);
+        $this->prepareCndOrderBy($qb, ['m.adminOrderby'], false);
 
         return $this->addOrderByForAdditionByTypeQuery($qb);
     }
@@ -500,23 +476,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
             ->setParameter('true', true);
     }
 
-    /**
-     * Define query for hasActivePaymentModules() method
-     * @todo: remove, unused
-     *
-     * @return \XLite\Model\QueryBuilder\AQueryBuilder
-     */
-    protected function defineHasActivePaymentModulesQuery()
-    {
-        //return $this->createPureQueryBuilder()
-        //    ->select('COUNT(m.method_id) cns')
-        //    ->andWhere('m.type != :offline')
-        //    ->andWhere('m.moduleEnabled = :moduleEnabled')
-        //    ->setParameter('offline', \XLite\Model\Payment\Method::TYPE_OFFLINE)
-        //    ->setParameter('moduleEnabled', true)
-        //    ->setMaxResults(1);
-    }
-
     /**
      * Define query for findOffline() method
      *
@@ -528,6 +487,40 @@ class Method extends \XLite\Model\Repo\Base\I18n
             ->setParameter('offline', \XLite\Model\Payment\Method::TYPE_OFFLINE);
     }
 
+    public function findByServiceName(string $serviceName): ?\XLite\Model\Payment\Method
+    {
+        if (\XLite::isAdminZone()) {
+            return $this->findOneBy(['service_name' => $serviceName]);
+        }
+
+        /** @var \XLite\Model\Payment\Method $method */
+        $method = $this->getFromCache('payment_method', ['service_name' => $serviceName]);
+        if (!$method) {
+            /** @var \XLite\Model\Payment\Method|null $method */
+            $method = $this->findOneBy(['service_name' => $serviceName]);
+
+            if ($method) {
+                $this->saveToCache(clone $method, 'payment_method', ['service_name' => $serviceName]);
+            }
+        } else {
+            $method = Database::getEM()->merge($method);
+        }
+
+        return $method;
+    }
+
+    protected function defineCacheCells()
+    {
+        $list = parent::defineCacheCells();
+
+        $list['all'] = [];
+        $list['payment_method'] = [
+            static::ATTRS_CACHE_CELL => ['payment_method'],
+        ];
+
+        return $list;
+    }
+
     // }}}
 
     // {{{ Update payment methods from marketplace
@@ -543,7 +536,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
     public function updatePaymentMethods($data, $countryCode = '')
     {
         if (!empty($data) && is_array($data)) {
-            $methods = [];
+            $methods                = [];
             $methodsFromMarketplace = [];
 
             // Get all payment methods list as an array
@@ -560,25 +553,28 @@ class Method extends \XLite\Model\Repo\Base\I18n
             }
 
             foreach ($data as $i => $extMethod) {
-
                 if (!empty($extMethod['service_name'])) {
+                    unset(
+                        $extMethod['enabled'],
+                        $extMethod['added'],
+                        $extMethod['iconURL']
+                    );
 
-                    $data[$i] = $extMethod;
+                    $data[$i]                 = $extMethod;
                     $methodsFromMarketplace[] = $extMethod['service_name'];
 
                     if (isset($methods[$extMethod['service_name']])) {
-
                         // Method already exists in the database
 
                         if (!$methods[$extMethod['service_name']]['fromMarketplace']) {
                             $data[$i] = [
-                                'service_name' => $extMethod['service_name'],
-                                'countries'    => !empty($extMethod['countries']) ? $extMethod['countries'] : [],
-                                'exCountries'  => !empty($extMethod['exCountries']) ? $extMethod['exCountries'] : [],
-                                'orderby'      => !empty($extMethod['orderby']) ? $extMethod['orderby'] : 0,
+                                'service_name'  => $extMethod['service_name'],
+                                'countries'     => !empty($extMethod['countries']) ? $extMethod['countries'] : [],
+                                'exCountries'   => !empty($extMethod['exCountries']) ? $extMethod['exCountries'] : [],
+                                'orderby'       => !empty($extMethod['orderby']) ? $extMethod['orderby'] : 0,
+                                'modulePageURL' => !empty($extMethod['modulePageURL']) ? $extMethod['modulePageURL'] : '',
                             ];
                         }
-
                     } else {
                         $data[$i]['fromMarketplace'] = 1;
                     }
@@ -588,22 +584,25 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
                         $data[$i]['countryPositions'] = [
                             [
-                                'countryCode' => $countryCode,
+                                'countryCode'   => $countryCode,
                                 'adminPosition' => $data[$i]['orderby'],
-                            ]
+                            ],
                         ];
 
                         unset($data[$i]['orderby']);
                     }
 
+                    if (isset($data[$i]['modulePageURL'])) {
+                        $data[$i]['modulePageURL'] = \XLite::getAppStoreUrl() . $data[$i]['modulePageURL'];
+                    }
+
+                    $data[$i]['predefined'] = (bool) ($extMethod['predefined'] ?? false);
                 } else {
                     // Wrong data row, ignore this
                     unset($data[$i]);
                 }
             }
 
-            $this->removeIrrelevantPaymentMethods($methodsFromMarketplace);
-
             // Save data as temporary yaml file
             $yaml = \Symfony\Component\Yaml\Yaml::dump(['XLite\\Model\\Payment\\Method' => $data]);
 
@@ -612,38 +611,94 @@ class Method extends \XLite\Model\Repo\Base\I18n
             \Includes\Utils\FileManager::write(LC_DIR_TMP . 'pm.yaml', $yaml);
 
             // Update database from yaml file
-            \XLite\Core\Database::getInstance()->loadFixturesFromYaml($yamlFile);
+            $this->getFixtureLoader()->loadYaml($yamlFile);
+
+            $this->removeUnavailablePaymentMethods($methodsFromMarketplace);
         }
     }
 
     /**
-     * Remove irrelevant payment methods
+     * Remove:
+     * 1. Installed payment methods whose class doesn't exist
+     * 2. Uninstalled payment methods which are no longer in the marketplace
      *
      * @param array $methodsFromMarketplace
-     *
-     * @return void
      */
-    protected function removeIrrelevantPaymentMethods($methodsFromMarketplace)
+    protected function removeUnavailablePaymentMethods($methodsFromMarketplace)
     {
-        $notInstalledPaymentsMethods = $this->getQueryBuilder()
-            ->select('m.service_name')
-            ->from($this->_entityName, 'm')
-            ->where('m.fromMarketplace = 1')
-            ->getArrayResult();
-
-        $irrelevantPaymentMethods = array_filter($notInstalledPaymentsMethods, function($method) use($methodsFromMarketplace) {
-            return !in_array($method['service_name'], $methodsFromMarketplace);
-        });
-
-        foreach ($irrelevantPaymentMethods as $methodToRemove) {
-            $this->getQueryBuilder()
-                ->delete($this->_entityName, 'm')
-                ->where('m.fromMarketplace = 1')
-                ->andWhere('m.service_name = :serviceName')
-                ->setParameter('serviceName', $methodToRemove['service_name'])
-                ->execute();
+        foreach ($this->findAllMethods() as $method) {
+            /** @var \XLite\Model\Payment\Method $method */
+            if (
+                !$method->isExisting()
+                || (
+                    $method->getFromMarketplace()
+                    && !in_array($method->getServiceName(), $methodsFromMarketplace)
+                )
+            ) {
+                $this->delete($method, false);
+            }
         }
+
+        \XLite\Core\Database::getEM()->flush();
     }
 
     // }}}
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            (!empty($entity['service_name']))
+            && ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+        ) {
+            return [
+                $entity['service_name'],
+                $result['name'] ?? '',
+                $result['title'] ?? '',
+                $result['description'] ?? '',
+                $result['adminDescription'] ?? '',
+                $result['altAdminDescription'] ?? '',
+                $result['instruction'] ?? ''
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(MethodTranslation $translation): ?array
+    {
+        /** @var \XLite\Model\Payment\Method $paymentMethod */
+        $paymentMethod = $translation->getOwner();
+
+        return [
+            $paymentMethod->getServiceName(),
+            $translation->getName(),
+            $translation->getTitle(),
+            $translation->getDescription(),
+            $translation->getAdminDescription(),
+            $translation->getAltAdminDescription(),
+            $translation->getInstruction()
+        ];
+    }
+
+    public function generateYamlEntityForTranslationModule(array $data, string $lngCode): ?array
+    {
+        if (empty($data[0])) {
+            return null;
+        }
+
+        return [
+            'service_name'  => $data[0],
+            'translations'  => [
+                array_filter([
+                    'code'                => $lngCode,
+                    'name'                => $data[1] ?? '',
+                    'title'               => $data[2] ?? '',
+                    'description'         => $data[3] ?? '',
+                    'adminDescription'    => $data[4] ?? '',
+                    'altAdminDescription' => $data[5] ?? '',
+                    'instruction'         => $data[6] ?? '',
+                ]),
+            ],
+        ];
+    }
 }
