@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,66 +7,55 @@
 
 namespace XLite\Model\Repo;
 
+use Iterator;
+use XLite\Model\ProductTranslation;
 use XLite\Model\QueryBuilder\AQueryBuilder;
 
 /**
  * The "product" model repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Product", summary="Add new product")
- * @Api\Operation\Read(modelClass="XLite\Model\Product", summary="Retrieve product by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Product", summary="Retrieve product by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Product", summary="Update product by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Product", summary="Delete product by id")
- *
- * @SWG\Tag(
- *   name="Product",
- *   description="Product is the building block of your store. It contains data about certain good you trade and is identified by SKU. Product is tightly coupled with its Category and Attributes.",
- *   @SWG\ExternalDocumentation(
- *     description="Find out more about product fields and options",
- *     url="https://kb.x-cart.com/products/adding_products.html"
- *   )
- * )
  */
 class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
 {
+    use ModelRepoTranslationTrait;
+
     /**
      * Allowable search params
      */
-    const P_SKU               = 'SKU';
-    const P_CATEGORY_ID       = 'categoryId';
-    const P_SUBSTRING         = 'substring';
-    const P_PRICE             = 'price';
-    const P_SEARCH_IN_SUBCATS = 'searchInSubcats';
-    const P_INVENTORY         = 'inventory';
+    public const P_SKU               = 'SKU';
+    public const P_CATEGORY_ID       = 'categoryId';
+    public const P_SUBSTRING         = 'substring';
+    public const P_PRICE             = 'price';
+    public const P_SEARCH_IN_SUBCATS = 'searchInSubcats';
+    public const P_INVENTORY         = 'inventory';
 
-    const P_INCLUDING          = 'including';
-    const P_PRODUCT_CLASS      = 'productClass';
-    const P_TAX_CLASS          = 'taxClass';
-    const P_EXCL_PRODUCT_ID    = 'excludingProductId';
-    const P_ENABLED            = 'enabled';
-    const P_ARRIVAL_DATE       = 'arrivalDate';
-    const P_ARRIVAL_DATE_RANGE = 'arrivalDateRange';
+    public const P_INCLUDING          = 'including';
+    public const P_PRODUCT_CLASS      = 'productClass';
+    public const P_TAX_CLASS          = 'taxClass';
+    public const P_EXCL_PRODUCT_ID    = 'excludingProductId';
+    public const P_ENABLED            = 'enabled';
+    public const P_ARRIVAL_DATE       = 'arrivalDate';
+    public const P_ARRIVAL_DATE_RANGE = 'arrivalDateRange';
 
-    const P_BY = 'by';
-    const P_BY_TITLE = 'byTitle';
-    const P_BY_DESCR = 'byDescr';
-    const P_BY_SKU   = 'bySKU';
+    public const P_BY = 'by';
+    public const P_BY_TITLE = 'byTitle';
+    public const P_BY_DESCR = 'byDescr';
+    public const P_BY_SKU   = 'bySKU';
 
-    const INCLUDING_ALL    = 'all';
-    const INCLUDING_ANY    = 'any';
-    const INCLUDING_PHRASE = 'phrase';
+    public const INCLUDING_ALL    = 'all';
+    public const INCLUDING_ANY    = 'any';
+    public const INCLUDING_PHRASE = 'phrase';
 
-    const INV_ALL = 'all'; // All
-    const INV_LOW = 'low'; // Low amount
-    const INV_OUT = 'out'; // Out of stock
-    const INV_IN  = 'in';  // In stock
+    public const INV_ALL = 'all'; // All
+    public const INV_LOW = 'low'; // Low amount
+    public const INV_OUT = 'out'; // Out of stock
+    public const INV_IN  = 'in';  // In stock
 
-    const TITLE_FIELD       = 'translations.name';
-    const BRIEF_DESCR_FIELD = 'translations.briefDescription';
-    const DESCR_FIELD       = 'translations.description';
-    const SKU_FIELD         = 'p.sku';
+    public const TITLE_FIELD       = 'translations.name';
+    public const BRIEF_DESCR_FIELD = 'translations.briefDescription';
+    public const DESCR_FIELD       = 'translations.description';
+    public const SKU_FIELD         = 'p.sku';
 
-    const SKU_GENERATION_LIMIT = 50;
+    public const SKU_GENERATION_LIMIT = 50;
 
     /**
      * Alternative record identifiers
@@ -87,9 +75,10 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     {
         $cnd = $this->searchState['currentSearchCnd'];
 
-        if (!\XLite::isAdminZone()
+        if (
+            !\XLite::isAdminZone()
             && !isset($cnd->{static::P_INVENTORY})
-            && 'everywhere' !== \XLite\Core\Config::getInstance()->General->show_out_of_stock_products
+            && \XLite\Core\Config::getInstance()->General->show_out_of_stock_products !== 'everywhere'
         ) {
             $cnd->{static::P_INVENTORY} = static::INV_IN;
         }
@@ -110,6 +99,9 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     {
         $queryBuilder = parent::createQueryBuilder($alias, $indexBy, $code);
 
+        $queryBuilder->groupBy($queryBuilder->getRootAliases()[0] . '.' . $this->getPrimaryKeyField());
+        $queryBuilder->addGroupBy('translations.name');
+
         $alias = $alias ?: $queryBuilder->getRootAlias();
         $this->addEnabledCondition($queryBuilder, $alias);
         $this->addDateCondition($queryBuilder, $alias);
@@ -203,15 +195,9 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
 
         if ($product) {
             foreach ($this->_class->fieldNames as $name) {
-                $mname = 'get' . \XLite\Core\Converter::convertToCamelCase($name);
-                // $maname assebmled from 'get' + \XLite\Core\Converter::convertToCamelCase() method
-                if (
-                    method_exists($product, $mname)
-                    || (
-                        $product instanceof \XLite\Core\MagicMethodsIntrospectionInterface
-                        && $product->hasMagicMethod($mname)
-                    )
-                ) {
+                $mname = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
+
+                if (method_exists($product, $mname)) {
                     $data[$name] = $product->$mname();
                 }
             }
@@ -244,8 +230,9 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     public function assignExternalEnabledCondition(\XLite\Model\QueryBuilder\AQueryBuilder $qb, $alias = 'p')
     {
 
-        if (!\XLite::isAdminZone()
-            && 'everywhere' !== \XLite\Core\Config::getInstance()->General->show_out_of_stock_products
+        if (
+            !\XLite::isAdminZone()
+            && \XLite\Core\Config::getInstance()->General->show_out_of_stock_products !== 'everywhere'
         ) {
             $this->prepareCndInventory($qb, static::INV_IN);
         }
@@ -275,7 +262,8 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
 
         $qb = $this->defineGenerateSKUQuery();
 
-        while ($i < static::SKU_GENERATION_LIMIT
+        while (
+            $i < static::SKU_GENERATION_LIMIT
             && 0 < (int)$qb->setParameter('sku', $sku)->getSingleScalarResult()
         ) {
             $i++;
@@ -302,7 +290,8 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
         $qb = $this->defineGenerateSKUQuery();
         $base = $sku;
 
-        while ($i < static::SKU_GENERATION_LIMIT
+        while (
+            $i < static::SKU_GENERATION_LIMIT
             && 0 < (int)$qb->setParameter('sku', $sku)->getSingleScalarResult()
         ) {
             $i++;
@@ -337,11 +326,11 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Returns the "low inventory products" amount
      *
-     * @return integer
+     * @return int
      */
     public function getLowInventoryProductsAmount()
     {
-        return \XLite\Core\Database::getRepo('XLite\Model\Product')
+        return (int) \XLite\Core\Database::getRepo('XLite\Model\Product')
             ->search($this->defineLowInventoryProductsAmountCnd(), true);
     }
 
@@ -397,7 +386,7 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
         // Compatibility to old search processor
         if (empty($conditionBySelected)) {
             foreach ($conditionsBy as $conditionBy) {
-                if ('Y' === $this->searchState['currentSearchCnd']->{$conditionBy}) {
+                if ($this->searchState['currentSearchCnd']->{$conditionBy} === 'Y') {
                     $conditionBySelected[$conditionBy] = $conditionBy;
                 }
             }
@@ -508,8 +497,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by sku", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -527,8 +514,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by enabled\disabled state", type="boolean")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -543,8 +528,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by category id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -561,11 +544,9 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
 
         if ($value === 'no_category') {
             $queryBuilder->andWhere('p.categoryProducts is empty');
-
         } elseif (empty($this->searchState['currentSearchCnd']->{static::P_SEARCH_IN_SUBCATS})) {
             $queryBuilder->andWhere('c.category_id = :categoryId')
                 ->setParameter('categoryId', $value);
-
         } elseif (!\XLite\Core\Database::getRepo('XLite\Model\Category')->addSubTreeCondition($queryBuilder, $value)) {
             // TODO - add throw exception
         }
@@ -574,8 +555,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by category ids", type="array")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param array                      $value        Condition data
      *
@@ -608,8 +587,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by substring in name and description", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
      *
@@ -623,13 +600,12 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
                 ? $including
                 : static::INCLUDING_PHRASE;
 
-            $this->{'processCndSubstring' . ucfirst($including)} ($queryBuilder, $value);
+            $this->{'processCndSubstring' . ucfirst($including)}($queryBuilder, $value);
         }
     }
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters by min price (first item) and max price (second item)", type="array", collectionFormat="multi", @Swg\Items(type="number"))
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param array                      $value        Condition data
@@ -640,10 +616,10 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     {
         if (is_array($value)) {
             $min = empty($value[0]) ? null : trim($value[0]);
-            $min = (0 === strlen($min) || !is_numeric($min)) ? null : (float)$min;
+            $min = (strlen($min) === 0 || !is_numeric($min)) ? null : (float)$min;
 
             $max = empty($value[1]) ? null : trim($value[1]);
-            $max = (0 === strlen($max) || !is_numeric($max)) ? null : (float)$max;
+            $max = (strlen($max) === 0 || !is_numeric($max)) ? null : (float)$max;
 
             $this->assignPriceRangeCondition($queryBuilder, $min, $max);
         }
@@ -692,17 +668,17 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
      */
     protected function assignPriceRangeCondition(\Doctrine\ORM\QueryBuilder $queryBuilder, $min, $max)
     {
-        if (null !== $min || null !== $max) {
+        if ($min !== null || $max !== null) {
             $field = \XLite::isAdminZone()
                 ? 'p.price'
                 : $this->getCalculatedField($queryBuilder, 'price');
 
-            if (null !== $min) {
+            if ($min !== null) {
                 $queryBuilder->andWhere($field . ' >= :minPrice')
                     ->setParameter('minPrice', (float)$min);
             }
 
-            if (null !== $max) {
+            if ($max !== null) {
                 $queryBuilder->andWhere($field . ' <= :maxPrice')
                     ->setParameter('maxPrice', (float)$max);
             }
@@ -805,7 +781,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
         if (preg_match_all('/"([^"]+)"/', $value, $match)) {
             $result = $match[1];
             $value = str_replace($match[0], '', $value);
-
         }
 
         return array_merge((array)$result, array_map('trim', explode(' ', $value)));
@@ -814,8 +789,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by stock status (inventory)", type="string", enum={"low", "out", "in"})
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param string                     $value        Condition data
      *
@@ -830,10 +803,8 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
 
         if ($value === static::INV_LOW) {
             $this->prepareCndInventoryLow($queryBuilder);
-
         } elseif ($value === static::INV_OUT) {
             $this->prepareCndInventoryOut($queryBuilder);
-
         } elseif ($value === static::INV_IN) {
             $this->prepareCndInventoryIn($queryBuilder);
         }
@@ -878,17 +849,17 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
         $orCnd = new \Doctrine\ORM\Query\Expr\Orx();
         $orCnd->add('p.inventoryEnabled = :disabled');
         $orCnd->add('p.amount > :zero');
+        $orCnd->add('p.amount = :zero and p.arrivalDate > :currentTime');
 
         $queryBuilder->andWhere($orCnd)
             ->setParameter('disabled', false)
-            ->setParameter('zero', 0);
+            ->setParameter('zero', 0)
+            ->setParameter('currentTime', \XLite\Core\Converter::time());
     }
 
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Excludes products with given IDs", type="array", collectionFormat="multi", @Swg\Items(type="integer"))
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param array                      $value        Condition data
      *
@@ -898,7 +869,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     {
         if (is_array($value) && 1 < count($value)) {
             $queryBuilder->andWhere('p.product_id NOT IN (' . implode(',', $value) . ')');
-
         } elseif ($value) {
             $queryBuilder->andWhere('p.product_id != :productId')
                 ->setParameter('productId', is_array($value) ? array_pop($value) : $value);
@@ -908,8 +878,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by arrival date (timestamp) arranged in two-value array [start, end]", type="array", collectionFormat="multi", @Swg\Items(type="integer"))
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -937,8 +905,6 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     /**
      * Prepare certain search condition
      *
-     * @Api\Condition(description="Filters products by arrival date in format of d-M-Y ~ d-M-Y", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param mixed                      $value        Condition data
      *
@@ -947,7 +913,7 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     protected function prepareCndArrivalDateRange(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
         if (!empty($value)) {
-            list($start, $end) = \XLite\View\FormField\Input\Text\DateRange::convertToArray($value);
+            [$start, $end] = \XLite\View\FormField\Input\Text\DateRange::convertToArray($value);
             if ($start) {
                 $queryBuilder->andWhere('p.arrivalDate >= :start')
                     ->setParameter('start', $start);
@@ -971,19 +937,19 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     protected function prepareCndOrderBy(\Doctrine\ORM\QueryBuilder $queryBuilder, array $value)
     {
         if (!$this->isCountSearchMode()) {
-            list($sort, $order) = $this->getSortOrderValue($value);
+            [$sort, $order] = $this->getSortOrderValue($value);
 
             // FIXME - add aliases for sort modes
-            if ('p.price' === $sort && !\XLite::isAdminZone()) {
+            if ($sort === 'p.price' && !\XLite::isAdminZone()) {
                 $sort = $this->getCalculatedFieldAlias($queryBuilder, 'price');
-            } elseif ('translations.name' === $sort) {
+            } elseif ($sort === 'translations.name') {
                 $this->addSortByTranslation($queryBuilder, $sort, $order);
                 $sort = 'calculatedName';
             }
 
             $queryBuilder->addOrderBy($sort, $order);
 
-            if ('p.product_id' !== $sort) {
+            if ($sort !== 'p.product_id') {
                 $queryBuilder->addOrderBy('p.product_id', $order);
             }
         }
@@ -1010,18 +976,20 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
         $defaultCode = \XLite::getDefaultLanguage();
 
         // Add additional join to translations with current language code
-        parent::addTranslationJoins($queryBuilder, $alias, 'st', $currentCode);
+        $this->addTranslationJoins($queryBuilder, $alias, 'st', $currentCode);
+        $queryBuilder->addGroupBy('st.name');
 
         if ($currentCode !== $defaultCode) {
             // Add additional join to translations with default language code
             $this->addTranslationJoins($queryBuilder, $alias, 'st2', $defaultCode);
+            $queryBuilder->addGroupBy('st2.name');
 
             // Add calculated field to the fields list to use this for sorting out
             $queryBuilder->addSelect('IFNULL(st.name,IFNULL(st2.name,translations.name)) calculatedName');
-
         } else {
             // Add calculated field to the fields list to use this for sorting out
             $queryBuilder->addSelect('IFNULL(st.name,translations.name) calculatedName');
+            $queryBuilder->addSelect('CAST(p.price AS UNSIGNED) someprice');
         }
     }
 
@@ -1035,7 +1003,7 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
      */
     protected function addEnabledCondition(\Doctrine\ORM\QueryBuilder $queryBuilder, $alias = null)
     {
-        if (!\XLite::isAdminZone()) {
+        if (!\XLite::isAdminZone() && !\XLite\Core\Request::getInstance()->isCLI()) {
             $this->assignEnabledCondition($queryBuilder, $alias);
         }
 
@@ -1097,10 +1065,22 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
      */
     protected function getCalculatedPriceJoinConditions()
     {
-        $profile = \XLite\Core\Auth::getInstance()->getProfile();
+        $controller = \XLite::getController();
+        $profile = null;
+
+        if ($controller instanceof \XLite\Controller\Customer\ACustomer) {
+            $profile = $controller->getCart(false)->getProfile()
+                ?: \XLite\Core\Auth::getInstance()->getProfile();
+        }
+
+        $qdZone = null;
+        if ($profile) {
+            $qdZone = \XLite\Core\QuickData::getInstance()->getQuickDataZoneForProfile($profile);
+        }
 
         return [
             'membership' => $profile && $profile->getMembership() ? $profile->getMembership() : null,
+            'zone' => $qdZone,
         ];
     }
 
@@ -1157,7 +1137,7 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
      */
     protected function addMembershipCondition(\Doctrine\ORM\QueryBuilder $queryBuilder, $alias = null)
     {
-        if (!\XLite::isAdminZone()) {
+        if (!\XLite::isAdminZone() && !\XLite\Core\Request::getInstance()->isCLI()) {
             $alias = $alias ?: $queryBuilder->getRootAlias();
             $membership = \XLite\Core\Auth::getInstance()->getMembershipId();
 
@@ -1166,52 +1146,12 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
             if ($membership) {
                 $queryBuilder->andWhere('membership.membership_id = :membershipId OR membership.membership_id IS NULL')
                     ->setParameter('membershipId', \XLite\Core\Auth::getInstance()->getMembershipId());
-
             } else {
                 $queryBuilder->andWhere('membership.membership_id IS NULL');
             }
         }
     }
 
-    // {{{ Export routines
-
-    // }}}
-
-    /**
-     * Insert single entity
-     *
-     * @param \XLite\Model\AEntity|array $entity Data to insert OPTIONAL
-     *
-     * @return \XLite\Model\AEntity|array
-     */
-    protected function performInsert($entity = null)
-    {
-        $entity = parent::performInsert($entity);
-
-        if ($entity && !$this->getBlockQuickDataFlag()) {
-            $entity->updateQuickData();
-        }
-
-        return $entity;
-    }
-
-    /**
-     * Update single entity
-     *
-     * @param \XLite\Model\AEntity $entity Entity to use
-     * @param array                $data   Data to save OPTIONAL
-     *
-     * @return void
-     */
-    protected function performUpdate(\XLite\Model\AEntity $entity, array $data = [])
-    {
-        parent::performUpdate($entity, $data);
-
-        if (!$this->getBlockQuickDataFlag()) {
-            $entity->updateQuickData();
-        }
-    }
-
     /**
      * Add the specific joints with the translation table
      *
@@ -1235,44 +1175,11 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     // {{{ Quick data
 
     /**
-     * Block quick data
-     *
-     * @var boolean
-     */
-    protected $blockQuickData = false;
-
-    /**
-     * Set block quick data flag
-     *
-     * @param boolean $flag Flag
-     *
-     * @return \XLite\Model\Repo\ARepo
-     */
-    public function setBlockQuickDataFlag($flag)
-    {
-        $this->blockQuickData = $flag;
-
-        return $this;
-    }
-
-    /**
-     * Get block quick data flag
-     *
-     * @return boolean
-     */
-    public function getBlockQuickDataFlag()
-    {
-        return $this->blockQuickData;
-    }
-
-    /**
-     * Count items for quick data
-     *
-     * @return integer
+     * @return int
      */
     public function countForQuickData()
     {
-        return (int)$this->defineCountForQuickDataQuery()->getSingleScalarResult();
+        return (int) $this->defineCountForQuickDataQuery()->getQuery()->getSingleScalarResult();
     }
 
     /**
@@ -1420,13 +1327,11 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     }
 
     /**
-     * Count items for quick data
-     *
-     * @return integer
+     * @return int
      */
     public function countForSales()
     {
-        return (int)$this->defineCountForSalesQuery()->getSingleScalarResult();
+        return (int) $this->defineCountForSalesQuery()->getQuery()->getSingleScalarResult();
     }
 
     /**
@@ -1471,4 +1376,148 @@ class Product extends \XLite\Model\Repo\Base\I18n implements \XLite\Base\IREST
     }
 
     // }}}
+
+    /**
+     * @return int
+     */
+    public function countForApplyAttributeValues()
+    {
+        return (int) $this->defineCountForApplyAttrValuesQuery()->getQuery()->getSingleScalarResult();
+    }
+
+    /**
+     * Define query builder for COUNT query
+     *
+     * @return \XLite\Model\QueryBuilder\AQueryBuilder
+     */
+    protected function defineCountForApplyAttrValuesQuery()
+    {
+        $qb = $this->createPureQueryBuilder();
+
+        return $qb->select(
+            'COUNT(DISTINCT ' . $qb->getMainAlias() . '.' . $this->getPrimaryKeyField() . ')'
+        );
+    }
+
+    /**
+     * Define items iterator
+     *
+     * @param integer $position Position OPTIONAL
+     *
+     * @return \Doctrine\ORM\Internal\Hydration\IterableResult
+     */
+    public function getApplyAttributeValuesIterator($position = 0)
+    {
+        return $this->defineApplyAttributeValuesIteratorQueryBuilder($position)
+            ->iterate();
+    }
+
+    /**
+     * Define iterator query builder
+     *
+     * @param integer $position Position
+     *
+     * @return \XLite\Model\QueryBuilder\AQueryBuilder
+     */
+    protected function defineApplyAttributeValuesIteratorQueryBuilder($position)
+    {
+        return $this->createPureQueryBuilder()
+            ->setFirstResult($position)
+            ->setMaxResults(\XLite\Core\EventListener\ApplyAttributeValues::CHUNK_LENGTH);
+    }
+
+    public function getDemoProductsCount(): int
+    {
+        return $this->createPureQueryBuilder('p')
+                    ->select('COUNT(p)')
+                    ->andWhere('p.isDemoProduct = 1')
+                    ->getSingleScalarResult();
+    }
+
+    public function deleteDemoProducts(): void
+    {
+        $this->createPureQueryBuilder('p')
+             ->delete($this->_entityName, 'p')
+             ->andWhere('p.isDemoProduct = 1')
+             ->execute();
+    }
+
+    /**
+     * Define demo items iterator
+     *
+     * @param integer $position Position OPTIONAL
+     *
+     * @return Iterator
+     */
+    public function getRemoveDemoDataIterator($position = 0)
+    {
+        return $this->defineRemoveDemoDataQueryBuilder($position)
+                    ->setMaxResults(\XLite\Core\EventListener\RemoveData::CHUNK_LENGTH)
+                    ->iterate();
+    }
+
+    protected function defineRemoveDemoDataQueryBuilder($position)
+    {
+        $qb = $this->defineRemoveDataQueryBuilder($position);
+
+        return $qb->andWhere($qb->getMainAlias() . '.isDemoProduct = 1');
+    }
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            !empty($entity['sku'])
+            && ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+        ) {
+            return [
+                $entity['sku'],
+                $result['name'] ?? '',
+                $result['description'] ?? '',
+                $result['briefDescription'] ?? '',
+                $result['metaTags'] ?? '',
+                $result['metaDesc'] ?? '',
+                $result['metaTitle'] ?? ''
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(ProductTranslation $translation): ?array
+    {
+        /** @var \Xlite\Model\Product $product */
+        $product = $translation->getOwner();
+
+        return [
+            $product->getSku(),
+            $translation->getName(),
+            $translation->getDescription(),
+            $translation->getBriefDescription(),
+            $translation->getMetaTags(),
+            $translation->getMetaDesc(),
+            $translation->getMetaTitle()
+        ];
+    }
+
+    public function generateYamlEntityForTranslationModule(array $data, string $lngCode): ?array
+    {
+        if (empty($data[0])) {
+            return null;
+        }
+
+        return [
+            'sku'          => $data[0],
+            'translations' => [
+                array_filter([
+                    'code'             => $lngCode,
+                    'name'             => $data[1] ?? '',
+                    'description'      => $data[2] ?? '',
+                    'briefDescription' => $data[3] ?? '',
+                    'metaTags'         => $data[4] ?? '',
+                    'metaDesc'         => $data[5] ?? '',
+                    'metaTitle'        => $data[6] ?? '',
+                ]),
+            ],
+        ];
+    }
 }
