@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -7,62 +6,58 @@
  */
 
 namespace XLite\Model\Repo;
-use XLite\Model\QueryBuilder\AQueryBuilder;
+
+use XCart\Security\UserRepositoryInterface;
+use XLite\Model\Profile as ProfileEntity;
 
 /**
  * The Profile model repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Profile", summary="Add new profile")
- * @Api\Operation\Read(modelClass="XLite\Model\Profile", summary="Retrieve profile by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Profile", summary="Retrieve profiles by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Profile", summary="Update profile by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Profile", summary="Delete profile by id")
  */
-class Profile extends \XLite\Model\Repo\ARepo
+class Profile extends \XLite\Model\Repo\ARepo implements UserRepositoryInterface
 {
     /**
      * Allowable search params
      */
-    const SEARCH_PROFILE_ID     = 'profile_id';
-    const SEARCH_ORDER_ID       = 'order_id';
-    const SEARCH_REFERER        = 'referer';
-    const SEARCH_MEMBERSHIP     = 'membership';
-    const SEARCH_ROLES          = 'roles';
-    const SEARCH_PERMISSIONS    = 'permissions';
-    const SEARCH_LANGUAGE       = 'language';
-    const SEARCH_PATTERN        = 'pattern';
-    const SEARCH_LOGIN          = 'login';
-    const SEARCH_AND_LOGIN      = 'andLogin';
-    const SEARCH_PHONE          = 'phone';
-    const SEARCH_COUNTRY        = 'country';
-    const SEARCH_STATE          = 'state';
-    const SEARCH_CUSTOM_STATE   = 'custom_state';
-    const SEARCH_ADDRESS        = 'address';
-    const SEARCH_USER_TYPE      = 'user_type';
-    const SEARCH_DATE_TYPE      = 'date_type';
-    const SEARCH_DATE_PERIOD    = 'date_period';
-    const SEARCH_START_DATE     = 'startDate';
-    const SEARCH_END_DATE       = 'endDate';
-    const SEARCH_DATE_RANGE     = 'dateRange';
-    const SEARCH_STATUS         = 'status';
-    const SEARCH_ONLY_REAL      = 'onlyReal';
+    public const SEARCH_PROFILE_ID     = 'profile_id';
+    public const SEARCH_ORDER_ID       = 'order_id';
+    public const SEARCH_REFERER        = 'referer';
+    public const SEARCH_MEMBERSHIP     = 'membership';
+    public const SEARCH_ROLES          = 'roles';
+    public const SEARCH_PERMISSIONS    = 'permissions';
+    public const SEARCH_LANGUAGE       = 'language';
+    public const SEARCH_PATTERN        = 'pattern';
+    public const SEARCH_LOGIN          = 'login';
+    public const SEARCH_AND_LOGIN      = 'andLogin';
+    public const SEARCH_PHONE          = 'phone';
+    public const SEARCH_COUNTRY        = 'country';
+    public const SEARCH_STATE          = 'state';
+    public const SEARCH_CUSTOM_STATE   = 'custom_state';
+    public const SEARCH_ADDRESS        = 'address';
+    public const SEARCH_USER_TYPE      = 'user_type';
+    public const SEARCH_DATE_TYPE      = 'date_type';
+    public const SEARCH_DATE_PERIOD    = 'date_period';
+    public const SEARCH_START_DATE     = 'startDate';
+    public const SEARCH_END_DATE       = 'endDate';
+    public const SEARCH_DATE_RANGE     = 'dateRange';
+    public const SEARCH_STATUS         = 'status';
+    public const SEARCH_ONLY_REAL      = 'onlyReal';
 
     /**
      * Password length
      */
-    const PASSWORD_LENGTH = 12;
+    public const PASSWORD_LENGTH = 12;
 
     /**
      * Default Recent administrators list length
      */
-    const DEFAULT_RECENT_ADMINS_LENGTH = 8;
+    public const DEFAULT_RECENT_ADMINS_LENGTH = 8;
 
     /**
      * Password characters list
      *
      * @var array
      */
-    protected static $passwordChars = array(
+    protected static $passwordChars = [
         '0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
         'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
         'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't',
@@ -70,7 +65,7 @@ class Profile extends \XLite\Model\Repo\ARepo
         'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
         'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X',
         'Y', 'Z',
-    );
+    ];
 
     /**
      * Repository type
@@ -92,7 +87,8 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         $queryBuilder = parent::createQueryBuilder($alias, $indexBy, $code);
 
-        $queryBuilder->linkLeft('p.addresses');
+        $rootAlias = $queryBuilder->getRootAliases()[0];
+        $queryBuilder->linkLeft(sprintf('%s.addresses', $rootAlias));
 
         return $queryBuilder;
     }
@@ -106,28 +102,16 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         return array_merge(
             parent::getExcludedConditions(),
-            array(
-                static::P_ORDER_BY          => array(
+            [
+                static::P_ORDER_BY          => [
                     static::SEARCH_MODE_COUNT
-                ),
+                ],
                 static::SEARCH_DATE_PERIOD  => static::EXCLUDE_FROM_ANY,
                 static::SEARCH_DATE_RANGE   => static::EXCLUDE_FROM_ANY,
-            )
+            ]
         );
     }
 
-    /**
-     * Find profile by CMS identifiers
-     *
-     * @param array $fields CMS identifiers
-     *
-     * @return \XLite\Model\Profile|void
-     */
-    public function findOneByCMSId(array $fields)
-    {
-        return $this->defineFindOneByCMSIdQuery($fields)->getSingleResult();
-    }
-
     /**
      * Search profile by login
      *
@@ -184,21 +168,17 @@ class Profile extends \XLite\Model\Repo\ARepo
      *
      * @return \XLite\Model\Profile|void
      */
-    public function findUserWithSameLogin(\XLite\Model\Profile $profile)
+    public function findUserWithSameLogin(ProfileEntity $profile)
     {
         return $this->defineFindUserWithSameLoginQuery($profile)->getSingleResult();
     }
 
     /**
-     * Find user with same login
-     *
-     * @param \XLite\Model\Profile $profile Profile object
-     *
-     * @return \XLite\Model\Profile|void
+     * @return bool
      */
-    public function checkRegisteredUserWithSameLogin(\XLite\Model\Profile $profile)
+    public function checkRegisteredUserWithSameLogin(ProfileEntity $profile)
     {
-        return (boolean) $this->defineCheckRegisteredUserWithSameLogin($profile)->getSingleScalarResult();
+        return (bool) $this->defineCheckRegisteredUserWithSameLogin($profile)->getQuery()->getSingleScalarResult();
     }
 
     /**
@@ -221,15 +201,15 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     public function findOneByRecord(array $data, \XLite\Model\AEntity $parent = null)
     {
-        if (isset($data['login'])
+        if (
+            isset($data['login'])
             && (isset($data['order_id'])
-                && (0 == $data['order_id'] && $data['order_id'] !== 'null')
-                || 1 === count($data)
+                && ($data['order_id'] == 0 && $data['order_id'] !== 'null')
+                || count($data) === 1
             )
         ) {
             // N.B. Thats loading only customerss
             $entity = $this->defineOneByRecord($data['login'])->getSingleResult();
-
         } else {
             $entity = parent::findOneByRecord($data, $parent);
         }
@@ -244,7 +224,7 @@ class Profile extends \XLite\Model\Repo\ARepo
      *
      * @return \XLite\Model\Profile
      */
-    public function findOneAnonymousByProfile(\XLite\Model\Profile $profile)
+    public function findOneAnonymousByProfile(ProfileEntity $profile)
     {
         return $this->defineFindOneAnonymousByProfileQuery($profile)->getSingleResult();
     }
@@ -291,7 +271,7 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         $cnd = $this->searchState['currentSearchCnd'];
 
-        if (!$cnd->{static::SEARCH_ORDER_ID}) {
+        if (isset($cnd->{static::SEARCH_ORDER_ID}) && !$cnd->{static::SEARCH_ORDER_ID}) {
             $cnd->{static::SEARCH_ORDER_ID} = 0;
         }
 
@@ -312,8 +292,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Shows only anonymous (true) or registered (false) user profiles", type="boolean")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -329,8 +307,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by order id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -346,8 +322,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by referer", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -359,8 +333,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by membership id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -368,14 +340,12 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndMembership(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        if ('A' !== $this->searchState['currentSearchCnd']->{static::SEARCH_USER_TYPE}) {
+        if ($this->searchState['currentSearchCnd']->{static::SEARCH_USER_TYPE} !== 'A') {
             $queryBuilder->bindMembership($value);
         }
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by role(s)", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -389,8 +359,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by available permission code(s)", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -404,8 +372,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by language", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -417,8 +383,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by name or email substring", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -430,8 +394,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by phone number", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -445,8 +407,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by email (OR clause)", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -460,8 +420,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by email (AND clause)", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -475,8 +433,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by country code", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -492,8 +448,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by state id (for countries with states)", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -509,8 +463,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by custom state name", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -524,8 +476,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by address id", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -537,8 +487,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by user type", type="string")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param mixed                      $value        Searchable value
      *
@@ -546,10 +494,10 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndUserType(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
-        $roles = array();
+        $roles = [];
 
         if (!is_array($value)) {
-            $value = array($value);
+            $value = [$value];
         }
 
         $condition = $queryBuilder->expr()->orX();
@@ -557,8 +505,7 @@ class Profile extends \XLite\Model\Repo\ARepo
         foreach ($value as $selectedType) {
             if (is_numeric($selectedType)) {
                 $roles[] = $selectedType;
-
-            } elseif ('C' === $selectedType) {
+            } elseif ($selectedType === 'C') {
                 $condition->add(
                     $queryBuilder->expr()->andX(
                         $queryBuilder->getRegisteredCondition(),
@@ -568,8 +515,7 @@ class Profile extends \XLite\Model\Repo\ARepo
 
                 $queryBuilder->setParameter('anonymous', true)
                     ->setParameter('adminAccessLevel', \XLite\Core\Auth::getInstance()->getAdminAccessLevel());
-
-            } elseif ('N' === $selectedType) {
+            } elseif ($selectedType === 'N') {
                 $condition->add(
                     $queryBuilder->expr()->andX(
                         $queryBuilder->getAnonymousCondition(),
@@ -613,8 +559,8 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         $dateRange = $this->getDateRange();
 
-        if (null !== $dateRange && in_array($value, array('R', 'L'), true)) {
-            $field = 'R' === $value ? 'p.added' : 'p.last_login';
+        if ($dateRange !== null && in_array($value, ['R', 'L'], true)) {
+            $field = $value === 'R' ? 'p.added' : 'p.last_login';
             $queryBuilder->bindMacroDate($field, $dateRange->startDate, $dateRange->endDate);
         }
     }
@@ -636,45 +582,43 @@ class Profile extends \XLite\Model\Repo\ARepo
             $startDate = null;
             $endDate = \XLite\Core\Converter::time();
 
-            if ('M' === $datePeriod) {
+            if ($datePeriod === 'M') {
                 $startDate = mktime(0, 0, 0, date('n', $endDate), 1, date('Y', $endDate));
-
-            } elseif ('W' === $datePeriod) {
+            } elseif ($datePeriod === 'W') {
                 $startDate = \XLite\Core\Converter::getDayStart($endDate - (date('w', $endDate) * 86400));
-
-            } elseif ('D' === $datePeriod) {
+            } elseif ($datePeriod === 'D') {
                 $startDate = \XLite\Core\Converter::getDayStart($endDate);
-
-            } elseif ('C' === $datePeriod) {
+            } elseif ($datePeriod === 'C') {
                 $paramStartDate = static::SEARCH_START_DATE;
                 $paramEndDate = static::SEARCH_END_DATE;
                 $paramDateRange = static::SEARCH_DATE_RANGE;
 
-                if (!empty($this->searchState['currentSearchCnd']->$paramStartDate)
+                if (
+                    !empty($this->searchState['currentSearchCnd']->$paramStartDate)
                     && !empty($this->searchState['currentSearchCnd']->$paramEndDate)
                 ) {
                     $tmpDate = strtotime($this->searchState['currentSearchCnd']->$paramStartDate);
 
-                    if (false !== $tmpDate) {
+                    if ($tmpDate !== false) {
                         $startDate = \XLite\Core\Converter::getDayStart($tmpDate);
                     }
 
                     $tmpDate = strtotime($this->searchState['currentSearchCnd']->$paramEndDate);
 
-                    if (false !== $tmpDate) {
+                    if ($tmpDate !== false) {
                         $endDate = \XLite\Core\Converter::getDayEnd($tmpDate);
                     }
-
                 } elseif (!empty($this->searchState['currentSearchCnd']->$paramDateRange)) {
-                    list($startDate, $endDate) = \XLite\View\FormField\Input\Text\DateRange::convertToArray(
+                    [$startDate, $endDate] = \XLite\View\FormField\Input\Text\DateRange::convertToArray(
                         $this->searchState['currentSearchCnd']->$paramDateRange
                     );
                 }
             }
 
-            if (null !== $startDate
-                && false !== $startDate
-                && false !== $endDate
+            if (
+                $startDate !== null
+                && $startDate !== false
+                && $endDate !== false
             ) {
                 $result = new \XLite\Core\CommonCell();
                 $result->startDate = $startDate;
@@ -696,15 +640,15 @@ class Profile extends \XLite\Model\Repo\ARepo
     protected function prepareOrderByAddressField(\Doctrine\ORM\QueryBuilder $queryBuilder, $fieldName)
     {
         $addressField = \XLite\Core\Database::getRepo('XLite\Model\AddressField')
-            ->findOneBy(array('serviceName' => $fieldName));
+            ->findOneBy(['serviceName' => $fieldName]);
 
         $queryBuilder
             ->leftJoin(
-            'addresses.addressFields',
-            'orderby_field_value_' . $fieldName,
-            \Doctrine\ORM\Query\Expr\Join::WITH,
-            'orderby_field_value_' . $fieldName . '.addressField = :' . $fieldName
-        )->setParameter($fieldName, $addressField);
+                'addresses.addressFields',
+                'orderby_field_value_' . $fieldName,
+                \Doctrine\ORM\Query\Expr\Join::WITH,
+                'orderby_field_value_' . $fieldName . '.addressField = :' . $fieldName
+            )->setParameter($fieldName, $addressField);
     }
 
     /**
@@ -721,9 +665,23 @@ class Profile extends \XLite\Model\Repo\ARepo
 
         $queryBuilder
             ->addSelect(
-            'CONCAT(CONCAT(orderby_field_value_firstname.value, \' \'),
+                'CONCAT(CONCAT(orderby_field_value_firstname.value, \' \'),
             orderby_field_value_lastname.value) as fullname'
-        );
+            );
+    }
+
+    /**
+     * order by non-anonymous priority
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
+     * @param string                     $order        Sort param
+     *
+     * @return void
+     */
+    protected function prepareCndOrderByAccessLevel(\Doctrine\ORM\QueryBuilder $queryBuilder, string $order)
+    {
+        $queryBuilder
+            ->addOrderBy('p.anonymous', $order === 'asc' ? 'desc' : 'asc');
     }
 
     /**
@@ -736,18 +694,20 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function prepareCndOrderBy(\Doctrine\ORM\QueryBuilder $queryBuilder, array $value)
     {
-        list($sort, ) = $this->getSortOrderValue($value);
+        [$sort, $order] = $this->getSortOrderValue($value);
 
-        if (\XLite\View\ItemsList\Model\Profile::SORT_BY_MODE_NAME === $sort) {
+        if ($sort === \XLite\View\ItemsList\Model\Profile::SORT_BY_MODE_NAME) {
             $this->prepareCndOrderByFullname($queryBuilder);
         }
 
         parent::prepareCndOrderBy($queryBuilder, $value);
+
+        if ($sort === \XLite\View\ItemsList\Model\Profile::SORT_BY_MODE_ACCESS_LEVEL) {
+            $this->prepareCndOrderByAccessLevel($queryBuilder, $order);
+        }
     }
 
     /**
-     * @Api\Condition(description="Filters profiles by status id", type="integer")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param string                     $value        Searchable value
      *
@@ -761,8 +721,6 @@ class Profile extends \XLite\Model\Repo\ARepo
     }
 
     /**
-     * @Api\Condition(description="Exclude profile copies (snapshots for certain order)", type="boolean")
-     *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder QueryBuilder instance
      * @param string                     $value        Searchable value
      *
@@ -798,14 +756,13 @@ class Profile extends \XLite\Model\Repo\ARepo
      *
      * @return \Doctrine\ORM\QueryBuilder
      */
-    protected function defineFindUserWithSameLoginQuery(\XLite\Model\Profile $profile)
+    protected function defineFindUserWithSameLoginQuery(ProfileEntity $profile)
     {
         $queryBuilder = $this->createQueryBuilder()
             ->bindSameLogin($profile);
 
         if ($profile->getOrder()) {
             $queryBuilder->bindOrder($profile->getOrder());
-
         } else {
             $queryBuilder->bindRegistered();
         }
@@ -820,7 +777,7 @@ class Profile extends \XLite\Model\Repo\ARepo
      *
      * @return \Doctrine\ORM\QueryBuilder
      */
-    protected function defineCheckRegisteredUserWithSameLogin(\XLite\Model\Profile $profile)
+    protected function defineCheckRegisteredUserWithSameLogin(ProfileEntity $profile)
     {
         $queryBuilder = $this->createQueryBuilder()
             ->select('COUNT(DISTINCT p.profile_id)')
@@ -828,7 +785,6 @@ class Profile extends \XLite\Model\Repo\ARepo
 
         if ($profile->getOrder()) {
             $queryBuilder->bindOrder($profile->getOrder());
-
         } else {
             $queryBuilder->bindRegistered();
         }
@@ -892,21 +848,7 @@ class Profile extends \XLite\Model\Repo\ARepo
         return $this->createQueryBuilder()
             ->selectCount()
             ->bindAdmin()
-            ->bindAndCondition('p.status', \XLite\Model\Profile::STATUS_ENABLED);
-    }
-
-    /**
-     * Define query for findOneByCMSId()
-     *
-     * @param array $fields Fields
-     *
-     * @return \Doctrine\ORM\PersistentCollection
-     */
-    protected function defineFindOneByCMSIdQuery(array $fields)
-    {
-        return $this->createQueryBuilder()
-            ->bindVisible()
-            ->mapAndConditions($fields);
+            ->bindAndCondition('p.status', ProfileEntity::STATUS_ENABLED);
     }
 
     /**
@@ -920,14 +862,14 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function defineFindByLoginPasswordQuery($login, $password, $orderId)
     {
-        $conditions = array(
+        $conditions = [
             'login'  => $login,
-            'status' => \XLite\Model\Profile::STATUS_ENABLED,
-        );
+            'status' => ProfileEntity::STATUS_ENABLED,
+        ];
 
         $queryBuilder = $this->createQueryBuilder();
 
-        if (null !== $password) {
+        if ($password !== null) {
             $conditions['password'] = $password;
         }
 
@@ -965,15 +907,16 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         $result = parent::collectAlternativeIdentifiersByRecord($data);
 
-        if (!$result
+        if (
+            !$result
             && !empty($data['login'])
             && isset($data['order_id'])
             && (!$data['order_id'] || $data['order_id'] === 'null')
         ) {
-            $result = array(
+            $result = [
                 'login' => $data['login'],
                 'order' => null,
-            );
+            ];
         }
 
         return $result;
@@ -990,9 +933,10 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function linkLoadedEntity(\XLite\Model\AEntity $entity, \XLite\Model\AEntity $parent, array $parentAssoc)
     {
-        if ($parent instanceof \XLite\Model\Order
+        if (
+            $parent instanceof \XLite\Model\Order
             && !$parentAssoc['mappedSetter']
-            && 'setProfile' === $parentAssoc['setter']
+            && $parentAssoc['setter'] === 'setProfile'
         ) {
             // Add order to profile if this profile - copy of original profile
             $parentAssoc['mappedSetter'] = 'setOrder';
@@ -1006,8 +950,6 @@ class Profile extends \XLite\Model\Repo\ARepo
      * Load fixture
      *
      * @param array                $record      Record
-     * @param array                $regular     Regular fields info OPTIONAL
-     * @param array                $assocs      Associations info OPTIONAL
      * @param \XLite\Model\AEntity $parent      Entity parent callback OPTIONAL
      * @param array                $parentAssoc Entity mapped propery method OPTIONAL
      *
@@ -1015,12 +957,11 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     public function loadFixture(
         array $record,
-        array $regular = array(),
-        array $assocs = array(),
         \XLite\Model\AEntity $parent = null,
-        array $parentAssoc = array()
+        array $parentAssoc = []
     ) {
-        $entity = parent::loadFixture($record, $regular, $assocs, $parent, $parentAssoc);
+        $entity = parent::loadFixture($record, $parent, $parentAssoc);
+
         $entity->updateSearchFakeField();
     }
 
@@ -1045,7 +986,7 @@ class Profile extends \XLite\Model\Repo\ARepo
      *
      * @return \XLite\Model\QueryBuilder\AQueryBuilder
      */
-    protected function defineFindOneAnonymousByProfileQuery(\XLite\Model\Profile $profile)
+    protected function defineFindOneAnonymousByProfileQuery(ProfileEntity $profile)
     {
         return $this->createQueryBuilder()
             ->bindAnonymous()
@@ -1072,14 +1013,7 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function defineCountForExportQuery()
     {
-        $result = parent::defineCountForExportQuery()
-                        ->bindVisible();
-
-        if (!isset($this->searchState['currentSearchCnd'])) {
-            $result->bindCustomer();
-        }
-
-        return $result;
+        return parent::defineCountForExportQuery()->bindVisible();
     }
 
     /**
@@ -1091,14 +1025,7 @@ class Profile extends \XLite\Model\Repo\ARepo
      */
     protected function defineExportIteratorQueryBuilder($position)
     {
-        $result = parent::defineExportIteratorQueryBuilder($position)
-                        ->bindVisible();
-
-        if (!isset($this->searchState['currentSearchCnd'])) {
-            $result->bindCustomer();
-        }
-
-        return $result;
+        return parent::defineExportIteratorQueryBuilder($position)->bindVisible();
     }
 
     // }}}
@@ -1116,6 +1043,8 @@ class Profile extends \XLite\Model\Repo\ARepo
     {
         $qb = parent::defineFindOneByImportConditionsQueryBuilder($conditions);
 
+        $qb->bindVisible();
+
         if (!\XLite\Core\Auth::getInstance()->isAdminProfilesManager()) {
             $qb->bindCustomer();
         }
@@ -1174,10 +1103,12 @@ class Profile extends \XLite\Model\Repo\ARepo
     /**
      * @param \XLite\Model\Profile $profile
      * @param null|string          $email
+     * @param null|string          $oldEmail
      */
-    public function updateOrderProfileEmailByOrigProfile($profile, $email = null)
+    public function updateOrderProfileEmailByOrigProfile($profile, $email = null, $oldEmail = null)
     {
         $email = $email ?: $profile->getLogin();
+        $oldEmail = $oldEmail ?: $profile->getLogin();
 
         $profiles = $this->createPureQueryBuilder('p')
             ->select('p.profile_id')
@@ -1185,10 +1116,10 @@ class Profile extends \XLite\Model\Repo\ARepo
             ->andWhere('o.orig_profile = :profile')
             ->setParameter('profile', $profile)
             ->andWhere('p.login = :oldEmail')
-            ->setParameter('oldEmail', $profile->getLogin())
+            ->setParameter('oldEmail', $oldEmail)
             ->getQuery()->getArrayResult();
 
-        $ids = array_map(function ($item) {
+        $ids = array_map(static function ($item) {
             return $item['profile_id'];
         }, $profiles);
 
@@ -1219,4 +1150,16 @@ class Profile extends \XLite\Model\Repo\ARepo
         return $qb->getSingleScalarResult();
     }
 
+    // UserRepositoryInterface
+
+    public function loadUserByIdentifier(string $identifier): ?ProfileEntity
+    {
+        return $this->findByLogin($identifier);
+    }
+
+    public function upgradePassword(ProfileEntity $user, string $newHashedPassword): void
+    {
+        $user->setPassword($newHashedPassword);
+        $this->update($user, [], true);
+    }
 }
