@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,23 +7,26 @@
 
 namespace XLite\Model\Repo\Shipping;
 
+use XCart\Doctrine\FixtureLoader;
+use XLite\Model\Repo\ModelRepoTranslationTrait;
+use XLite\Model\Shipping\MethodTranslation;
+
 /**
  * Shipping method
- *
- * @Api\Operation\Create(modelClass="XLite\Model\Shipping\Method", summary="Add new shipping methods")
- * @Api\Operation\Read(modelClass="XLite\Model\Shipping\Method", summary="Retrieve shipping methods by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\Shipping\Method", summary="Retrieve shipping methods by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\Shipping\Method", summary="Update shipping methods by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\Shipping\Method", summary="Delete shipping methods by id")
  */
 class Method extends \XLite\Model\Repo\Base\I18n
 {
+    use ModelRepoTranslationTrait;
+
     /**
      * Search parameters
      */
-    const P_CARRIER  = 'carrier';
-    const P_ADDED    = 'added';
-    
+    public const P_CARRIER              = 'carrier';
+    public const P_ADDED                = 'added';
+    public const P_ENABLED              = 'enabled';
+    public const P_PROCESSOR            = 'processor';
+    public const P_EXCL_PROCESSORS      = 'excludingProcessors';
+    public const P_ALL_CARRIER_SERVICES = 'allCarrierServices';
 
     /**
      * Repository type
@@ -38,10 +40,24 @@ class Method extends \XLite\Model\Repo\Base\I18n
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('processor', 'code'),
-    );
+    protected $alternativeIdentifier = [
+        ['processor', 'code'],
+    ];
 
+    /**
+     * max position of current fixtures loader
+     *
+     * @var int
+     */
+    protected $position = [];
+
+    /**
+     * @return FixtureLoader
+     */
+    protected function getFixtureLoader()
+    {
+        return \XCart\Container::getContainer()->get(FixtureLoader::class);
+    }
 
     /**
      * Find all methods as options list
@@ -112,12 +128,11 @@ class Method extends \XLite\Model\Repo\Base\I18n
         // Array of allowed fields and flag required/optional
         $fields = $this->getAllowedFields();
 
-        $errorFields = array();
+        $errorFields = [];
 
         foreach ($fields as $field => $required) {
             if (isset($data[$field])) {
                 $fields[$field] = $data[$field];
-
             } elseif ($required) {
                 $errorFields[] = $field;
             }
@@ -134,7 +149,6 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
         if ($method) {
             $this->update($method, $fields);
-
         } else {
             $method = new \XLite\Model\Shipping\Method();
             $method->map($fields);
@@ -170,7 +184,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
      */
     protected function findMethodToUpdate($data)
     {
-        return $this->findOneBy(array('processor' => $data['processor'], 'code' => $data['code']));
+        return $this->findOneBy(['processor' => $data['processor'], 'code' => $data['code']]);
     }
 
     /**
@@ -214,7 +228,7 @@ class Method extends \XLite\Model\Repo\Base\I18n
     /**
      * Define query builder object for findOneMaxPositionByProcessor()
      *
-     * @param string  $processorId Processor Id
+     * @param string $processorId Processor Id
      *
      * @return \Doctrine\ORM\QueryBuilder
      */
@@ -269,10 +283,9 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filter methods by carrier name", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
-     * @param string                     $value        Profile
+     * @param string                     $value        Condition data
      *
      * @return void
      */
@@ -284,10 +297,36 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filter methods by added state", type="boolean")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
-     * @param string                     $value        Profile
+     * @param string                     $value        Condition data
+     *
+     * @return void
+     */
+    protected function prepareCndProcessor(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        $queryBuilder->andWhere('m.processor = :processor')
+            ->setParameter('processor', $value);
+    }
+
+    /**
+     * Prepare certain search condition
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
+     * @param array                      $value        Processors
+     *
+     * @return void
+     */
+    protected function prepareCndExcludingProcessors(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        $queryBuilder->andWhere("m.processor NOT IN ('" . implode("','", $value) . "')");
+    }
+
+    /**
+     * Prepare certain search condition
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
+     * @param string                     $value        Condition data
      *
      * @return void
      */
@@ -297,6 +336,56 @@ class Method extends \XLite\Model\Repo\Base\I18n
             ->setParameter('added', $value);
     }
 
+    /**
+     * Prepare certain search condition
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
+     * @param boolean                    $value        Condition data
+     *
+     * @return void
+     */
+    protected function prepareCndEnabled(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        $queryBuilder
+            ->andWhere($this->getMainAlias($queryBuilder) . '.enabled = :enabled_value')
+            ->setParameter('enabled_value', $value);
+    }
+
+    /**
+     * Prepare certain search condition
+     *
+     * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
+     * @param string                     $value        Condition data
+     *
+     * @return void
+     */
+    protected function prepareCndAllCarrierServices(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
+    {
+        if ($value) {
+            $queryBuilder->andWhere('m.carrier IN (:processors) OR m.processor = :offline')
+                ->setParameter('processors', $this->getEnabledAddedProcessors())
+                ->setParameter('offline', 'offline');
+        }
+    }
+
+    /**
+     * @return array
+     */
+    protected function getEnabledAddedProcessors()
+    {
+        $processors = $this->createQueryBuilder('ma')
+            ->select('DISTINCT ma.processor')
+            ->andWhere('ma.added = :added')
+            ->andWhere('ma.enabled = :enabled')
+            ->andWhere('ma.carrier = :carrier')
+            ->setParameter('added', true)
+            ->setParameter('enabled', true)
+            ->setParameter('carrier', '')
+            ->getResult();
+
+        return array_map(static fn (array $processor): string => $processor['processor'], $processors);
+    }
+
     // {{{ Online methods
 
     /**
@@ -362,64 +451,227 @@ class Method extends \XLite\Model\Repo\Base\I18n
 
     // }}}
 
+    /**
+     * @param array                     $record
+     * @param \XLite\Model\AEntity|null $parent
+     * @param array                     $parentAssoc
+     *
+     * @return \XLite\Model\AEntity
+     */
+    public function loadFixture(
+        array $record,
+        \XLite\Model\AEntity $parent = null,
+        array $parentAssoc = []
+    ) {
+        $this->position[$record['processor']] = $this->getPositionCounter($record['processor']) + 10;
+        $record['position'] = $this->position[$record['processor']];
+
+        return parent::loadFixture($record, $parent, $parentAssoc);
+    }
+
+    /**
+     * @param string $processor
+     *
+     * @return int
+     */
+    protected function getPositionCounter($processor)
+    {
+        if (empty($this->position[$processor])) {
+            $this->position[$processor] = $this->getMaxPosition($processor);
+        }
+
+        return $this->position[$processor];
+    }
+
     // {{{ Update shipping methods from marketplace
 
     /**
      * Update shipping methods with data received from the marketplace
      *
-     * @param array $data List of payment methods received from marketplace
+     * @param array $data List of shipping methods received from marketplace
      *
      * @return void
      */
     public function updateShippingMethods($data)
     {
-        if (!empty($data) && is_array($data)) {
-            $tmpMethods = $this->createQueryBuilder('m')
+        if (is_array($data)) {
+            $existingMethods = $this->createQueryBuilder('m')
                 ->select('m')
                 ->getQuery()
                 ->getArrayResult();
 
-            if ($tmpMethods) {
-                $methods = array();
-                // Prepare associative array of existing methods with 'processor' as a key
-                foreach ($tmpMethods as $m) {
-                    if ('offline' !== $m['processor'] && '' === $m['carrier']) {
-                        $methods[$m['processor']] = $m;
-                    }
+            $existingOnlineMethods = [];
+
+            foreach ($existingMethods as $m) {
+                if ($m['processor'] === 'shipping_solution') {
+                    $this->deleteById($m['method_id'], false);
+                } elseif ($m['processor'] !== 'offline' && $m['carrier'] === '') {
+                    $existingOnlineMethods[$m['processor']] = $m;
                 }
-
-                foreach ($data as $i => $extMethod) {
-                    if (!empty($extMethod['processor'])) {
-                        $extMethod['fromMarketplace'] = 1;
-                        unset($extMethod['added'], $extMethod['enabled'], $extMethod['position']);
-
-                        $data[$i] = $extMethod;
-
-                        if (isset($methods[$extMethod['processor']])) {
-                            // Method already exists in the database
-                            if (!$methods[$extMethod['processor']]['fromMarketplace']) {
-                                // Method is not from marketplace, do not update
-                                unset($data[$i]);
-                            }
-                        }
-
-                    } else {
-                        // Wrong data row, ignore this
-                        unset($data[$i]);
-                    }
-                }
-
-                // Save data as temporary yaml file
-                $yaml = \Symfony\Component\Yaml\Yaml::dump(array('XLite\\Model\\Shipping\\Method' => $data));
-                $yamlFile = LC_DIR_TMP . 'shm.yaml';
-
-                \Includes\Utils\FileManager::write(LC_DIR_TMP . 'shm.yaml', $yaml);
-
-                // Update database from yaml file
-                \XLite\Core\Database::getInstance()->loadFixturesFromYaml($yamlFile);
             }
+
+            $shippingMethods = array_merge(
+                $this->getOnlineShippingMethods($data['processors'] ?? [], $existingOnlineMethods),
+                $this->getShippingSolutions($data['addons'] ?? [])
+            );
+
+            // Save data as temporary yaml file
+            $yaml     = \Symfony\Component\Yaml\Yaml::dump(['XLite\\Model\\Shipping\\Method' => $shippingMethods]);
+            $yamlPath = LC_DIR_TMP . 'shm.yaml';
+
+            \Includes\Utils\FileManager::write($yamlPath, $yaml);
+
+            // Update database from yaml file
+            $this->getFixtureLoader()->loadYaml($yamlPath);
         }
     }
 
+    /**
+     * Get online shipping methods from the marketplace
+     *
+     * @param array $methodsFromMarketplace List of shipping methods received from the marketplace
+     * @param array $existingOnlineMethods  List of shipping methods received from the database
+     *
+     * @return array
+     */
+    protected function getOnlineShippingMethods($methodsFromMarketplace, $existingOnlineMethods)
+    {
+        $result = [];
+
+        foreach ($methodsFromMarketplace as $methodFromMarketplace) {
+            $processor = $methodFromMarketplace['processor'];
+
+            if ($processor !== '') {
+                if (
+                    isset($existingOnlineMethods[$processor])
+                    && $existingOnlineMethods[$processor]['fromMarketplace']
+                ) {
+                    continue;
+                }
+
+                $methodFromMarketplace['fromMarketplace'] = 1;
+
+                unset(
+                    $methodFromMarketplace['added'],
+                    $methodFromMarketplace['enabled'],
+                    $methodFromMarketplace['position'],
+                    $methodFromMarketplace['iconURL']
+                );
+
+                $result[] = $methodFromMarketplace;
+            }
+        }
+
+        return $result;
+    }
+
+    /**
+     * Get shipping solutions from the marketplace
+     *
+     * @param array $addonsFromMarketplace List of addons received from the marketplace
+     *
+     * @return array
+     */
+    protected function getShippingSolutions($addonsFromMarketplace)
+    {
+        $result = [];
+
+        foreach ($addonsFromMarketplace as $addonId) {
+            $result[] = [
+                'processor'       => 'shipping_solution',
+                'moduleName'      => $addonId,
+                'fromMarketplace' => 1,
+            ];
+        }
+
+        return $result;
+    }
+
     // }}}
+
+    /**
+     * return last offline pos if next pos not equal 100-200-etc
+     *
+     * @param string $processor
+     *
+     * @return int
+     */
+    public function getMaxPosition($processor)
+    {
+        $processorPos = $this->createPureQueryBuilder('m')
+            ->select('MAX(m.position)')
+            ->andWhere('m.processor = :processor')
+            ->setParameter('processor', $processor)
+            ->setMaxResults(1)
+            ->getSingleScalarResult();
+
+        if (empty($processorPos)) {
+            if ($processor === 'offline') {
+                return 0;
+            }
+
+            $pos = $this->createPureQueryBuilder('m')
+                ->select('MAX(m.position)')
+                ->setMaxResults(1)
+                ->getSingleScalarResult();
+
+            return empty($pos) ? 1000 : ceil($pos / 1000) * 1000;
+        }
+
+        return $processorPos;
+    }
+
+    public function getTranslationDataFromYamlStructure(array $entity, string $lngCode): ?array
+    {
+        if (
+            !empty($entity['processor'])
+            && !empty($entity['code'])
+            && ($result = $this->getTranslationFromYamlStructure($entity, $lngCode))
+            && !empty($result['name'])
+        ) {
+            return [
+                $entity['processor'],
+                $entity['code'],
+                $result['name'],
+                $result['deliveryTime'] ?? '',
+                $result['adminDescription'] ?? ''
+            ];
+        }
+
+        return null;
+    }
+
+    public function getTranslationDataFromModel(MethodTranslation $translation): ?array
+    {
+        /** @var \XLite\Model\Shipping\Method $shippingMethod */
+        $shippingMethod = $translation->getOwner();
+
+        return [
+            $shippingMethod->getProcessor(),
+            $shippingMethod->getCode(),
+            $translation->getName(),
+            $translation->getDeliveryTime(),
+            $translation->getAdminDescription()
+        ];
+    }
+
+    public function generateYamlEntityForTranslationModule(array $data, string $lngCode): ?array
+    {
+        if (empty($data[0]) || empty($data[1]) || empty($data[2])) {
+            return null;
+        }
+
+        return [
+            'processor'    => $data[0],
+            'code'         => $data[1],
+            'translations' => [
+                array_filter([
+                    'code'             => $lngCode,
+                    'name'             => $data[2],
+                    'deliveryTime'     => $data[3] ?? '',
+                    'adminDescription' => $data[4] ?? '',
+                ]),
+            ],
+        ];
+    }
 }
