@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -10,21 +9,15 @@ namespace XLite\Model\Repo;
 
 /**
  * Country repository
- *
- * @Api\Operation\Create(modelClass="XLite\Model\State", summary="Add new state")
- * @Api\Operation\Read(modelClass="XLite\Model\State", summary="Retrieve state by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\State", summary="Retrieve states by conditions")
- * @Api\Operation\Update(modelClass="XLite\Model\State", summary="Update state by id")
- * @Api\Operation\Delete(modelClass="XLite\Model\State", summary="Delete state by id")
  */
 class State extends \XLite\Model\Repo\ARepo
 {
     /**
      * Allowable search params
      */
-    
-    const P_SUBSTRING       = 'substring';
-    const P_COUNTRY_CODE    = 'countryCode';
+
+    public const P_SUBSTRING       = 'substring';
+    public const P_COUNTRY_CODE    = 'countryCode';
 
     /**
      * Repository type
@@ -45,9 +38,9 @@ class State extends \XLite\Model\Repo\ARepo
      *
      * @var array
      */
-    protected $alternativeIdentifier = array(
-        array('code', 'country_code'),
-    );
+    protected $alternativeIdentifier = [
+        ['code', 'country_code'],
+    ];
 
     /**
      * Get dump 'Other' state
@@ -59,7 +52,7 @@ class State extends \XLite\Model\Repo\ARepo
     public function getOtherState($customState = null)
     {
         $state = new \XLite\Model\State();
-        $state->state = isset($customState) ? $customState : 'Other';
+        $state->state = $customState ?? 'Other';
         $state->state_id = -1;
 
         return $state;
@@ -74,7 +67,7 @@ class State extends \XLite\Model\Repo\ARepo
      */
     public function isOtherStateId($stateId)
     {
-        return -1 == $stateId;
+        return $stateId == -1;
     }
 
     /**
@@ -86,13 +79,13 @@ class State extends \XLite\Model\Repo\ARepo
      */
     public function getCodeById($stateId)
     {
-        $result = $this->getFromCache('codes', array('state_id' => $stateId));
+        $result = $this->getFromCache('codes', ['state_id' => $stateId]);
 
         if (!isset($result)) {
             $entity = $this->defineGetCodeByIdQuery($stateId)->getSingleResult();
             $result = $entity ? $entity->getCode() : '';
 
-            $this->saveToCache($result, 'codes', array('state_id' => $stateId));
+            $this->saveToCache($result, 'codes', ['state_id' => $stateId]);
         }
 
         return $result;
@@ -172,7 +165,7 @@ class State extends \XLite\Model\Repo\ARepo
     {
         $country = \XLite\Core\Database::getRepo('XLite\Model\Country')->find($countryCode);
 
-        return $country ? $this->defineByCountryQuery($country)->getResult() : array();
+        return $country ? $this->defineByCountryQuery($country)->getResult() : [];
     }
 
     /**
@@ -198,7 +191,7 @@ class State extends \XLite\Model\Repo\ARepo
      */
     public function getCountByCountryAndStateId($countryCode, $stateId)
     {
-        return $this->defineGetCountByCountryAndStateId($countryCode, $stateId)->getSingleResult()['cnt'];
+        return $this->defineGetCountByCountryAndStateId($countryCode, $stateId)->getQuery()->getSingleResult()['cnt'];
     }
 
     /**
@@ -219,7 +212,7 @@ class State extends \XLite\Model\Repo\ARepo
      *
      * @param string $countryCode Country code
      * @param string $region Region code
-     * 
+     *
      * @return \XLite\Model\State|void
      */
     public function findByCountryCodeGroupedByRegion($countryCode)
@@ -241,13 +234,10 @@ class State extends \XLite\Model\Repo\ARepo
     {
         if (!empty($data['country_code']) && !empty($data['code'])) {
             $result = $this->findOneByCountryAndCode($data['country_code'], $data['code']);
-
-        } elseif ($parent && $parent instanceOf \XLite\Model\Country) {
+        } elseif ($parent && $parent instanceof \XLite\Model\Country) {
             $result = $this->findOneByCountryAndCode($parent->getCode(), $data['code']);
-
         } elseif (!empty($data['code']) && !empty($data['country']) && is_array($data['country']) && !empty($data['country']['code'])) {
             $result = $this->findOneByCountryAndCode($data['country']['code'], $data['code']);
-
         } else {
             $result = parent::findOneByRecord($data, $parent);
         }
@@ -257,27 +247,27 @@ class State extends \XLite\Model\Repo\ARepo
 
     /**
      * Grouping states by region
-     * 
+     *
      * @param array $states States to group
-     * 
+     *
      * @return array
      */
     protected function getGroupedByRegion(array $states)
     {
-        $regions = array();
+        $regions = [];
 
         foreach ($states as $state) {
-            if (null === $state->getRegion()) {
+            if ($state->getRegion() === null) {
                 $regions[] = $state;
-            }else{
+            } else {
                 $code = $state->getRegion()->getCode();
                 if (isset($regions[$code])) {
                     $regions[$code]['options'][] = $state;
-                }else{
-                    $regions[$code] = array(
+                } else {
+                    $regions[$code] = [
                         'label'     => $state->getRegion()->getName(),
-                        'options'   => array($state)
-                    );
+                        'options'   => [$state]
+                    ];
                 }
             }
         }
@@ -411,17 +401,17 @@ class State extends \XLite\Model\Repo\ARepo
     {
         $list = parent::defineCacheCells();
 
-        $list['all'] = array(
-            static::RELATION_CACHE_CELL => array('\XLite\Model\Country'),
-        );
+        $list['all'] = [
+            static::RELATION_CACHE_CELL => ['\XLite\Model\Country'],
+        ];
 
-        $list['allGrouped'] = array(
-            static::RELATION_CACHE_CELL => array('\XLite\Model\Country'),
-        );
+        $list['allGrouped'] = [
+            static::RELATION_CACHE_CELL => ['\XLite\Model\Country'],
+        ];
 
-        $list['codes'] = array(
-            static::ATTRS_CACHE_CELL => array('state_id'),
-        );
+        $list['codes'] = [
+            static::ATTRS_CACHE_CELL => ['state_id'],
+        ];
 
         return $list;
     }
@@ -430,7 +420,6 @@ class State extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters states by country code", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param \XLite\Model\Profile       $value        Profile
@@ -440,7 +429,6 @@ class State extends \XLite\Model\Repo\ARepo
     protected function prepareCndCountryCode(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
         if (!empty($value)) {
-
             $queryBuilder->innerJoin('s.country', 'c')
                 ->andWhere('c.code = :countryCode')
                 ->setParameter('countryCode', $value);
@@ -450,7 +438,6 @@ class State extends \XLite\Model\Repo\ARepo
 
     /**
      * Prepare certain search condition
-     * @Api\Condition(description="Filters states by substring", type="string")
      *
      * @param \Doctrine\ORM\QueryBuilder $queryBuilder Query builder to prepare
      * @param \XLite\Model\Profile       $value        Profile
@@ -460,7 +447,6 @@ class State extends \XLite\Model\Repo\ARepo
     protected function prepareCndSubstring(\Doctrine\ORM\QueryBuilder $queryBuilder, $value)
     {
         if (!empty($value)) {
-
             $queryBuilder->andWhere('s.state LIKE :substring')
                 ->setParameter('substring', '%' . $value . '%');
         }
