@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -7,13 +6,11 @@
  */
 
 namespace XLite\Model\Repo;
+
 use XLite\Core\Layout;
 
 /**
  * View list repository
- *
- * @Api\Operation\Read(modelClass="XLite\Model\ViewList", summary="Retrieve view list item by id")
- * @Api\Operation\ReadAll(modelClass="XLite\Model\ViewList", summary="Retrieve all view list items")
  */
 class ViewList extends \XLite\Model\Repo\ARepo
 {
@@ -44,7 +41,7 @@ class ViewList extends \XLite\Model\Repo\ARepo
     {
         $list = parent::defineCacheCells();
         $list['class_list'] = [
-            static::ATTRS_CACHE_CELL => ['list', 'zone'],
+            static::ATTRS_CACHE_CELL => ['list', 'interface', 'zone'],
         ];
 
         return $list;
@@ -56,16 +53,29 @@ class ViewList extends \XLite\Model\Repo\ARepo
      * Find class list
      *
      * @param string $list List name
-     * @param string $zone Current interface name OPTIONAL
+     * @param string $interface
+     * @param string $zone
      *
      * @return array
      */
-    public function findClassList($list, $zone = \XLite\Model\ViewList::INTERFACE_CUSTOMER)
+    public function findClassList($list, $interface = \Xlite::INTERFACE_WEB, $zone = \XLite::ZONE_CUSTOMER)
     {
-        $data = $this->getFromCache('class_list', ['list' => $list, 'zone' => $zone, 'preset' => $this->getCurrentPreset()]);
+        $params = [
+            'list' => $list,
+            'interface' => $interface,
+            'zone' => $zone,
+            'preset' => $this->getCurrentPreset()
+        ];
+
+        if ($interface !== \XLite::INTERFACE_WEB) {
+            $zone = '';
+            unset($params['zone']);
+        }
+
+        $data = $this->getFromCache('class_list', $params);
         if (!isset($data)) {
-            $data = $this->retrieveClassList($list, $zone);
-            $this->saveToCache($data, 'class_list', ['list' => $list, 'zone' => $zone, 'preset' => $this->getCurrentPreset()]);
+            $data = $this->retrieveClassList($list, $interface, $zone);
+            $this->saveToCache($data, 'class_list', $params);
         }
 
         return $data;
@@ -75,24 +85,29 @@ class ViewList extends \XLite\Model\Repo\ARepo
      * Find class list
      *
      * @param string $list List name
-     * @param string $zone Current interface name OPTIONAL
+     * @param string $interface
+     * @param string $zone
      *
      * @return array
      */
-    public function findClassListWithFallback($list, $zone = \XLite\Model\ViewList::INTERFACE_CUSTOMER)
+    public function findClassListWithFallback($list, $interface = \XLite::INTERFACE_WEB, $zone = \XLite::ZONE_CUSTOMER)
     {
-        $data = $this->getFromCache(
-            'class_list_with_fallback',
-            ['list' => $list, 'zone' => $zone]
-        );
+        $params = [
+            'list' => $list,
+            'interface' => $interface,
+            'zone' => $zone
+        ];
+
+        if ($interface !== \XLite::INTERFACE_WEB) {
+            $zone = '';
+            unset($params['zone']);
+        }
+
+        $data = $this->getFromCache('class_list_with_fallback', $params);
 
         if (!isset($data)) {
-            $data = $this->retrieveClassListWithFallback($list, $zone);
-            $this->saveToCache(
-                $data,
-                'class_list_with_fallback',
-                ['list' => $list, 'zone' => $zone]
-            );
+            $data = $this->retrieveClassListWithFallback($list, $interface, $zone);
+            $this->saveToCache($data, 'class_list_with_fallback', $params);
         }
 
         return $data;
@@ -117,34 +132,37 @@ class ViewList extends \XLite\Model\Repo\ARepo
      * Perform Class list query
      *
      * @param string $list List name
-     * @param string $zone Current interface name
+     * @param string $interface
+     * @param string $zone
      *
      * @return array
      */
-    public function retrieveClassList($list, $zone)
+    public function retrieveClassList($list, $interface, $zone)
     {
-        return $this->defineClassListQuery($list, $zone)->getResult();
+        return $this->defineClassListQuery($list, $interface, $zone)->getResult();
     }
 
     /**
      * Perform Class list query
      *
      * @param string $list List name
-     * @param string $zone Current interface name
+     * @param string $interface
+     * @param string $zone
      *
      * @return array
      */
-    public function retrieveClassListWithFallback($list, $zone)
+    public function retrieveClassListWithFallback($list, $interface, $zone)
     {
         $result = [];
 
-        $actual = $this->defineClassListWithFallbackQuery($list, $zone)->getResult();
+        $actual = $this->defineClassListWithFallbackQuery($list, $interface, $zone)->getResult();
 
         foreach ($actual as $viewList) {
             $key = $viewList->getHashWithoutZone();
 
-            if (!isset($result[$key])
-                || $result[$key]->getZone() === \XLite::COMMON_INTERFACE
+            if (
+                !isset($result[$key])
+                || $result[$key]->getZone() === \XLite::ZONE_COMMON
             ) {
                 $result[$key] = $viewList;
             }
@@ -164,16 +182,18 @@ class ViewList extends \XLite\Model\Repo\ARepo
     {
         $qb = $this->createQueryBuilder()
             ->addSelect('CASE WHEN v.override_mode > 0 THEN v.weight_override ELSE v.weight END AS HIDDEN ORD')
-            ->andWhere('IF (v.list_override != :empty AND v.override_mode > 0, v.list_override, v.list) IN (:list)')
+            ->andWhere('IFELSE(v.list_override != :empty AND v.override_mode > 0, v.list_override, v.list) IN (:list)')
             ->andWhere('v.list_id NOT IN (SELECT DISTINCT IDENTITY(vl.parent) FROM XLite\Model\ViewList vl WHERE IDENTITY(vl.parent) IS NOT NULL AND vl.preset LIKE :preset AND vl.override_mode != :disable_preset_mode)')
             ->andWhere('v.list_id NOT IN (SELECT DISTINCT vll.list_id FROM XLite\Model\ViewList vll WHERE IDENTITY(vll.parent) IS NOT NULL AND (vll.preset NOT LIKE :preset OR vll.override_mode = :disable_preset_mode))')
             ->andWhere('v.version IS NULL')
             ->andWhere('v.override_mode IN (:modes)')
+            ->andWhere('v.deleted = :deleted')
             ->orderBy('ORD', 'asc')
             ->setParameter('empty', '')
             ->setParameter('list', explode(',', $list))
             ->setParameter('preset', $this->getCurrentPreset())
             ->setParameter('modes', $this->getDisplayableModes())
+            ->setParameter('deleted', false)
             ->setParameter('disable_preset_mode', \XLite\Model\ViewList::OVERRIDE_DISABLE_PRESET);
 
         return $qb;
@@ -183,15 +203,22 @@ class ViewList extends \XLite\Model\Repo\ARepo
      * Define query builder for findClassList()
      *
      * @param string $list Class list name
-     * @param string $zone Current interface name
+     * @param string $interface
+     * @param string $zone
      *
      * @return \Doctrine\ORM\QueryBuilder
      */
-    protected function defineClassListQuery($list, $zone)
+    protected function defineClassListQuery($list, $interface, $zone)
     {
         $qb = $this->defineZoneAgnosticClassListQuery($list)
-            ->andWhere('v.zone LIKE :zone')
-            ->setParameter('zone', $zone);
+            ->andWhere('v.interface LIKE :interface')
+            ->setParameter('interface', $interface);
+
+        if ($zone) {
+            $qb
+                ->andWhere('v.zone LIKE :zone')
+                ->setParameter('zone', $zone);
+        }
 
         return $qb;
     }
@@ -200,16 +227,21 @@ class ViewList extends \XLite\Model\Repo\ARepo
      * Define query builder for findClassList()
      *
      * @param string $list Class list name
-     * @param string $zone Current interface name
+     * @param string $interface
+     * @param string $zone
      *
      * @return \Doctrine\ORM\QueryBuilder
      */
-    protected function defineClassListWithFallbackQuery($list, $zone)
+    protected function defineClassListWithFallbackQuery($list, $interface, $zone)
     {
         $qb = $this->defineZoneAgnosticClassListQuery($list)
+            ->andWhere('v.interface = :interface')
+            ->setParameter('interface', $interface);
+
+        $qb
             ->andWhere('v.zone IN (:zone, :fallback)')
             ->setParameter('zone', $zone)
-            ->setParameter('fallback', \XLite::COMMON_INTERFACE);
+            ->setParameter('fallback', \XLite::ZONE_COMMON);
 
         return $qb;
     }
@@ -306,39 +338,6 @@ class ViewList extends \XLite\Model\Repo\ARepo
         return $this->defineOverriddenQueryBuilder()->getResult();
     }
 
-    /**
-     * Find overridden view list items
-     *
-     * @return array
-     */
-    public function findOverriddenData()
-    {
-        $qb = $this->defineOverriddenQueryBuilder();
-        $alias = $qb->getMainAlias();
-
-        $properties = [
-            'list_override',
-            'weight_override',
-            'override_mode',
-            'list',
-            'child',
-            'tpl',
-            'zone',
-            'weight',
-            'preset'
-        ];
-
-        $qb->select("v.list_id");
-
-        foreach ($properties as $property) {
-            $qb->addSelect("{$alias}.{$property}");
-        }
-
-        $qb->addSelect('IDENTITY(v.parent)');
-
-        return $qb->getArrayResult();
-    }
-
     /**
      * Define overridden query builder
      *
@@ -367,12 +366,40 @@ class ViewList extends \XLite\Model\Repo\ARepo
         }
 
         $conditions = [
-            'list'   => $other->getList(),
-            'child'  => $other->getChild(),
-            'tpl'    => $other->getTpl(),
-            'zone'   => $other->getZone(),
-            'weight' => $other->getWeight(),
-            'preset' => $other->getPreset()
+            'list'     => $other->getList(),
+            'child'    => $other->getChild(),
+            'entityId' => $other->getEntityId(),
+            'tpl'      => $other->getTpl(),
+            'zone'     => $other->getZone(),
+            'weight'   => $other->getWeight(),
+            'preset'   => $other->getPreset(),
+        ];
+
+        return $this->findEqualByData($conditions, $versioned);
+    }
+
+    /**
+     * Find first entity equal to $other
+     *
+     * @param \XLite\Model\ViewList $other     Other entity
+     * @param boolean               $versioned Add `version is not null` condition
+     *
+     * @return \XLite\Model\ViewList|null
+     */
+    public function findEqualParent(\XLite\Model\ViewList $other, $versioned = false)
+    {
+        if (!$other) {
+            return null;
+        }
+
+        $conditions = [
+            'list'          => $other->getList(),
+            'child'         => $other->getChild(),
+            'entityId'      => $other->getEntityId(),
+            'tpl'           => $other->getTpl(),
+            'zone'          => $other->getZone(),
+            'parent'        => null,
+            'override_mode' => \XLite\Model\ViewList::OVERRIDE_OFF,
         ];
 
         return $this->findEqualByData($conditions, $versioned);
@@ -388,7 +415,7 @@ class ViewList extends \XLite\Model\Repo\ARepo
      */
     public function findEqualByData($conditions, $versioned = false)
     {
-        $params = array_filter($conditions, function ($item) {
+        $params = array_filter($conditions, static function ($item) {
             return $item !== null;
         });
 
@@ -408,5 +435,56 @@ class ViewList extends \XLite\Model\Repo\ARepo
 
         return $qb->getSingleResult();
     }
-}
 
+    /**
+     * Update template rows for banner system
+     *
+     * @param array $childs childs to update
+     *
+     */
+    public function updateOverrideModeByChilds($childs)
+    {
+        $expr = new \Doctrine\ORM\Query\Expr();
+        $this->createPureQueryBuilder('p')
+            ->update($this->_entityName, 'p')
+            ->set('p.override_mode', ':override_mode')
+            ->setParameter('override_mode', \XLite\Model\ViewList::OVERRIDE_DISABLE_PRESET)
+            ->where($expr->in('p.child', $childs))
+            ->andWhere('p.version IS NULL')
+            ->andWhere('p.entityId IS NULL')
+            ->andWhere('p.tpl = :tpl')->setParameter('tpl', '')// to use tclz key
+            ->execute();
+    }
+
+    /**
+     * Find view lists by child
+     */
+    public function findByChildTpl($child, $tpl)
+    {
+        return $this->createQueryBuilder()
+            ->where('v.child = :child')
+            ->setParameter('child', $child)
+            ->andWhere('v.tpl = :tpl')->setParameter('tpl', $tpl)// to use tclz key
+            ->getResult();
+    }
+
+    /**
+     * @param array $criteria
+     *
+     * @return mixed
+     */
+    public function removeByCriteria(array $criteria)
+    {
+        $queryBuilder = $this->createPureQueryBuilder('v')
+            ->delete($this->_entityName, 'v');
+
+        $where = [];
+        $params = [];
+        foreach ($criteria as $field => $value) {
+            $where[] = "v.{$field} = :{$field}";
+            $params[$field] = $value;
+        }
+
+        return $queryBuilder->where(...$where)->setParameters($params)->execute();
+    }
+}
