@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,24 +7,29 @@
 
 namespace XLite\Model;
 
+use Includes\Utils\ArrayManager;
+use XLite\Core\Cache\ExecuteCachedTrait;
+
 /**
  * Common shipping method
  */
 class Shipping extends \XLite\Base\Singleton
 {
+    use ExecuteCachedTrait;
+
     /**
      * RuntimeDefaultAddressCache
      *
      * @var array
      */
-    static $runtimeDefaultAddressCache = false;
+    public static $runtimeDefaultAddressCache = false;
 
     /**
      * List of registered shipping processors
      *
      * @var \XLite\Model\Shipping\Processor\AProcessor[]
      */
-    protected static $registeredProcessors = array();
+    protected static $registeredProcessors = [];
 
     /**
      * Flag: Ignore long shipping rates calculations mode (if true)
@@ -35,6 +39,8 @@ class Shipping extends \XLite\Base\Singleton
      */
     protected static $ignoreLongCalculations = false;
 
+    protected static bool $isCalculatedShippingRatesApiRequest = false;
+
     /**
      * Set $ignoreLongCalculations variable
      *
@@ -67,11 +73,12 @@ class Shipping extends \XLite\Base\Singleton
      */
     public static function registerProcessor($processorClass)
     {
-        if (!isset(static::$registeredProcessors[$processorClass])
-            && \XLite\Core\Operator::isClassExists($processorClass)
+        if (
+            !isset(static::$registeredProcessors[$processorClass])
+            && class_exists($processorClass)
         ) {
             static::$registeredProcessors[$processorClass] = new $processorClass();
-            uasort(static::$registeredProcessors, array(\XLite\Model\Shipping::getInstance(), 'compareProcessors'));
+            uasort(static::$registeredProcessors, [\XLite\Model\Shipping::getInstance(), 'compareProcessors']);
         }
     }
 
@@ -137,7 +144,22 @@ class Shipping extends \XLite\Base\Singleton
      */
     public function getRates(\XLite\Logic\Order\Modifier\Shipping $modifier)
     {
-        $rates = array();
+        $ratesArray = [];
+
+        $countryAddressField = \XLite\Core\Database::getRepo('XLite\Model\AddressField')
+            ->findOneBy(['serviceName' => 'country_code']);
+
+        if ($countryAddressField && $countryAddressField->getEnabled()) {
+            $address = $this->getDestinationAddress($modifier);
+
+            /** @var \XLite\Model\Country $shippingCountry */
+            $shippingCountry = \XLite\Core\Database::getRepo('XLite\Model\Country')
+                ->findOneByCode($address['country'] ?? '');
+
+            if (!$shippingCountry || !$shippingCountry->getEnabled()) {
+                return [];
+            }
+        }
 
         foreach (static::$registeredProcessors as $processor) {
             if (!$this->isProcessorEnabled($processor, $modifier)) {
@@ -148,13 +170,15 @@ class Shipping extends \XLite\Base\Singleton
                 static::setIgnoreLongCalculationsMode(true);
             }
             // Get rates from processors
-            $rates = array_merge($rates, $this->getProcessorRates($processor, $modifier));
+            $ratesArray[] = $this->getProcessorRates($processor, $modifier);
 
             if ($processor->hasError()) {
                 $processor->flushErrorLog();
             }
         }
 
+        $rates = array_merge(...$ratesArray);
+
         $rates = $this->applyMarkups($modifier, $rates);
 
         $rates = $this->postProcessRates($rates);
@@ -162,13 +186,29 @@ class Shipping extends \XLite\Base\Singleton
         return $rates;
     }
 
-    protected function shouldAllowLongCalculations()
+    public function shouldAllowLongCalculations()
     {
-        $refererTarget = \XLite\Core\Request::getInstance()->getAjaxRefererTarget();
+        $refererTarget       = \XLite\Core\Request::getInstance()->getAjaxRefererTarget();
         $isValidAjaxRequests = in_array($refererTarget, ['cart', 'checkout'], true);
 
         return (\XLite::getController()->isAJAX() && $isValidAjaxRequests)
-            || \XLite::isAdminZone();
+            || (!\XLite::getController()->isAJAX() && \XLite::getController()->getTarget() === 'checkout')
+            || \XLite::isAdminZone()
+            || $this->isCalculatedShippingRatesApiRequest();
+    }
+
+    protected function isCalculatedShippingRatesApiRequest()
+    {
+        return $this->executeCachedRuntime(static function () {
+            $requestStack = \XCart\Container::getContainer()->get('request_stack');
+            $route        = $requestStack?->getCurrentRequest()?->attributes?->get('_route');
+
+            return in_array(
+                $route,
+                ['api_orders_post_collection', 'api_calculated shipping rates_post_collection'],
+                true
+            );
+        });
     }
 
     /**
@@ -190,7 +230,6 @@ class Shipping extends \XLite\Base\Singleton
         return $result;
     }
 
-
     /**
      * Get lists of address fields required by all enabled shipping processors
      *
@@ -198,7 +237,7 @@ class Shipping extends \XLite\Base\Singleton
      */
     public static function getRequiredAddressFields()
     {
-        $fields = array();
+        $fields = [];
 
         foreach (static::getProcessors() as $processor) {
             if ($processor->isConfigured()) {
@@ -226,9 +265,7 @@ class Shipping extends \XLite\Base\Singleton
             $address = $profile->getShippingAddress()->toArray();
         }
 
-        return null === $address
-            ? static::getDefaultAddress()
-            : $address;
+        return $address ?? static::getDefaultAddress();
     }
 
     /**
@@ -239,11 +276,11 @@ class Shipping extends \XLite\Base\Singleton
     public static function getDefaultAddress()
     {
         if (static::$runtimeDefaultAddressCache === false) {
-            $config = \XLite\Core\Config::getInstance()->Shipping;
-            $state = \XLite\Model\Address::getDefaultFieldValue('state');
+            $config  = \XLite\Core\Config::getInstance()->Shipping;
+            $state   = \XLite\Model\Address::getDefaultFieldValue('state');
             $country = \XLite\Model\Address::getDefaultFieldValue('country');
 
-            static::$runtimeDefaultAddressCache = array(
+            static::$runtimeDefaultAddressCache = [
                 'address'      => $config->anonymous_address,
                 'city'         => \XLite\Model\Address::getDefaultFieldValue('city'),
                 'state'        => $state ? $state->getCode() : '',
@@ -251,7 +288,7 @@ class Shipping extends \XLite\Base\Singleton
                 'zipcode'      => \XLite\Model\Address::getDefaultFieldValue('zipcode'),
                 'country'      => $country ? $country->getCode() : '',
                 'type'         => $config->anonymous_address_type,
-            );
+            ];
         }
 
         return static::$runtimeDefaultAddressCache;
@@ -274,10 +311,8 @@ class Shipping extends \XLite\Base\Singleton
 
         if ($a1 === $bottomProcessorId) {
             $result = 1;
-
         } elseif ($b1 === $bottomProcessorId) {
             $result = -1;
-
         } else {
             $result = strcasecmp($a1, $b1);
         }
@@ -310,7 +345,7 @@ class Shipping extends \XLite\Base\Singleton
     {
         $rates = $processor->getRates($modifier);
 
-        return $rates && is_array($rates) ? $rates : array();
+        return $rates && is_array($rates) ? $rates : [];
     }
 
     /**
@@ -324,13 +359,13 @@ class Shipping extends \XLite\Base\Singleton
     protected function applyMarkups($modifier, $rates)
     {
         if (!empty($rates)) {
-            $markups = array();
+            $markups = [];
 
             // Calculate markups
             foreach ($rates as $id => $rate) {
                 // If markup has already been calculated for rate then continue iteration
 
-                if (null !== $rate->getMarkup()) {
+                if ($rate->getMarkup() !== null) {
                     continue;
                 }
 
@@ -366,15 +401,16 @@ class Shipping extends \XLite\Base\Singleton
      */
     protected function postProcessRates($rates)
     {
-        $savedRatesValues = \XLite\Core\Session::getInstance()->savedRatesValues ?: array();
-        $hash = array();
+        $savedRatesValues = \XLite\Core\Session::getInstance()->savedRatesValues ?: [];
+        $hash = [];
 
         if (!empty($rates)) {
             // Generate hash of rate values: methodId => baseRate
             foreach ($rates as $rate) {
                 $hash[$rate->getMethodId()] = 1;
                 $extraData = $rate->getExtraData();
-                if ($extraData
+                if (
+                    $extraData
                     && isset($extraData->cod_rate)
                     && $extraData->cod_rate
                     && $extraData->cod_rate > $rate->getBaseRate()
@@ -390,7 +426,7 @@ class Shipping extends \XLite\Base\Singleton
                 }
             }
         } else {
-            $savedRatesValues = array();
+            $savedRatesValues = [];
         }
 
         // Save rate values in the session
@@ -398,4 +434,32 @@ class Shipping extends \XLite\Base\Singleton
 
         return $rates;
     }
+
+    /**
+     * @param \XLite\Logic\Order\Modifier\Shipping $modifier
+     *
+     * @return array
+     */
+    protected function getHashData(\XLite\Logic\Order\Modifier\Shipping $modifier)
+    {
+        return [
+            'destAddress'        => $this->getDestinationAddress($modifier),
+            'weight'             => $modifier->getWeight(),
+            'countItems'         => $modifier->countItems(),
+            'subtotal'           => $modifier->getSubtotal(),
+            'discountedSubtotal' => $modifier->getDiscountedSubtotal(),
+        ];
+    }
+
+    /**
+     * Get hash of shipping modifier
+     *
+     * @param \XLite\Logic\Order\Modifier\Shipping $modifier
+     *
+     * @return string
+     */
+    public function getHash(\XLite\Logic\Order\Modifier\Shipping $modifier)
+    {
+        return ArrayManager::md5($this->getHashData($modifier));
+    }
 }
