@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,14 +7,20 @@
 
 namespace XLite\Model\Shipping\Processor;
 
+use XLite\Core\Database;
+use Includes\Utils\Module\Module;
+use XLite\InjectLoggerTrait;
+
 /**
  * Shipping processor model
  */
 abstract class AProcessor extends \XLite\Base\SuperClass
 {
-    const STATE_ALL = 'all';
-    const STATE_ENABLED_ONLY = 'enabled_only';
-    const MINIMUM_ITEM_WEIGHT = 0.01;
+    use InjectLoggerTrait;
+
+    public const STATE_ALL = 'all';
+    public const STATE_ENABLED_ONLY = 'enabled_only';
+    public const MINIMUM_ITEM_WEIGHT = 0.01;
 
     /**
      * Processor's shipping methods (runtime cache)
@@ -25,14 +30,13 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     protected $methods;
 
     /**
-     * Module processor cache object
-     * false                        - it is not initialized yet
-     * null                         - no payment processor
-     * \XLite\Model\Module class    - shipping processor assigned
+     * null   - it is not initialized yet
+     * false  - no module
+     * string - module id
      *
-     * @var boolean|null|\XLite\Model\Module
+     * @var boolean|null|string
      */
-    protected $moduleCache = false;
+    protected $moduleId;
 
     /**
      * Log of request/response pairs during communication with a shipping server
@@ -49,6 +53,13 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected $errorMsg;
 
+    /**
+     * max position of current processor carriers
+     *
+     * @var int
+     */
+    protected $position = 0;
+
     /**
      * Returns processor Id
      *
@@ -61,7 +72,16 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      *
      * @return string
      */
-    abstract public function getProcessorName();
+    public function getProcessorName()
+    {
+        $carrier = Database::getRepo('XLite\Model\Shipping\Method')->findOnlineCarrier(
+            $this->getProcessorId()
+        );
+
+        return $carrier
+            ? $carrier->getName()
+            : '';
+    }
 
     /**
      * Define public constructor
@@ -78,10 +98,10 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     public function getSettingsTemplate()
     {
-        $module = $this->getModule();
+        [$author, $name] = Module::explodeModuleId($this->getModule());
 
-        return $module
-            ? sprintf('modules/%s/%s/settings.twig', $module->getAuthor(), $module->getName())
+        return $author && $name
+            ? sprintf('modules/%s/%s/settings.twig', $author, $name)
             : '';
     }
 
@@ -92,10 +112,10 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     public function getTestTemplate()
     {
-        $module = $this->getModule();
+        [$author, $name] = Module::explodeModuleId($this->getModule());
 
-        return $module
-            ? sprintf('modules/%s/%s/test.twig', $module->getAuthor(), $module->getName())
+        return $author && $name
+            ? sprintf('modules/%s/%s/test.twig', $author, $name)
             : '';
     }
 
@@ -146,17 +166,15 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     /**
      * Get processor module
      *
-     * @return \XLite\Model\Module|null
+     * @return string|null|bool
      */
     public function getModule()
     {
-        if (false === $this->moduleCache) {
-            $this->moduleCache = preg_match('/XLite\\\Module\\\(\w+)\\\(\w+)\\\/S', get_called_class(), $match)
-                ? \XLite\Core\Database::getRepo('XLite\Model\Module')->findModuleByName($match[1] . '\\' . $match[2])
-                : null;
+        if ($this->moduleId === null) {
+            $this->moduleId = Module::getModuleIdByClassName(static::class) ?: false;
         }
 
-        return $this->moduleCache;
+        return $this->moduleId;
     }
 
     /**
@@ -178,7 +196,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     public function getRequiredAddressFields()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -215,11 +233,10 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     public function getRates($inputData, $ignoreCache = false)
     {
         $this->setError();
-        $rates = array();
+        $rates = [];
 
         if (!$this->isConfigured()) {
             $this->setError(sprintf('%s module is not configured', $this->getProcessorName()));
-
         } elseif ($this->hasMethods(static::STATE_ENABLED_ONLY)) {
             $data = $this->prepareInputData($inputData);
             if ($data) {
@@ -262,7 +279,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected function prepareDataFromModifier(\XLite\Logic\Order\Modifier\Shipping $inputData)
     {
-        return array();
+        return [];
     }
 
     /**
@@ -299,7 +316,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected function performRequest($data, $ignoreCache)
     {
-        return array();
+        return [];
     }
 
     /**
@@ -328,8 +345,8 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     {
         $methods = $this->fetchMethods();
 
-        return static::STATE_ENABLED_ONLY === $state
-            ? array_filter($methods, function ($item) {
+        return $state === static::STATE_ENABLED_ONLY
+            ? array_filter($methods, static function ($item) {
                 /** @var \XLite\Model\Shipping\Method $item */
                 return $item->isEnabled();
             })
@@ -355,13 +372,13 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected function fetchMethods()
     {
-        if (null === $this->methods) {
+        if ($this->methods === null) {
             /** @var \XLite\Model\Repo\Shipping\Method $repo */
             $repo = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method');
             $this->methods = $repo->findMethodsByProcessor($this->getProcessorId(), false);
         }
 
-        return $this->methods ?: array();
+        return $this->methods ?: [];
     }
 
     /**
@@ -377,7 +394,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
         $methods = $this->getMethods($state);
 
         return is_array($methods)
-            ? array_reduce($methods, function ($carry, $item) use ($code) {
+            ? array_reduce($methods, static function ($carry, $item) use ($code) {
                 /** @var \XLite\Model\Shipping\Method $item */
                 return $carry ?: ($code === $item->getCode() ? $item : null);
             }, null)
@@ -396,12 +413,14 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     protected function createMethod($code, $name, $enabled = true)
     {
         $method = $this->getMethodByCode($code);
-        if (null === $method) {
+        if ($method === null) {
             /** @var \XLite\Model\Repo\Shipping\Method $repo */
             $repo = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method');
 
+            $this->position = $this->getPositionCounter() + 10;
+
             $method = $repo->createShippingMethod(
-                $this->prepareCreateMethodData($code, $name, $enabled)
+                $this->prepareCreateMethodData($code, $name, $enabled, $this->position)
             );
             $this->methods[] = $method;
         }
@@ -409,25 +428,39 @@ abstract class AProcessor extends \XLite\Base\SuperClass
         return $method;
     }
 
+    /**
+     * @return int
+     */
+    protected function getPositionCounter()
+    {
+        if (!$this->position) {
+            $repo = \XLite\Core\Database::getRepo('XLite\Model\Shipping\Method');
+            $this->position = $repo->getMaxPosition($this->getProcessorName());
+        }
+
+        return $this->position;
+    }
+
     /**
      * Prepare data for methods creation
      *
-     * @param string  $code    Method code
-     * @param string  $name    Method name
-     * @param boolean $enabled Enabled state OPTIONAL
+     * @param string  $code     Method code
+     * @param string  $name     Method name
+     * @param boolean $enabled  Enabled state OPTIONAL
+     * @param int     $position Position OPTIONAL
      *
      * @return array
      */
-    protected function prepareCreateMethodData($code, $name, $enabled = true)
+    protected function prepareCreateMethodData($code, $name, $enabled = true, $position = 0)
     {
-        return array(
+        return [
             'processor' => $this->getProcessorId(),
             'carrier'   => $this->getProcessorId(),
             'code'      => $code,
             'enabled'   => (bool) $enabled,
-            'position'  => 0,
+            'position'  => $position,
             'name'      => $name,
-        );
+        ];
     }
 
     /**
@@ -489,13 +522,15 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     /**
      * Returns configuration category
      *
-     * @return string
+     * @return array
      */
     protected function getConfigurationPath()
     {
-        return preg_match('/XLite\\\Module\\\(\w+)\\\(\w+)\\\/S', get_called_class(), $match)
-            ? array($match[1] ,$match[2])
-            : null;
+        $moduleId = Module::getModuleIdByClassName(get_called_class());
+
+        return $moduleId
+            ? explode(Module::ID_SEPARATOR, $moduleId)
+            : [];
     }
 
     // }}}
@@ -523,7 +558,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected function getPackageLimits()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -566,6 +601,25 @@ abstract class AProcessor extends \XLite\Base\SuperClass
         return null;
     }
 
+    /**
+     * This method must return params of the URL to the detailed tracking information about the package.
+     * Tracking number is provided.
+     *
+     * @param string $trackingNumber
+     *
+     * @return null|string
+     */
+    public function getTrackingURLParams($trackingNumber)
+    {
+        $params = $this->getTrackingInformationParams($trackingNumber);
+        $params = array_map(static function ($paramName, $paramValue) {
+            return "{$paramName}={$paramValue}";
+        }, array_keys($params), $params);
+
+
+        return implode('&', $params);
+    }
+
     /**
      * This method must return the form method 'post' or 'get' value.
      *
@@ -587,7 +641,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     public function getTrackingInformationParams($trackingNumber)
     {
-        return array();
+        return [];
     }
 
     // }}}
@@ -617,7 +671,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     protected function getDataFromCache($key)
     {
         $data = null;
-        $cacheDriver = \XLite\Core\Database::getCacheDriver();
+        $cacheDriver = \XLite\Core\Cache::getInstance()->getDriver();
         $key = $this->getKeyHash($key);
 
         if ($cacheDriver->contains($key)) {
@@ -638,24 +692,13 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      */
     protected function saveDataInCache($key, $data, $lifeTime = 0)
     {
-        \XLite\Core\Database::getCacheDriver()->save($this->getKeyHash($key), $data, $lifeTime);
+        \XLite\Core\Cache::getInstance()->getDriver()->save($this->getKeyHash($key), $data, $lifeTime);
     }
 
     // }}}
 
     // {{{ Logging
 
-    /**
-     * Returns an API communication log
-     * @deprecated use #getApiCommunicationMessage instead
-     *
-     * @return array
-     */
-    public function getApiCommunicationLog()
-    {
-        return $this->getApiCommunicationMessage();
-    }
-
     /**
      * Returns an API communication message
      *
@@ -686,28 +729,6 @@ abstract class AProcessor extends \XLite\Base\SuperClass
         return $this->errorMsg;
     }
 
-    /**
-     * Returns error message
-     * @deprecated Use #getError() instead
-     *
-     * @return string
-     */
-    public function getErrorMsg()
-    {
-        return $this->getError();
-    }
-
-    /**
-     * Write transaction log
-     * @deprecated
-     *
-     * @return void
-     */
-    public function logTransaction()
-    {
-        $this->flushErrorLog();
-    }
-
     /**
      * Write error log
      *
@@ -716,7 +737,7 @@ abstract class AProcessor extends \XLite\Base\SuperClass
     public function flushErrorLog()
     {
         if ($this->hasError()) {
-            \XLite\Logger::getInstance()->log($this->formatError($this->getError()));
+            $this->getLogger()->debug($this->formatError($this->getError()));
         }
     }
 
@@ -726,12 +747,18 @@ abstract class AProcessor extends \XLite\Base\SuperClass
      * @param mixed $message Message to log
      *
      * @return void
+     *
+     * @deprecated since CDev-Core 5.5.0
      */
     protected function log($message)
     {
-        $message = is_scalar($message) ? (string) $message : var_export($message, true);
+        trigger_deprecation('CDev-Core', '5.5.0', '"%s" is deprecated.', __METHOD__);
 
-        \XLite\Logger::logCustom($this->getProcessorId(), $message);
+        if (is_scalar($message)) {
+            $this->getLogger($this->getProcessorId())->debug($message);
+        } else {
+            $this->getLogger($this->getProcessorId())->debug('', (array) $message);
+        }
     }
 
     /**
