@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\Model;
 
-
 class TargetCleanUrl extends \XLite\Model\AEntity
 {
     /**
@@ -47,7 +45,7 @@ class TargetCleanUrl extends \XLite\Model\AEntity
      *
      * @param array $data Entity properties OPTIONAL
      */
-    public function __construct(array $data = array())
+    public function __construct(array $data = [])
     {
         $this->cleanURLs = new \Doctrine\Common\Collections\ArrayCollection();
 
@@ -73,4 +71,4 @@ class TargetCleanUrl extends \XLite\Model\AEntity
     {
         return null;
     }
-}
\ No newline at end of file
+}
