@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,15 +7,17 @@
 
 namespace XLite\Model;
 
+use Doctrine\ORM\Mapping as ORM;
+
 /**
  * Tax class multilingual data
  *
- * @Entity
+ * @ORM\Entity
  *
- * @Table (name="tax_class_translations",
+ * @ORM\Table (name="tax_class_translations",
  *         indexes={
- *              @Index (name="ci", columns={"code","id"}),
- *              @Index (name="id", columns={"id"})
+ *              @ORM\Index (name="ci", columns={"code","id"}),
+ *              @ORM\Index (name="id", columns={"id"})
  *         }
  * )
  */
@@ -27,10 +28,18 @@ class TaxClassTranslation extends \XLite\Model\Base\Translation
      *
      * @var string
      *
-     * @Column (type="string", length=255)
+     * @ORM\Column (type="string", length=255)
      */
     protected $name;
 
+    /**
+     * @var \XLite\Model\TaxClass
+     *
+     * @ORM\ManyToOne (targetEntity="XLite\Model\TaxClass", inversedBy="translations")
+     * @ORM\JoinColumn (name="id", referencedColumnName="id", onDelete="CASCADE")
+     */
+    protected $owner;
+
     /**
      * Set name
      *
@@ -46,7 +55,7 @@ class TaxClassTranslation extends \XLite\Model\Base\Translation
     /**
      * Get name
      *
-     * @return string 
+     * @return string
      */
     public function getName()
     {
@@ -56,7 +65,7 @@ class TaxClassTranslation extends \XLite\Model\Base\Translation
     /**
      * Get label_id
      *
-     * @return integer 
+     * @return integer
      */
     public function getLabelId()
     {
@@ -78,7 +87,7 @@ class TaxClassTranslation extends \XLite\Model\Base\Translation
     /**
      * Get code
      *
-     * @return string 
+     * @return string
      */
     public function getCode()
     {
