@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,16 +7,46 @@
 
 namespace XLite\Model;
 
+use Doctrine\ORM\Mapping as ORM;
 use Includes\Utils\URLManager;
 
 /**
  * Temporary file store
  *
- * @Entity
- * @Table  (name="temporary_files")
+ * @ORM\Entity
+ * @ORM\Table  (name="temporary_files")
  */
 class TemporaryFile extends \XLite\Model\Base\Image
 {
+    /**
+     * Alternative image text
+     *
+     * @var string
+     */
+    protected $alt = '';
+
+    /**
+     * Set alt
+     *
+     * @param string $alt
+     * @return TemporaryFile
+     */
+    public function setAlt($alt)
+    {
+        $this->alt = $alt;
+        return $this;
+    }
+
+    /**
+     * Get alt
+     *
+     * @return string
+     */
+    public function getAlt()
+    {
+        return $this->alt;
+    }
+
     /**
      * Check - file is image or not
      *
