@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,17 +17,17 @@ class TypeBool extends \XLite\Model\WidgetParam\TypeSet
      *
      * @var array
      */
-    protected $trueValues = array('1', 'true', 1, true);
+    protected $trueValues = ['1', 'true', 1, true];
 
     /**
      * Options
      *
      * @var array
      */
-    protected $options = array(
+    protected $options = [
         'true'  => 'Yes',
         'false' => 'No',
-    );
+    ];
 
     /**
      * Get value by name
