@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -30,11 +29,11 @@ class TypeCollection extends \XLite\Model\WidgetParam\AWidgetParam
      */
     protected function getValidationSchema($value)
     {
-        return array(
-            array(
+        return [
+            [
                 static::ATTR_CONDITION => !is_array($value),
                 static::ATTR_MESSAGE   => ' is not an array',
-            ),
-        );
+            ],
+        ];
     }
 }
