@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,16 +12,6 @@ namespace XLite\Module;
  */
 abstract class AModuleSkin extends AModule
 {
-    /**
-     * The module is defined as skin module
-     *
-     * @return integer|null
-     */
-    public static function getModuleType()
-    {
-        return static::MODULE_TYPE_SKIN;
-    }
-
     /**
      * Returns supported layout types
      *
@@ -30,7 +19,10 @@ abstract class AModuleSkin extends AModule
      */
     public static function getLayoutTypes()
     {
-        return \XLite\Core\Layout::getInstance()->getLayoutTypes();
+        return [
+            \XLite\Core\Layout::LAYOUT_GROUP_DEFAULT => \XLite\Core\Layout::getInstance()->getLayoutTypes(),
+            \XLite\Core\Layout::LAYOUT_GROUP_HOME    => \XLite\Core\Layout::getInstance()->getLayoutTypes(),
+        ];
     }
 
     /**
@@ -40,17 +32,7 @@ abstract class AModuleSkin extends AModule
      */
     public static function getLayoutColors()
     {
-        return array();
-    }
-
-    /**
-     * Return module dependencies
-     *
-     * @return array
-     */
-    final public static function getDependencies()
-    {
-        return array();
+        return [];
     }
 
     /**
@@ -72,14 +54,4 @@ abstract class AModuleSkin extends AModule
     {
         return false;
     }
-
-    /**
-     * Check if skin supports preloaded images
-     *
-     * @return boolean
-     */
-    public static function isUsePreloadedImages()
-    {
-        return false;
-    }
 }
