@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,7 @@
 
 namespace XLite\View;
 
-use XLite\Core\ConfigParser;
+use XLite\Core\WidgetCache;
 
 /**
  * Resources container routine
@@ -63,15 +62,20 @@ abstract class AResourcesContainer extends \XLite\View\Container
     public function getCSSResourceFromCache(array $resources)
     {
         return $this->getResourceFromCache(
-                static::RESOURCE_CSS,
-                $resources,
-                [
+            static::RESOURCE_CSS,
+            $resources,
+            [
                     static::RESOURCE_CSS,
                     \XLite\Core\Request::getInstance()->isHTTPS() ? 'https' : 'http',
                     $resources[0]['media'],
                 ],
-                'prepareCSSCache'
-            ) + ['media' => $resources[0]['media']];
+            'prepareCSSCache'
+        ) + ['media' => $resources[0]['media']];
+    }
+
+    protected static function getWidgetCache(): WidgetCache
+    {
+        return \XCart\Container::getContainer()->get(WidgetCache::class);
     }
 
     /**
@@ -79,17 +83,33 @@ abstract class AResourcesContainer extends \XLite\View\Container
      *
      * @return integer
      */
-    protected static function getLatestCacheTimestamp()
+    public static function getLatestCacheTimestamp()
     {
         if (!isset(\XLite\View\AResourcesContainer::$latestCacheTimestamp)) {
-            \XLite\View\AResourcesContainer::$latestCacheTimestamp = intval(
-                \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getVar(\XLite::CACHE_TIMESTAMP)
-            );
+            $timestamp = static::getWidgetCache()->get([\XLite::CACHE_TIMESTAMP]);
+
+            if (!$timestamp) {
+                $timestamp = static::refreshCacheTimestamp();
+            }
+
+            \XLite\View\AResourcesContainer::$latestCacheTimestamp = $timestamp;
         }
 
         return \XLite\View\AResourcesContainer::$latestCacheTimestamp;
     }
 
+    public static function refreshCacheTimestamp(): int
+    {
+        $newCacheTimestamp = (int) microtime(true);
+
+        static::getWidgetCache()->set(
+            [\XLite::CACHE_TIMESTAMP],
+            $newCacheTimestamp
+        );
+
+        return $newCacheTimestamp;
+    }
+
     /**
      * Return JS resources structure from the file cache
      *
@@ -124,7 +144,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
         $pathToCacheDir = static::getResourceCacheDir($paramsForCache);
         \Includes\Utils\FileManager::mkdirRecursive($pathToCacheDir);
 
-        $file = hash('sha256', serialize($resources)) . '.' . $type;
+        $file     = hash('sha256', serialize($resources)) . '.' . $type;
         $filePath = $pathToCacheDir . $file;
 
         if (!\Includes\Utils\FileManager::isFile($filePath)) {
@@ -142,7 +162,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
             'file' => $filePath,
             'url'  => \XLite::getInstance()
                 ->getShopURL(
-                    str_replace(LC_DS, '/', substr($filePath, strlen(LC_DIR_ROOT))),
+                    str_replace(LC_DS, '/', substr($filePath, strlen(LC_DIR_PUBLIC))),
                     \XLite\Core\Request::getInstance()->isHTTPS()
                 ),
         ];
@@ -160,15 +180,15 @@ abstract class AResourcesContainer extends \XLite\View\Container
     {
         $data = '';
         if (isset($resource['file'])) {
-            $filePath = $resource['file'];
+            $filePath    = $resource['file'];
             $minFilePath = str_replace(LC_DIR_SKINS, static::getMinifiedCacheDir(static::RESOURCE_CSS), $filePath);
             $minFilePath = dirname($minFilePath) . LC_DS . basename($minFilePath, '.css') . '.min.css';
-            $minified = false;
+            $minified    = false;
 
             $origPath = $filePath;
 
             if (\Includes\Utils\FileManager::isFileReadable($minFilePath)) {
-                $data = \Includes\Utils\FileManager::read($minFilePath);
+                $data     = \Includes\Utils\FileManager::read($minFilePath);
                 $minified = true;
                 $origPath = $minFilePath;
             } else {
@@ -236,18 +256,20 @@ abstract class AResourcesContainer extends \XLite\View\Container
      */
     public function processCSSURLHandler(array $matches, $filePath, $origPath)
     {
-        $url = trim($matches[1]);
+        $url       = trim($matches[1]);
+        $isDataURL = true;
 
         if (!preg_match('/^[\'"]?data:/Ss', $url)) {
-            $first = substr($url, 0, 1);
+            $isDataURL = false;
+            $first     = substr($url, 0, 1);
 
-            if ('"' == $first || '\'' == $first) {
+            if ($first == '"' || $first == '\'') {
                 $url = stripslashes(substr($url, 1, -1));
             }
 
             if (!preg_match('/^(?:https?:)?\/\//Ss', $url)) {
-                if ('/' === substr($url, 0, 1)) {
-                    $dir = LC_DIR_ROOT;
+                if (substr($url, 0, 1) === '/') {
+                    $dir = LC_DIR_PUBLIC;
                 } else {
                     $dir = dirname($origPath) . LC_DS;
                 }
@@ -260,13 +282,14 @@ abstract class AResourcesContainer extends \XLite\View\Container
                 $url = $this->fixUrl($url);
             }
 
-
             if (preg_match('/[\'"]/Ss', $url)) {
                 $url = '"' . addslashes($url) . '"';
             }
         }
 
-        return 'url(' . $url . ')';
+        return $isDataURL
+            ? 'url(' . $url . ')'
+            : 'url("' . $url . '")';
     }
 
     protected function fixUrl($url)
@@ -289,30 +312,18 @@ abstract class AResourcesContainer extends \XLite\View\Container
     {
         $data = '';
         if (isset($resource['file'])) {
-            $filePath = $resource['file'];
+            $filePath    = $resource['file'];
             $minFilePath = str_replace(LC_DIR_SKINS, static::getMinifiedCacheDir(static::RESOURCE_JS), $filePath);
             $minFilePath = dirname($minFilePath) . LC_DS . basename($minFilePath, '.js') . '.min.js';
-            $minified = false;
 
             // Get file content
             if (\Includes\Utils\FileManager::isFileReadable($minFilePath)) {
                 $data = \Includes\Utils\FileManager::read($minFilePath);
-                $minified = true;
             } else {
                 $data = \Includes\Utils\FileManager::read($filePath);
             }
 
-            $noMinify = !empty($resource['no_minify']) || !empty($resource['no-minify']);
-
-            if (!$minified && !$noMinify && strpos(basename($filePath), '.min.js') == false) {
-                // Minify js content
-                $data = $this->minifyJS($data, $filePath);
-
-                \Includes\Utils\FileManager::write($minFilePath, $data);
-            }
-
             $data = trim($data);
-
             $data = preg_replace('/\)$/S', ');', $data);
         }
 
@@ -321,36 +332,6 @@ abstract class AResourcesContainer extends \XLite\View\Container
             : '';
     }
 
-    /**
-     * Make simple js-minification and return minified JS content
-     *
-     * @param string $content  Source JS content
-     * @param string $filePath Source file path
-     *
-     * @return string
-     */
-    protected function minifyJS($content, $filePath)
-    {
-        require_once LC_DIR_LIB . 'Minify' . LC_DS . 'JSMinPlus.php';
-
-        try {
-            ob_start();
-            $result = \JSMinPlus::minify($content);
-            $error = ob_get_contents();
-            ob_end_clean();
-
-            if (false === $result) {
-                throw new \Exception(sprintf('[%s] %s', $filePath, $error));
-            }
-
-        } catch (\Exception $e) {
-            \XLite\Logger::getInstance()->registerException($e);
-            $result = $content;
-        }
-
-        return $result;
-    }
-
     /**
      * Check if the CSS resources should be aggregated
      *
@@ -392,6 +373,10 @@ abstract class AResourcesContainer extends \XLite\View\Container
      */
     protected function getResourceURL($url, $params = [])
     {
+        if (filter_var($url, FILTER_VALIDATE_URL) === false && substr($url, 0, 1) !== '/') {
+            $url = '/' . $url;
+        }
+
         return isset($params['no_timestamp']) && $params['no_timestamp']
             ? $url
             : $url . (strpos($url, '?') === false ? '?' : '&') . static::getLatestCacheTimestamp();
@@ -450,10 +435,10 @@ abstract class AResourcesContainer extends \XLite\View\Container
     public function groupResourcesByUrl($resources, $cacheHandler)
     {
         $groupByUrl = [];
-        $group = [];
+        $group      = [];
 
         foreach ($resources as $info) {
-            if (0 === strpos($info['url'], '//')) {
+            if (strpos($info['url'], '//') === 0) {
                 $info['url'] = (\XLite\Core\Request::getInstance()->isHTTPS() ? 'https:' : 'http:') . $info['url'];
             }
 
@@ -498,19 +483,26 @@ abstract class AResourcesContainer extends \XLite\View\Container
         $groupByMedia = [];
 
         foreach ($list as $fileInfo) {
+            $index = '';
 
-            $index = (isset($fileInfo['interface']) && 'common' == $fileInfo['interface'] ? 'common-' : '')
-                . (isset($fileInfo['media']) ? $fileInfo['media'] : 'all');
+            if (
+                isset($fileInfo['zone'])
+                && $fileInfo['zone'] === \XLite::ZONE_COMMON
+            ) {
+                $index .= \XLite::ZONE_COMMON . '-';
+            }
+
+            $index .= ($fileInfo['media'] ?? 'all');
 
             $groupByMedia[$index][] = $fileInfo;
         }
 
         $list = [];
         foreach ($groupByMedia as $group) {
-            $list = array_merge($list, $this->groupResourcesByUrl($group, 'getCSSResourceFromCache'));
+            $list[] = $this->groupResourcesByUrl($group, 'getCSSResourceFromCache');
         }
 
-        return $list;
+        return array_merge(...$list);
     }
 
     /**
@@ -532,8 +524,6 @@ abstract class AResourcesContainer extends \XLite\View\Container
 
         if (isset($resource['media'])) {
             switch ($resource['media']) {
-                case 'print':
-                    return '';
                 case 'all':
                     break;
                 default:
@@ -541,19 +531,20 @@ abstract class AResourcesContainer extends \XLite\View\Container
             }
         }
 
-        $webDir = ConfigParser::getOptions(['host_details', 'web_dir_wo_slash']);
+        $webDir = \Includes\Utils\ConfigParser::getOptions(['host_details', 'web_dir']);
 
         $content = preg_replace_callback(
             '/url\(([^)]+)\)/Ss',
             function (array $matches) use ($filePath, $webDir) {
-                $relativeUrl = $this->processCSSURLHandler($matches, LC_DIR_ROOT, $filePath);
+                $relativeUrl = $this->processCSSURLHandler($matches, LC_DIR_PUBLIC, $filePath);
 
                 if (
                     !preg_match('/^[\'"]?data:/Ss', $matches[1])
                     && !preg_match('/^(?:https?:)?\/\//Ss', $matches[1])
                 ) {
                     $prefix = $webDir ? $webDir . '/' : '';
-                    return 'url(' . $prefix . mb_substr($relativeUrl, 4);
+
+                    return 'url("' . $prefix . mb_substr($relativeUrl, 5);
                 }
 
                 return $relativeUrl;
@@ -577,7 +568,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
     {
         if (isset($resource['file'])) {
             $resourceKey = md5(serialize($resource));
-            $result = in_array($resourceKey, static::$optimizedResources) || !$this->isResourceKeyInCookie($resourceKey);
+            $result      = in_array($resourceKey, static::$optimizedResources) || !$this->isResourceKeyInCookie($resourceKey);
 
             if ($result) {
                 $this->addResourceKeyToCookie($resourceKey);
@@ -602,7 +593,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
         $viewedResources = $request->viewedResources;
 
         if (!empty($viewedResources) && !is_array($viewedResources)) {
-            $viewedResources = @unserialize($viewedResources);
+            $viewedResources = @json_decode($viewedResources);
         }
 
         if (!is_array($viewedResources)) {
@@ -613,7 +604,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
         $viewedResources = array_slice($viewedResources, -50);
 
         $viewedResources[] = $resourceKey;
-        $request->setCookie('viewedResources', serialize(array_unique($viewedResources)), 3600);
+        $request->setCookie('viewedResources', json_encode(array_unique($viewedResources)), 3600);
         $request->viewedResources = $viewedResources;
     }
 
@@ -631,7 +622,7 @@ abstract class AResourcesContainer extends \XLite\View\Container
         $viewedResources = $request->viewedResources;
 
         if (!empty($viewedResources) && !is_array($viewedResources)) {
-            $viewedResources = @unserialize($viewedResources);
+            $viewedResources = @json_decode($viewedResources);
         }
 
         if (is_array($viewedResources)) {
