@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,10 @@
 
 namespace XLite\View;
 
-use XLite\Core\DependencyInjection\ContainerAwareTrait;
-use XLite\Core\Event\WidgetAfterRenderEvent;
-use XLite\Core\Event\WidgetBeforeRenderEvent;
-use XLite\Core\Events;
+use Includes\Utils\ArrayManager;
+use Includes\Utils\ConfigParser;
+use Twig\Markup;
+use XLite\Core\Cache\CacheKeyPartsGenerator;
 use XLite\Core\View\DTO\Assets;
 use XLite\Core\View\DTO\RenderedWidget;
 use XLite\Core\View\DynamicWidgetInterface;
@@ -19,45 +18,40 @@ use XLite\Core\View\DynamicWidgetRenderer;
 use XLite\Core\View\RenderingContextFactory;
 use XLite\Core\View\RenderingContextInterface;
 use XLite\Core\WidgetCache;
+use XLite\InjectLoggerTrait;
 
 /**
  * Abstract widget
  */
 abstract class AView extends \XLite\Core\Handler
 {
-    use ContainerAwareTrait, OutputHelpersTrait;
+    use OutputHelpersTrait;
+    use InjectLoggerTrait;
 
     /**
      * Resource types
      */
-    const RESOURCE_JS  = 'js';
-    const RESOURCE_CSS = 'css';
+    public const RESOURCE_JS  = 'js';
+    public const RESOURCE_CSS = 'css';
 
     /**
      * Common widget parameter names
      */
-    const PARAM_TEMPLATE = 'template';
-    const PARAM_METADATA = 'metadata';
-    const PARAM_MODES    = 'modes';
+    public const PARAM_TEMPLATE = 'template';
+    public const PARAM_METADATA = 'metadata';
+    public const PARAM_MODES    = 'modes';
 
     /**
      *  View list insertation position
      */
-    const INSERT_BEFORE = 'before';
-    const INSERT_AFTER  = 'after';
-    const REPLACE       = 'replace';
+    public const INSERT_BEFORE = 'before';
+    public const INSERT_AFTER  = 'after';
+    public const REPLACE       = 'replace';
 
     /**
      * Favicon resource short path
      */
-    const FAVICON = 'favicon.ico';
-
-    /**
-     * Views tail
-     *
-     * @var   array
-     */
-    protected static $viewsTail = [];
+    public const FAVICON = 'favicon.ico';
 
     /**
      * View lists (cache)
@@ -105,16 +99,6 @@ abstract class AView extends \XLite\Core\Handler
         return [];
     }
 
-    /**
-     * Get templates tail
-     *
-     * @return array
-     */
-    public static function getTail()
-    {
-        return static::$viewsTail;
-    }
-
     /**
      * Use current controller context
      *
@@ -126,7 +110,7 @@ abstract class AView extends \XLite\Core\Handler
     {
         $value = parent::__get($name);
 
-        return null !== $value ? $value : \XLite::getController()->$name;
+        return $value ?? \XLite::getController()->$name;
     }
 
     /**
@@ -139,6 +123,24 @@ abstract class AView extends \XLite\Core\Handler
      */
     public function __call($method, array $args = [])
     {
+        if (method_exists($this, $method)) {
+            return call_user_func_array([$this, $method], $args);
+        }
+
+        $tmpMethod = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($method);
+
+        if (method_exists($this, $tmpMethod)) {
+            return call_user_func_array([$this, $tmpMethod], $args);
+        }
+
+        if (property_exists($this, $method)) {
+            return $this->{$method};
+        }
+
+        if ($value = $this->getParam($method)) {
+            return $value;
+        }
+
         return call_user_func_array([\XLite::getController(), $method], $args);
     }
 
@@ -221,9 +223,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getSafeValue($string)
     {
-        return $this->getRenderingContext()
-            ->getTemplatingEngine()
-            ->getSafeValue($string);
+        return new Markup($string, 'UTF-8');
     }
 
     /**
@@ -265,8 +265,6 @@ abstract class AView extends \XLite\Core\Handler
             return;
         }
 
-        $this->dispatchBeforeRenderEvent();
-
         if ($overrideTemplate || $this->checkVisibility()) {
             if ($originalWidget) {
                 $this->initView();
@@ -277,10 +275,7 @@ abstract class AView extends \XLite\Core\Handler
 
             if ($renderedWidget !== null) {
                 $this->displayRenderedWidget($renderedWidget);
-
-                $this->dispatchAfterRenderEvent($template, WidgetAfterRenderEvent::STATE_VISIBLE | WidgetAfterRenderEvent::STATE_CACHED);
             } else {
-
                 if ($cacheEnabled) {
                     $this->getRenderingContext()->startBuffering();
                 }
@@ -294,12 +289,7 @@ abstract class AView extends \XLite\Core\Handler
 
                     $this->displayRenderedWidget($renderedWidget);
                 }
-
-                $this->dispatchAfterRenderEvent($template, WidgetAfterRenderEvent::STATE_VISIBLE);
             }
-
-        } else {
-            $this->dispatchAfterRenderEvent($template);
         }
     }
 
@@ -312,30 +302,36 @@ abstract class AView extends \XLite\Core\Handler
     {
         $templateName = $this->getTemplateName($template);
 
-        $engine = $this->getRenderingContext()->getTemplatingEngine();
+        $twig = \XCart\Container::getServiceLocator()->getTwig();
 
-        $templatePath = $engine->getTemplatePath($templateName);
+        $loader = $twig->getLoader();
+
+        $templatePath = false;
+        if ($templateName) {
+            $templatePath = $loader->getSourceContext($templateName)->getPath();
+        }
 
         if ($templatePath !== false) {
             // Collect the specific data to send it to the finalizeTemplateDisplay method
             $profilerData = $this->prepareTemplateDisplay($templatePath);
 
-            static::$viewsTail[] = $templatePath;
+            $globals = $twig->getGlobals();
+            $oldThis = array_key_exists('this', $globals) ? $globals['this'] : null;
 
-            $engine->display($templateName, $this);
+            $twig->addGlobal('this', $this);
 
-            array_pop(static::$viewsTail);
+            $twig->display($templateName, ['this' => $this]);
+
+            $twig->addGlobal('this', $oldThis);
 
             $this->finalizeTemplateDisplay($templatePath, $profilerData);
-
-        } else if ($this->getDefaultTemplate() !== null) {
-            \XLite\Logger::getInstance()->log(
+        } elseif ($this->getDefaultTemplate() !== null) {
+            $this->getLogger()->debug(
                 sprintf(
                     'Empty compiled template. View class: %s, view main template: %s',
                     get_class($this),
                     $this->getTemplate()
-                ),
-                \LOG_DEBUG
+                )
             );
         }
     }
@@ -381,11 +377,11 @@ abstract class AView extends \XLite\Core\Handler
 
     /**
      * Check for current mode
-     * @todo: must be static
      *
      * @param array $modes List of allowed modes
      *
      * @return boolean
+     *
      */
     public function isDisplayRequiredForMode(array $modes)
     {
@@ -413,7 +409,7 @@ abstract class AView extends \XLite\Core\Handler
     {
         $value = parent::get($name);
 
-        return null !== $value ? $value : \XLite::getController()->get($name);
+        return $value ?? \XLite::getController()->get($name);
     }
 
     /**
@@ -426,7 +422,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     public function getChildWidget($class = null, array $params = [])
     {
-        if (null !== $class) {
+        if ($class !== null) {
             /** @var AView $widget */
             $widget = new $class($params);
 
@@ -479,15 +475,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getTemplateName($template = null)
     {
-        $template = $template ?: $this->getTemplate();
-
-        if (!$this->checkLicense()) {
-            $template = $this->showLicenseMessage()
-                ? $this->getLicenseMessageTemplate()
-                : '';
-        }
-
-        return $template;
+        return $template ?: $this->getTemplate();
     }
 
     /**
@@ -512,7 +500,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function finalizeTemplateDisplay($template, array $profilerData)
     {
-        if (!$this->isCloned && null === $template) {
+        if (!$this->isCloned && $template === null) {
             $this->closeView();
         }
     }
@@ -617,8 +605,7 @@ abstract class AView extends \XLite\Core\Handler
     {
         return static::checkTarget()
             && $this->checkMode()
-            && $this->checkACL()
-            && ($this->checkLicense() || $this->showLicenseMessage());
+            && $this->checkACL();
     }
 
     /**
@@ -631,47 +618,6 @@ abstract class AView extends \XLite\Core\Handler
         return true;
     }
 
-    /**
-     * Check if current page is accessible for current x-cart license
-     *
-     * @return boolean
-     */
-    protected function checkLicense()
-    {
-        return true;
-    }
-
-    /**
-     * Show license message
-     * @todo: rename to isShowLicenseMessage
-     *
-     * @return boolean
-     */
-    protected function showLicenseMessage()
-    {
-        return false;
-    }
-
-    /**
-     * Returns license message template
-     *
-     * @return string
-     */
-    protected function getLicenseMessageTemplate()
-    {
-        return 'license_message.twig';
-    }
-
-    /**
-     * Returns license message
-     *
-     * @return string
-     */
-    protected function getLicenseMessage()
-    {
-        return '';
-    }
-
     /**
      * FIXME - must be removed
      *
@@ -694,9 +640,9 @@ abstract class AView extends \XLite\Core\Handler
     protected static function getResourcesSchema()
     {
         return [
-            ['getCommonFiles', 100, \XLite::COMMON_INTERFACE],
-            ['getResources', 200, null],
-            ['getThemeFiles', 300, null],
+            ['getCommonFiles', 100, \XLite::INTERFACE_WEB, \XLite::ZONE_COMMON],
+            ['getResources', 200, null, null],
+            ['getThemeFiles', 300, null, null],
         ];
     }
 
@@ -812,17 +758,18 @@ abstract class AView extends \XLite\Core\Handler
     {
         return [
             [
-                'file' => LC_DEVELOPER_MODE ? 'vue/vue.js' : 'vue/vue.min.js',
-                'no_minify' => true
+                'file'      => LC_DEVELOPER_MODE ? 'vue/vue.js' : 'vue/vue.min.js',
+                'no_minify' => true,
             ],
             [
-                'file' => LC_DEVELOPER_MODE ? 'vue/vuex.js' : 'vue/vuex.min.js',
-                'no_minify' => true
+                'file'      => LC_DEVELOPER_MODE ? 'vue/vuex.js' : 'vue/vuex.min.js',
+                'no_minify' => true,
             ],
             'vue/vue.loadable.js',
             'vue/vue.registerComponent.js',
             'js/vue/vue.js',
-            'js/vue/component.js'
+            'js/vue/component.js',
+            'js/vue/event_bus.js',
         ];
     }
 
@@ -839,14 +786,6 @@ abstract class AView extends \XLite\Core\Handler
         ];
     }
 
-    /**
-     * Flag indicating that AView's theme files were already registered to avoid iterating over and over again
-     * Much more clean way is to move the whole resource declaration into the concrete widget class (representing a root of the page), but it will break BC
-     *
-     * @var bool
-     */
-    private static $returnedAViewsThemeFiles = false;
-
     /**
      * Return theme common files
      *
@@ -856,12 +795,6 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getThemeFiles($adminZone = null)
     {
-        if (self::$returnedAViewsThemeFiles) {
-            return [];
-        }
-
-        self::$returnedAViewsThemeFiles = true;
-
         return [
             static::RESOURCE_JS  => [],
             static::RESOURCE_CSS => [],
@@ -934,9 +867,9 @@ abstract class AView extends \XLite\Core\Handler
     protected function registerResourcesForCurrentWidget()
     {
         foreach (static::getResourcesSchema() as $data) {
-            list($method, $index, $interface) = $data;
+            [$method, $index, $interface, $zone] = $data;
 
-            $this->registerResources($this->$method(), $index, $interface, $method);
+            $this->registerResources($this->$method(), $index, $interface, $zone, $method);
         }
 
         $this->registerMetas();
@@ -994,9 +927,9 @@ abstract class AView extends \XLite\Core\Handler
      * @see \XLite\View\AView::registerResourcesForCurrentWidget()
      * @see \XLite\View\AView::initView()
      */
-    protected function registerResources(array $resources, $index, $interface = null, $owner = null)
+    protected function registerResources(array $resources, $index, $interface = null, $zone = null, $owner = null)
     {
-        $this->getRenderingContext()->registerAssets(new Assets($resources, $index, $interface, $owner));
+        $this->getRenderingContext()->registerAssets(new Assets($resources, $index, $interface, $zone, $owner));
     }
 
     /**
@@ -1135,7 +1068,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     public static function formatPrice($value, \XLite\Model\Currency $currency = null, $strictFormat = false)
     {
-        if (null === $currency) {
+        if ($currency === null) {
             $currency = \XLite::getInstance()->getCurrency();
         }
 
@@ -1146,7 +1079,7 @@ abstract class AView extends \XLite\Core\Handler
 
         $parts = $currency->formatParts($value);
 
-        if (isset($parts['sign']) && '-' === $parts['sign']) {
+        if (isset($parts['sign']) && $parts['sign'] === '-') {
             $parts['sign'] = '− ';
         }
 
@@ -1166,7 +1099,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     public static function formatWeight($value)
     {
-        list($thousandDelimiter, $decimalDelimiter)
+        [$thousandDelimiter, $decimalDelimiter]
             = explode('|', \XLite\Core\Config::getInstance()->Units->weight_format);
 
         $result = number_format($value, 4, $decimalDelimiter, $thousandDelimiter);
@@ -1189,7 +1122,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     public function formatPriceHTML($value, \XLite\Model\Currency $currency = null, $strictFormat = false)
     {
-        if (null === $currency) {
+        if ($currency === null) {
             $currency = \XLite::getInstance()->getCurrency();
         }
 
@@ -1200,7 +1133,7 @@ abstract class AView extends \XLite\Core\Handler
 
         $parts = $currency->formatParts($value);
 
-        if (isset($parts['sign']) && '-' === $parts['sign']) {
+        if (isset($parts['sign']) && $parts['sign'] === '-') {
             $parts['sign'] = '&minus;&#8197;';
         }
 
@@ -1252,16 +1185,12 @@ abstract class AView extends \XLite\Core\Handler
     {
         if (1024 > $size) {
             $result = static::t('X bytes', ['value' => $size]);
-
         } elseif (1048576 > $size) {
             $result = static::t('X kB', ['value' => round($size / 1024, 1)]);
-
         } elseif (1073741824 > $size) {
             $result = static::t('X MB', ['value' => round($size / 1048576, 1)]);
-
         } else {
             $result = static::t('X GB', ['value' => round($size / 1073741824, 1)]);
-
         }
 
         return $result;
@@ -1286,8 +1215,9 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected static function formatPartsStrictly($parts)
     {
-        if (1 == \XLite\Core\Config::getInstance()->General->trailing_zeroes
-            && '00' == $parts['decimal']
+        if (
+            \XLite\Core\Config::getInstance()->General->trailing_zeroes == 1
+            && $parts['decimal'] == '00'
         ) {
             unset($parts['decimal'], $parts['decimalDelimiter']);
         }
@@ -1309,7 +1239,7 @@ abstract class AView extends \XLite\Core\Handler
 
         $class = [];
 
-        if (1 == $this->$indexName) {
+        if ($this->$indexName == 1) {
             $class[] = 'first';
         }
 
@@ -1346,20 +1276,6 @@ abstract class AView extends \XLite\Core\Handler
         return \Includes\Utils\ArrayManager::getIndex($array, $field, true);
     }
 
-    /**
-     * Helper to get object field values
-     *
-     * @param object  $object   Object to get field value
-     * @param string  $field    Field name
-     * @param boolean $isGetter Flag OPTIONAL
-     *
-     * @return mixed
-     */
-    protected function getObjectField($object, $field, $isGetter = true)
-    {
-        return \Includes\Utils\ArrayManager::getObjectField($object, $field, $isGetter);
-    }
-
     /**
      * Truncates the baseObject property value to specified length
      * @todo: add twig filter
@@ -1377,18 +1293,16 @@ abstract class AView extends \XLite\Core\Handler
         if (is_scalar($base)) {
             $string = $base;
             $length = $field;
-
         } else {
             if ($base instanceof \XLite\Model\AEntity) {
-                $string = $base->{'get' . \XLite\Core\Converter::convertToCamelCase($field)}();
+                $string = $base->{'get' . \Includes\Utils\Converter::convertToUpperCamelCase($field)}();
             } else {
                 $string = $base->get($field);
             }
         }
 
-        if (0 == $length) {
+        if ($length == 0) {
             $string = '';
-
         } elseif (strlen($string) > $length) {
             $length -= strlen($etc);
             if (!$breakWords) {
@@ -1538,7 +1452,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getRowClass($row, $oddCSSClass, $evenCSSClass = null)
     {
-        return 0 === ($row % 2) ? $oddCSSClass : $evenCSSClass;
+        return ($row % 2) === 0 ? $oddCSSClass : $evenCSSClass;
     }
 
     /**
@@ -1582,44 +1496,19 @@ abstract class AView extends \XLite\Core\Handler
     {
         $children = \XLite\Core\Database::getRepo('XLite\Model\ViewList')->findClassList(
             $list,
-            static::detectCurrentViewZone()
+            \XLite\Core\Layout::getInstance()->getInterface(),
+            \XLite\Core\Layout::getInstance()->getZone()
         );
 
         return $children;
     }
 
-    /**
-     * Detect current view zone
-     *
-     * @return string
-     */
-    protected static function detectCurrentViewZone()
-    {
-        if (\XLite\Core\Layout::getInstance()->getInterface() === \XLite::MAIL_INTERFACE) {
-            $zone = \XLite\Model\ViewList::INTERFACE_MAIL;
-
-        } elseif (\XLite\Core\Layout::getInstance()->getInterface() === \XLite::PDF_INTERFACE) {
-            $zone = \XLite\Model\ViewList::INTERFACE_PDF;
-
-        } elseif (\XLite\Core\Layout::getInstance()->getInterface() === \XLite::CONSOLE_INTERFACE) {
-            $zone = \XLite\Model\ViewList::INTERFACE_CONSOLE;
-
-        } elseif (\XLite\Core\Layout::getInstance()->getInterface() === \XLite::ADMIN_INTERFACE) {
-            $zone = \XLite\Model\ViewList::INTERFACE_ADMIN;
-
-        } else {
-            $zone = \XLite\Model\ViewList::INTERFACE_CUSTOMER;
-        }
-
-        return $zone;
-    }
-
     /**
      * addViewListChild
      *
-     * @param array   &$list      List to modify
-     * @param array   $properties Node properties
-     * @param integer $weight     Node position OPTIONAL
+     * @param array   &$list       List to modify
+     * @param array    $properties Node properties
+     * @param integer  $weight     Node position OPTIONAL
      *
      * @return void
      */
@@ -1665,7 +1554,6 @@ abstract class AView extends \XLite\Core\Handler
                     $this->getViewListItemWidgetParams($widget),
                     $widget->getChild()
                 );
-
             } elseif ($widget->getTpl()) {
                 // List child is template
                 $widgets[] = $this->getWidget(
@@ -1708,7 +1596,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getListItemMetadata($item)
     {
-        return [];
+        return ['entityId' => $item->getEntityId() ?: null];
     }
 
     /**
@@ -1818,29 +1706,25 @@ abstract class AView extends \XLite\Core\Handler
             foreach ($patches as $node) {
                 $node = $node->cloneNode(true);
 
-                if (static::INSERT_BEFORE === $insertType) {
+                if ($insertType === static::INSERT_BEFORE) {
                     // Insert patch node before XPath result node
                     $place->parentNode->insertBefore($node, $place);
-
-                } elseif (static::INSERT_AFTER === $insertType) {
+                } elseif ($insertType === static::INSERT_AFTER) {
                     // Insert patch node after XPath result node
                     if ($place->nextSibling) {
                         $place->parentNode->insertBefore($node, $place->nextSibling);
                         $insertType = self::INSERT_BEFORE;
                         $place      = $place->nextSibling;
-
                     } else {
                         $place->parentNode->appendChild($node);
                     }
-
-                } elseif (static::REPLACE === $insertType) {
+                } elseif ($insertType === static::REPLACE) {
                     // Replace XPath result node to patch node
                     $place->parentNode->replaceChild($node, $place);
 
                     if ($node->nextSibling) {
                         $place      = $node->nextSibling;
                         $insertType = self::INSERT_BEFORE;
-
                     } else {
                         $place      = $node;
                         $insertType = self::INSERT_AFTER;
@@ -1902,7 +1786,7 @@ abstract class AView extends \XLite\Core\Handler
             $tail = '[' . implode('][', array_slice($args, 2)) . ']';
         }
 
-        return $this->getPrefixPostedData() . (null !== $id ? '[' . $id . ']' : '') . '[' . $field . ']' . $tail;
+        return $this->getPrefixPostedData() . ($id !== null ? '[' . $id . ']' : '') . '[' . $field . ']' . $tail;
     }
 
     /**
@@ -1927,6 +1811,16 @@ abstract class AView extends \XLite\Core\Handler
         return LC_DEVELOPER_MODE;
     }
 
+    /**
+     * Checks if update notifications are enabled.
+     *
+     * @return boolean
+     */
+    protected function isUpgradeFunctionalityDisplayed()
+    {
+        return \XLite::areUpdateNotificationsEnabled();
+    }
+
     /**
      * Checks if rendering is done for mobile device
      *
@@ -1954,7 +1848,8 @@ abstract class AView extends \XLite\Core\Handler
     {
         $result = '';
 
-        if (LC_USE_CLEAN_URLS
+        if (
+            LC_USE_CLEAN_URLS
             && \XLite\Core\Router::getInstance()->isUseLanguageUrls()
             && !\XLite::isAdminZone()
         ) {
@@ -1995,6 +1890,16 @@ abstract class AView extends \XLite\Core\Handler
         return \XLite\Core\Layout::getInstance()->getLogo();
     }
 
+    /**
+     * Get logo alt
+     *
+     * @return string
+     */
+    public function getLogoAlt()
+    {
+        return \XLite\Core\Layout::getInstance()->getLogoAlt();
+    }
+
     /**
      * Get apple icon
      *
@@ -2002,7 +1907,14 @@ abstract class AView extends \XLite\Core\Handler
      */
     public function getAppleIcon()
     {
-        return \XLite\Core\Layout::getInstance()->getAppleIcon();
+        $url = \XLite\Core\Layout::getInstance()->getAppleIcon();
+
+        $webDir = \Includes\Utils\ConfigParser::getOptions(['host_details', 'web_dir']) . '/';
+        if (substr($url, 0, strlen($webDir)) !== $webDir) {
+            $url = $webDir . $url;
+        }
+
+        return $url;
     }
 
     /**
@@ -2012,7 +1924,14 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getFavicon()
     {
-        return \XLite\Core\Layout::getInstance()->getFavicon();
+        $url = \XLite\Core\Layout::getInstance()->getFavicon();
+
+        $webDir = \Includes\Utils\ConfigParser::getOptions(['host_details', 'web_dir']) . '/';
+        if (substr($url, 0, strlen($webDir)) !== $webDir) {
+            $url = $webDir . $url;
+        }
+
+        return $url;
     }
 
     /**
@@ -2022,7 +1941,15 @@ abstract class AView extends \XLite\Core\Handler
      */
     public function getInvoiceLogo()
     {
-        return $this->getLogo();
+        $interface = \XLite\Core\Layout::getInstance()->getInterface();
+
+        return \XLite\Core\Layout::getInstance()->getInvoiceLogo(
+            in_array(
+                $interface,
+                [\XLite::INTERFACE_MAIL, \XLite::INTERFACE_PDF],
+                true
+            )
+        );
     }
 
     /**
@@ -2035,7 +1962,7 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getAddressSectionData(\XLite\Model\Address $address = null, $showEmpty = false)
     {
-        $result    = [];
+        $result = [];
 
         if (!$address) {
             return $result;
@@ -2045,7 +1972,7 @@ abstract class AView extends \XLite\Core\Handler
 
         foreach (\XLite\Core\Database::getRepo('XLite\Model\AddressField')->findAllEnabled() as $field) {
             $method            = 'get'
-                . \Includes\Utils\Converter::convertToCamelCase(
+                . \Includes\Utils\Converter::convertToUpperCamelCase(
                     $field->getViewGetterName() ?: $field->getServiceName()
                 );
             $addressFieldValue = $address->{$method}();
@@ -2054,7 +1981,7 @@ abstract class AView extends \XLite\Core\Handler
             switch ($field->getServiceName()) {
                 case 'state_id':
                     $addressFieldValue = $hasStates ? $addressFieldValue : null;
-                    if (null === $addressFieldValue && $hasStates) {
+                    if ($addressFieldValue === null && $hasStates) {
                         $addressFieldValue = $address->getCustomState();
                     }
                     break;
@@ -2066,7 +1993,7 @@ abstract class AView extends \XLite\Core\Handler
                 default:
             }
 
-            if (strlen($addressFieldValue) || $showEmpty) {
+            if ((string) $addressFieldValue !== '' || $showEmpty) {
                 $result[$field->getServiceName()] = [
                     'css_class' => $cssFieldName,
                     'title'     => $field->getName(),
@@ -2075,6 +2002,26 @@ abstract class AView extends \XLite\Core\Handler
             }
         }
 
+        $firstEnabledAddressLineField = '';
+        foreach (['address1', 'address2', 'address3'] as $line) {
+            if (isset($result[$line])) {
+                $firstEnabledAddressLineField = $line;
+                break;
+            }
+        }
+
+        $result = ArrayManager::insertAfterKey($result, $firstEnabledAddressLineField, 'address_line_concat_comma_divided', [
+            'css_class' => 'address-address_line_concat_comma_divided',
+            'label'     => static::t('Address'),
+            'value'     => $address->getAddressLineConcatCommaDivided(),
+        ]);
+
+        foreach (['address1', 'address2', 'address3'] as $line) {
+            if (isset($result[$line])) {
+                $result[$line]['css_class'] .= ' hidden';
+            }
+        }
+
         return $result;
     }
 
@@ -2095,23 +2042,10 @@ abstract class AView extends \XLite\Core\Handler
 
     // {{{ SVG
 
-    /**
-     * Get SVG image
-     *
-     * @param string $path      Path
-     * @param string $interface Interface code OPTIONAL
-     *
-     * @return string
-     */
-    public function getSVGImage($path, $interface = null)
+    public function cleanSVGImageContent(string $rawContent): string
     {
-        $content = null;
-
-        $path = \XLite\Core\Layout::getInstance()->getResourceFullPath($path, $interface);
-
-        if ($path && file_exists($path)) {
-            $content = file_get_contents($path);
-            $content = preg_replace(
+        return trim(
+            preg_replace(
                 [
                     '/<\?xml [^>]+>/Ssi',
                     '/<!ENTITY [^>]+>/Ss',
@@ -2122,9 +2056,27 @@ abstract class AView extends \XLite\Core\Handler
                     '/<!--\s.+\s-->/USs',
                 ],
                 ['', '', '', '', '', '><', ''],
-                $content
-            );
-            $content = trim($content);
+                $rawContent
+            )
+        );
+    }
+
+    /**
+     * Get SVG image
+     *
+     * @param string $path      Path
+     *
+     * @return string
+     */
+    public function getSVGImage($path)
+    {
+        $content = null;
+
+        $path = \XLite\Core\Layout::getInstance()->getResourceFullPath($path);
+
+        if ($path && file_exists($path)) {
+            $content = file_get_contents($path);
+            $content = $this->cleanSVGImageContent($content);
         }
 
         return $content;
@@ -2154,7 +2106,10 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getCache()
     {
-        return $this->getContainer()->get('widget_cache');
+        /** @var WidgetCache $widgetCache */
+        $widgetCache = \XCart\Container::getContainer()->get(WidgetCache::class);
+
+        return $widgetCache;
     }
 
     /**
@@ -2253,13 +2208,11 @@ abstract class AView extends \XLite\Core\Handler
         if ($this->isCacheAllowed()) {
             if ($this->getCache()->has($cacheKeyParts)) {
                 $result = $this->getCache()->get($cacheKeyParts);
-
             } else {
                 $result = $function();
 
                 $this->getCache()->set($cacheKeyParts, $result, $this->getCacheTTL());
             }
-
         } else {
             $result = $function();
         }
@@ -2270,11 +2223,14 @@ abstract class AView extends \XLite\Core\Handler
     /**
      * Get an instance of CacheKeyPartsGenerator
      *
-     * @return \XLite\Core\Cache\CacheKeyPartsGenerator
+     * @return CacheKeyPartsGenerator
      */
     protected function getCacheKeyPartsGenerator()
     {
-        return $this->getContainer()->get('XLite\Core\Cache\CacheKeyPartsGenerator');
+        /** @var CacheKeyPartsGenerator $widgetCache */
+        $cacheKeyPartsGenerator = \XCart\Container::getContainer()->get(CacheKeyPartsGenerator::class);
+
+        return $cacheKeyPartsGenerator;
     }
 
     // }}}
@@ -2301,26 +2257,6 @@ abstract class AView extends \XLite\Core\Handler
         return 'block block-block';
     }
 
-    /**
-     * URL of the page where free license can be activated
-     *
-     * @return string
-     */
-    protected function getActivateFreeLicenseURL()
-    {
-        return \Includes\Utils\Module\Manager::getRegistry()->getServiceURL('free-license');
-    }
-
-    /**
-     * Check if the store has any license
-     *
-     * @return boolean
-     */
-    protected function hasLicense()
-    {
-        return \XLite::hasXCNLicenseKey();
-    }
-
     /**
      * Return affiliate URL
      * @todo: add twig function
@@ -2345,6 +2281,43 @@ abstract class AView extends \XLite\Core\Handler
         return \XLite::getInstance()->getShopURL(\XLite::getAdminScript());
     }
 
+    /**
+     * Admin authorization flow
+     * Login / Password recovery
+     *
+     * @return boolean
+     */
+    protected function isAdminAuthorizationFlow()
+    {
+        return \XLite::isAdminZone()
+            && (
+                !\XLite\Core\Auth::getInstance()->isLogged()
+                || !\XLite\Core\Auth::getInstance()->isAdmin()
+                || $this->isForceChangePassword()
+            );
+    }
+
+    /**
+     * Get user role to define if user is admin
+     *
+     * @return string
+     */
+    protected function getLoggedUserRole()
+    {
+        if (!\XLite\Core\Auth::getInstance()->isLogged()) {
+            return 'unauthorized';
+        }
+
+        return  \XLite\Core\Auth::getInstance()->isAdmin() ? 'admin' : 'customer';
+    }
+
+    public static function getMarketplaceApiUrl(): string
+    {
+        $marketplace = ConfigParser::getOptions(['marketplace']) ?? [];
+
+        return $marketplace['url'] ?? '';
+    }
+
     /**
      * Define the tag name
      * Currently we use the rule: '<tagName>' must have 'tag-<tagName>' language variable or it will be proceeded as is
@@ -2395,7 +2368,6 @@ abstract class AView extends \XLite\Core\Handler
 
     // }}}
 
-
     // {{{ Rendering context
 
     /** @var RenderingContextInterface */
@@ -2425,29 +2397,9 @@ abstract class AView extends \XLite\Core\Handler
      */
     protected function getDynamicWidgetRenderer()
     {
-        return $this->getContainer()->get('dynamic_widget_renderer');
-    }
+        /** @var DynamicWidgetRenderer $widgetCache */
+        $dynamicWidgetRenderer = \XCart\Container::getContainer()->get(DynamicWidgetRenderer::class);
 
-    /**
-     * Dispatch WidgetBeforeRenderEvent
-     */
-    protected function dispatchBeforeRenderEvent()
-    {
-        $eventDispatcher = $this->getContainer()->get('event_dispatcher');
-
-        $eventDispatcher->dispatch(Events::WIDGET_BEFORE_RENDER, new WidgetBeforeRenderEvent($this));
-    }
-
-    /**
-     * Dispatch WidgetAfterRenderEvent
-     *
-     * @param string $template
-     * @param int    $state See WidgetAfterRenderEvent::STATE_* for possible state values
-     */
-    protected function dispatchAfterRenderEvent($template, $state = 0)
-    {
-        $eventDispatcher = $this->getContainer()->get('event_dispatcher');
-
-        $eventDispatcher->dispatch(Events::WIDGET_AFTER_RENDER, new WidgetAfterRenderEvent($this, $state, $template));
+        return $dynamicWidgetRenderer;
     }
 }
