@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,7 @@ namespace XLite\View;
  */
 class AccessLink extends \XLite\View\AView
 {
-    const PARAM_LINK = 'link';
+    public const PARAM_LINK = 'link';
 
     /**
      * Define widget parameters
@@ -24,9 +23,9 @@ class AccessLink extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_LINK => new \XLite\Model\WidgetParam\TypeString('Access link', ''),
-        );
+        ];
     }
 
     /**
@@ -61,4 +60,4 @@ class AccessLink extends \XLite\View\AView
     {
         return $this->getParam(static::PARAM_LINK);
     }
-}
\ No newline at end of file
+}
