@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,7 +8,7 @@
 namespace XLite\View\Base;
 
 /**
- * Sticky panel 
+ * Sticky panel
  */
 abstract class StickyPanel extends \XLite\View\Container
 {
@@ -27,20 +26,6 @@ abstract class StickyPanel extends \XLite\View\Container
         return $list;
     }
 
-    /**
-     * Register CSS files
-     *
-     * @return array
-     */
-    public function getCSSFiles()
-    {
-        $list = parent::getCSSFiles();
-
-        $list[] = 'css/stickyPanel.css';
-
-        return $list;
-    }
-
     /**
      * Return widget default template
      *
@@ -52,8 +37,8 @@ abstract class StickyPanel extends \XLite\View\Container
     }
 
     /**
-     * Get class 
-     * 
+     * Get class
+     *
      * @return string
      */
     protected function getClass()
