@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -24,7 +23,8 @@ trait ViewListsFallbackTrait
     {
         return \XLite\Core\Database::getRepo('XLite\Model\ViewList')->findClassListWithFallback(
             $list,
-            static::detectCurrentViewZone()
+            \XLite\Core\Layout::getInstance()->getInterface(),
+            \XLite\Core\Layout::getInstance()->getZone()
         );
     }
 }
