@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * File Selector Dialog widget
  *
@@ -21,7 +22,7 @@ class BrowseServer extends \XLite\View\SimpleDialog
      * @var array
      *
      */
-    protected $fsEntries = array('catalog' => array(), 'file' => array());
+    protected $fsEntries = ['catalog' => [], 'file' => []];
 
     /**
      * Return list of allowed targets
@@ -37,13 +38,13 @@ class BrowseServer extends \XLite\View\SimpleDialog
     }
 
     /**
-     * Return files catalog repository. {lc_catalog}/files
+     * Return files catalog repository. {lc_catalog}/public/files
      *
      * @return string
      */
     public static function getFilesCatalog()
     {
-        return LC_DIR_ROOT . 'files';
+        return LC_DIR_ROOT . 'public/files';
     }
 
     /**
@@ -108,14 +109,14 @@ class BrowseServer extends \XLite\View\SimpleDialog
         $currentCatalog = $this->getCurrentCatalog();
         $filesCatalog = $this->getFilesCatalog();
 
-        return array(
+        return [
             'current_catalog'   => str_replace($filesCatalog, '', $currentCatalog),
             'up_catalog'        => str_replace(
                 $filesCatalog,
                 '',
                 $currentCatalog === $filesCatalog ? $currentCatalog : dirname($currentCatalog)
             ),
-        );
+        ];
     }
 
     /**
@@ -135,13 +136,13 @@ class BrowseServer extends \XLite\View\SimpleDialog
             $path = $file->getPathname();
             $type = $file->isDir() ? 'catalog' : 'file';
 
-            if ('.' !== substr($file->getBasename(), 0, 1) && 'service' !== $file->getBasename()) {
-                $this->fsEntries[$type][$path] = array(
+            if (substr($file->getBasename(), 0, 1) !== '.' && $file->getBasename() !== 'service') {
+                $this->fsEntries[$type][$path] = [
                     'type'      => $type,
                     'extension' => pathinfo($path, PATHINFO_EXTENSION),
                     'name'      => $file->getBasename(),
                     'fullName'  => $file->getBasename(),
-                );
+                ];
             }
         }
 
@@ -162,10 +163,10 @@ class BrowseServer extends \XLite\View\SimpleDialog
     }
 
     /**
-     * Get file entry class 
-     * 
+     * Get file entry class
+     *
      * @param array $entry Entry
-     *  
+     *
      * @return string
      */
     protected function getItemClass(array $entry)
