@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Button\Addon;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Enter license key popup text
  *
@@ -15,12 +16,7 @@ namespace XLite\View\Button\Addon;
  */
 class EnterLicenseKey extends \XLite\View\Button\APopupButton
 {
-    /**
-     * Register JS files
-     *
-     * @return array
-     */
-    public function getJSFiles()
+    public function getJSFiles(): array
     {
         $list   = parent::getJSFiles();
         $list[] = 'button/js/enter_license_key.js';
@@ -28,47 +24,22 @@ class EnterLicenseKey extends \XLite\View\Button\APopupButton
         return $list;
     }
 
-    /**
-     * Return content for popup button
-     *
-     * @return string
-     */
-    protected function getDefaultLabel()
+    protected function getDefaultLabel(): string
     {
         return 'Activate license key';
     }
 
-    /**
-     * Return URL parameters to use in AJAX popup
-     *
-     * @return array
-     */
-    protected function prepareURLParams()
+    protected function prepareURLParams(): array
     {
         return [
             'target' => 'module_key',
             'action' => 'view',
-            'widget' => '\XLite\View\ModulesManager\AddonKey',
+            'widget' => '\XLite\View\LicenseManager\AddonKey',
         ];
     }
 
-    /**
-     * Return CSS classes
-     *
-     * @return string
-     */
-    protected function getClass()
+    protected function getClass(): string
     {
         return parent::getClass() . ' enter-license-key';
     }
-
-    /**
-     * Button is visible only if license has been activated
-     *
-     * @return boolean
-     */
-    protected function isVisible()
-    {
-        return parent::isVisible() && \XLite::hasXCNLicenseKey();
-    }
 }
