@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Button;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * More addons link
  *
@@ -19,14 +20,14 @@ class AllAddons extends \XLite\View\Button\Link
      * Check if widget is visible
      *
      * @return boolean
-     */    
+     */
     protected function isVisible()
     {
-        return parent::isVisible() 
-            && 'addons_list_installed' === \XLite\Core\Request::getInstance()->target
+        return parent::isVisible()
+            && \XLite\Core\Request::getInstance()->target === 'addons_list_installed'
             && isset(\XLite\Core\Request::getInstance()->recent);
     }
-    
+
     /**
      * Define widget parameters
      *
