@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class ConfirmRegular extends \XLite\View\Button\Regular
     /**
      * Widget parameter names
      */
-    const PARAM_CONFIRM_TEXT = 'confirmText';
+    public const PARAM_CONFIRM_TEXT = 'confirmText';
 
     /**
      * Define widget parameters
