@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -28,9 +27,7 @@ trait ConfirmableTrait
      */
     protected function getConfirmationText()
     {
-        return $this->getParam(static::getConfirmWidgetParamName()) === null
-            ? $this->getDefaultConfirmationText()
-            : $this->getParam(static::getConfirmWidgetParamName());
+        return $this->getParam(static::getConfirmWidgetParamName()) ?? $this->getDefaultConfirmationText();
     }
 
     /**
@@ -43,7 +40,8 @@ trait ConfirmableTrait
         $code = parent::getDefaultJSCode();
 
         if ($this->getConfirmationText()) {
-            $code = 'if (confirm(\'' . static::t($this->getConfirmationText()) . '\')) { ' . $code . ' }';
+            $code = 'if (confirm(\'' . static::t($this->getConfirmationText()) . '\')) { ' . $code .
+                ' } else { core.trigger(\'confirm_reject\', this) }';
         }
 
         return $code;
