@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,22 +15,22 @@ class FileSelector extends \XLite\View\Button\APopupButton
     /**
      * Name of object to link uploaded file (e.g. equal to 'product', 'category')
      */
-    const PARAM_OBJECT = 'object';
+    public const PARAM_OBJECT = 'object';
 
     /**
      * Identificator of linked object.
      */
-    const PARAM_OBJECT_ID = 'objectId';
+    public const PARAM_OBJECT_ID = 'objectId';
 
     /**
      * Name of the uploaded file object (e.g. 'image', 'icon', 'file')
      */
-    const PARAM_FILE_OBJECT = 'fileObject';
+    public const PARAM_FILE_OBJECT = 'fileObject';
 
     /**
      * Identificator of the uploaded file object. Used if file must be substituted (update action)
      */
-    const PARAM_FILE_OBJECT_ID = 'fileObjectId';
+    public const PARAM_FILE_OBJECT_ID = 'fileObjectId';
 
     /**
      * Register JS files
@@ -70,14 +69,14 @@ class FileSelector extends \XLite\View\Button\APopupButton
      */
     protected function prepareURLParams()
     {
-        return array(
+        return [
             'target'        => 'select_file',
             'object'        => $this->getParam(static::PARAM_OBJECT),
             'objectId'      => $this->getParam(static::PARAM_OBJECT_ID),
             'fileObject'    => $this->getParam(static::PARAM_FILE_OBJECT),
             'fileObjectId'  => $this->getParam(static::PARAM_FILE_OBJECT_ID),
             'widget'        => '\XLite\View\FileSelectorDialog',
-        );
+        ];
     }
 
     /**
@@ -99,12 +98,12 @@ class FileSelector extends \XLite\View\Button\APopupButton
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_OBJECT          => new \XLite\Model\WidgetParam\TypeString('Object', 'product'),
             static::PARAM_OBJECT_ID       => new \XLite\Model\WidgetParam\TypeInt('Object ID', 0),
             static::PARAM_FILE_OBJECT     => new \XLite\Model\WidgetParam\TypeString('File object', 'image'),
             static::PARAM_FILE_OBJECT_ID  => new \XLite\Model\WidgetParam\TypeInt('File object ID', 0),
-        );
+        ];
     }
 
     /**
