@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -15,16 +14,16 @@ class Category extends \XLite\View\Button\ItemsExport
 {
     protected function getAdditionalButtons()
     {
-        $list = array();
+        $list = [];
 
         $list['CSV'] = $this->getWidget(
-            array(
+            [
                 'label'      => 'CSV',
                 'style'      => 'always-enabled action link list-action',
                 'icon-style' => '',
                 'entity'     => 'XLite\Logic\Export\Step\Categories',
                 'session'    => \XLite\View\ItemsList\Model\Category::getConditionCellName(),
-            ),
+            ],
             'XLite\View\Button\ExportCSV'
         );
 
