@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -32,7 +31,7 @@ class Extensions extends \XLite\View\Button\APopupLink
     {
         return [
             'target' => 'hot_addons_list',
-            'widget' => 'XLite\View\ItemsList\Module\HotAddons',
+            'widget' => 'XLite\View\HotAddons',
         ];
     }
 
@@ -55,11 +54,10 @@ class Extensions extends \XLite\View\Button\APopupLink
     {
         $list = parent::getAttributes();
 
-        return array_merge($list, [
-            'data-toggle'    => 'tooltip',
-            'data-placement' => 'bottom',
-            'title'          => static::t('Add addons'),
-        ]);
+        return array_merge(
+            $list,
+            ['title' => static::t('Add addons')]
+        );
     }
 
     /**
