@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class QuickLook extends \XLite\View\Button\Regular
     /**
      * Widget param names
      */
-    const PARAM_PRODUCT = 'product';
+    public const PARAM_PRODUCT = 'product';
 
 
     /**
@@ -68,10 +67,13 @@ class QuickLook extends \XLite\View\Button\Regular
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_PRODUCT     => new \XLite\Model\WidgetParam\TypeObject(
-                'Product', null, false, '\XLite\Model\Product'
+                'Product',
+                null,
+                false,
+                '\XLite\Model\Product'
             ),
-        );
+        ];
     }
 }
