@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,26 +12,20 @@ namespace XLite\View\Button\Shipping;
  */
 class AddMethod extends \XLite\View\Button\APopupButton
 {
+    public const PARAM_SHIPPING_METHOD_TYPE = 'shippingType';
+
     /**
-     * Register CSS files
+     * Define widget params
      *
-     * @return array
+     * @return void
      */
-    public function getCSSFiles()
+    protected function defineWidgetParams()
     {
-        $list = parent::getCSSFiles();
-        $list[] = 'shipping/add_method/style.less';
+        parent::defineWidgetParams();
 
-        $onlineCarrierLink = new \XLite\View\Button\Shipping\OnlineCarrier();
-        $list = array_merge($list, $onlineCarrierLink->getCSSFiles());
-
-        $shippingTypes = new \XLite\View\Tabs\ShippingType();
-        $list = array_merge($list, $shippingTypes->getCSSFiles());
-
-        $shippingMarkups = new \XLite\View\ItemsList\Model\Shipping\Markups();
-        $list = array_merge($list, $shippingMarkups->getCSSFiles());
-
-        return $list;
+        $this->widgetParams += [
+            static::PARAM_SHIPPING_METHOD_TYPE => new \XLite\Model\WidgetParam\TypeString('Shipping methods type', ''),
+        ];
     }
 
     /**
@@ -42,23 +35,26 @@ class AddMethod extends \XLite\View\Button\APopupButton
      */
     public function getJSFiles()
     {
-        $list = parent::getJSFiles();
+        $list   = parent::getJSFiles();
         $list[] = 'button/js/shipping/add_method.js';
 
-        $list[] = 'shipping/add_method/controller.js';
-
-        $onlineCarrierLink = new \XLite\View\Button\Shipping\OnlineCarrier();
-        $list = array_merge($list, $onlineCarrierLink->getJSFiles());
-
         $shippingTypes = new \XLite\View\Tabs\ShippingType();
+
         $list = array_merge($list, $shippingTypes->getJSFiles());
 
-        $shippingMarkups = new \XLite\View\ItemsList\Model\Shipping\Markups();
-        $list = array_merge($list, $shippingMarkups->getJSFiles());
-
         return $list;
     }
 
+    /**
+     * Return shipping methods type which is provided to the widget
+     *
+     * @return string
+     */
+    protected function getShippingType()
+    {
+        return $this->getParam(static::PARAM_SHIPPING_METHOD_TYPE);
+    }
+
     /**
      * Return URL parameters to use in AJAX popup
      *
@@ -66,20 +62,11 @@ class AddMethod extends \XLite\View\Button\APopupButton
      */
     protected function prepareURLParams()
     {
-        return array(
-            'target' => 'shipping_method_selection',
-            'widget' => 'XLite\View\Shipping\AddMethod',
-        );
-    }
-
-    /**
-     * Return default button label
-     *
-     * @return string
-     */
-    protected function getDefaultLabel()
-    {
-        return 'Add shipping method';
+        return [
+            'target'       => 'shipping_method_selection',
+            'widget'       => 'XLite\View\Shipping\AddMethod',
+            'shippingType' => $this->getShippingType(),
+        ];
     }
 
     /**
