@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -33,11 +32,11 @@ class ConfirmWithPassword extends \XLite\View\Button\APopupButton
      */
     protected function prepareURLParams()
     {
-        return array(
+        return [
             'target' => 'confirm',
             'mode'   => 'withPassword',
             'widget' => 'XLite\View\Confirm\WithPassword',
-        );
+        ];
     }
 
     /**
