@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -30,7 +29,7 @@ class Review extends \XLite\View\Checkout\Step\AStep
      */
     public function getTitle()
     {
-        return 'Order review';
+        return static::t('Order review');
     }
 
     /**
