@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,9 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
 use XLite\Core\Layout;
+use XLite\Core\PreloadedLabels\ProviderInterface;
 
 /**
  * Common resources loader
@@ -16,7 +17,7 @@ use XLite\Core\Layout;
  * @ListChild (list="admin.center", zone="admin")
  * @ListChild (list="layout.main", zone="customer")
  */
-class CommonResources extends \XLite\View\AView
+class CommonResources extends \XLite\View\AView implements ProviderInterface
 {
     /**
      * Get list of methods, priorities and interfaces for the resources
@@ -26,10 +27,10 @@ class CommonResources extends \XLite\View\AView
     protected static function getResourcesSchema()
     {
         return [
-            ['getCommonFiles', 50, \XLite::COMMON_INTERFACE],
-            ['getResources', 60, null],
-            ['getThemeFiles', 70, null],
-            ['getPrintFiles', 400, null],
+            ['getCommonFiles', 50, \XLite::INTERFACE_WEB, \XLite::ZONE_COMMON],
+            ['getResources', 60, null, null],
+            ['getThemeFiles', 70, null, null],
+            ['getPrintFiles', 400, null, null],
         ];
     }
 
@@ -65,14 +66,14 @@ class CommonResources extends \XLite\View\AView
      */
     protected function getCommonFiles()
     {
-        $return = [
+        return [
             static::RESOURCE_JS  => [
                 [
                     'file'      => 'js/jquery.min.js',
                     'no_minify' => true,
                 ],
                 [
-                    'file'      => 'js/jquery-migrate.js',
+                    'file'      => 'js/jquery-migrate.min.js',
                     'no_minify' => true,
                 ],
                 [
@@ -87,10 +88,6 @@ class CommonResources extends \XLite\View\AView
                     'file'      => 'js/jquery.cookie.min.js',
                     'no_minify' => true,
                 ],
-                [
-                    'file'      => 'js/jquery.browser.min.js',
-                    'no_minify' => true,
-                ],
                 [
                     'file'      => 'js/underscore-min.js',
                     'no_minify' => true,
@@ -126,19 +123,18 @@ class CommonResources extends \XLite\View\AView
                 ],
                 'js/regex-mask-plugin.js',
                 'js/common.js',
-                'js/core.element.js',
-                'js/core.js',
-                'js/core.extend.js',
-                'js/core.controller.js',
-                'js/core.loadable.js',
-                'js/core.utils.js',
+                'js/xcart.element.js',
+                'js/xcart.js',
+                'js/xcart.extend.js',
+                'js/xcart.controller.js',
+                'js/xcart.loadable.js',
+                'js/xcart.utils.js',
                 'js/lazyload.js',
                 'js/json5.min.js',
-                'js/core.popup.js',
-                'js/core.popup_button.js',
-                'js/core.form.js',
+                'js/xcart.popup.js',
+                'js/xcart.popup_button.js',
+                'js/xcart.form.js',
                 'js/loadCSS.min.js',
-                'js/cssrelpreload.min.js',
                 'js/onloadCSS.min.js',
                 'js/functionNamePolyfill/Function.name.js',
                 [
@@ -154,7 +150,9 @@ class CommonResources extends \XLite\View\AView
                 [
                     'file'      => 'js/lazysizes.min.js',
                     'no_minify' => true,
-                ]
+                ],
+                'js/tooltip.js',
+                'js/popover.js'
             ],
             static::RESOURCE_CSS => [
                 'css/normalize.css',
@@ -168,20 +166,12 @@ class CommonResources extends \XLite\View\AView
                     'weight' => 0,
                 ],
                 [
-                    'url'   => '//fonts.googleapis.com/css?family='
-                        . urlencode('Open Sans:300italic,400italic,600italic,700italic,400,300,600,700')
-                        . '&subset='
-                        . urlencode('latin,cyrillic,latin-ext'),
-                    'media' => 'not print',
-                    'async' => true,
+                    'file'   => 'fonts/fonts.less',
+                    'media'  => 'screen',
+                    'weight' => 1,
                 ],
             ],
         ];
-
-        if (\XLite\Core\Auth::getInstance()->isLogged()) {
-            $return[static::RESOURCE_JS][] = 'js/tooltip.js';
-        }
-        return $return;
     }
 
     /**
@@ -193,7 +183,7 @@ class CommonResources extends \XLite\View\AView
      */
     protected function getThemeFiles($adminZone = null)
     {
-        return (null === $adminZone ? \XLite::isAdminZone() : $adminZone)
+        return ($adminZone ?? \XLite::isAdminZone())
             ? [
                 static::RESOURCE_CSS => [
                     'css/style.css',
@@ -247,7 +237,7 @@ class CommonResources extends \XLite\View\AView
      */
     public function getCommonLessFiles()
     {
-        return array_filter($this->getCommonFiles()[static::RESOURCE_CSS], function ($resource) {
+        return array_filter($this->getCommonFiles()[static::RESOURCE_CSS], static function ($resource) {
             if (is_array($resource)) {
                 if (!isset($resource['file'])) {
                     return false;
@@ -259,4 +249,11 @@ class CommonResources extends \XLite\View\AView
             return preg_match('/\.less$/S', $resource);
         });
     }
+
+    public function getPreloadedLanguageLabels()
+    {
+        return [
+            'Close' => static::t('Close')
+        ];
+    }
 }
