@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -33,16 +32,6 @@ abstract class Container extends \XLite\View\RequestHandler\ARequestHandler
         return null;
     }
 
-    /**
-     * isWrapper
-     *
-     * @return boolean
-     */
-    protected function isWrapper()
-    {
-        return $this->getParam(self::PARAM_TEMPLATE) == $this->getDefaultTemplate();
-    }
-
     /**
      * Return file name for body template
      *
@@ -80,6 +69,6 @@ abstract class Container extends \XLite\View\RequestHandler\ARequestHandler
      */
     protected function useBodyTemplate()
     {
-        return \XLite\Core\CMSConnector::isCMSStarted() && $this->isWrapper();
+        return false;
     }
 }
