@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,9 @@
 
 namespace XLite\View;
 
+use XLite\Core\Request;
+use XLite\Model\WidgetParam\TypeString;
+
 /**
  * File uploader
  */
@@ -18,20 +20,21 @@ class FileUploader extends \XLite\View\AView
     /**
      * Widget param names
      */
-    const PARAM_OBJECT             = 'object';
-    const PARAM_OBJECT_ID          = 'objectId';
-    const PARAM_MESSAGE            = 'message';
-    const PARAM_HELP_MESSAGE       = 'helpMessage';
-    const PARAM_MAX_WIDTH          = 'maxWidth';
-    const PARAM_MAX_HEIGHT         = 'maxHeight';
-    const PARAM_IS_IMAGE           = 'isImage';
-    const PARAM_IS_TEMPORARY       = 'isTemporary';
-    const PARAM_NAME               = 'fieldName';
-    const PARAM_MULTIPLE           = 'multiple';
-    const PARAM_POSITION           = 'position';
-    const PARAM_IS_VIA_URL_ALLOWED = 'isViaUrlAllowed';
-    const PARAM_IS_REMOVABLE       = 'removable';
-    const PARAM_HAS_ALT            = 'hasAlt';
+    public const PARAM_OBJECT             = 'object';
+    public const PARAM_OBJECT_ID          = 'objectId';
+    public const PARAM_MESSAGE            = 'message';
+    public const PARAM_HELP_MESSAGE       = 'helpMessage';
+    public const PARAM_MAX_WIDTH          = 'maxWidth';
+    public const PARAM_MAX_HEIGHT         = 'maxHeight';
+    public const PARAM_IS_IMAGE           = 'isImage';
+    public const PARAM_IS_TEMPORARY       = 'isTemporary';
+    public const PARAM_NAME               = 'fieldName';
+    public const PARAM_MULTIPLE           = 'multiple';
+    public const PARAM_POSITION           = 'position';
+    public const PARAM_IS_VIA_URL_ALLOWED = 'isViaUrlAllowed';
+    public const PARAM_IS_REMOVABLE       = 'removable';
+    public const PARAM_HAS_ALT            = 'hasAlt';
+    public const PARAM_ACCEPT             = 'accept';
 
     /**
      * @return array
@@ -170,7 +173,7 @@ class FileUploader extends \XLite\View\AView
             $index = $this->getParam(static::PARAM_OBJECT_ID);
             if (!$index) {
                 if ($this->getObject()) {
-                    $index = (integer)$this->getObject()->getId();
+                    $index = (int)$this->getObject()->getId();
                     if ($this->getParam(static::PARAM_IS_TEMPORARY) && $index > 0) {
                         $index = '-' . $index;
                     }
@@ -195,7 +198,7 @@ class FileUploader extends \XLite\View\AView
                 continue;
             }
 
-            if (is_numeric($part) && (integer)$part == $part) {
+            if (is_numeric($part) && (int)$part == $part) {
                 $name .= '[' . $part . ']';
             } else {
                 $name .= '.' . $part;
@@ -206,7 +209,7 @@ class FileUploader extends \XLite\View\AView
             $index = $this->getParam(static::PARAM_OBJECT_ID);
             if (!$index) {
                 if ($this->getObject()) {
-                    $index = (integer)$this->getObject()->getId();
+                    $index = (int)$this->getObject()->getId();
                     if ($this->getParam(static::PARAM_IS_TEMPORARY) && $index > 0) {
                         $index = '-' . $index;
                     }
@@ -266,6 +269,7 @@ class FileUploader extends \XLite\View\AView
             static::PARAM_IS_VIA_URL_ALLOWED => new \XLite\Model\WidgetParam\TypeInt('Is ViaUrl allowed', true),
             static::PARAM_IS_REMOVABLE       => new \XLite\Model\WidgetParam\TypeBool('Is removable', true),
             static::PARAM_HAS_ALT            => new \XLite\Model\WidgetParam\TypeBool('Has alt', true),
+            static::PARAM_ACCEPT             => new TypeString('Accept extensions/mime types (divided by comma)', '')
         ];
     }
 
@@ -281,18 +285,6 @@ class FileUploader extends \XLite\View\AView
         return $object && $object->getId();
     }
 
-    /**
-     * Set widget params
-     *
-     * @param array $params Handler params
-     *
-     * @return void
-     */
-    public function setWidgetParams(array $params)
-    {
-        parent::setWidgetParams($params);
-    }
-
     /**
      * Check object is image or not
      *
@@ -382,6 +374,16 @@ class FileUploader extends \XLite\View\AView
             && $this->isImage();
     }
 
+    /**
+     * Return alt
+     *
+     * @return string
+     */
+    protected function getAlt()
+    {
+        return $this->getParam(static::PARAM_IS_IMAGE) && method_exists($this->getObject(), 'getAlt') ? $this->getObject()->getAlt() : '';
+    }
+
     /**
      * Check widget has alt or not
      *
@@ -400,7 +402,9 @@ class FileUploader extends \XLite\View\AView
      */
     protected function isModelHasAlt()
     {
-        $result = $this->getParam(static::PARAM_IS_IMAGE) && method_exists($this->getObject(), 'getAlt');
+        $result = $this->getParam(static::PARAM_IS_IMAGE)
+            && \is_object($this->getObject())
+            && method_exists($this->getObject(), 'getAlt');
 
         if (
             !$result
@@ -446,6 +450,27 @@ class FileUploader extends \XLite\View\AView
         return $result;
     }
 
+    protected function getOptions(): array
+    {
+        return [
+            'basePath'            => $this->getVModel(),
+            'name'                => $this->getName(),
+            'isRemovable'         => $this->isRemovable(),
+            'isTemporary'         => $this->isTemporary(),
+            'isMultiple'          => $this->isMultiple(),
+            'isImage'             => $this->isImage(),
+            'hasFile'             => $this->hasFile(),
+            'error'               => $this->getMessage() ? '1' : '',
+            'defaultErrorMessage' => static::t($this->getErrorMessageDefault()),
+            'alt'                 => $this->hasAlt() ? $this->getAlt() : '',
+            'initialAlt'          => $this->hasAlt() ? $this->getAlt() : '',
+            'realErrorMessage'    => static::t($this->getMessage()),
+            'preview'             => $this->getPreview(),
+            'link'                => $this->getLink(),
+            'temp_id'             => $this->isTemporary() ? $this->getObject()->getId() : null,
+        ];
+    }
+
     /**
      * Return templates directory name
      *
@@ -475,4 +500,9 @@ class FileUploader extends \XLite\View\AView
     {
         return $this->fieldName == 'favicon';
     }
+
+    protected function getAccept(): string
+    {
+        return (string) (Request::getInstance()->accept ?? $this->getParam(self::PARAM_ACCEPT));
+    }
 }
