@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ abstract class AItem extends \XLite\View\Form\AForm
     /**
      * Widget paramater names
      */
-    const PARAM_ITEM    = 'item';
+    public const PARAM_ITEM    = 'item';
 
 
     /**
@@ -39,7 +38,10 @@ abstract class AItem extends \XLite\View\Form\AForm
         parent::defineWidgetParams();
 
         $this->widgetParams[self::PARAM_ITEM] = new \XLite\Model\WidgetParam\TypeObject(
-            'Cart item', null, false, '\XLite\Model\OrderItem'
+            'Cart item',
+            null,
+            false,
+            '\XLite\Model\OrderItem'
         );
     }
 
@@ -53,9 +55,9 @@ abstract class AItem extends \XLite\View\Form\AForm
         parent::initView();
 
         $this->widgetParams[self::PARAM_FORM_PARAMS]->appendValue(
-            array(
+            [
                 'cart_id' => $this->getParam(self::PARAM_ITEM)->getItemId()
-            )
+            ]
         );
     }
 }
