@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -30,8 +29,8 @@ abstract class AShippingEstimator extends \XLite\View\Form\AForm
      */
     protected function getCommonFormParams()
     {
-        return parent::getCommonFormParams() + array(
+        return parent::getCommonFormParams() + [
             'widget' => 'XLite\View\ShippingEstimator\ShippingEstimate',
-        );
+        ];
     }
 }
