@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -40,10 +39,9 @@ class Table extends \XLite\View\Form\ItemsList\AItemsList
      */
     protected function getDefaultParams()
     {
-        return array(
+        return [
             'product_class_id'  => intval(\XLite\Core\Request::getInstance()->product_class_id),
             'itemsList'         => '\XLite\View\ItemsList\Model\Attribute',
-        );
+        ];
     }
-
 }
