@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Form\Model;
 
+use XLite\Core\Request;
+
 /**
  * Attributes list search form
  */
@@ -64,10 +65,15 @@ class Attribute extends \XLite\View\Form\AForm
      */
     protected function getDefaultParams()
     {
-        return array(
-            'id'                => \XLite\Core\Request::getInstance()->id,
-            'product_class_id'  => \XLite\Core\Request::getInstance()->product_class_id,
-        );
-    }
+        $params = [
+            'id'                => Request::getInstance()->id,
+            'product_class_id'  => Request::getInstance()->product_class_id,
+        ];
 
+        if ($returnURL = Request::getInstance()->return_url) {
+            $params['returnURL'] = $returnURL;
+        }
+
+        return $params;
+    }
 }
