@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -64,9 +63,8 @@ class ProductSelection extends \XLite\View\Form\AForm
      */
     protected function getDefaultParams()
     {
-        return array(
+        return [
             'id' => \XLite\Core\Request::getInstance()->id,
-        );
+        ];
     }
-
-}
\ No newline at end of file
+}
