@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -63,18 +62,17 @@ class AddToCart extends \XLite\View\Form\Product\AProduct
      */
     protected function getFormDefaultParams()
     {
-        $result = array();
+        $result = [];
 
         $product = $this->getProduct();
 
         if ($product) {
-            $result = array(
+            $result = [
                 'product_id'  => $product->getProductId(),
                 'category_id' => $product->getCategoryId(),
-            );
+            ];
         }
 
         return $result;
     }
-
 }
