@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -40,9 +39,9 @@ class Main extends \XLite\View\Form\Product\Search\Customer\ACustomer
      */
     protected function getDefaultParams()
     {
-        return parent::getDefaultParams() + array(
+        return parent::getDefaultParams() + [
             'searchInSubcats'   => 'Y',
             'itemsList'         => '\XLite\View\ItemsList\Product\Customer\Search',
-        );
+        ];
     }
 }
