@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -17,7 +16,7 @@ class Sort extends \XLite\View\Form\AForm
      * Widget parameter names
      */
 
-    const PARAM_PARAMS = 'params';
+    public const PARAM_PARAMS = 'params';
 
 
     /**
@@ -49,9 +48,9 @@ class Sort extends \XLite\View\Form\AForm
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
-            self::PARAM_PARAMS => new \XLite\Model\WidgetParam\TypeCollection('Parameters', array()),
-        );
+        $this->widgetParams += [
+            self::PARAM_PARAMS => new \XLite\Model\WidgetParam\TypeCollection('Parameters', []),
+        ];
 
         $this->widgetParams[self::PARAM_CLASS_NAME]->setValue('sort-box');
     }
