@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,7 +19,7 @@ class TestEmail extends \XLite\View\Form\AForm
      */
     protected function getDefaultTarget()
     {
-        return 'settings';
+        return 'test_email';
     }
 
     /**
@@ -32,18 +31,4 @@ class TestEmail extends \XLite\View\Form\AForm
     {
         return 'test_email';
     }
-
-    /**
-     * Required form parameters
-     *
-     * @return array
-     */
-    protected function getCommonFormParams()
-    {
-        $list = parent::getCommonFormParams();
-
-        $list['page'] = $this->page;
-
-        return $list;
-    }
 }
