@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\FormField;
 
+use XLite\Model\WidgetParam\TypeString;
+
 /**
  * Abstract form field
  */
@@ -16,52 +17,50 @@ abstract class AFormField extends \XLite\View\AView
     /**
      * Widget param names
      */
-    const PARAM_VALUE      = 'value';
-    const PARAM_REQUIRED   = 'required';
-    const PARAM_ATTRIBUTES = 'attributes';
-    const PARAM_NAME       = 'fieldName';
-    const PARAM_ID         = 'fieldId';
-    const PARAM_LABEL      = 'label';
-    const PARAM_LABEL_PARAMS = 'labelParams';
-    const PARAM_COMMENT    = 'comment';
-    const PARAM_HELP       = 'help';
-    const PARAM_HELP_WIDGET       = 'helpWidget';
-    const PARAM_LABEL_HELP        = 'labelHelp';
-    const PARAM_LABEL_HELP_WIDGET = 'labelHelpWidget';
-    const PARAM_FIELD_ONLY      = 'fieldOnly';
-    const PARAM_WRAPPER_CLASS   = 'wrapperClass';
-    const PARAM_FORM_CONTROL   = 'formControl';
+    public const PARAM_VALUE      = 'value';
+    public const PARAM_REQUIRED   = 'required';
+    public const PARAM_ATTRIBUTES = 'attributes';
+    public const PARAM_NAME       = 'fieldName';
+    public const PARAM_ID         = 'fieldId';
+    public const PARAM_LABEL      = 'label';
+    public const PARAM_LABEL_PARAMS = 'labelParams';
+    public const PARAM_COMMENT    = 'comment';
+    public const PARAM_HELP       = 'help';
+    public const PARAM_HELP_WIDGET       = 'helpWidget';
+    public const PARAM_LABEL_HELP        = 'labelHelp';
+    public const PARAM_LABEL_HELP_WIDGET = 'labelHelpWidget';
+    public const PARAM_FIELD_ONLY      = 'fieldOnly';
+    public const PARAM_FIELD_LABEL     = 'fieldLabel';
+    public const PARAM_WRAPPER_CLASS   = 'wrapperClass';
+    public const PARAM_FORM_CONTROL   = 'formControl';
+    public const PARAM_LINK_HREF       = 'linkHref';
+    public const PARAM_LINK_TEXT       = 'linkText';
+    public const PARAM_LINK_IMG        = 'linkImg';
+    public const PARAM_TRUSTED         = 'trusted';
+    public const PARAM_NO_PARENT_FORM  = 'noParentForm';
 
-    /** @deprecated */
-    const PARAM_USE_COLON       = 'useColon';
-    const PARAM_LINK_HREF       = 'linkHref';
-    const PARAM_LINK_TEXT       = 'linkText';
-    const PARAM_LINK_IMG        = 'linkImg';
-    const PARAM_TRUSTED         = 'trusted';
-    const PARAM_NO_PARENT_FORM  = 'noParentForm';
+    public const PARAM_IS_ALLOWED_FOR_CUSTOMER = 'isAllowedForCustomer';
 
-    const PARAM_IS_ALLOWED_FOR_CUSTOMER = 'isAllowedForCustomer';
+    public const PARAM_DEPENDENCY = 'dependency';
 
-    const PARAM_DEPENDENCY = 'dependency';
-
-    const PARAM_EDIT_ON_CLICK = 'editOnClick';
+    public const PARAM_EDIT_ON_CLICK = 'editOnClick';
 
     /**
      * Available field types
      */
-    const FIELD_TYPE_LABEL      = 'label';
-    const FIELD_TYPE_TEXT       = 'text';
-    const FIELD_TYPE_PASSWORD   = 'password';
-    const FIELD_TYPE_SELECT     = 'select';
-    const FIELD_TYPE_CHECKBOX   = 'checkbox';
-    const FIELD_TYPE_RADIO      = 'radio';
-    const FIELD_TYPE_TEXTAREA   = 'textarea';
-    const FIELD_TYPE_SEPARATOR  = 'separator';
-    const FIELD_TYPE_ITEMS_LIST = 'itemsList';
-    const FIELD_TYPE_HIDDEN     = 'hidden';
-    const FIELD_TYPE_LISTBOX    = 'listbox';
-    const FIELD_TYPE_FILE       = 'file';
-    const FIELD_TYPE_COMPLEX    = 'complex';
+    public const FIELD_TYPE_LABEL      = 'label';
+    public const FIELD_TYPE_TEXT       = 'text';
+    public const FIELD_TYPE_PASSWORD   = 'password';
+    public const FIELD_TYPE_SELECT     = 'select';
+    public const FIELD_TYPE_CHECKBOX   = 'checkbox';
+    public const FIELD_TYPE_RADIO      = 'radio';
+    public const FIELD_TYPE_TEXTAREA   = 'textarea';
+    public const FIELD_TYPE_SEPARATOR  = 'separator';
+    public const FIELD_TYPE_ITEMS_LIST = 'itemsList';
+    public const FIELD_TYPE_HIDDEN     = 'hidden';
+    public const FIELD_TYPE_LISTBOX    = 'listbox';
+    public const FIELD_TYPE_FILE       = 'file';
+    public const FIELD_TYPE_COMPLEX    = 'complex';
 
     /**
      * name
@@ -96,11 +95,11 @@ abstract class AFormField extends \XLite\View\AView
      *
      * @var array
      */
-    protected $nameTranslation = array(
+    protected $nameTranslation = [
         '[' => '-',
         ']' => '',
         '_' => '-',
-    );
+    ];
 
     /**
      * Return field type
@@ -172,10 +171,23 @@ abstract class AFormField extends \XLite\View\AView
         return $this->getParam(self::PARAM_LABEL);
     }
 
+    /**
+     * @return string
+     */
+    public function getFieldLabel()
+    {
+        return $this->getParam(static::PARAM_FIELD_LABEL);
+    }
+
+    public function isFieldLabelHidden(): bool
+    {
+        return true;
+    }
+
     /**
      * getLabel
      *
-     * @return string
+     * @return array
      */
     public function getLabelParams()
     {
@@ -199,7 +211,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     public function getFieldId()
     {
-        return $this->getParam(self::PARAM_ID) ?: strtolower(strtr($this->getName(), $this->nameTranslation));
+        return $this->getParam(self::PARAM_ID) ?: strtolower(strtr($this->getName() ?? '', $this->nameTranslation));
     }
 
     /**
@@ -221,10 +233,10 @@ abstract class AFormField extends \XLite\View\AView
     {
         $this->setValue($this->sanitize());
 
-        return array(
+        return [
             $this->getValidityFlag(),
             $this->getValidityFlag() ? null : $this->errorMessage
-        );
+        ];
     }
 
     /**
@@ -245,11 +257,11 @@ abstract class AFormField extends \XLite\View\AView
      *
      * @param array $params Widget params OPTIONAL
      */
-    public function __construct(array $params = array())
+    public function __construct(array $params = [])
     {
         if (isset($params[self::PARAM_NAME])) {
             $this->name = $params[self::PARAM_NAME];
-        };
+        }
 
         parent::__construct($params);
     }
@@ -304,6 +316,14 @@ abstract class AFormField extends \XLite\View\AView
         return 'form_field/form_field.twig';
     }
 
+    /**
+     * @return string
+     */
+    protected function getFieldLabelTemplate()
+    {
+        return 'form_field/form_field_label.twig';
+    }
+
     /**
      * Return name of the folder with templates
      *
@@ -321,7 +341,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function checkSavedValue()
     {
-        return null !== $this->callFormMethod('getSavedData', array($this->getName()));
+        return $this->callFormMethod('getSavedData', [$this->getName()]) !== null;
     }
 
     /**
@@ -331,7 +351,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getValidityFlag()
     {
-        if (null === $this->validityFlag) {
+        if ($this->validityFlag === null) {
             $this->validityFlag = $this->checkFieldValidity();
         }
 
@@ -365,10 +385,10 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getCommonAttributes()
     {
-        return array(
+        return [
             'id'   => $this->getFieldId(),
             'name' => $this->getName(),
-        );
+        ];
     }
 
     /**
@@ -432,7 +452,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function assembleValidationRules()
     {
-        return $this->isRequired() ? array('required') : array();
+        return $this->isRequired() ? ['required'] : [];
     }
 
     /**
@@ -478,13 +498,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getAttributesCode()
     {
-        $result = '';
-
-        foreach ($this->getAttributes() as $name => $value) {
-            $result .= ' ' . $name . '="' . func_htmlspecialchars($value) . '"';
-        }
-
-        return $result;
+        return ' ' . static::convertToHtmlAttributeString($this->getAttributes());
     }
 
     /**
@@ -515,7 +529,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getDefaultValue()
     {
-        return null !== $this->name ? $this->callFormMethod('getDefaultFieldValue', array($this->name)) : null;
+        return $this->name !== null ? $this->callFormMethod('getDefaultFieldValue', [$this->name]) : null;
     }
 
     /**
@@ -528,14 +542,14 @@ abstract class AFormField extends \XLite\View\AView
         $isValid = true;
         $errorMessage = null;
 
-        if (null !== $this->name) {
-            $result = $this->callFormMethod('validateFormField', array($this));
+        if ($this->name !== null) {
+            $result = $this->callFormMethod('validateFormField', [$this]);
             if (is_array($result)) {
-                list($isValid, $errorMessage) = $result;
+                [$isValid, $errorMessage] = $result;
             }
         }
 
-        return array($isValid, $errorMessage);
+        return [$isValid, $errorMessage];
     }
 
     /**
@@ -555,7 +569,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getDefaultLabelParams()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -565,7 +579,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getDefaultAttributes()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -587,42 +601,40 @@ abstract class AFormField extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
-            self::PARAM_ID         => new \XLite\Model\WidgetParam\TypeString('Id', ''),
-            self::PARAM_NAME       => new \XLite\Model\WidgetParam\TypeString('Name', $this->getDefaultName()),
-            self::PARAM_VALUE      => new \XLite\Model\WidgetParam\TypeString('Value', $this->getDefaultValue()),
-            self::PARAM_LABEL      => new \XLite\Model\WidgetParam\TypeString('Label', $this->getDefaultLabel()),
-            self::PARAM_LABEL_PARAMS => new \XLite\Model\WidgetParam\TypeCollection('Label params', $this->getDefaultLabelParams()),
-            self::PARAM_REQUIRED   => new \XLite\Model\WidgetParam\TypeBool('Required', false),
-            self::PARAM_COMMENT    => new \XLite\Model\WidgetParam\TypeString('Comment', null),
-            self::PARAM_HELP       => new \XLite\Model\WidgetParam\TypeString('Help', null),
+        $this->widgetParams += [
+            self::PARAM_ID                => new \XLite\Model\WidgetParam\TypeString('Id', ''),
+            self::PARAM_NAME              => new \XLite\Model\WidgetParam\TypeString('Name', $this->getDefaultName()),
+            self::PARAM_VALUE             => new \XLite\Model\WidgetParam\TypeString('Value', $this->getDefaultValue()),
+            self::PARAM_LABEL             => new \XLite\Model\WidgetParam\TypeString('Label', $this->getDefaultLabel()),
+            self::PARAM_LABEL_PARAMS      => new \XLite\Model\WidgetParam\TypeCollection('Label params', $this->getDefaultLabelParams()),
+            self::PARAM_REQUIRED          => new \XLite\Model\WidgetParam\TypeBool('Required', false),
+            self::PARAM_COMMENT           => new \XLite\Model\WidgetParam\TypeString('Comment', null),
+            self::PARAM_HELP              => new \XLite\Model\WidgetParam\TypeString('Help', null),
             self::PARAM_HELP_WIDGET       => new \XLite\Model\WidgetParam\TypeString('Help widget class name', null),
             self::PARAM_LABEL_HELP        => new \XLite\Model\WidgetParam\TypeString('Label help', null),
             self::PARAM_LABEL_HELP_WIDGET => new \XLite\Model\WidgetParam\TypeString('Label help widget class name', null),
-            self::PARAM_ATTRIBUTES => new \XLite\Model\WidgetParam\TypeCollection('Attributes', $this->getDefaultAttributes()),
-            self::PARAM_WRAPPER_CLASS => new \XLite\Model\WidgetParam\TypeString('Wrapper class', $this->getDefaultWrapperClass()),
-            self::PARAM_FORM_CONTROL   => new \XLite\Model\WidgetParam\TypeBool('Is form control', true),
+            self::PARAM_ATTRIBUTES        => new \XLite\Model\WidgetParam\TypeCollection('Attributes', $this->getDefaultAttributes()),
+            self::PARAM_WRAPPER_CLASS     => new \XLite\Model\WidgetParam\TypeString('Wrapper class', $this->getDefaultWrapperClass()),
+            self::PARAM_FORM_CONTROL      => new \XLite\Model\WidgetParam\TypeBool('Is form control', true),
+            static::PARAM_FIELD_LABEL     => new TypeString('Field label text', ''),
 
-            /** @deprecated */
-            self::PARAM_USE_COLON     => new \XLite\Model\WidgetParam\TypeBool('Use colon', false),
-
-            self::PARAM_LINK_HREF     => new \XLite\Model\WidgetParam\TypeString('Link href', ''),
-            self::PARAM_LINK_TEXT     => new \XLite\Model\WidgetParam\TypeString('Link text', ''),
-            self::PARAM_LINK_IMG      => new \XLite\Model\WidgetParam\TypeString('Link img', ''),
+            self::PARAM_LINK_HREF      => new \XLite\Model\WidgetParam\TypeString('Link href', ''),
+            self::PARAM_LINK_TEXT      => new \XLite\Model\WidgetParam\TypeString('Link text', ''),
+            self::PARAM_LINK_IMG       => new \XLite\Model\WidgetParam\TypeString('Link img', ''),
             self::PARAM_NO_PARENT_FORM => new \XLite\Model\WidgetParam\TypeBool('Form field has no parent form', false),
 
             self::PARAM_IS_ALLOWED_FOR_CUSTOMER => new \XLite\Model\WidgetParam\TypeBool(
                 'Is allowed for customer',
                 $this->isAllowedForCustomer
             ),
-            self::PARAM_FIELD_ONLY    => new \XLite\Model\WidgetParam\TypeBool(
+            self::PARAM_FIELD_ONLY              => new \XLite\Model\WidgetParam\TypeBool(
                 'Skip wrapping with label and required flag, display just a field itself',
                 $this->getDefaultParamFieldOnly()
             ),
-            self::PARAM_DEPENDENCY => new \XLite\Model\WidgetParam\TypeCollection('Dependency', array()),
-            self::PARAM_TRUSTED    => new \XLite\Model\WidgetParam\TypeBool('Trusted (value may contain anything)', false),
-            self::PARAM_EDIT_ON_CLICK => new \XLite\Model\WidgetParam\TypeBool('Edit on click', false),
-        );
+            self::PARAM_DEPENDENCY              => new \XLite\Model\WidgetParam\TypeCollection('Dependency', []),
+            self::PARAM_TRUSTED                 => new \XLite\Model\WidgetParam\TypeBool('Trusted (value may contain anything)', false),
+            self::PARAM_EDIT_ON_CLICK           => new \XLite\Model\WidgetParam\TypeBool('Edit on click', false),
+        ];
     }
 
     /**
@@ -632,7 +644,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function checkFieldValue()
     {
-        return '' !== $this->getValue();
+        return $this->getValue() !== '';
     }
 
     /**
@@ -647,9 +659,8 @@ abstract class AFormField extends \XLite\View\AView
         if ($this->isRequired() && !$this->checkFieldValue()) {
             $this->errorMessage = $this->getRequiredFieldErrorMessage();
             $result = false;
-
         } else {
-            list($result, $this->errorMessage) = $this->validateFormField();
+            [$result, $this->errorMessage] = $this->validateFormField();
         }
 
         return $result;
@@ -662,7 +673,7 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getRequiredFieldErrorMessage()
     {
-        return \XLite\Core\Translation::lbl('The X field is empty', array('name' => $this->getLabel()));
+        return \XLite\Core\Translation::lbl('The X field is empty', ['name' => $this->getLabel()]);
     }
 
     /**
@@ -683,16 +694,15 @@ abstract class AFormField extends \XLite\View\AView
      *
      * @return mixed
      */
-    protected function callFormMethod($method, array $args = array())
+    protected function callFormMethod($method, array $args = [])
     {
         $result = null;
 
         if (!$this->getParam(static::PARAM_NO_PARENT_FORM)) {
-
             $form = \XLite\View\Model\AModel::getCurrentForm();
 
             $result = $form && method_exists($form, $method)
-                ? call_user_func_array(array($form, $method), $args)
+                ? call_user_func_array([$form, $method], $args)
                 : null;
         }
 
@@ -717,9 +727,12 @@ abstract class AFormField extends \XLite\View\AView
     protected function getDefaultWrapperClass()
     {
         $suffix = preg_replace(
-            '/^.+\\\(?:Module\\\([a-zA-Z0-9]+\\\[a-zA-Z0-9]+\\\))?View\\\FormField\\\(.+)$/Ss',
-            '$1$2',
-            get_called_class()
+            [
+                '/^(?:\\\\)?XLite\\\\View\\\\FormField\\\\(.+)$/Ss',
+                '/^(?:\\\\)?(?:[a-zA-Z0-9]+\\\\[a-zA-Z0-9]+\\\\)View\\\\FormField\\\\(.+)$/Ss'
+            ],
+            '$1',
+            static::class
         );
         $suffix = str_replace('\\', '-', strtolower($suffix));
 
@@ -767,7 +780,23 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function hasDifferentSavedValue()
     {
-        return $this->callFormMethod('hasDifferentSavedValue', array($this->getName()));
+        return $this->callFormMethod('hasDifferentSavedValue', [$this->getName()]);
+    }
+
+    /**
+     * @return \XLite\Core\Translation|Label
+     */
+    protected function getSavedErrorMessage()
+    {
+        return $this->callFormMethod('getSavedErrorMessage', [$this->getName()]);
+    }
+
+    /**
+     * @return boolean
+     */
+    protected function showErrorsViaTopMessage()
+    {
+        return $this->callFormMethod('showErrorsViaTopMessage');
     }
 
     /**
@@ -809,10 +838,10 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getContainerAttributes()
     {
-        return array(
+        return [
             'class'          => $this->getContainerClass(),
             'data-is-escape' => $this->isEscapeValue() ? '1' : '',
-        );
+        ];
     }
 
     /**
@@ -842,14 +871,12 @@ abstract class AFormField extends \XLite\View\AView
      */
     protected function getViewContainerAttributes()
     {
-        $attributes = [
+        return [
             'class' => [
                 'view',
                 'editable',
             ],
         ];
-
-        return $attributes;
     }
 
     /**
