@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,19 @@
 
 namespace XLite\View\FormField;
 
-use Includes\Utils\Module\Manager;
+use XCart\Domain\ModuleManagerDomain;
 
 class ContactUsComment extends \XLite\View\FormField\AFormField
 {
+    protected ?ModuleManagerDomain $moduleManagerDomain;
+
+    public function __construct(array $params = [])
+    {
+        $this->moduleManagerDomain = \XCart\Container::getContainer()?->get(ModuleManagerDomain::class);
+
+        parent::__construct($params);
+    }
+
     /**
      * Return field type
      *
@@ -33,14 +41,12 @@ class ContactUsComment extends \XLite\View\FormField\AFormField
     }
 
     /**
-     * @return string
+     * @return string|null
      */
     public function getLink()
     {
-        if (Manager::getRegistry()->getModule('CDev\ContactUs')) {
-            return Manager::getRegistry()->isModuleEnabled('CDev\ContactUs')
-                ? Manager::getRegistry()->getModuleSettingsUrl('CDev\ContactUs')
-                : Manager::getRegistry()->getModuleServiceURL('CDev\ContactUs');
+        if ($this->moduleManagerDomain?->isEnabled('CDev-ContactUs')) {
+            return $this->buildURL('module', '', ['moduleId' => 'CDev-ContactUs']);
         }
 
         return null;
