@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -36,4 +35,20 @@ class Image extends \XLite\View\FormField\FileUploader\AFileUploader
 
         return $list;
     }
+
+    protected function getAccept(): string
+    {
+        $isSvgAllowed = $this->isSvgAllowed();
+
+        return implode(
+            ', ',
+            array_map(
+                static fn (string $ext): string => ".{$ext}",
+                array_filter(
+                    \XLite\Model\Base\Image::getAllowedExtensions(),
+                    static fn(string $ext): bool => ($isSvgAllowed || $ext !== \XLite\Model\Base\Image::SVG_EXTENSION)
+                )
+            )
+        );
+    }
 }
