@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,7 +21,7 @@ class Position extends \XLite\View\FormField\Inline\Base\Single
     {
         $list = parent::getCSSFiles();
 
-        $list[] = 'form_field/inline/input/text/position.css';
+        $list[] = 'form_field/inline/input/text/position.less';
 
         return $list;
     }
@@ -57,8 +56,6 @@ class Position extends \XLite\View\FormField\Inline\Base\Single
     protected function getFieldParams(array $field)
     {
         return parent::getFieldParams($field)
-            + array(\XLite\View\FormField\Input\Text\Base\Numeric::PARAM_MOUSE_WHEEL_ICON => false);
+            + [\XLite\View\FormField\Input\Text\Base\Numeric::PARAM_MOUSE_WHEEL_ICON => false];
     }
-
 }
-
