@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,10 +21,10 @@ class Move extends \XLite\View\FormField\Inline\Input\Text\Position\Move
      */
     protected function preprocessValueBeforeSave($value)
     {
-        return array(
+        return [
             'position' => $value,
             'product'  => $this->getProduct(),
-        );
+        ];
     }
 
     /**
