@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,7 +21,6 @@ class Product extends \XLite\View\FormField\Inline\Input\Text\Price
      */
     protected function getFieldParams(array $field)
     {
-        return parent::getFieldParams($field) + array('min' => 0);
+        return parent::getFieldParams($field) + ['min' => 0];
     }
-
 }
