@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\View\FormField\Inline\Select\Select2;
 
-
 class Countries extends \XLite\View\FormField\Inline\Base\Single
 {
     /**
@@ -40,8 +38,8 @@ class Countries extends \XLite\View\FormField\Inline\Base\Single
      */
     protected function preprocessValueBeforeSave($value)
     {
-        return array_map(function ($code) {
+        return array_map(static function ($code) {
             return \XLite\Core\Database::getRepo('XLite\Model\Country')->find($code);
         }, (array)$value);
     }
-}
\ No newline at end of file
+}
