@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -32,7 +31,7 @@ class Enabled extends \XLite\View\FormField\Input\Checkbox\Simple
      */
     protected function isChecked()
     {
-        return parent::isChecked() || true === (bool) $this->getValue();
+        return parent::isChecked() || (bool) $this->getValue() === true;
     }
 
     /**
