@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,19 +7,18 @@
 
 namespace XLite\View\FormField\Input\Checkbox;
 
-
 /**
  * StatesForCountries
  */
 class StatesForCountries extends \XLite\View\FormField\Input\Checkbox\YesNo
 {
-    const SESSION_CELL_NAME = 'states_for_selected_countries';
+    public const SESSION_CELL_NAME = 'states_for_selected_countries';
 
     /**
      * @inheritdoc
      */
     public function getValue()
     {
-        return (boolean)\XLite\Core\Session::getInstance()->{static::SESSION_CELL_NAME};
+        return (bool)\XLite\Core\Session::getInstance()->{static::SESSION_CELL_NAME};
     }
-}
\ No newline at end of file
+}
