@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\View\FormField\Input\Text;
 
-
 use XLite\View\FormField\Select\EmailFrom;
 
 class EmailFromManual extends \XLite\View\FormField\Input\Text\Email
@@ -19,7 +17,7 @@ class EmailFromManual extends \XLite\View\FormField\Input\Text\Email
 
         $request = \XLite\Core\Request::getInstance();
 
-        if ($result && mb_strtolower($request->action) === 'update') {
+        if ($result && mb_strtolower((string) $request->action) === 'update') {
             $result = $request->mail_from_type === EmailFrom::OPTION_MANUAL;
         }
 
@@ -30,4 +28,4 @@ class EmailFromManual extends \XLite\View\FormField\Input\Text\Email
     {
         return static::t('Specify email address');
     }
-}
\ No newline at end of file
+}
