@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -45,7 +44,7 @@ class IntegerWithInfinity extends \XLite\View\FormField\Input\Text\Integer
      */
     protected function assembleValidationRules()
     {
-        $list = array_diff(parent::assembleValidationRules(), array('custom[integer]'));
+        $list = array_diff(parent::assembleValidationRules(), ['custom[integer]']);
         $list[] = 'custom[integerWithInfinity]';
 
         return $list;
@@ -60,7 +59,7 @@ class IntegerWithInfinity extends \XLite\View\FormField\Input\Text\Integer
      */
     protected function assembleClasses(array $classes)
     {
-        $list = array_diff(parent::assembleClasses($classes), array('integer'));
+        $list = array_diff(parent::assembleClasses($classes), ['integer']);
         $list[] = 'with-infinity';
         $list[] = 'integer-with-infinity';
 
