@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -23,20 +22,18 @@ class SKU extends \XLite\View\FormField\Input\Text
         $result = parent::checkFieldValidity();
 
         if ($result && $this->getValue()) {
-
             $validator = new \XLite\Core\Validator\SKU($this->getProductId());
 
             try {
                 $validator->validate($this->getValue());
-
             } catch (\XLite\Core\Validator\Exception $exception) {
                 $message = static::t($exception->getMessage(), $exception->getLabelArguments());
                 $result = false;
                 $this->errorMessage = \XLite\Core\Translation::lbl(
                     ($exception->getPublicName() ? static::t($exception->getPublicName()) . ': ' : '') . $message,
-                    array(
+                    [
                         'name' => $this->getLabel(),
-                    )
+                    ]
                 );
             }
         }
