@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -28,9 +27,9 @@ class URL extends \XLite\View\FormField\Input\Text
                 $result = false;
                 $this->errorMessage = \XLite\Core\Translation::lbl(
                     'The value of the X field has an incorrect format',
-                    array(
+                    [
                         'name' => $this->getLabel(),
-                    )
+                    ]
                 );
             }
         }
