@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class State extends \XLite\View\FormField\Listbox\AListbox
     /**
      * Widget param names
      */
-    const PARAM_ALL = 'all';
+    public const PARAM_ALL = 'all';
 
 
     /**
@@ -28,15 +27,14 @@ class State extends \XLite\View\FormField\Listbox\AListbox
      */
     public function setValue($value)
     {
-        if (is_object($value) && $value instanceOf \Doctrine\Common\Collections\Collection) {
+        if (is_object($value) && $value instanceof \Doctrine\Common\Collections\Collection) {
             $value = $value->toArray();
-
         } elseif (!is_array($value)) {
-            $value = array($value);
+            $value = [$value];
         }
 
         foreach ($value as $k => $v) {
-            if (is_object($v) && $v instanceOf \XLite\Model\AEntity) {
+            if (is_object($v) && $v instanceof \XLite\Model\AEntity) {
                 $value[$k] = $v->getCountry()->getCode() . '_' . $v->getCode();
             }
         }
@@ -52,9 +50,9 @@ class State extends \XLite\View\FormField\Listbox\AListbox
     protected function getDefaultOptions()
     {
         $list = \XLite\Core\Database::getRepo('XLite\Model\State')->findAllStates();
-        usort($list, array('\XLite\Model\Zone', 'sortStates'));
+        usort($list, ['\XLite\Model\Zone', 'sortStates']);
 
-        $options = array();
+        $options = [];
 
         foreach ($list as $state) {
             $options[$state->getCountry()->getCode() . '_' . $state->getCode()] = $state->getCountry()->getCountry() . ': ' . $state->getState();
