@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,8 +19,8 @@ class AccountStatusSearch extends \XLite\View\FormField\Select\AccountStatus
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             '' => static::t('Any status'),
-        ) + parent::getDefaultOptions();
+        ] + parent::getDefaultOptions();
     }
 }
