@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,8 +19,8 @@ class AttributeGroups extends \XLite\View\FormField\Select\Regular
      */
     protected function getAttributeGroupsList()
     {
-        $list = array();
-        $cnd = new \XLite\Core\CommonCell;
+        $list = [];
+        $cnd = new \XLite\Core\CommonCell();
         $cnd->productClass = $this->getProductClass();
 
         foreach (\XLite\Core\Database::getRepo('\XLite\Model\AttributeGroup')->search($cnd) as $e) {
@@ -38,8 +37,8 @@ class AttributeGroups extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             '0' => static::t('No group'),
-        ) + $this->getAttributeGroupsList();
+        ] + $this->getAttributeGroupsList();
     }
 }
