@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,9 +19,9 @@ class CSVDelimiter extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             ',' => ', (' . static::t('Comma') . ')',
             ';' => '; (' . static::t('Semicolon') . ')',
-        );
+        ];
     }
 }
