@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,11 +7,10 @@
 
 namespace XLite\View\FormField\Select;
 
-
 class CloudZoomMode extends \XLite\View\FormField\Select\ASelect
 {
-    const MODE_INSIDE = 'inside';
-    const MODE_OUTSIDE = 'outside';
+    public const MODE_INSIDE = 'inside';
+    public const MODE_OUTSIDE = 'outside';
 
     /**
      * Return default options list
@@ -26,4 +24,4 @@ class CloudZoomMode extends \XLite\View\FormField\Select\ASelect
             static::MODE_OUTSIDE => static::t('Cloud Zoom mode Outside'),
         ];
     }
-}
\ No newline at end of file
+}
