@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,25 +15,7 @@ class Currency extends \XLite\View\FormField\Select\Regular
     /**
      * Additional widget param
      */
-    const PARAM_USE_CODE_AS_KEY = 'useCodeAsKey';
-
-    /**
-     * getDefaultOptions
-     *
-     * @return array
-     */
-    protected function getDefaultOptions()
-    {
-        $list = array();
-
-        foreach (\XLite\Core\Database::getRepo('XLite\Model\Currency')->findAllSortedByName() as $currency) {
-            $list[$currency->getCurrencyId()] = $this->getOptionName($currency);
-        }
-
-        asort($list);
-
-        return $list;
-    }
+    public const PARAM_USE_CODE_AS_KEY = 'useCodeAsKey';
 
     /**
      * Get options list
@@ -43,34 +24,19 @@ class Currency extends \XLite\View\FormField\Select\Regular
      */
     protected function getOptions()
     {
-        $list = array();
+        $list = [];
 
-        if ($this->getParam(self::PARAM_USE_CODE_AS_KEY)) {
-            foreach (\XLite\Core\Database::getRepo('XLite\Model\Currency')->findAllSortedByName() as $currency) {
-                $list[$currency->getCode()] = $this->getOptionName($currency);
-            }
+        foreach (\XLite\Core\Database::getRepo('XLite\Model\Currency')->findAllSortedByName() as $currency) {
+            $key = $this->getParam(self::PARAM_USE_CODE_AS_KEY)
+                ? $currency->getCode()
+                : $currency->getCurrencyId();
 
-            asort($list);
-
-        } else {
-            $list = parent::getOptions();
+            $list[$key] = sprintf('%s - %s', $currency->getCode(), $currency->getName());
         }
 
         return $list;
     }
 
-    /**
-     * Returns option name
-     *
-     * @param \XLite\Model\Currency $currency Currency
-     *
-     * @return string
-     */
-    protected function getOptionName($currency)
-    {
-        return sprintf('%s - %s', $currency->getCode(), $currency->getName());
-    }
-
     /**
      * Define widget params
      *
@@ -80,8 +46,8 @@ class Currency extends \XLite\View\FormField\Select\Regular
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_USE_CODE_AS_KEY => new \XLite\Model\WidgetParam\TypeBool('Use currency codes as keys', false),
-        );
+        ];
     }
 }
