@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,12 +19,12 @@ class DefaultProductSortOrder extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             'default'   => static::t('Recommended'),
             'priceAsc'  => static::t('Price asc'),
             'priceDesc' => static::t('Price desc'),
             'nameAsc'   => static::t('Name asc'),
             'nameDesc'  => static::t('Name desc'),
-        );
+        ];
     }
 }
