@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,11 +19,11 @@ class ExportAttrs extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             'global'           => static::t('Global attributes'),
             'global_n_classes' => static::t('Global & Classes attributes'),
             'all'              => static::t('All attributes'),
             'none'             => static::t('No attributes'),
-        );
+        ];
     }
 }
