@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,12 +19,11 @@ class InventoryState extends \XLite\View\FormField\Select\ASelect
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             'all' => static::t('Any stock status'),
             'in'  => static::t('In stock'),
             'low' => static::t('Low stock'),
             'out' => static::t('Out of stock'),
-        );
+        ];
     }
-
 }
