@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,20 +7,23 @@
 
 namespace XLite\View\FormField\Select\Model;
 
+use XLite\Core\PreloadedLabels\ProviderInterface;
+
 /**
  * Form abstract selector
  */
-abstract class AModel extends \XLite\View\FormField\AFormField
+abstract class AModel extends \XLite\View\FormField\AFormField implements ProviderInterface
 {
     /**
      * Widget param names
      */
-    const PARAM_MIN_COUNT               = 'min_count';
-    const PARAM_EMPTY_PHRASE            = 'empty_phrase';
-    const PARAM_EMPTY_MODEL_DEFINITION  = 'empty_model_definition';
-    const PARAM_GETTER                  = 'getter';
-    const PARAM_PLACEHOLDER             = 'placeholder';
-    const PARAM_IS_MODEL_REQUIRED       = 'is_model_required';
+    public const PARAM_MIN_COUNT               = 'min_count';
+    public const PARAM_EMPTY_PHRASE            = 'empty_phrase';
+    public const PARAM_EMPTY_MODEL_DEFINITION  = 'empty_model_definition';
+    public const PARAM_GETTER                  = 'getter';
+    public const PARAM_PLACEHOLDER             = 'placeholder';
+    public const PARAM_IS_MODEL_REQUIRED       = 'is_model_required';
+    public const PARAM_SPACER_PATH             = 'spacer_path';
 
     /**
      * Defines the text value of the model
@@ -96,26 +98,43 @@ abstract class AModel extends \XLite\View\FormField\AFormField
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_MIN_COUNT => new \XLite\Model\WidgetParam\TypeInt(
-                'Minimum symbols count after which the search will be permitted', $this->getDefaultMinCount(), false
+                'Minimum symbols count after which the search will be permitted',
+                $this->getDefaultMinCount(),
+                false
             ),
             static::PARAM_EMPTY_PHRASE => new \XLite\Model\WidgetParam\TypeString(
-                'Text for the empty list', $this->getDefaultEmptyPhrase(), false
+                'Text for the empty list',
+                $this->getDefaultEmptyPhrase(),
+                false
             ),
             static::PARAM_EMPTY_MODEL_DEFINITION => new \XLite\Model\WidgetParam\TypeString(
-                'Text when no model is selected', $this->getDefaultEmptyModelDefinition(), false
+                'Text when no model is selected',
+                $this->getDefaultEmptyModelDefinition(),
+                false
             ),
             static::PARAM_GETTER => new \XLite\Model\WidgetParam\TypeString(
-                'URL which will be the getter of the search objects', $this->getDefaultGetter(), false
+                'URL which will be the getter of the search objects',
+                $this->getDefaultGetter(),
+                false
             ),
             static::PARAM_PLACEHOLDER => new \XLite\Model\WidgetParam\TypeString(
-                'Text for the placeholder', '', false
+                'Text for the placeholder',
+                '',
+                false
             ),
             static::PARAM_IS_MODEL_REQUIRED => new \XLite\Model\WidgetParam\TypeBool(
-                'Flag if the model required to be selected', true, false
+                'Flag if the model required to be selected',
+                true,
+                false
             ),
-        );
+            static::PARAM_SPACER_PATH => new \XLite\Model\WidgetParam\TypeString(
+                'Spacer image path',
+                $this->getDefaultSpacerPath(),
+                false
+            ),
+        ];
     }
 
     /**
@@ -158,6 +177,17 @@ abstract class AModel extends \XLite\View\FormField\AFormField
         return '';
     }
 
+    /**
+     * @return string
+     */
+    protected function getDefaultSpacerPath()
+    {
+        return \XLite\Core\Layout::getInstance()->getResourceWebPath(
+            'images/spacer.gif',
+            \XLite\Core\Layout::WEB_PATH_OUTPUT_URL
+        );
+    }
+
     /**
      * Returns getter url
      *
@@ -185,10 +215,11 @@ abstract class AModel extends \XLite\View\FormField\AFormField
      */
     protected function getCommentedData()
     {
-        return array(
-            static::PARAM_MIN_COUNT => $this->getParam(static::PARAM_MIN_COUNT),
-            static::PARAM_GETTER    => $this->getGetter(),
-        );
+        return [
+            static::PARAM_MIN_COUNT   => $this->getParam(static::PARAM_MIN_COUNT),
+            static::PARAM_GETTER      => $this->getGetter(),
+            static::PARAM_SPACER_PATH => $this->getParam(static::PARAM_SPACER_PATH),
+        ];
     }
 
     /**
@@ -198,11 +229,11 @@ abstract class AModel extends \XLite\View\FormField\AFormField
      */
     protected function defineCSSClasses()
     {
-        $result = array(
+        $result = [
             'model-input-selector',
             'field-model-selector',
             'form-control',
-        );
+        ];
 
         if ($this->isRequired()) {
             $result[] = 'required';
@@ -262,4 +293,11 @@ abstract class AModel extends \XLite\View\FormField\AFormField
 
         return $value;
     }
+
+    public function getPreloadedLanguageLabels()
+    {
+        return [
+            'Enter X more characters to start search' => static::t('Enter X more characters to start search')
+        ];
+    }
 }
