@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,11 +7,10 @@
 
 namespace XLite\View\FormField\Select;
 
-
 class ObjectNameInPageTitleOrder extends \XLite\View\FormField\Select\Regular
 {
-    const OPTION_FIRST = 'F';
-    const OPTION_LAST = 'L';
+    public const OPTION_FIRST = 'F';
+    public const OPTION_LAST = 'L';
 
     /**
      * getDefaultOptions
