@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,8 +17,8 @@ abstract class AOrderStatus extends \XLite\View\FormField\Select\Regular
     /**
      * Common params
      */
-    const PARAM_ORDER = 'order';
-    const PARAM_ALL_OPTION  = 'allOption';
+    public const PARAM_ORDER = 'order';
+    public const PARAM_ALL_OPTION  = 'allOption';
 
     /**
      * Define repository name
@@ -62,14 +61,19 @@ abstract class AOrderStatus extends \XLite\View\FormField\Select\Regular
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_ORDER => new \XLite\Model\WidgetParam\TypeObject(
-                'Order', null, false, '\XLite\Model\Order'
+                'Order',
+                null,
+                false,
+                '\XLite\Model\Order'
             ),
             self::PARAM_ALL_OPTION  => new \XLite\Model\WidgetParam\TypeBool(
-                'Show "All status" option', false, false
+                'Show "All status" option',
+                false,
+                false
             ),
-        );
+        ];
     }
 
     /**
@@ -79,7 +83,7 @@ abstract class AOrderStatus extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -90,10 +94,10 @@ abstract class AOrderStatus extends \XLite\View\FormField\Select\Regular
     protected function getOptions()
     {
         $data = $this->getRepo()->findBy(
-            array(),
-            array('position' => 'asc')
+            [],
+            ['position' => 'asc']
         );
-        $list = array();
+        $list = [];
         foreach ($data as $status) {
             if (
                 !$this->getOrder()
@@ -106,10 +110,9 @@ abstract class AOrderStatus extends \XLite\View\FormField\Select\Regular
         }
 
         if ($this->getOrder() && !$this->getValue()) {
-            $list = array(0 => static::t('Status is not defined')) + $list;
-
+            $list = [0 => static::t('Status is not defined')] + $list;
         } elseif ($this->getParam(static::PARAM_ALL_OPTION)) {
-            $list = array(0 => static::t($this->getAllStatusesLabel())) + $list;
+            $list = [0 => static::t($this->getAllStatusesLabel())] + $list;
         }
 
         return $list;
