@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,6 @@ namespace XLite\View\FormField\Select;
  */
 class PaymentTransactionStatus extends \XLite\View\FormField\Select\Regular
 {
-
     /**
      * Get default options
      *
@@ -23,11 +21,12 @@ class PaymentTransactionStatus extends \XLite\View\FormField\Select\Regular
     {
         $statuses = \XLite\Model\Payment\Transaction::getStatuses();
 
-        $options = array(
+        $options = [
             ''  => static::t('All payment transaction statuses')
-        );
+        ];
 
-        if (!\XLite\Model\Payment\Transaction::showInitializedTransactions()
+        if (
+            !\XLite\Model\Payment\Transaction::showInitializedTransactions()
             && isset($statuses[\XLite\Model\Payment\Transaction::STATUS_INITIALIZED])
         ) {
             unset($statuses[\XLite\Model\Payment\Transaction::STATUS_INITIALIZED]);
@@ -39,5 +38,4 @@ class PaymentTransactionStatus extends \XLite\View\FormField\Select\Regular
 
         return $options;
     }
-
 }
