@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,8 +19,8 @@ class ProductClass extends \XLite\View\FormField\Select\Regular
      */
     protected function getProductClassesList()
     {
-        $list = array();
-        $cnd = new \XLite\Core\CommonCell;
+        $list = [];
+        $cnd = new \XLite\Core\CommonCell();
         foreach (\XLite\Core\Database::getRepo('\XLite\Model\ProductClass')->search($cnd) as $e) {
             $list[$e->getId()] = htmlspecialchars($e->getName());
         }
@@ -36,6 +35,6 @@ class ProductClass extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(0 => static::t('No class')) + $this->getProductClassesList();
+        return [0 => static::t('No class')] + $this->getProductClassesList();
     }
 }
