@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,6 +19,6 @@ class ProductClassWithNew extends \XLite\View\FormField\Select\ProductClass
      */
     protected function getDefaultOptions()
     {
-        return parent::getDefaultOptions() + array(-1 => static::t('New product class'));
+        return parent::getDefaultOptions() + [-1 => static::t('New product class')];
     }
 }
