@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,7 +19,7 @@ class Customer extends \XLite\View\FormField\Select\Profile\AProfile
      */
     protected function getDefaultOptions()
     {
-        $list = array();
+        $list = [];
 
         foreach (\XLite\Core\Database::getRepo('XLite\Model\Profile')->findAllCustomerAccounts() as $profile) {
             $list[$profile->getProfileId()] = $profile->getLogin();
