@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,7 @@ namespace XLite\View\FormField\Select\RadioButtonsList\Attribute;
  */
 class CheckboxAddToNew extends \XLite\View\FormField\Select\RadioButtonsList\ARadioButtonsList
 {
-    const NO_VALUE_OPTION = 'no_value';
+    public const NO_VALUE_OPTION = 'no_value';
 
     /**
      * Get default options list
@@ -22,11 +21,11 @@ class CheckboxAddToNew extends \XLite\View\FormField\Select\RadioButtonsList\ARa
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             static::NO_VALUE_OPTION  => static::t('No pre-defined value'),
             '1'   => static::t('Yes'),
             '0'   => static::t('No'),
-        );
+        ];
     }
 
     /**
