@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,6 +19,6 @@ class Regular extends \XLite\View\FormField\Select\ASelect
      */
     protected function getDefaultOptions()
     {
-        return array();
+        return [];
     }
 }
