@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,11 +19,12 @@ class ShippingTableType extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             'S'   => static::t('shippingTableType.Subtotal'),
+            'DS'  => static::t('shippingTableType.DiscountedSubtotal'),
             'W'   => static::t('shippingTableType.Weight'),
             'I'   => static::t('shippingTableType.Items'),
             'WSI' => static::t('shippingTableType.All'),
-        );
+        ];
     }
 }
