@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,11 +21,11 @@ class TimeFormat extends \XLite\View\FormField\Select\Regular
     {
         $time = \XLite\Core\Converter::time();
 
-        return array(
+        return [
             '%T'  => \XLite\Core\Converter::formatDate($time, '%T'),
             '%H:%M' => \XLite\Core\Converter::formatDate($time, '%H:%M'),
             '%I:%M %p'  => \XLite\Core\Converter::formatDate($time, '%I:%M %p'),
             '%r'  => \XLite\Core\Converter::formatDate($time, '%r'),
-        );
+        ];
     }
 }
