@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -36,11 +35,11 @@ class WeightUnit extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             'lbs' => static::t('LB'),
             'oz'  => static::t('OZ'),
             'kg'  => static::t('KG'),
             'g'   => static::t('G'),
-        );
+        ];
     }
 }
