@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,8 +15,8 @@ class YesNo extends \XLite\View\FormField\Select\Regular
     /**
      * Yes/No mode values
      */
-    const YES = 'Y';
-    const NO  = 'N';
+    public const YES = 'Y';
+    public const NO  = 'N';
 
     /**
      * getDefaultOptions
@@ -26,10 +25,10 @@ class YesNo extends \XLite\View\FormField\Select\Regular
      */
     protected function getDefaultOptions()
     {
-        return array(
+        return [
             static::YES => static::t('Yes'),
             static::NO  => static::t('No'),
-        );
+        ];
     }
 
     /**
@@ -43,7 +42,6 @@ class YesNo extends \XLite\View\FormField\Select\Regular
 
         if ($value === true || $value === '1' || $value === 1) {
             $value = static::YES;
-
         } elseif ($value === false || $value === '0' || $value === 0) {
             $value = static::NO;
         }
