@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class Advanced extends \XLite\View\FormField\Textarea\Simple
     /**
      * Widget param name
      */
-    const PARAM_STYLE = 'style';
+    public const PARAM_STYLE = 'style';
 
     /**
      * Define widget parameters
@@ -27,9 +26,9 @@ class Advanced extends \XLite\View\FormField\Textarea\Simple
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_STYLE => new \XLite\Model\WidgetParam\TypeString('Style', $this->getDefaultStyle()),
-        );
+        ];
     }
 
     /**
