@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,14 +8,11 @@
 namespace XLite\View\FormModel\Product;
 
 use XLite\Core\Config;
-use XLite\Core\Converter;
 use XLite\Core\Database;
 use XLite\Core\Translation;
 use XLite\View\Button\AButton;
 use XLite\View\Button\Link;
-use XLite\View\Button\SimpleLink;
 use XLite\View\Button\Submit;
-use XLite\View\FormField\Select\FloatFormat;
 
 /**
  * Product form model
@@ -106,8 +102,12 @@ class Info extends \XLite\View\FormModel\AFormModel
         }
 
         $taxClassSchema = [
-            'label'    => static::t('Tax class'),
-            'position' => 200,
+            'label'       => static::t('Tax class'),
+            'description' => static::t(
+                'Tax classes link',
+                ['link' => $this->buildURL('tax_classes')]
+            ),
+            'position'    => 200,
         ];
         if ($taxClasses) {
             $taxClassSchema = array_replace(
@@ -131,9 +131,6 @@ class Info extends \XLite\View\FormModel\AFormModel
         $currency = \XLite::getInstance()->getCurrency();
         $currencySymbol = $currency->getCurrencySymbol(false);
 
-        $weightFormat = Config::getInstance()->Units->weight_format;
-        $weightFormatDelimiters = FloatFormat::getDelimiters($weightFormat);
-
         $inventoryTrackingDescription = $this->getDataObject()->default->identity && $this->getInventoryTrackingDescriptionTemplate()
             ? $this->getWidget([
                 'template' => $this->getInventoryTrackingDescriptionTemplate(),
@@ -148,7 +145,8 @@ class Info extends \XLite\View\FormModel\AFormModel
 
         $cleanUrlExt = \XLite\Model\Repo\CleanURL::isProductUrlHasExt() ? '.html' : '';
 
-        if ($product
+        if (
+            $product
             && $product->getCleanURL()
             && \XLite\Model\Repo\CleanURL::isProductUrlHasExt()
             && !preg_match('/.html$/', $product->getCleanURL())
@@ -203,11 +201,13 @@ class Info extends \XLite\View\FormModel\AFormModel
                     'label'    => static::t('Description'),
                     'type'     => 'XLite\View\FormModel\Type\TextareaAdvancedType',
                     'position' => 500,
+                    'help'     => static::t('Enter a brief product description that will display on the product listing pages')
                 ],
                 'full_description'   => [
                     'label'    => static::t('Full description'),
                     'type'     => 'XLite\View\FormModel\Type\TextareaAdvancedType',
                     'position' => 600,
+                    'help'     => static::t('Enter a full product description that will display in the Description tab')
                 ],
                 'available_for_sale' => [
                     'label'    => static::t('Available for sale'),
@@ -260,55 +260,81 @@ class Info extends \XLite\View\FormModel\AFormModel
                 'inventory_tracking' => [
                     'label'       => static::t('Inventory tracking for this product is'),
                     'description' => $inventoryTrackingDescription,
-                    'type'        => 'XLite\View\FormModel\Type\Base\CompositeType',
-                    'fields'      => [
-                        'inventory_tracking' => [
-                            'type'     => 'XLite\View\FormModel\Type\SwitcherType',
-                            'position' => 100,
-                        ],
-                        'quantity'           => [
-                            'label'             => static::t('Quantity in stock'),
-                            'type'              => 'XLite\View\FormModel\Type\PatternType',
-                            'inputmask_pattern' => [
-                                'alias'      => 'integer',
-                                'rightAlign' => false,
-                            ],
-                            'show_when'         => [
-                                'prices_and_inventory' => [
-                                    'inventory_tracking' => [
-                                        'inventory_tracking' => '1',
-                                    ],
-                                ],
-                            ],
-                            'position'          => 200,
-                        ],
-                    ],
+                    'type'        => 'XLite\View\FormModel\Type\InventoryTrackingType',
+                    'default'     => $this->getDataObject()->prices_and_inventory->inventory_tracking->quantity,
                     'position'    => 400,
                 ],
             ],
             'shipping'             => [
+                'requires_shipping_status' => [
+                    'label'                => static::t('Requires shipping'),
+                    'help'                 => static::t('Keep “Requires shipping“ turned off, if the product is intangible and is not shipped.'),
+                    'type'                 => 'XLite\View\FormModel\Type\SwitcherType',
+                    'position'             => 100,
+                ],
                 'weight'            => [
-                    'label'             => static::t('Weight'),
-                    'type'              => 'XLite\View\FormModel\Type\SymbolType',
-                    'symbol'            => Config::getInstance()->Units->weight_symbol,
-                    'inputmask_pattern' => [
+                    'label'              => static::t('Weight'),
+                    'type'               => 'XLite\View\FormModel\Type\SymbolType',
+                    'symbol'             => Config::getInstance()->Units->weight_symbol,
+                    'inputmask_pattern'  => [
                         'alias'          => 'xcdecimal',
                         'digitsOptional' => false,
                         'rightAlign'     => false,
                         'digits'         => 4,
                     ],
-                    'position'          => 100,
+                    'show_when'          => [
+                        'shipping' => [
+                            'requires_shipping_status' => true,
+                        ],
+                    ],
+                    'position'          => 200,
+                ],
+                'dimensions'       => [
+                    'label'     => static::t('Dimensions') . ' (' . Translation::translateDimSymbol() . ')',
+                    'type'     => 'XLite\View\FormModel\Type\Base\CompositeType',
+                    'fields'   => [
+                        'length' => [
+                            'label'            => static::t('Length'),
+                            'show_label_block' => true,
+                            'type'             => 'XLite\View\FormModel\Type\PatternType',
+                            'inputmask_pattern'    => [
+                                'alias'          => 'xcdecimal',
+                                'rightAlign'     => false,
+                                'digits'         => 2,
+                            ],
+                            'position'         => 100,
+                        ],
+                        'width' => [
+                            'label'    => static::t('Width'),
+                            'type'     => 'XLite\View\FormModel\Type\PatternType',
+                            'inputmask_pattern'    => [
+                                'alias'          => 'xcdecimal',
+                                'rightAlign'     => false,
+                                'digits'         => 2,
+                            ],
+                            'position' => 200,
+                        ],
+                        'height' => [
+                            'label'    => static::t('Height'),
+                            'type'     => 'XLite\View\FormModel\Type\PatternType',
+                            'inputmask_pattern'    => [
+                                'alias'          => 'xcdecimal',
+                                'rightAlign'     => false,
+                                'digits'         => 2,
+                            ],
+                            'position' => 300,
+                        ],
+                    ],
+                    'show_when' => [
+                        'shipping' => [
+                            'requires_shipping_status' => true,
+                        ],
+                    ],
+                    'position' => 300,
                 ],
                 'requires_shipping' => [
-                    'label'    => static::t('Requires shipping'),
                     'type'     => 'XLite\View\FormModel\Type\Base\CompositeType',
-                    'position' => 200,
                     'fields'   => [
-                        'requires_shipping' => [
-                            'label'    => static::t('Requires shipping'),
-                            'type'     => 'XLite\View\FormModel\Type\SwitcherType',
-                            'position' => 100,
-                        ],
                         'shipping_box'      => [
                             'type'             => 'XLite\View\FormModel\Type\Base\CompositeType',
                             'show_label_block' => false,
@@ -318,16 +344,6 @@ class Info extends \XLite\View\FormModel\AFormModel
                                     'type'     => 'Symfony\Component\Form\Extension\Core\Type\CheckboxType',
                                     'position' => 100,
                                 ],
-                                'dimensions'   => [
-                                    'label'     => static::t('Length x Width x Height') . ' (' . Translation::translateDimSymbol() . ')',
-                                    'type'      => 'XLite\View\FormModel\Type\DimensionsType',
-                                    'show_when' => [
-                                        '..' => [
-                                            'separate_box' => 1,
-                                        ],
-                                    ],
-                                    'position'  => 200,
-                                ],
                                 'items_in_box' => [
                                     'label'             => static::t('Maximum items in box'),
                                     'type'              => 'XLite\View\FormModel\Type\PatternType',
@@ -340,7 +356,7 @@ class Info extends \XLite\View\FormModel\AFormModel
                                             'separate_box' => 1,
                                         ],
                                     ],
-                                    'position'          => 300,
+                                    'position'          => 200,
                                 ],
                             ],
                             'show_when'        => [
@@ -348,9 +364,15 @@ class Info extends \XLite\View\FormModel\AFormModel
                                     'requires_shipping' => '1',
                                 ],
                             ],
-                            'position'         => 500,
+                            'position'         => 100,
                         ],
                     ],
+                    'show_when'        => [
+                        'shipping' => [
+                            'requires_shipping_status' => true,
+                        ],
+                    ],
+                    'position' => 400,
                 ],
             ],
             'marketing'            => [
@@ -420,7 +442,7 @@ class Info extends \XLite\View\FormModel\AFormModel
             ],
         ];
 
-        if ((boolean)$this->getDataObject()->default->identity) {
+        if ((bool)$this->getDataObject()->default->identity) {
             $schema[self::SECTION_DEFAULT]['sku']['required'] = true;
             $schema[self::SECTION_DEFAULT]['sku']['constraints']['Symfony\Component\Validator\Constraints\NotBlank'] = [
                 'message' => static::t('This field is required'),
@@ -466,37 +488,11 @@ class Info extends \XLite\View\FormModel\AFormModel
                     Link::PARAM_LOCATION => $url,
                 ]
             );
-
-            $result['preview-product'] = new SimpleLink(
-                [
-                    AButton::PARAM_LABEL => 'Preview product page',
-                    AButton::PARAM_STYLE => 'model-button link action',
-                    Link::PARAM_BLANK    => true,
-                    Link::PARAM_LOCATION => $this->getProductPreviewURL(),
-                ]
-            );
         }
 
         return $result;
     }
 
-    /**
-     * @return string
-     */
-    protected function getProductPreviewURL()
-    {
-        $identity = $this->getDataObject()->default->identity;
-        return Converter::buildURL(
-            'product',
-            'preview',
-            [
-                'product_id' => $identity,
-                'shopKey'    => \XLite\Core\Auth::getInstance()->getShopKey(),
-            ],
-            \XLite::getCustomerScript()
-        );
-    }
-
     protected function getProductEntity()
     {
         return Database::getRepo('XLite\Model\Product')->find($this->getDataObject()->default->identity);
