@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -57,9 +56,13 @@ class Inventory extends \XLite\View\FormModel\AFormModel
                     'type'     => 'XLite\View\FormModel\Type\SwitcherType',
                     'position' => 100,
                 ],
+                'quantity_origin' => [
+                    'type' => 'Symfony\Component\Form\Extension\Core\Type\HiddenType',
+                ],
                 'quantity_in_stock'                 => [
                     'label'             => static::t('Quantity in stock'),
-                    'type'              => 'XLite\View\FormModel\Type\PatternType',
+                    'type'              => 'XLite\View\FormModel\Type\InventoryQtyType',
+                    'default'           => $this->getDataObject()->default->quantity_in_stock,
                     'inputmask_pattern' => [
                         'alias'      => 'integer',
                         'rightAlign' => false,
@@ -117,14 +120,6 @@ class Inventory extends \XLite\View\FormModel\AFormModel
         return 'getInventoryFormModelObject';
     }
 
-    /**
-     * @return string
-     */
-    protected function getViewDataGetterName()
-    {
-        return 'getInventoryFormModelData';
-    }
-
     /**
      * Get a list of CSS files required to display the widget properly
      *
