@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -29,7 +28,7 @@ class FormTypeExtension extends AbstractTypeExtension
             $isSubTree = is_array($subTree)
                 && array_filter(
                     array_map(
-                        function ($item) {
+                        static function ($item) {
                             return !is_int($item);
                         },
                         array_keys($subTree)
@@ -62,7 +61,7 @@ class FormTypeExtension extends AbstractTypeExtension
         $currentPath = preg_replace('/^[^\.]*.|\.[^\.]*$/', '', $model);
         $prepared = [];
         foreach ($dependency as $key => $rule) {
-            if ('..' === $key) {
+            if ($key === '..') {
                 $key = $currentPath;
             }
 
@@ -74,7 +73,6 @@ class FormTypeExtension extends AbstractTypeExtension
             if (is_array($value)) {
                 $value = array_map('strval', array_values($value));
                 $condition[] = '(' . json_encode($value) . '.indexOf(' . $path . ') != -1) ';
-
             } elseif (is_scalar($value)) {
                 $condition[] = $path . '==\'' . $value . '\'';
             }
@@ -91,10 +89,12 @@ class FormTypeExtension extends AbstractTypeExtension
     public function buildView(FormView $view, FormInterface $form, array $options)
     {
         // @todo: $v.. move to separate method
-        $vModel = str_replace(['[]', '[', ']'], ['', '.', ''], $view->vars['full_name']);
+        $vModel = !in_array($view->vars['full_name'], ['form[returnURL]', 'form[' . \XLite::FORM_ID . ']'], true)
+            ? str_replace(['[]', '[', ']'], ['', '.', ''], $view->vars['full_name'])
+            : '';
         $vValidatePath = explode('.', $vModel);
         $validationRoot = array_shift($vValidatePath);
-        $vValidatePath = implode('_', array_map(['XLite\Core\Converter', 'convertToCamelCase'], $vValidatePath));
+        $vValidatePath = implode('_', array_map(['\Includes\Utils\Converter', 'convertToUpperCamelCase'], $vValidatePath));
 
         $vValidator = '$' . $validationRoot . '.' . strtolower($vValidatePath);
         $vForm = '$' . $validationRoot;
@@ -111,7 +111,7 @@ class FormTypeExtension extends AbstractTypeExtension
             ? $options['validation_trigger']
             : '';
 
-        $rowClasses = implode(' ', array_map(function ($item) {
+        $rowClasses = implode(' ', array_map(static function ($item) {
             return str_replace('_', '-', $item) . '-row';
         }, array_slice($view->vars['block_prefixes'], 0, -1)));
 
@@ -122,6 +122,14 @@ class FormTypeExtension extends AbstractTypeExtension
             $attr[':disabled'] = '!(' . (static::prepareDependency($options['enable_when'], $vModel, $validationRoot) ?: '""') . ')';
         }
 
+        $vShow = '';
+        if ($options['show_when']) {
+            $vShow = static::prepareDependency($options['show_when'], $vModel, $validationRoot);
+        }
+        if ($options['hide_when']) {
+            $vShow = '!(' . static::prepareDependency($options['hide_when'], $vModel, $validationRoot) . ')';
+        }
+
         $view->vars = array_replace($view->vars, [
             'show_label_block'  => $options['show_label_block'] === null || $options['show_label_block'],
             'label_description' => $options['label_description'],
@@ -143,9 +151,7 @@ class FormTypeExtension extends AbstractTypeExtension
             'data_object' => $options['data_object'],
             'view_object' => $options['view_object'],
 
-            'v_show' => $options['show_when']
-                ? static::prepareDependency($options['show_when'], $vModel, $validationRoot)
-                : '',
+            'v_show' => $vShow,
 
             'attr' => array_replace($view->vars['attr'], $attr),
         ]);
@@ -179,6 +185,7 @@ class FormTypeExtension extends AbstractTypeExtension
 
             'show_when'   => [],
             'enable_when' => [],
+            'hide_when'   => [],
         ]);
     }
 
