@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -11,7 +10,6 @@ namespace XLite\View\FormModel\Type;
 use Symfony\Component\Form\FormInterface;
 use Symfony\Component\Form\FormView;
 use Symfony\Component\OptionsResolver\OptionsResolver;
-use XLite\View\AView;
 use XLite\View\FormModel\Type\Base\AType;
 
 class CaptionType extends AType
