@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -27,7 +26,7 @@ class ProductCategoryLoader implements ChoiceLoaderInterface
      */
     public function loadChoiceList($value = null)
     {
-        return new ArrayChoiceList(array_keys($this->getCategories()));
+        return new ArrayChoiceList([]);
     }
 
     /**
@@ -59,26 +58,7 @@ class ProductCategoryLoader implements ChoiceLoaderInterface
      */
     public function getValueLabel($value)
     {
-        $categories = $this->getCategories();
 
-        return (string) (isset($categories[$value]) ? $categories[$value] : $value);
-    }
-
-    /**
-     * @return array
-     */
-    protected function getCategories()
-    {
-        return $this->executeCachedRuntime(function() {
-            $repo = \XLite\Core\Database::getRepo('XLite\Model\Category');
-
-            $categories = $repo->getAllCategoriesAsDTO();
-            $result     = [];
-            foreach ($categories as $category) {
-                $result[$category['id']] = $category['fullName'];
-            }
-
-            return $result;
-        });
+        return $value;
     }
 }
