@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,11 +7,6 @@
 
 namespace XLite\View;
 
-/**
- * HTTPS settings page widget
- *
- * @ListChild (list="admin.center", zone="admin")
- */
 class HttpsSettings extends \XLite\View\Dialog
 {
     use HttpsCheckerTrait;
@@ -20,7 +14,7 @@ class HttpsSettings extends \XLite\View\Dialog
     /**
      * Suffix of URL to check https availability
      */
-    const CHECK_URI_SUFFIX = 'skins/common/js/php.js';
+    public const CHECK_URI_SUFFIX = 'skins/common/js/php.js';
 
     /**
      * Return list of allowed targets
@@ -97,7 +91,7 @@ class HttpsSettings extends \XLite\View\Dialog
      */
     protected function getArticleUrl()
     {
-        return static::t('https://kb.x-cart.com/general_setup/inaccessible_admin_area_after_enabling_https.html');
+        return static::t('https://support.x-cart.com/en/articles/5161316-inaccessible-admin-area-after-enabling-https');
     }
 
     /**
