@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,33 +15,39 @@ class Image extends \XLite\View\AView
     /**
      * Widget arguments names
      */
-    const PARAM_IMAGE             = 'image';
-    const PARAM_ALT               = 'alt';
-    const PARAM_MAX_WIDTH         = 'maxWidth';
-    const PARAM_MAX_HEIGHT        = 'maxHeight';
-    const PARAM_SIZE_ID           = 'sizeId';
-    const PARAM_CENTER_IMAGE      = 'centerImage';
-    const PARAM_VERTICAL_ALIGN    = 'verticalAlign';
-    const PARAM_USE_CACHE         = 'useCache';
-    const PARAM_USE_DEFAULT_IMAGE = 'useDefaultImage';
-    const PARAM_IMAGE_SIZE_TYPE   = 'imageSizeType';
-    const PARAM_LAZY_LOAD         = 'lazyLoad';
-    const PARAM_USE_TIMESTAMP     = 'useTimestamp';
-    const PARAM_RESIZE_IMAGE      = 'resizeImage';
+    public const PARAM_IMAGE             = 'image';
+    public const PARAM_ALT               = 'alt';
+    public const PARAM_MAX_WIDTH         = 'maxWidth';
+    public const PARAM_MAX_HEIGHT        = 'maxHeight';
+    public const PARAM_SIZE_ID           = 'sizeId';
+    public const PARAM_CENTER_IMAGE      = 'centerImage';
+    public const PARAM_VERTICAL_ALIGN    = 'verticalAlign';
+    public const PARAM_USE_CACHE         = 'useCache';
+    public const PARAM_USE_DEFAULT_IMAGE = 'useDefaultImage';
+    public const PARAM_IMAGE_SIZE_TYPE   = 'imageSizeType';
+    public const PARAM_LAZY_LOAD         = 'lazyLoad';
+    public const PARAM_USE_TIMESTAMP     = 'useTimestamp';
+    public const PARAM_RESIZE_IMAGE      = 'resizeImage';
 
 
     /**
      * Vertical align types
      */
-    const VERTICAL_ALIGN_TOP    = 'top';
-    const VERTICAL_ALIGN_MIDDLE = 'middle';
-    const VERTICAL_ALIGN_BOTTOM = 'bottom';
+    public const VERTICAL_ALIGN_TOP    = 'top';
+    public const VERTICAL_ALIGN_MIDDLE = 'middle';
+    public const VERTICAL_ALIGN_BOTTOM = 'bottom';
 
     /**
      * Default image (no image) dimensions
      */
-    const DEFAULT_IMAGE_WIDTH  = 300;
-    const DEFAULT_IMAGE_HEIGHT = 300;
+    public const DEFAULT_IMAGE_WIDTH  = 120;
+    public const DEFAULT_IMAGE_HEIGHT = 120;
+
+    /**
+     * Image alt text maximum length.
+     * Long alt texts are not good in terms of accessibility.
+     */
+    public const ALT_TEXT_MAX_LENGTH = 100;
 
     /**
      * Allowed properties names
@@ -107,11 +112,12 @@ class Image extends \XLite\View\AView
             }
         }
 
-        if ($this->getParam(self::PARAM_MAX_WIDTH) == 0
+        if (
+            $this->getParam(self::PARAM_MAX_WIDTH) == 0
             && $this->getParam(self::PARAM_MAX_HEIGHT) == 0
             && $this->getParam(self::PARAM_IMAGE_SIZE_TYPE)
         ) {
-            list($width, $height) = \XLite\Logic\ImageResize\Generator::getImageSizes(
+            [$width, $height] = \XLite\Logic\ImageResize\Generator::getImageSizes(
                 \XLite\Logic\ImageResize\Generator::MODEL_PRODUCT,
                 $this->getParam(self::PARAM_IMAGE_SIZE_TYPE)
             );
@@ -146,7 +152,7 @@ class Image extends \XLite\View\AView
 
         if (!$url && $this->getParam(self::PARAM_USE_DEFAULT_IMAGE)) {
             // Default image
-            $url = \XLite::getInstance()->getOptions(['images', 'default_image']);
+            $url = \Includes\Utils\ConfigParser::getOptions(['images', 'default_image']);
 
             if (!\XLite\Core\Converter::isURL($url)) {
                 $url = \XLite\Core\Layout::getInstance()->getResourceWebPath(
@@ -163,11 +169,29 @@ class Image extends \XLite\View\AView
     /**
      * Get image alternative text
      *
-     * @return void
+     * @return string
      */
     public function getAlt()
     {
-        return $this->getParam(self::PARAM_ALT);
+        return $this->getShortenedAlt(
+            (string) $this->getParam(self::PARAM_ALT)
+        );
+    }
+
+    protected function getShortenedAlt(string $alt): string
+    {
+        if (mb_strlen($alt) > static::ALT_TEXT_MAX_LENGTH - 3) {
+            $shortenedAlt = mb_substr(
+                $alt,
+                0,
+                static::ALT_TEXT_MAX_LENGTH - 3
+            );
+
+            $alt = "{$shortenedAlt}...";
+        }
+
+
+        return $alt;
     }
 
     /**
@@ -193,8 +217,8 @@ class Image extends \XLite\View\AView
             $this->getParam(self::PARAM_IMAGE)
             && $this->getParam(self::PARAM_IMAGE)->isExists()
             && $this->getParam(self::PARAM_USE_CACHE)
-            && ($this->resizedURL !== $this->retinaResizedURL &&
-                !$this->isOriginalImageUrl($this->retinaResizedURL)
+            && ($this->resizedURL !== $this->retinaResizedURL
+                && !$this->isOriginalImageUrl($this->retinaResizedURL)
             )
         ) {
             $this->properties['srcset'] = $this->retinaResizedURL
@@ -304,7 +328,7 @@ class Image extends \XLite\View\AView
     protected function checkDefaultImage()
     {
         return $this->getParam(self::PARAM_USE_DEFAULT_IMAGE)
-               && \XLite::getInstance()->getOptions(['images', 'default_image']);
+               && \Includes\Utils\ConfigParser::getOptions(['images', 'default_image']);
     }
 
     /**
@@ -317,13 +341,10 @@ class Image extends \XLite\View\AView
         $result = parent::isVisible();
 
         if ($result) {
-
             if ($this->checkImage()) {
                 $this->processImage();
-
             } elseif ($this->checkDefaultImage()) {
                 $this->processDefaultImage();
-
             } else {
                 $result = false;
             }
@@ -339,7 +360,7 @@ class Image extends \XLite\View\AView
      */
     protected function setImageMargin()
     {
-        $vertical = ($this->getParam(self::PARAM_MAX_HEIGHT) - $this->properties['height']) / 2;
+        $vertical = ($this->getParam(self::PARAM_MAX_HEIGHT) - ($this->properties['height'] ?? 0)) / 2;
 
         switch ($this->getParam(self::PARAM_VERTICAL_ALIGN)) {
             case self::VERTICAL_ALIGN_TOP:
@@ -373,12 +394,43 @@ class Image extends \XLite\View\AView
     {
         if (!isset($this->properties['style'])) {
             $this->properties['style'] = $style;
-
         } else {
             $this->properties['style'] .= ' ' . $style;
         }
     }
 
+    /**
+     * Fit image to first available size if available
+     *
+     * @return array
+     */
+    protected function fitImage()
+    {
+        $width = max(0, $this->getParam(self::PARAM_MAX_WIDTH));
+        $height = max(0, $this->getParam(self::PARAM_MAX_HEIGHT));
+        $image = $this->getParam(self::PARAM_IMAGE);
+        $sizes = $image ? \XLite\Logic\ImageResize\Generator::getModelImageSizes(get_class($image)) : [];
+
+        if ($sizes && $width && $height) {
+            $newmaxw = 0;
+            $newmaxh = 0;
+            foreach ($sizes as $size) {
+                if ($width <= $size[0] && $height <= $size[1]) {
+                    if (($newmaxw >= $size[0] && $newmaxh >= $size[1]) || (!$newmaxw && !$newmaxh)) {
+                        $newmaxw = $size[0];
+                        $newmaxh = $size[1];
+                    }
+                }
+            }
+            if ($newmaxw && $newmaxh) {
+                $width  = $newmaxw;
+                $height = $newmaxh;
+            }
+        }
+
+        return [$width, $height];
+    }
+
     /**
      * Preprocess image
      *
@@ -387,15 +439,28 @@ class Image extends \XLite\View\AView
     protected function processImage()
     {
         if ($this->getParam(self::PARAM_RESIZE_IMAGE)) {
-            $maxw = max(0, $this->getParam(self::PARAM_MAX_WIDTH));
-            $maxh = max(0, $this->getParam(self::PARAM_MAX_HEIGHT));
+            [
+                $maxw,
+                $maxh
+            ] = $this->fitImage();
 
-            list(
+            [
                 $this->properties['width'],
                 $this->properties['height'],
                 $this->resizedURL,
                 $this->retinaResizedURL
-                ) = $this->getParam(self::PARAM_IMAGE)->getResizedURL($maxw, $maxh);
+            ] = $this->getParam(self::PARAM_IMAGE)->getResizedURL($maxw, $maxh, $this->getParam(self::PARAM_MAX_WIDTH), $this->getParam(self::PARAM_MAX_HEIGHT));
+
+            foreach (['width', 'height'] as $prop) {
+                if (empty($this->properties[$prop])) {
+                    unset($this->properties[$prop]);
+                }
+            }
+
+            if (!isset($this->properties['width']) && !isset($this->properties['height'])) {
+                $this->properties['class'] = (empty($this->properties['class']) ? '' : $this->properties['class'] . ' ')
+                    . 'img-size-unknown';
+            }
         }
 
         // Center the image vertically and horizontally
@@ -411,11 +476,17 @@ class Image extends \XLite\View\AView
      */
     protected function processDefaultImage()
     {
-        list($this->properties['width'], $this->properties['height']) = \XLite\Core\ImageOperator::getCroppedDimensions(
+
+        [
+            $maxw,
+            $maxh
+            ] = $this->fitImage();
+
+        [$this->properties['width'], $this->properties['height']] = \XLite\Core\ImageOperator::getCroppedDimensions(
             static::DEFAULT_IMAGE_WIDTH,
             static::DEFAULT_IMAGE_HEIGHT,
-            max(0, $this->getParam(self::PARAM_MAX_WIDTH)),
-            max(0, $this->getParam(self::PARAM_MAX_HEIGHT))
+            $maxw,
+            $maxh
         );
 
         // Center the image vertically and horizontally
