@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,7 +21,7 @@ class ErrorsFile extends \XLite\View\Import\Failed
      */
     protected function getMessageType($type)
     {
-        return 'E' === $type
+        return $type === 'E'
             ? static::t('Errors')
             : static::t('Warnings');
     }
@@ -38,11 +37,11 @@ class ErrorsFile extends \XLite\View\Import\Failed
     {
         $errorsAll = $this->getErrorsGroups($file);
 
-        $errors = array_filter($errorsAll, function ($item) {
+        $errors = array_filter($errorsAll, static function ($item) {
             return $item['type'] === 'E';
         });
 
-        $warnings = array_filter($errorsAll, function ($item) {
+        $warnings = array_filter($errorsAll, static function ($item) {
             return $item['type'] === 'W';
         });
 
