@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Import;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Warnings section widget
  *
@@ -53,15 +54,15 @@ class Warnings extends \XLite\View\Import\Failed
     /**
      * Return title
      *
-     * @return string 
+     * @return string
      */
     protected function getTitle()
     {
         return static::t(
             'The script found {{number}} errors during import',
-            array(
-                'number' => \XLite\Core\Database::getRepo('XLite\Model\ImportLog')->count()
-            )
+            [
+                'number' => \XLite\Core\Database::getRepo('XLite\Model\ImportLog')->countLogs()
+            ]
         );
     }
 }
