@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Invoice widget
  *
@@ -20,7 +21,7 @@ class Invoice extends \XLite\View\AView
     /**
      * Widget parameter names
      */
-    const PARAM_ORDER = 'order';
+    public const PARAM_ORDER = 'order';
 
     /**
      * Shipping modifier (cache)
@@ -79,14 +80,14 @@ class Invoice extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_ORDER => new \XLite\Model\WidgetParam\TypeObject(
                 'Order',
                 null,
                 false,
                 'XLite\Model\Order'
             ),
-        );
+        ];
     }
 
     /**
@@ -127,7 +128,7 @@ class Invoice extends \XLite\View\AView
      */
     protected function getInvoiceTitle()
     {
-        return static::t('Invoice X', array('id' => $this->getOrder()->getOrderNumber()));
+        return static::t('Invoice X', ['id' => $this->getOrder()->getOrderNumber()]);
     }
 
     /**
@@ -181,7 +182,7 @@ class Invoice extends \XLite\View\AView
      */
     protected function getShippingModifier()
     {
-        if (null === $this->shippingModifier) {
+        if ($this->shippingModifier === null) {
             $this->shippingModifier = $this->getOrder()
                 ->getModifier(\XLite\Model\Base\Surcharge::TYPE_SHIPPING, 'SHIPPING');
         }
@@ -216,7 +217,7 @@ class Invoice extends \XLite\View\AView
      */
     protected function getPaymentInstructions()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getOrder()->getVisiblePaymentMethods() as $method) {
             if ($method->getInstruction()) {
@@ -301,7 +302,7 @@ class Invoice extends \XLite\View\AView
         return static::formatPrice(
             abs($surcharge['cost']),
             $this->getOrder()->getCurrency(),
-            \XLite::ADMIN_INTERFACE !== \XLite\Core\Layout::getInstance()->getInterface()
+            \XLite\Core\Layout::getInstance()->getZone() !== \XLite::ZONE_ADMIN
         );
     }
 
@@ -320,13 +321,13 @@ class Invoice extends \XLite\View\AView
     protected function getAddressSectionData(\XLite\Model\Address $address = null, $showEmpty = false)
     {
         $data = parent::getAddressSectionData($address, $showEmpty);
-        $result = array();
+        $result = [];
 
-        $name = array(
-            'title'     => isset($data['title'])     ? $data['title']     : null,
-            'firstname' => isset($data['firstname']) ? $data['firstname'] : null,
-            'lastname'  => isset($data['lastname'])  ? $data['lastname']  : null,
-        );
+        $name = [
+            'title'     => $data['title'] ?? null,
+            'firstname' => $data['firstname'] ?? null,
+            'lastname'  => $data['lastname'] ?? null,
+        ];
 
         foreach ($data as $serviceName => $field) {
             $field['title_visible'] = $this->isAddressFieldTitleVisible(
@@ -346,6 +347,8 @@ class Invoice extends \XLite\View\AView
             }
         }
 
+        unset($result['address1'], $result['address2'], $result['address3']);
+
         return $result;
     }
 
@@ -370,7 +373,7 @@ class Invoice extends \XLite\View\AView
      */
     protected function getAddressFieldTitleHiddenList()
     {
-        return array('phone');
+        return ['phone'];
     }
 
     /**
@@ -398,7 +401,7 @@ class Invoice extends \XLite\View\AView
 
         $billingFields = $order->isPaymentSectionVisible()
             ? $this->getAddressSectionData($order->getProfile()->getBillingAddress())
-            : array();
+            : [];
 
         return $shippingFields
             && $billingFields
@@ -422,7 +425,7 @@ class Invoice extends \XLite\View\AView
         return \XLite\Core\Converter::buildFullURL(
             'order',
             '',
-            array('order_number' => $this->getOrder()->getOrderNumber()),
+            ['order_number' => $this->getOrder()->getOrderNumber()],
             \XLite::getAdminScript()
         );
     }
@@ -445,14 +448,14 @@ class Invoice extends \XLite\View\AView
                 $acc,
                 'order',
                 '',
-                array('order_number' => $this->getOrder()->getOrderNumber()),
+                ['order_number' => $this->getOrder()->getOrderNumber()],
                 \XLite::getCustomerScript()
             );
         } else {
             return \XLite\Core\Converter::buildFullURL(
                 'order',
                 '',
-                array('order_number' => $this->getOrder()->getOrderNumber()),
+                ['order_number' => $this->getOrder()->getOrderNumber()],
                 \XLite::getCustomerScript()
             );
         }
@@ -469,10 +472,10 @@ class Invoice extends \XLite\View\AView
      */
     protected function getAddressFiledTemplate($type, $serviceName, $field)
     {
-        $method = 'getAddressField' . \XLite\Core\Converter::convertToCamelCase($serviceName) . 'Template';
+        $method = 'getAddressField' . \Includes\Utils\Converter::convertToUpperCamelCase($serviceName) . 'Template';
 
         return method_exists($this, $method)
-            ? call_user_func(array($this, $method), $type, $field)
+            ? call_user_func([$this, $method], $type, $field)
             : 'order/invoice/parts/address_field.twig';
     }
 
@@ -603,7 +606,7 @@ class Invoice extends \XLite\View\AView
      */
     protected function getAddressFieldTypeTemplate($type, $field)
     {
-        return \XLite\Model\Address::SHIPPING === $type
+        return $type === \XLite\Model\Address::SHIPPING
             ? 'order/invoice/parts/address_field/type.twig'
             : null;
     }
