@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -21,15 +20,15 @@ abstract class AItemsList extends \XLite\View\Container
     /**
      * Widget param names
      */
-    const PARAM_SORT_BY    = 'sortBy';
-    const PARAM_SORT_ORDER = 'sortOrder';
-    const PARAM_AJAX_ITEMS_PER_PAGE = 'itemsPerPage';
+    public const PARAM_SORT_BY    = 'sortBy';
+    public const PARAM_SORT_ORDER = 'sortOrder';
+    public const PARAM_AJAX_ITEMS_PER_PAGE = 'itemsPerPage';
 
     /**
      * SQL orderby directions
      */
-    const SORT_ORDER_ASC  = 'asc';
-    const SORT_ORDER_DESC = 'desc';
+    public const SORT_ORDER_ASC  = 'asc';
+    public const SORT_ORDER_DESC = 'desc';
 
     /**
      * Default layout template
@@ -50,7 +49,7 @@ abstract class AItemsList extends \XLite\View\Container
      *
      * @var array
      */
-    protected $sortByModes = array();
+    protected $sortByModes = [];
 
     protected function getSortByModesField()
     {
@@ -67,17 +66,17 @@ abstract class AItemsList extends \XLite\View\Container
      *
      * @var array
      */
-    protected $sortOrderModes = array(
+    protected $sortOrderModes = [
         self::SORT_ORDER_ASC  => 'Ascending',
         self::SORT_ORDER_DESC => 'Descending',
-    );
+    ];
 
     /**
      * Sorting widget IDs list
      *
      * @var array
      */
-    protected static $sortWidgetIds = array();
+    protected static $sortWidgetIds = [];
 
     /**
      * Return dir which contains the page body template
@@ -169,7 +168,7 @@ abstract class AItemsList extends \XLite\View\Container
      *
      * @return string
      */
-    public function getActionURL(array $params = array())
+    public function getActionURL(array $params = [])
     {
         return $this->getURL($params + $this->getURLParams());
     }
@@ -249,7 +248,7 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function getListHeadClass()
     {
-        return '';
+        return 'head-h3 ';
     }
 
     /**
@@ -440,7 +439,7 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function isEmptyListTemplateVisible()
     {
-        return false === $this->hasResults();
+        return $this->hasResults() === false;
     }
 
     /**
@@ -460,10 +459,10 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function getPagerParams()
     {
-        return array(
+        return [
             \XLite\View\Pager\APager::PARAM_ITEMS_COUNT => $this->getItemsCount(),
             \XLite\View\Pager\APager::PARAM_LIST        => $this,
-        );
+        ];
     }
 
     /**
@@ -522,7 +521,7 @@ abstract class AItemsList extends \XLite\View\Container
      */
     public static function getSearchParams()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -557,8 +556,9 @@ abstract class AItemsList extends \XLite\View\Container
         // If there is any of searchParams in request data we should not fallback to session storage
         // because in that case we need brand new search
         // Unless we are in searchMode, in which we should fallback to save values to session
-        if (count($searchParamsNamesIntersect) === 0
-            || (isset($requestData['mode']) && 'append' === $requestData['mode'])
+        if (
+            count($searchParamsNamesIntersect) === 0
+            || (isset($requestData['mode']) && $requestData['mode'] === 'append')
             || $forceFallback
         ) {
             $sessionStorage = new \XLite\View\ItemsList\SessionSearchValuesStorage(
@@ -633,7 +633,8 @@ abstract class AItemsList extends \XLite\View\Container
         $processor = static::getSearchCaseProcessor();
 
         $defaultsProvider = $this->getDefaultValuesProvider();
-        if ($defaultsProvider
+        if (
+            $defaultsProvider
             && $defaultsProvider instanceof ISearchValuesStorage
         ) {
             $processor->setDefaultValuesStorage($defaultsProvider);
@@ -771,7 +772,8 @@ abstract class AItemsList extends \XLite\View\Container
     {
         $paramSortBy = $this->getParam(static::PARAM_SORT_BY);
 
-        if (empty($paramSortBy)
+        if (
+            empty($paramSortBy)
             || !array_key_exists($paramSortBy, $this->sortByModes)
         ) {
             $paramSortBy = $this->getSortByModeDefault();
@@ -789,7 +791,8 @@ abstract class AItemsList extends \XLite\View\Container
     {
         $paramSortOrder = $this->getParam(static::PARAM_SORT_ORDER);
 
-        if (empty($paramSortOrder)
+        if (
+            empty($paramSortOrder)
             || !in_array(
                 $paramSortOrder,
                 [static::SORT_ORDER_DESC, static::SORT_ORDER_ASC],
@@ -812,7 +815,7 @@ abstract class AItemsList extends \XLite\View\Container
         parent::defineWidgetParams();
 
         if (!empty($this->sortByModes)) {
-            $this->widgetParams += array(
+            $this->widgetParams += [
                 static::PARAM_SORT_BY => new \XLite\Model\WidgetParam\TypeSet(
                     'Sort by',
                     $this->getSortByModeDefault(),
@@ -825,7 +828,7 @@ abstract class AItemsList extends \XLite\View\Container
                     false,
                     $this->sortOrderModes
                 ),
-            );
+            ];
         }
     }
 
@@ -852,9 +855,9 @@ abstract class AItemsList extends \XLite\View\Container
     protected function getCommonParams()
     {
         if (!isset($this->commonParams)) {
-            $this->commonParams = array(
+            $this->commonParams = [
                 static::PARAM_SESSION_CELL => $this->getSessionCell()
-            );
+            ];
 
             $this->commonParams = array_merge(
                 $this->commonParams,
@@ -898,11 +901,11 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function getAJAXSpecificParams()
     {
-        return array(
+        return [
             static::PARAM_AJAX_WIDGET => get_class($this),
             static::PARAM_AJAX_TARGET => \XLite\Core\Request::getInstance()->target,
             static::PARAM_AJAX_ITEMS_PER_PAGE => $this->getPager()->getWidgetParams('itemsPerPage')->value
-        );
+        ];
     }
 
     /**
@@ -932,11 +935,11 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function getItemsListParams()
     {
-        return array(
+        return [
             'urlparams'     => $this->getURLParams(),
             'urlajaxparams' => $this->getURLAJAXParams(),
             'cell'          => $this->getSessionCell(),
-        );
+        ];
     }
 
     /**
@@ -982,7 +985,7 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function isSortOrderAsc($sortOrder = null)
     {
-        return static::SORT_ORDER_ASC === ($sortOrder ?: $this->getSortOrder());
+        return ($sortOrder ?: $this->getSortOrder()) === static::SORT_ORDER_ASC;
     }
 
     /**
@@ -1124,9 +1127,9 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function getWidgetTagAttributes()
     {
-        $data = array(
+        $data = [
             'class' => $this->getListCSSClasses(),
-        );
+        ];
 
         $arguments = $this->defineWidgetSignificantArguments();
         if ($arguments) {
@@ -1143,11 +1146,16 @@ abstract class AItemsList extends \XLite\View\Container
      */
     protected function defineWidgetSignificantArguments()
     {
-        return array(
+        return [
             static::PARAM_SORT_BY    => $this->getSortBy(),
             static::PARAM_SORT_ORDER => $this->getSortOrder(),
-        );
+        ];
     }
 
     // }}}
+
+    protected function getListHeadTag(): string
+    {
+        return 'div';
+    }
 }
