@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,28 +7,37 @@
 
 namespace XLite\View\ItemsList\Model;
 
+use XLite\Core\Cache\ExecuteCachedTrait;
+
 /**
  * Abstract admin model-based items list
  */
 abstract class AModel extends \XLite\View\ItemsList\AItemsList
 {
+    use ExecuteCachedTrait;
+
     /**
      * Sortable types
      */
-    const SORT_TYPE_NONE  = 0;
-    const SORT_TYPE_MOVE  = 1;
-    const SORT_TYPE_INPUT = 2;
+    public const SORT_TYPE_NONE  = 0;
+    public const SORT_TYPE_MOVE  = 1;
+    public const SORT_TYPE_INPUT = 2;
 
     /**
      * Create inline position
      */
-    const CREATE_INLINE_NONE   = 0;
-    const CREATE_INLINE_TOP    = 1;
-    const CREATE_INLINE_BOTTOM = 2;
+    public const CREATE_INLINE_NONE   = 0;
+    public const CREATE_INLINE_TOP    = 1;
+    public const CREATE_INLINE_BOTTOM = 2;
+
+    /**
+     * Session cell to store lines errors
+     */
+    public const SAVED_LINES_WITH_ERRORS = 'savedLinesWithErrors';
 
 
     /**
-     * Hightlight step
+     * Highlight step
      *
      * @var integer
      */
@@ -40,14 +48,21 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      *
      * @var array
      */
-    protected $errorMessages = array();
+    protected $errorMessages = [];
 
     /**
      * Warning messages
      *
      * @var array
      */
-    protected $warningMessages = array();
+    protected $warningMessages = [];
+
+    /**
+     * Lines with errors
+     *
+     * @var array
+     */
+    protected $linesWithErrors = [];
 
     /**
      * Request data
@@ -70,7 +85,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected $createdEntities = [];
 
-    static protected $savedDataCache = null;
+    protected static $savedDataCache = null;
 
     // {{{ Fields
 
@@ -160,7 +175,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      *
      * @return void
      */
-    public function processQuick(array $parameters = array())
+    public function processQuick(array $parameters = [])
     {
         $this->setWidgetParams($parameters);
         $this->init();
@@ -182,9 +197,18 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         }
 
         $this->processRemove();
+
+        if ($this->shouldRenameDuplicates()) {
+            $this->processRenameDuplicates();
+        }
+
         $this->processUpdate();
         $this->processCreate();
 
+        if ($this->showLinesWithErrors()) {
+            $this->saveLinesWithErrors();
+        }
+
         \XLite\Core\Database::getEM()->flush();
     }
 
@@ -197,7 +221,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getCreateFieldClasses()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -222,12 +246,10 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
                         $this->postprocessInsertedEntity($entity, $line);
                         $this->createdEntities[] = $entity;
                         $count++;
-
                     } else {
                         $this->undoCreatedEntity($entity, true);
                         $errCount++;
                     }
-
                 } else {
                     $this->undoCreatedEntity($entity, false);
                     $errCount++;
@@ -341,7 +363,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getCreateMessage($count)
     {
-        return static::t('X entities has been created', array('count' => $count));
+        return static::t('X entities has been created', ['count' => $count]);
     }
 
     /**
@@ -363,7 +385,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     {
         $entityClass = $this->defineRepositoryName();
 
-        return new $entityClass;
+        return new $entityClass();
     }
 
     /**
@@ -373,7 +395,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getDumpEntity()
     {
-        if (null === $this->dumpEntity) {
+        if ($this->dumpEntity === null) {
             $this->dumpEntity = $this->createEntity();
         }
 
@@ -394,6 +416,10 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         if ($this->dumpEntity instanceof \XLite\Model\AEntity) {
             $this->removeDumpEntity($this->dumpEntity);
         }
+
+        if ($this->showLinesWithErrors()) {
+            $this->clearSavedLinesWithErrors();
+        }
     }
 
     /**
@@ -413,10 +439,12 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getNewDataLine()
     {
-        $data = $this->getRequestData();
-        $prefix = $this->getCreateDataPrefix();
+        return $this->executeCachedRuntime(function () {
+            $data = $this->getRequestData();
+            $prefix = $this->getCreateDataPrefix();
 
-        return (isset($data[$prefix]) && is_array($data[$prefix])) ? $data[$prefix] : array();
+            return (isset($data[$prefix]) && is_array($data[$prefix])) ? $data[$prefix] : [];
+        });
     }
 
     /**
@@ -430,7 +458,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function isNewLineSufficient(array $line, $key)
     {
-        return 0 !== $key && 0 < count($line);
+        return $key !== 0 && 0 < count($line);
     }
 
     /**
@@ -443,7 +471,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function createInlineFields(array $line, \XLite\Model\AEntity $entity)
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getCreateFieldClasses() as $object) {
             $this->prepareInlineField($object, $entity);
@@ -494,7 +522,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getRemoveMessage($count)
     {
-        return \XLite\Core\Translation::lbl('X entities has been removed', array('count' => $count));
+        return \XLite\Core\Translation::lbl('X entities has been removed', ['count' => $count]);
     }
 
     /**
@@ -547,7 +575,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         $data = $this->getRequestData();
         $prefix = $this->getRemoveDataPrefix();
 
-        $list = array();
+        $list = [];
 
         if (isset($data[$prefix]) && is_array($data[$prefix]) && $data[$prefix]) {
             foreach ($data[$prefix] as $id => $allow) {
@@ -576,6 +604,103 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
 
     // }}}
 
+    // {{{ Rename duplicates
+
+    /**
+     * Return true if duplicates should be renamed
+     *
+     * @return boolean
+     */
+    protected function shouldRenameDuplicates()
+    {
+        return false;
+    }
+
+    /**
+     * Process renaming of duplicate items
+     */
+    protected function processRenameDuplicates()
+    {
+        if ($this->renameDuplicates()) {
+            $this->postProcessRenameDuplicates();
+        }
+    }
+
+    /**
+     * @return boolean
+     */
+    protected function renameDuplicates()
+    {
+        $data = $this->getRequestData();
+        $dataPrefix = $this->getDataPrefix();
+        $entitiesDataFromRequest = $data[$dataPrefix];
+        $repo = $this->getRepository();
+
+        $duplicateItemsWereRenamed = false;
+
+        foreach ($this->findDuplicateNames() as $duplicateName) {
+            $duplicateItems = $this->findDuplicates($duplicateName['name']);
+            $duplicateItemsCount = count($duplicateItems);
+
+            for ($i = 1; $i < $duplicateItemsCount; $i++) {
+                $id = $duplicateItems[$i]->getId();
+
+                if ($entitiesDataFromRequest[$id]['name'] === $duplicateName['name']) {
+                    $newName = $duplicateItems[$i]->getName() . '_' . $id;
+
+                    $duplicateItems[$i]->setName($newName);
+                    $entitiesDataFromRequest[$id]['name'] = $newName;
+
+                    $repo->update($duplicateItems[$i], [], false);
+                    $duplicateItemsWereRenamed = true;
+                }
+            }
+        }
+
+        if ($duplicateItemsWereRenamed) {
+            $data[$dataPrefix] = $entitiesDataFromRequest;
+            $this->requestData = $data;
+        }
+
+        return $duplicateItemsWereRenamed;
+    }
+
+    /**
+     * Postprocess renaming of duplicate items
+     */
+    protected function postProcessRenameDuplicates()
+    {
+        \XLite\Core\TopMessage::getInstance()->addWarning(
+            'Identical entries were renamed as follows: entry_XXXX, where XXXX are numbers. Please review and correct them if necessary.'
+        );
+
+        $requestData = $this->getRequestData();
+        $dataPrefix = $this->getDataPrefix();
+
+        $this->setSavedData($requestData[$dataPrefix]);
+        \XLite\Core\Database::getEM()->flush();
+    }
+
+    /**
+     * @return array
+     */
+    protected function findDuplicateNames()
+    {
+        return [];
+    }
+
+    /**
+     * @param string $name
+     *
+     * @return array
+     */
+    protected function findDuplicates($name)
+    {
+        return [];
+    }
+
+    // }}}
+
     // {{{ Update
 
     /**
@@ -588,7 +713,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         $result = true;
 
         if ($this->isActiveModelProcessing()) {
-            $result = $this->validateUpdate() && false !== $this->update();
+            $result = $this->validateUpdate() && $this->update() !== false;
 
             if (!$result) {
                 $this->processUpdateErrors();
@@ -638,18 +763,59 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function update()
     {
-        $count = $this->saveEntities();
+        $this->saveEntities();
 
-        if ($this->prevalidateEntities()) {
-            $this->updateEntities();
+        return $this->showLinesWithErrors()
+            ? $this->updateWithLinesErrors()
+            : $this->updateWithTopMessageErrors();
+    }
 
-            \XLite\Core\Database::getEM()->flush();
-        } else {
-            $this->undoEntities();
-            $count = false;
+    /**
+     * Update items
+     * If there are any errors save correct entities and show line errors near wrong lines
+     *
+     * @return boolean
+     */
+    protected function updateWithLinesErrors()
+    {
+        $result = true;
+
+        foreach ($this->getPageDataForUpdate() as $entity) {
+            if ($this->prevalidateEntity($entity)) {
+                if ($this->isDefault()) {
+                    $this->setDefaultValue($entity, $this->isDefaultEntity($entity));
+                }
+
+                $entity->getRepository()->update($entity, [], false);
+            } else {
+                \XLite\Core\Database::getEM()->detach($entity);
+                $result = false;
+            }
         }
 
-        return $count;
+        \XLite\Core\Database::getEM()->flush();
+
+        return $result;
+    }
+
+    /**
+     * Update items
+     * If there are any errors undo all entities and show top message
+     *
+     * @return boolean
+     */
+    protected function updateWithTopMessageErrors()
+    {
+        if ($this->prevalidateEntities()) {
+            $this->updateEntities();
+            \XLite\Core\Database::getEM()->flush();
+            $result = true;
+        } else {
+            $this->undoEntities();
+            $result = false;
+        }
+
+        return $result;
     }
 
     /**
@@ -716,7 +882,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     protected function updateEntities()
     {
         foreach ($this->getPageDataForUpdate() as $entity) {
-            $entity->getRepository()->update($entity, array(), false);
+            $entity->getRepository()->update($entity, [], false);
             if ($this->isDefault()) {
                 $this->setDefaultValue($entity, $this->isDefaultEntity($entity));
             }
@@ -786,7 +952,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     protected function validateCell(\XLite\View\FormField\Inline\AInline $inline, $key = null)
     {
         $inline->setValueFromRequest($this->getRequestData(), $key);
-        list($flag, $message) = $inline->validate();
+        [$flag, $message] = $inline->validate();
         if (!$flag) {
             $this->addErrorMessage($inline, $message);
         }
@@ -825,7 +991,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function defineInlineFields()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getPageDataForUpdate() as $entity) {
             foreach ($this->getFieldObjects() as $object) {
@@ -847,7 +1013,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function prepareInlineField(\XLite\View\FormField\Inline\AInline $field, \XLite\Model\AEntity $entity)
     {
-        $field->setWidgetParams(array('entity' => $entity, 'itemsList' => $this));
+        $field->setWidgetParams(['entity' => $entity, 'itemsList' => $this]);
     }
 
     /**
@@ -860,9 +1026,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     {
         $data = $this->getSavedData();
 
-        return isset($data[$id][$fieldName])
-            ? $data[$id][$fieldName]
-            : null;
+        return $data[$id][$fieldName] ?? null;
     }
 
     /**
@@ -874,8 +1038,9 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         // because executeCachedRuntime bind to the object, not class
 
         if (!static::$savedDataCache) {
-            static::$savedDataCache = \XLite\Core\Session::getInstance()->get(
-                get_class($this)
+            $session = \XLite\Core\Session::getInstance();
+            static::$savedDataCache = $session->get(
+                get_class($this) . '_' . $session->getCurrentLanguage()
             );
         }
 
@@ -887,8 +1052,9 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function setSavedData($data)
     {
-        \XLite\Core\Session::getInstance()->set(
-            get_class($this),
+        $session = \XLite\Core\Session::getInstance();
+        $session->set(
+            get_class($this) . '_' . $session->getCurrentLanguage(),
             $data
         );
     }
@@ -910,7 +1076,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getPageDataForUpdate()
     {
-        $list = array();
+        $list = [];
         foreach ($this->getPageData() as $entity) {
             if ($entity->isPersistent()) {
                 $list[] = $entity;
@@ -931,7 +1097,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getRequestData()
     {
-        if (null === $this->requestData) {
+        if ($this->requestData === null) {
             $this->requestData = $this->defineRequestData();
         }
 
@@ -1003,6 +1169,76 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         return $this->warningMessages;
     }
 
+    /**
+     * @param array  $line
+     * @param string $fieldName
+     * @param string $errorMessage
+     */
+    protected function addLineWithError($line, $fieldName, $errorMessage)
+    {
+        $type = isset($line['id'])
+            ? 'existing'
+            : 'new';
+
+        $this->linesWithErrors[$type][] = [
+            'fields' => $line,
+            'error' => [
+                'fieldName' => $fieldName,
+                'message' => $errorMessage,
+            ]
+        ];
+    }
+
+    /**
+     * @return array
+     */
+    protected function getLinesWithErrors()
+    {
+        return $this->linesWithErrors;
+    }
+
+    /**
+     * Save new lines with errors in session
+     */
+    protected function saveLinesWithErrors()
+    {
+        \XLite\Core\Session::getInstance()->set(
+            self::SAVED_LINES_WITH_ERRORS,
+            $this->getLinesWithErrors() ?: []
+        );
+    }
+
+    /**
+     * Fetch saved new lines with errors from session
+     *
+     * @return array
+     */
+    protected function getSavedLinesWithErrors()
+    {
+        return \XLite\Core\Session::getInstance()->get(self::SAVED_LINES_WITH_ERRORS);
+    }
+
+    /**
+     * Clear new lines with errors in session
+     */
+    protected function clearSavedLinesWithErrors()
+    {
+        \XLite\Core\Session::getInstance()->set(
+            self::SAVED_LINES_WITH_ERRORS,
+            []
+        );
+    }
+
+    /**
+     * Return true if lines with errors should be shown
+     *
+     * @return boolean
+     */
+    protected function showLinesWithErrors()
+    {
+        return false;
+    }
+
     // }}}
 
     // {{{ Content helpers
@@ -1033,13 +1269,13 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     }
 
     /**
-     * Check - body tempalte is visible or not
+     * Check - body template is visible or not
      *
      * @return boolean
      */
     protected function isPageBodyVisible()
     {
-        return $this->hasResults() || static::CREATE_INLINE_NONE !== $this->isInlineCreation();
+        return $this->hasResults() || $this->isInlineCreation() !== static::CREATE_INLINE_NONE;
     }
 
     /**
@@ -1072,12 +1308,12 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getLineAttributes($index, \XLite\Model\AEntity $entity = null)
     {
-        $result = array(
+        $result = [
             'class'   => $this->defineLineClass($index, $entity),
             'data-id' => $entity ? $entity->getUniqueIdentifier() : 0,
-        );
+        ];
 
-        if (-1 == $index) {
+        if ($index == -1) {
             $result['style'] = 'display: none;';
             $result['v-pre'] = '';
         }
@@ -1095,9 +1331,9 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function defineLineClass($index, \XLite\Model\AEntity $entity = null)
     {
-        $classes = array('line');
+        $classes = ['line'];
 
-        if (0 === $index) {
+        if ($index === 0) {
             $classes[] = 'first';
         }
 
@@ -1111,7 +1347,6 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
 
         if ($entity && $entity->isPersistent()) {
             $classes[] = 'entity-' . $entity->getUniqueIdentifier();
-
         } else {
             $classes[] = 'create-tpl';
             $classes[] = 'dump-entity';
@@ -1159,10 +1394,10 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     {
         $parts = explode('\\', get_called_class());
 
-        $names = array();
-        if ('Module' === $parts[1]) {
-            $names[] = strtolower($parts[2]);
-            $names[] = strtolower($parts[3]);
+        $names = [];
+        if ($parts[0] !== 'XLite') {
+            $names[] = strtolower($parts[0]);
+            $names[] = strtolower($parts[1]);
         }
 
         $names[] = strtolower($parts[count($parts) - 1]);
@@ -1179,7 +1414,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     {
         $result = null;
 
-        if (1 == $this->getItemsCount()) {
+        if ($this->getItemsCount() == 1) {
             $data = $this->getPageData();
             $result = current($data);
         }
@@ -1201,7 +1436,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
         return \XLite\Core\Converter::buildURL(
             $column[static::COLUMN_LINK],
             '',
-            array($entity->getUniqueIdentifierName() => $entity->getUniqueIdentifier())
+            [$entity->getUniqueIdentifierName() => $entity->getUniqueIdentifier()]
         );
     }
 
@@ -1227,10 +1462,10 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getContainerAttributes()
     {
-        return array(
+        return [
             'class'         => $this->getContainerClass(),
             'data-js-class' => $this->getJSHandlerClassName(),
-        );
+        ];
     }
 
     /**
@@ -1240,7 +1475,7 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
      */
     protected function getContainerAttributesAsString()
     {
-        $list = array();
+        $list = [];
         foreach ($this->getContainerAttributes() as $name => $value) {
             $list[] = $name . '="' . func_htmlspecialchars($value) . '"';
         }
@@ -1390,4 +1625,20 @@ abstract class AModel extends \XLite\View\ItemsList\AItemsList
     }
 
     // }}}
+
+    /**
+     * Return specific items list parameters that will be sent to JS code
+     *
+     * @return array
+     */
+    protected function getItemsListParams()
+    {
+        $itemsListParams = parent::getItemsListParams();
+
+        if ($this->showLinesWithErrors()) {
+            $itemsListParams['linesWithErrors'] = $this->getSavedLinesWithErrors();
+        }
+
+        return  $itemsListParams;
+    }
 }
