@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -30,7 +29,7 @@ abstract class AOrder extends \XLite\View\ItemsList\Model\Table
      */
     protected function getListNameSuffixes()
     {
-        return array('orders');
+        return ['orders'];
     }
 
     /**
@@ -56,8 +55,7 @@ abstract class AOrder extends \XLite\View\ItemsList\Model\Table
         return \XLite\Core\Converter::buildURL(
             $column[static::COLUMN_LINK],
             '',
-            array('order_number' => $entity->getOrderNumber())
+            ['order_number' => $entity->getOrderNumber()]
         );
     }
 }
-
