@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,14 +17,14 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
     /**
      * Widget param names
      */
-    const PARAM_ORDER = 'order';
+    public const PARAM_ORDER = 'order';
 
     /**
      * Order items data (before they are changed)
      *
      * @var array
      */
-    protected $orderItemsData = array();
+    protected $orderItemsData = [];
 
     /**
      * Cached order object
@@ -36,7 +35,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
 
     /**
      * PageDataForUpdate runtime cache
-     * 
+     *
      * @var array
      */
     protected $pageDataForUpdate;
@@ -106,7 +105,6 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
             foreach ($items as $item) {
                 $item->calculate();
             }
-
         } else {
             \XLite\Core\TopMessage::getInstance()->addError(static::t('All items cannot be removed from the order.'));
             $this->setActionError();
@@ -166,7 +164,8 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
         foreach ($this->getPageDataForUpdate() as $entity) {
             $entityId = $entity->getItemId();
             $product = $entity->getProduct();
-            if ($product
+            if (
+                $product
                 && isset($data['order_items'][$entityId]['attribute_values'])
                 && is_array($data['order_items'][$entityId]['attribute_values'])
                 && $entity->isActualAttributes()
@@ -247,7 +246,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getOrderItemsDataFields()
     {
-        return array('name', 'sku', 'price', 'amount', 'attributeValues');
+        return ['name', 'sku', 'price', 'amount', 'attributeValues'];
     }
 
     /**
@@ -257,20 +256,19 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getOrderItemsData()
     {
-        $result = array();
+        $result = [];
         $fields = $this->getOrderItemsDataFields();
         if ($this->pageDataForUpdate === null) {
             $this->pageDataForUpdate = $this->getPageDataForUpdate();
         }
         foreach ($this->pageDataForUpdate as $entity) {
-            $itemData = array();
+            $itemData = [];
             foreach ($fields as $field) {
-                $getter = 'getOrderItemDataFieldValue' . ucfirst($field);
+                $getter = 'getOrderItemDataFieldValue' . \Includes\Utils\Converter::convertToUpperCamelCase($field);
                 if (method_exists($this, $getter)) {
                     $itemData[$field] = $this->$getter($entity);
-
                 } else {
-                    $getter = 'get' . ucfirst($field);
+                    $getter = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($field);
                     if (method_exists($entity, $getter)) {
                         $itemData[$field] = $entity->$getter();
                     }
@@ -298,7 +296,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
             $changedFields = $this->getChangedFields($itemId, $data, $newItemsData);
 
             if (!empty($changedFields)) {
-                $diff = array_diff($changedFields, array('attributeValues'));
+                $diff = array_diff($changedFields, ['attributeValues']);
 
                 if (!empty($diff)) {
                     // Order item is changed: register this
@@ -349,25 +347,24 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getChangedFields($itemId, $data = null, $newItemsData = null)
     {
-        $changedFields = array();
+        $changedFields = [];
 
-        if (null === $data) {
+        if ($data === null) {
             $data = $this->orderItemsData[$itemId];
         }
 
-        if (null === $newItemsData) {
+        if ($newItemsData === null) {
             $newItemsData = $this->getOrderItemsData();
         }
 
         $fields = $this->getOrderItemsDataFields();
 
         foreach ($fields as $field) {
-            $method = 'isItemDataChanged' . ucfirst($field);
+            $method = 'isItemDataChanged' . \Includes\Utils\Converter::convertToUpperCamelCase($field);
 
             if (method_exists($this, $method)) {
                 // Detect field changes via specific method
                 $isChanged = $this->$method($data[$field], $newItemsData[$itemId][$field]);
-
             } else {
                 $isChanged = ($newItemsData[$itemId][$field] != $data[$field]);
             }
@@ -389,14 +386,14 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getOrderItemDataFieldValueAttributeValues($entity)
     {
-        $result = array();
+        $result = [];
 
         if ($entity->getAttributeValues()) {
             foreach ($entity->getAttributeValues() as $av) {
-                $result[$av->getAttributeId()] = array(
+                $result[$av->getAttributeId()] = [
                     'name'  => $av->getActualName(),
                     'value' => $av->getActualValue(),
-                );
+                ];
             }
         }
 
@@ -464,7 +461,8 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function changeItemAmountInStock($entity)
     {
-        if (isset($this->orderItemsData[$entity->getItemId()]['amount'])
+        if (
+            isset($this->orderItemsData[$entity->getItemId()]['amount'])
             && $entity->getAmount() != $this->orderItemsData[$entity->getItemId()]['amount']
         ) {
             // Calculate amount to update stock: negative when qty was increased and positive when decreased
@@ -484,17 +482,17 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
     {
         static $result;
 
-        if (null === $result) {
+        if ($result === null) {
             $result = \XLite\Controller\Admin\Order::isNeedProcessStock();
 
             if ($result) {
                 $order = $this->getOrder();
 
                 $property = \XLite\Core\Database::getRepo('XLite\Model\Order\Status\Property')->findOneBy(
-                    array(
+                    [
                         'paymentStatus'  => $order->getPaymentStatus(),
                         'shippingStatus' => $order->getShippingStatus(),
-                    )
+                    ]
                 );
 
                 $result = !($property ? $property->getIncStock() : false);
@@ -513,7 +511,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getAttributeValuesAsString($entity)
     {
-        $result = array();
+        $result = [];
 
         foreach ($entity->getAttributeValues() as $av) {
             $result[] = sprintf('%s: %s', $av->getActualName(), $av->getActualValue());
@@ -566,9 +564,9 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_ORDER => new \XLite\Model\WidgetParam\TypeObject('Order', null, false, 'XLite\Model\Order'),
-        );
+        ];
     }
 
     /**
@@ -578,7 +576,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getOrder()
     {
-        if (null === $this->order) {
+        if ($this->order === null) {
             $order = $this->getParam(static::PARAM_ORDER);
 
             // Get temporary order if exists otherwise get current order
@@ -595,40 +593,40 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        return array(
-            'name' => array(
+        return [
+            'name' => [
                 static::COLUMN_NAME         => static::t('Order items'),
                 static::COLUMN_CREATE_CLASS => 'XLite\View\FormField\Inline\Select\Model\Product\OrderItem',
                 static::COLUMN_TEMPLATE     => 'items_list/model/table/order_item/cell.name.twig',
-                static::COLUMN_PARAMS       => array(
+                static::COLUMN_PARAMS       => [
                     'required' => true,
                     \XLite\View\FormField\Select\Model\OrderItemSelector::PARAM_ORDER_ID => $this->getOrder()->getOrderId(),
-                ),
+                ],
                 static::COLUMN_MAIN         => true,
                 static::COLUMN_ORDERBY      => 100,
-            ),
-            'price' => array(
+            ],
+            'price' => [
                 static::COLUMN_NAME     => static::t('Price'),
                 static::COLUMN_CLASS    => 'XLite\View\FormField\Inline\Input\Text\Price\OrderItemPrice',
-                static::COLUMN_PARAMS   => array(
+                static::COLUMN_PARAMS   => [
                     \XLite\View\FormField\Input\Text\Base\Numeric::PARAM_MIN              => 0,
                     \XLite\View\FormField\Input\Text\Base\Numeric::PARAM_MOUSE_WHEEL_CTRL => false,
-                ),
+                ],
                 static::COLUMN_ORDERBY  => 200,
-            ),
-            'amount' => array(
+            ],
+            'amount' => [
                 static::COLUMN_NAME    => static::t('Qty'),
                 static::COLUMN_CLASS   => 'XLite\View\FormField\Inline\Input\Text\Integer\OrderItemAmount',
-                static::COLUMN_PARAMS  => array('required' => true),
+                static::COLUMN_PARAMS  => ['required' => true],
                 static::COLUMN_ORDERBY => 300,
-            ),
-            'total' => array(
+            ],
+            'total' => [
                 static::COLUMN_NAME     => static::t('Total'),
                 static::COLUMN_TEMPLATE => 'items_list/model/table/order_item/cell.total.twig',
                 static::COLUMN_CREATE_TEMPLATE => 'items_list/model/table/order_item/cell.total.twig',
                 static::COLUMN_ORDERBY  => 400,
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -728,7 +726,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
         $result = parent::getLineAttributes($index, $entity);
 
         if ($entity) {
-            $result['data-clear-price'] = $entity->getPrice();
+            $result['data-clear-price'] = $entity->getProduct()->getDisplayPrice();
         }
 
         return $result;
@@ -763,7 +761,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
         return $classes;
     }
 
-    
+
 
     // {{{ Search
 
@@ -774,7 +772,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     public static function getSearchParams()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -789,7 +787,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
         foreach (static::getSearchParams() as $modelParam => $requestParam) {
             $paramValue = $this->getParam($requestParam);
 
-            if ('' !== $paramValue && 0 !== $paramValue) {
+            if ($paramValue !== '' && $paramValue !== 0) {
                 $result->$modelParam = $paramValue;
             }
         }
@@ -813,26 +811,26 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
         $orderId = $this->getOrder()->getOrderId();
         $tmpOrderData = \XLite\Controller\Admin\Order::getTemporaryOrderData();
 
-        $tmpItems = array();
+        $tmpItems = [];
 
         if (empty($tmpOrderData[$orderId])) {
             // Current order is not a source order - search for temporary order in cache
 
-            foreach ($tmpOrderData as $oid => $tmpData) {
+            foreach ($tmpOrderData as $tmpData) {
                 $tmpOid = is_object($tmpData['order']) ? $tmpData['order']->getOrderId() : (int) $tmpData['order'];
 
                 if ($tmpOid == $orderId) {
-                    $tmpItems = isset($tmpData['items']) ? $tmpData['items'] : array();
+                    $tmpItems = $tmpData['items'] ?? [];
                     break;
                 }
             }
         }
 
         if (!empty($tmpItems)) {
-            $dataTypes = array(
+            $dataTypes = [
                 $this->getDataPrefix(),
                 $this->getRemoveDataPrefix(),
-            );
+            ];
 
             // Add data for temporary order
             foreach ($tmpItems as $origId => $tmpId) {
@@ -957,7 +955,7 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
      */
     protected function getOriginalPrice(\XLite\Model\OrderItem $item)
     {
-        return $item->getPrice();
+        return $item->getProduct()->getDisplayPrice();
     }
 
     /**
@@ -1032,35 +1030,31 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
 
         if ($isUpdate && !$this->getChangedFields($entity->getItemId())) {
             // Ignore order item validation if item was updated but was not changed
-
         } elseif (!$entity->isActualAttributes()) {
             $data = $this->getRequestData();
             if (isset($data['order_items'][$entity->getItemId()]['attribute_values'])) {
                 $message = static::t('Order item attributes are out-of-date and cannot be edited');
             }
-
         } elseif (!$this->isValidEntity($entity)) {
             $result = false;
             $message = static::t('Product with selected properties cannot be purchased');
-
         } elseif (!$isUpdate && $entity->hasWrongAmount()) {
             $result = false;
             $message = static::t(
                 'The specified amount of product exceeds maximum amount of product in stock',
-                array(
+                [
                     'value' => $entity->getAmount(),
                     'max'   => $entity->getProductAvailableAmount(),
-                )
+                ]
             );
-
         } elseif ($isUpdate && $entity->isItemHasWrongAmount($entity)) {
             $result = false;
             $message = static::t(
                 'The specified amount of product exceeds maximum amount of product in stock',
-                array(
+                [
                     'value' => $entity->getAmount(),
                     'max'   => $entity->getProductAvailableAmount() + $this->orderItemsData[$entity->getItemId()]['amount'],
-                )
+                ]
             );
         }
 
@@ -1071,7 +1065,6 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
                 $message,
                 $this->formatItem($entity)
             );
-
         } elseif (!empty($message)) {
             $this->warningMessages[] = sprintf(
                 '[%s] %s: %s',
@@ -1095,7 +1088,8 @@ class OrderItem extends \XLite\View\ItemsList\Model\Table
     {
         $result = 0 < $entity->getAmount();
 
-        if ($result
+        if (
+            $result
             && (
                 $entity->hasAttributeValues()
                 || (
