@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\ItemsList\Model;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Order tracking number items list
  *
@@ -18,7 +19,7 @@ class OrderTrackingNumber extends \XLite\View\ItemsList\Model\Table
     /**
      * Widget parameter name
      */
-    const PARAM_ORDER_ID = 'orderId';
+    public const PARAM_ORDER_ID = 'orderId';
 
     /**
      * Defines the CSS files
@@ -80,28 +81,28 @@ class OrderTrackingNumber extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        $columns = array(
-            'value' => array(
+        $columns = [
+            'value' => [
                 static::COLUMN_CLASS    => 'XLite\View\FormField\Inline\Input\Text',
-                static::COLUMN_PARAMS   => array('required' => true),
+                static::COLUMN_PARAMS   => ['required' => true, 'placeholder' => static::t('Enter tracking number')],
                 static::COLUMN_MAIN     => true,
                 static::COLUMN_NAME     => static::t('Tracking number'),
                 static::COLUMN_ORDERBY  => 200,
-            ),
-            'creationDate' => array(
+            ],
+            'creationDate' => [
                 static::COLUMN_NAME     => static::t('Creation date'),
                 static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/order_tracking_number/cell.creation_date.twig',
                 static::COLUMN_ORDERBY  => 100,
-            )
-        );
+            ]
+        ];
 
         if ($this->getOrder()->getTrackingInformationURL('')) {
-            $columns['track'] = array(
+            $columns['track'] = [
                 static::COLUMN_NAME     => static::t('Payment status'),
                 static::COLUMN_LINK     => 'track',
                 static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/order_tracking_number/cell.track.twig',
                 static::COLUMN_ORDERBY  => 300,
-            );
+            ];
         }
 
         return $columns;
@@ -203,11 +204,12 @@ class OrderTrackingNumber extends \XLite\View\ItemsList\Model\Table
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_ORDER_ID => new \XLite\Model\WidgetParam\TypeInt(
-                'OrderID ', null
+                'OrderID ',
+                null
             ),
-        );
+        ];
     }
 
     /**
@@ -229,9 +231,9 @@ class OrderTrackingNumber extends \XLite\View\ItemsList\Model\Table
      */
     public static function getSearchParams()
     {
-        return array(
+        return [
             \XLite\Model\Repo\OrderTrackingNumber::P_ORDER_ID => static::PARAM_ORDER_ID,
-        );
+        ];
     }
 
     /**
