@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,12 +7,11 @@
 
 namespace XLite\View\ItemsList\Model\Payment\Item;
 
-
 use XLite\Model\Payment\Method;
 
 class PaymentMethod extends \XLite\View\AView
 {
-    const PARAM_METHOD = 'method';
+    public const PARAM_METHOD = 'method';
 
     protected function isVisible()
     {
@@ -22,16 +20,16 @@ class PaymentMethod extends \XLite\View\AView
 
     protected function getDefaultTemplate()
     {
-        return 'items_list/payment/online_methods/entry.twig';
+        return 'items_list/payment/popup_methods/entry.twig';
     }
 
     protected function defineWidgetParams()
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
-            static::PARAM_METHOD  => new \XLite\Model\WidgetParam\TypeObject('Payment method'),
-        );
+        $this->widgetParams += [
+            static::PARAM_METHOD => new \XLite\Model\WidgetParam\TypeObject('Payment method'),
+        ];
     }
 
     /**
@@ -48,9 +46,9 @@ class PaymentMethod extends \XLite\View\AView
     public function getAdminIconURL()
     {
         $method = $this->getPayment();
-        $url = $method->getAdminIconURL();
+        $url    = $method->getAdminIconURL();
 
-        if (!$url && $method->isModuleInstalled() && !$method->getModuleEnabled()) {
+        if (!$url && $method->isModuleInstalled() && !$method->isModuleEnabled()) {
             $name = explode('_', $method->getModuleName(), 2);
 
             $url = \XLite\Core\Layout::getInstance()->getResourceWebPath(
@@ -60,4 +58,4 @@ class PaymentMethod extends \XLite\View\AView
 
         return $url;
     }
-}
\ No newline at end of file
+}
