@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,16 +7,20 @@
 
 namespace XLite\View\ItemsList\Model\Payment;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Methods items list
+ *
+ * @ListChild (list="payment.method.add.online", zone="admin", weight="10")
  */
 class OnlineMethods extends \XLite\View\ItemsList\Model\Table
 {
     /**
      * Widget params
      */
-    const PARAM_SUBSTRING = 'substring';
-    const PARAM_COUNTRY   = 'country';
+    public const PARAM_SUBSTRING = 'substring';
+    public const PARAM_COUNTRY   = 'country';
 
     /**
      * Get search panel widget class
@@ -58,9 +61,9 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
     {
         return array_merge(
             parent::getAllowedTargets(),
-            array(
+            [
                 'payment_method_selection',
-            )
+            ]
         );
     }
 
@@ -71,7 +74,7 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
      */
     public function getJSFiles()
     {
-        $list = parent::getJSFiles();
+        $list   = parent::getJSFiles();
         $list[] = $this->getDir() . '/' . \XLite\View\ItemsList\Model\Table::getPageBodyDir() . '/controller.js';
         $list[] = $this->getDir() . '/' . $this->getPageBodyDir() . '/controller.js';
 
@@ -107,14 +110,16 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_SUBSTRING => new \XLite\Model\WidgetParam\TypeString(
-                'Substring', ''
+                'Substring',
+                ''
             ),
-            static::PARAM_COUNTRY => new \XLite\Model\WidgetParam\TypeString(
-                'Country code', static::getDefaultCountry()
+            static::PARAM_COUNTRY   => new \XLite\Model\WidgetParam\TypeString(
+                'Country code',
+                static::getDefaultCountry()
             ),
-        );
+        ];
     }
 
     /**
@@ -124,12 +129,12 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        return array(
-            'name' => array(
+        return [
+            'name' => [
                 static::COLUMN_NAME    => static::t('Payment method'),
-                static::COLUMN_ORDERBY  => 100,
-            ),
-        );
+                static::COLUMN_ORDERBY => 100,
+            ],
+        ];
     }
 
     /**
@@ -171,7 +176,7 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
      */
     protected function getPageBodyDir()
     {
-        return 'payment/online_methods';
+        return 'payment/popup_methods';
     }
 
     // }}}
@@ -193,20 +198,20 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
      */
     protected function getSearchCondition()
     {
-        $countryCode = trim($this->getParam(static::PARAM_COUNTRY));
+        $countryCode = trim($this->getParam(static::PARAM_COUNTRY) ?: '');
 
         \XLite\Core\Marketplace::getInstance()->updatePaymentMethods($countryCode);
 
         $result = parent::getSearchCondition();
 
-        $result->{\XLite\Model\Repo\Payment\Method::P_ORDER_BY_FORCE} = array(
-            'adminPosition, countryPosition.adminPosition, translations.name', 'asc'
-        );
-        $result->{\XLite\Model\Repo\Payment\Method::P_TYPE} = array(
+        $result->{\XLite\Model\Repo\Payment\Method::P_ORDER_BY_FORCE} = [
+            'adminPosition, countryPosition.adminPosition, translations.name', 'asc',
+        ];
+        $result->{\XLite\Model\Repo\Payment\Method::P_TYPE}           = [
             \XLite\Model\Payment\Method::TYPE_ALLINONE,
             \XLite\Model\Payment\Method::TYPE_CC_GATEWAY,
             \XLite\Model\Payment\Method::TYPE_ALTERNATIVE,
-        );
+        ];
 
         $result->{\XLite\Model\Repo\Payment\Method::P_EX_COUNTRY} = $countryCode;
 
@@ -216,7 +221,7 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
     /**
      * Default search conditions
      *
-     * @param  \XLite\Core\CommonCell $searchCase Search case
+     * @param \XLite\Core\CommonCell $searchCase Search case
      *
      * @return \XLite\Core\CommonCell
      */
@@ -246,12 +251,12 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
      *
      * @return array
      */
-    static public function getSearchParams()
+    public static function getSearchParams()
     {
-        return array(
-            \XLite\Model\Repo\Payment\Method::P_NAME        => static::PARAM_SUBSTRING,
-            \XLite\Model\Repo\Payment\Method::P_COUNTRY     => static::PARAM_COUNTRY,
-        );
+        return [
+            \XLite\Model\Repo\Payment\Method::P_NAME    => static::PARAM_SUBSTRING,
+            \XLite\Model\Repo\Payment\Method::P_COUNTRY => static::PARAM_COUNTRY,
+        ];
     }
 
     /**
@@ -276,7 +281,6 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
         return parent::getEmptyListDir() . '/' . $this->getPageBodyDir();
     }
 
-
     /**
      * Get message on empty search results
      *
@@ -288,18 +292,18 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
 
         if (!empty($searchRequestParams['country'])) {
             $country = \XLite\Core\Database::getRepo('XLite\Model\Country')->findOneBy(
-                array(
-                    'code' => $searchRequestParams['country']
-                )
+                [
+                    'code' => $searchRequestParams['country'],
+                ]
             );
         }
 
         return static::t(
             'No payment methods found based on the selected criteria',
-            array(
+            [
                 'substring' => $searchRequestParams['name'],
                 'country'   => !empty($country) ? $country->getCountry() : static::t('All countries'),
-            )
+            ]
         );
     }
 
@@ -319,4 +323,9 @@ class OnlineMethods extends \XLite\View\ItemsList\Model\Table
     {
         return \XLite\Core\Marketplace::getContactUsURL();
     }
+
+    protected function isOnlineMethodsList()
+    {
+        return true;
+    }
 }
