@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\ItemsList\Model\Payment;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Payment transactions items list
  *
@@ -18,27 +19,27 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
     /**
      * Widget param names
      */
-    const PARAM_SEARCH_SUBSTRING = 'substring';
-    const PARAM_SEARCH_PUBLIC_ID = 'public_id';
-    const PARAM_SEARCH_DATE      = 'date';
-    const PARAM_SEARCH_STATUS    = 'status';
-    const PARAM_SEARCH_VALUE     = 'value';
-    const PARAM_SEARCH_ZIPCODE   = 'zipcode';
-    const PARAM_SEARCH_CUSTOMER_NAME = 'customerName';
+    public const PARAM_SEARCH_SUBSTRING = 'substring';
+    public const PARAM_SEARCH_PUBLIC_ID = 'public_id';
+    public const PARAM_SEARCH_DATE      = 'date';
+    public const PARAM_SEARCH_STATUS    = 'status';
+    public const PARAM_SEARCH_VALUE     = 'value';
+    public const PARAM_SEARCH_ZIPCODE   = 'zipcode';
+    public const PARAM_SEARCH_CUSTOMER_NAME = 'customerName';
 
     /**
      * Sort modes
      *
      * @var   array
      */
-    protected $sortByModes = array(
+    protected $sortByModes = [
         't.public_id'      => 'Public ID',
         'ordr.orderNumber' => 'Order',
         't.date'           => 'Date',
         't.type'           => 'Type',
         't.status'         => 'Status',
         't.value'          => 'Value',
-    );
+    ];
 
     /**
      * Return list of allowed targets
@@ -47,7 +48,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
      */
     public static function getAllowedTargets()
     {
-        return array_merge(parent::getAllowedTargets(), array('payment_transactions'));
+        return array_merge(parent::getAllowedTargets(), ['payment_transactions']);
     }
 
     /**
@@ -121,36 +122,6 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
 
     // {{{ License banner
 
-    /**
-     * Check if current page is accessible for current x-cart license
-     *
-     * @return boolean
-     */
-    protected function checkLicense()
-    {
-        return !\XLite::isFreeLicense();
-    }
-
-    /**
-     * Show license message
-     *
-     * @return boolean
-     */
-    protected function showLicenseMessage()
-    {
-        return true;
-    }
-
-    /**
-     * Returns license message template
-     *
-     * @return string
-     */
-    protected function getLicenseMessageTemplate()
-    {
-        return 'payment_transactions/license_message.twig';
-    }
-
     /**
      * Returns purchase license URL
      *
@@ -162,7 +133,6 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
     }
     // }}}
 
-
     /**
      * Define widget parameters
      *
@@ -172,7 +142,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_SEARCH_SUBSTRING => new \XLite\Model\WidgetParam\TypeString('Substring', ''),
             static::PARAM_SEARCH_PUBLIC_ID => new \XLite\Model\WidgetParam\TypeString('Public id', ''),
             static::PARAM_SEARCH_DATE      => new \XLite\Model\WidgetParam\TypeString('Date', ''),
@@ -180,7 +150,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
             static::PARAM_SEARCH_VALUE     => new \XLite\Model\WidgetParam\TypeString('Value', ''),
             static::PARAM_SEARCH_ZIPCODE   => new \XLite\Model\WidgetParam\TypeString('Customer zip/postal code', ''),
             static::PARAM_SEARCH_CUSTOMER_NAME => new \XLite\Model\WidgetParam\TypeString('Customer name', ''),
-        );
+        ];
     }
 
     /**
@@ -190,43 +160,43 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        return array(
-            'public_id' => array(
+        return [
+            'public_id' => [
                 static::COLUMN_NAME => static::t('Public id'),
                 static::COLUMN_SORT => 't.public_id',
-            ),
-            'order' => array(
+            ],
+            'order' => [
                 static::COLUMN_NAME => static::t('Order'),
                 static::COLUMN_LINK => 'order',
                 static::COLUMN_SORT => 'ordr.orderNumber',
-            ),
-            'profile' => array(
+            ],
+            'profile' => [
                 static::COLUMN_NAME     => static::t('Customer'),
                 static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/order/cell.profile.twig',
                 static::COLUMN_NO_WRAP  => true,
-            ),
-            'date' => array(
+            ],
+            'date' => [
                 static::COLUMN_NAME => static::t('Date'),
                 static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/order/cell.date.twig',
                 static::COLUMN_SORT => 't.date',
-            ),
-            'method_name' => array(
+            ],
+            'method_name' => [
                 static::COLUMN_NAME => static::t('Method name'),
-            ),
-            'type' => array(
+            ],
+            'type' => [
                 static::COLUMN_NAME => static::t('Type'),
                 static::COLUMN_SORT => 't.type',
-            ),
-            'status' => array(
+            ],
+            'status' => [
                 static::COLUMN_NAME => static::t('Status'),
                 static::COLUMN_SORT => 't.status',
                 static::COLUMN_TEMPLATE => 'payment_transactions/parts/cell.transaction_status.twig',
-            ),
-            'value' => array(
+            ],
+            'value' => [
                 static::COLUMN_NAME => static::t('Value'),
                 static::COLUMN_SORT => 't.value',
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -364,7 +334,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
     protected function isLink(array $column, \XLite\Model\AEntity $entity)
     {
         return parent::isLink($column, $entity)
-            && ('order' !== $column[static::COLUMN_CODE] || $this->hasLinkableOrder($entity));
+            && ($column[static::COLUMN_CODE] !== 'order' || $this->hasLinkableOrder($entity));
     }
 
     /*
@@ -389,11 +359,11 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
      */
     protected function buildEntityURL(\XLite\Model\AEntity $entity, array $column)
     {
-        return 'order' === $column[static::COLUMN_CODE]
+        return $column[static::COLUMN_CODE] === 'order'
             ? \XLite\Core\Converter::buildURL(
                 $column[static::COLUMN_LINK],
                 '',
-                array('order_number' => $this->getOrder($entity)->getOrderNumber())
+                ['order_number' => $this->getOrder($entity)->getOrderNumber()]
             )
             : parent::buildEntityURL($entity, $column);
     }
@@ -454,7 +424,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
     {
         $list = \XLite\Model\Payment\Transaction::getStatuses();
 
-        return static::t($list[$value].'[S]');
+        return static::t($list[$value] . '[S]');
     }
 
     /**
@@ -478,7 +448,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
      */
     protected function getTransactionStatusPopoverContent(\XLite\Model\Payment\Transaction $entity)
     {
-        return $this->getWidget(array('entity' => $entity), '\XLite\View\FailedTransactionTooltip')->getContent();
+        return $this->getWidget(['entity' => $entity], '\XLite\View\FailedTransactionTooltip')->getContent();
     }
 
     /**
@@ -551,7 +521,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
      */
     public static function getSearchParams()
     {
-        return array(
+        return [
             \XLite\Model\Repo\Payment\Transaction::SEARCH_SUBSTRING => static::PARAM_SEARCH_SUBSTRING,
             \XLite\Model\Repo\Payment\Transaction::SEARCH_PUBLIC_ID => static::PARAM_SEARCH_PUBLIC_ID,
             \XLite\Model\Repo\Payment\Transaction::SEARCH_DATE      => static::PARAM_SEARCH_DATE,
@@ -559,7 +529,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
             \XLite\Model\Repo\Payment\Transaction::SEARCH_VALUE     => static::PARAM_SEARCH_VALUE,
             \XLite\Model\Repo\Payment\Transaction::SEARCH_ZIPCODE   => static::PARAM_SEARCH_ZIPCODE,
             \XLite\Model\Repo\Payment\Transaction::SEARCH_CUSTOMER_NAME => static::PARAM_SEARCH_CUSTOMER_NAME,
-        );
+        ];
     }
 
     /**
@@ -597,7 +567,7 @@ class Transaction extends \XLite\View\ItemsList\Model\Table
         foreach (static::getSearchParams() as $modelParam => $requestParam) {
             $paramValue = $this->getParam($requestParam);
 
-            if ('' !== $paramValue && 0 !== $paramValue) {
+            if ($paramValue !== '' && $paramValue !== 0) {
                 $result->$modelParam = $paramValue;
             }
         }
