@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -22,7 +21,7 @@ abstract class AAdmin extends \XLite\View\ItemsList\Model\Product\AProduct
      */
     protected function getRemoveMessage($count)
     {
-        return \XLite\Core\Translation::lbl('X product(s) has been removed', array('count' => $count));
+        return \XLite\Core\Translation::lbl('X product(s) has been removed', ['count' => $count]);
     }
 
     /**
@@ -34,7 +33,7 @@ abstract class AAdmin extends \XLite\View\ItemsList\Model\Product\AProduct
      */
     protected function getCreateMessage($count)
     {
-        return \XLite\Core\Translation::lbl('X product(s) has been created', array('count' => $count));
+        return \XLite\Core\Translation::lbl('X product(s) has been created', ['count' => $count]);
     }
 
     /**
@@ -55,6 +54,31 @@ abstract class AAdmin extends \XLite\View\ItemsList\Model\Product\AProduct
     protected function checkACL()
     {
         return parent::checkACL()
-            && \XLite\Core\Auth::getInstance()->isPermissionAllowed('manage catalog');
+            && \XLite\Core\Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_CATALOG');
+    }
+
+    /**
+     * Get search condition for update all found actions
+     *
+     * @return \XLite\Core\CommonCell
+     */
+    public function getActionSearchCondition()
+    {
+        $cnd = $this->getSearchCondition();
+        unset($cnd->orderBy);
+
+        return $cnd;
+    }
+
+    /**
+     * Return wrapper form options
+     *
+     * @return array
+     */
+    protected function getFormOptions()
+    {
+        return array_merge(parent::getFormOptions(), [
+            \XLite\View\Form\AForm::PARAM_CONFIRM_REMOVE => true
+        ]);
     }
 }
