@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -17,25 +16,20 @@ use XLite\View\ItemsList\ASearchValuesStorage;
 use XLite\View\SearchPanel\ASearchPanel;
 use XLite\View\SearchPanel\SimpleSearchPanel;
 
-/**
- * Search product
- *
- * @ListChild (list="admin.center", zone="admin")
- */
 class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
 {
     /**
      * Widget param names
      */
-    const PARAM_SUBSTRING         = 'substring';
-    const PARAM_CATEGORY_ID       = 'categoryId';
-    const PARAM_SEARCH_IN_SUBCATS = 'searchInSubcats';
-    const PARAM_BY_TITLE          = 'by_title';
-    const PARAM_BY_DESCR          = 'by_descr';
-    const PARAM_BY_SKU            = 'by_sku';
-    const PARAM_INVENTORY         = 'inventory';
-    const PARAM_ENABLED           = 'enabled';
-    const PARAM_INCLUDING         = 'including';
+    public const PARAM_SUBSTRING         = 'substring';
+    public const PARAM_CATEGORY_ID       = 'categoryId';
+    public const PARAM_SEARCH_IN_SUBCATS = 'searchInSubcats';
+    public const PARAM_BY_TITLE          = 'by_title';
+    public const PARAM_BY_DESCR          = 'by_descr';
+    public const PARAM_BY_SKU            = 'by_sku';
+    public const PARAM_INVENTORY         = 'inventory';
+    public const PARAM_ENABLED           = 'enabled';
+    public const PARAM_INCLUDING         = 'including';
 
     /**
      * Define and set widget attributes; initialize widget
@@ -73,27 +67,17 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     {
         $params = parent::getFormParams();
 
-        if ('low' === \XLite\Core\Request::getInstance()->{static::PARAM_INVENTORY}) {
+        if (\XLite\Core\Request::getInstance()->{static::PARAM_INVENTORY} === 'low') {
             $params[static::PARAM_INVENTORY] = 'low';
         }
 
         return $params;
     }
 
-    /**
-     * Return list of allowed targets
-     *
-     * @return array
-     */
-    public static function getAllowedTargets()
-    {
-        return array_merge(parent::getAllowedTargets(), ['product_list']);
-    }
-
     /**
      * Should itemsList be wrapped with form
      *
-     * @return boolean
+     * @return bool
      */
     protected function wrapWithFormByDefault()
     {
@@ -180,7 +164,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
      */
     protected function getCreateButtonLabel()
     {
-        return 'Add product';
+        return 'New product';
     }
 
     /**
@@ -203,6 +187,16 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
         return array_merge(parent::getListNameSuffixes(), ['search']);
     }
 
+    /**
+     * Get container class
+     *
+     * @return string
+     */
+    protected function getContainerClass()
+    {
+        return parent::getContainerClass() . ' products-admin-search';
+    }
+
     /**
      * Get panel class
      *
@@ -216,7 +210,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     /**
      * Should search params values be saved to session or not
      *
-     * @return boolean
+     * @return bool
      */
     protected function saveSearchConditions()
     {
@@ -346,12 +340,9 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
         $enabledFieldName = Product::P_ENABLED;
 
         if ($result->{$enabledFieldName} && $result->{$enabledFieldName}->getValue()) {
-            $booleanValue = 'enabled' === $result->{$enabledFieldName}->getValue()
-                ? true
-                : false;
+            $booleanValue = $result->{$enabledFieldName}->getValue() === 'enabled';
 
             $result->{$enabledFieldName}->setValue($booleanValue);
-
         } else {
             unset($result->{$enabledFieldName});
         }
@@ -360,7 +351,6 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
         if (empty($result->{static::PARAM_CATEGORY_ID})) {
             unset($result->{static::PARAM_CATEGORY_ID});
             unset($result->{static::PARAM_SEARCH_IN_SUBCATS});
-
         } else {
             $result->{static::PARAM_SEARCH_IN_SUBCATS} = true;
         }
@@ -371,7 +361,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     /**
      * Checks if this itemslist is exportable through 'Export all' button
      *
-     * @return boolean
+     * @return bool
      */
     protected function isExportable()
     {
@@ -404,7 +394,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     {
         $class = parent::getColumnClass($column, $entity);
 
-        if ('qty' == $column[static::COLUMN_CODE] && !$entity->getInventoryEnabled()) {
+        if ($column[static::COLUMN_CODE] == 'qty' && !$entity->getInventoryEnabled()) {
             $class .= ' infinity';
         }
 
@@ -417,12 +407,12 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
      * @param array                $column Column
      * @param \XLite\Model\AEntity $entity Model OPTIONAL
      *
-     * @return boolean
+     * @return bool
      */
     protected function hasColumnAttention(array $column, \XLite\Model\AEntity $entity = null)
     {
         return parent::hasColumnAttention($column, $entity)
-            || ('qty' == $column[static::COLUMN_CODE] && $entity && $entity->isLowLimitReached());
+            || ($column[static::COLUMN_CODE] == 'qty' && $entity && $entity->isLowLimitReached());
     }
 
     // {{{ Behaviors
@@ -430,7 +420,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     /**
      * Mark list as removable
      *
-     * @return boolean
+     * @return bool
      */
     protected function isRemoved()
     {
@@ -440,7 +430,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     /**
      * Mark list as switchable (enable / disable)
      *
-     * @return boolean
+     * @return bool
      */
     protected function isSwitchable()
     {
@@ -450,7 +440,7 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
     /**
      * Mark list as selectable
      *
-     * @return boolean
+     * @return bool
      */
     protected function isSelectable()
     {
@@ -474,4 +464,22 @@ class Search extends \XLite\View\ItemsList\Model\Product\Admin\AAdmin
             ? func_htmlspecialchars($value->getName())
             : '';
     }
+
+    /**
+     * @return string
+     */
+    protected function getDefaultTemplate()
+    {
+        return 'common/search_container.twig';
+    }
+
+    /**
+     * @return array
+     */
+    protected function getAttributes()
+    {
+        return [
+            'data-widget' => 'XLite\View\ItemsList\Model\Product\Admin\Search'
+        ];
+    }
 }
