@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,27 +7,20 @@
 
 namespace XLite\View\ItemsList\Model;
 
-/**
- * Product classes items list
- *
- * @ListChild (list="admin.center", zone="admin")
- */
 class ProductClass extends \XLite\View\ItemsList\Model\Table
 {
-    /**
-     * Return list of allowed targets
-     *
-     * @return array
-     */
     public static function getAllowedTargets()
     {
-        return array_merge(parent::getAllowedTargets(), array('product_classes'));
+        $list   = parent::getAllowedTargets();
+        $list[] = 'product_classes';
+
+        return $list;
     }
 
     /**
      * Should itemsList be wrapped with form
      *
-     * @return boolean
+     * @return bool
      */
     protected function wrapWithFormByDefault()
     {
@@ -38,7 +30,7 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
     /**
      * Get wrapper form target
      *
-     * @return array
+     * @return string
      */
     protected function getFormTarget()
     {
@@ -52,19 +44,19 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        return array(
-            'name' => array(
+        return [
+            'name' => [
                 static::COLUMN_CLASS        => 'XLite\View\FormField\Inline\Input\Text\ProductClass',
-                static::COLUMN_PARAMS       => array('required' => true),
+                static::COLUMN_PARAMS       => ['required' => true],
                 static::COLUMN_MAIN         => true,
                 static::COLUMN_ORDERBY      => 100,
-            ),
-            'attributes' => array(
+            ],
+            'attributes' => [
                 static::COLUMN_TEMPLATE      => 'product_classes/parts/edit_attributes.twig',
                 static::COLUMN_HEAD_TEMPLATE => 'product_classes/parts/edit_attributes.twig',
                 static::COLUMN_ORDERBY       => 200,
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -74,17 +66,7 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineRepositoryName()
     {
-        return 'XLite\Model\ProductClass';
-    }
-
-    /**
-     * Get create entity URL
-     *
-     * @return string
-     */
-    protected function getCreateURL()
-    {
-        return \XLite\Core\Converter::buildUrl('product_class');
+        return \XLite\Model\ProductClass::class;
     }
 
     /**
@@ -107,13 +89,85 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
         return static::CREATE_INLINE_TOP;
     }
 
+    /**
+     * @param \XLite\Model\AEntity $entity Entity
+     *
+     * @return bool
+     */
+    protected function prevalidateEntity(\XLite\Model\AEntity $entity)
+    {
+        $result = parent::prevalidateEntity($entity);
+
+        if ($result) {
+            $productClassRepo = $this->getRepository();
+
+            $cnd = new \XLite\Core\CommonCell();
+            $cnd->{$productClassRepo::CND_NAME} = $entity->getName();
+            $cnd->{$productClassRepo::CND_EXCLUDING_ID} = $entity->getId();
+
+            $duplicateProductClasses = $productClassRepo->search($cnd);
+
+            if ($duplicateProductClasses) {
+                $hasDuplicates = false;
+
+                foreach ($duplicateProductClasses as $duplicateProductClass) {
+                    if ($duplicateProductClass->getName() ===  $entity->getName()) {
+                        $hasDuplicates = true;
+                        break;
+                    }
+                }
+
+                if ($hasDuplicates) {
+                    $line = [
+                        'id'       => $entity->getId(),
+                        'name'     => $entity->getName(),
+                        'position' => $entity->getPosition(),
+                    ];
+
+                    $this->addLineWithError(
+                        $line,
+                        'name',
+                        static::t('This product class already exists')
+                    );
+
+                    $result = false;
+                }
+            }
+        }
+
+        return $result;
+    }
+
+    /**
+     * @param array  $fields Fields list
+     * @param string $key    Field key
+     *
+     * @return bool
+     */
+    protected function validateNewEntity($fields, $key)
+    {
+        $line = $this->getNewDataLine()[$key];
+
+        if ($this->getRepository()->findOneByName($line['name'])) {
+            $this->addLineWithError(
+                $line,
+                'name',
+                static::t('This product class already exists')
+            );
+
+            return false;
+        }
+
+        return parent::validateNewEntity($fields, $key);
+    }
+
 
     // {{{ Behaviors
 
     /**
      * Mark list as removable
      *
-     * @return boolean
+     * @return bool
      */
     protected function isRemoved()
     {
@@ -160,9 +214,9 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
      *
      * @return array
      */
-    static public function getSearchParams()
+    public static function getSearchParams()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -177,7 +231,7 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
         foreach (static::getSearchParams() as $modelParam => $requestParam) {
             $paramValue = $this->getParam($requestParam);
 
-            if ('' !== $paramValue && 0 !== $paramValue) {
+            if ($paramValue !== '' && $paramValue !== 0) {
                 $result->$modelParam = $paramValue;
             }
         }
@@ -198,12 +252,11 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
     {
         if ($entity && $entity->isPersistent()) {
             $result = $entity->getAttributesCount();
-
         } else {
-            $cnd = new \XLite\Core\CommonCell;
+            $cnd = new \XLite\Core\CommonCell();
             $cnd->productClass = null;
             $cnd->product = null;
-            $result = \XLite\Core\Database::getRepo('\XLite\Model\Attribute')->search($cnd, true);
+            $result = \XLite\Core\Database::getRepo('XLite\Model\Attribute')->search($cnd, true);
         }
 
         return $result;
@@ -219,7 +272,7 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
     protected function getEditURL($entity)
     {
         return $entity && $entity->getId()
-            ? $this->buildURL('attributes', '', array('product_class_id' => $entity->getId()))
+            ? $this->buildURL('attributes', '', ['product_class_id' => $entity->getId()])
             : $this->buildURL('attributes');
     }
 
@@ -246,25 +299,48 @@ class ProductClass extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Return entities list
+     * Return true if lines with errors should be shown
      *
-     * @param \XLite\Core\CommonCell $cnd       Search condition
-     * @param boolean                $countOnly Return items list or only its size OPTIONAL
-     *
-     * @return array|integer
+     * @return bool
      */
-    protected function getData(\XLite\Core\CommonCell $cnd, $countOnly = false)
+    protected function showLinesWithErrors()
     {
-        if ($countOnly) {
-            $result = 1 + parent::getData($cnd, $countOnly);
+        return true;
+    }
 
-        } else {
-            $class = new \XLite\Model\ProductClass;
-            $class->setName(static::t('Global attributes'));
+    /**
+     * Return true if duplicates should be renamed
+     *
+     * @return bool
+     */
+    protected function shouldRenameDuplicates()
+    {
+        return true;
+    }
 
-            $result = array_merge(array($class), parent::getData($cnd, $countOnly));
-        }
+    /**
+     * @return array
+     */
+    protected function findDuplicateNames()
+    {
+        $repo = $this->getRepository();
 
-        return $result;
+        return $repo
+            ? $repo->findDuplicateNames()
+            : [];
+    }
+
+    /**
+     * @param string $name
+     *
+     * @return array
+     */
+    protected function findDuplicates($name)
+    {
+        $repo = $this->getRepository();
+
+        return $repo
+            ? $repo->findByName($name)
+            : [];
     }
 }
