@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,12 @@
 
 namespace XLite\View\ItemsList\Model;
 
+use XLite\Core\Auth;
+use XLite\Model\Role;
+use XLite\Model\Role\Permission;
+
 /**
- * Profiles items list
- *
- * @ListChild (list="admin.center", zone="admin")
+ * User profiles
  */
 class Profile extends \XLite\View\ItemsList\Model\Table
 {
@@ -25,60 +26,64 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     /**
      * Widget param names
      */
-    const PARAM_PATTERN         = 'pattern';
-    const PARAM_USER_TYPE       = 'user_type';
-    const PARAM_MEMBERSHIP      = 'membership';
-    const PARAM_COUNTRY         = 'country';
-    const PARAM_STATE           = 'state';
-    const PARAM_CUSTOM_STATE    = 'customState';
-    const PARAM_ADDRESS         = 'address';
-    const PARAM_PHONE           = 'phone';
-    const PARAM_DATE_TYPE       = 'date_type';
-    const PARAM_DATE_PERIOD     = 'date_period';
-    const PARAM_DATE_RANGE      = 'dateRange';
-    const PARAM_STATUS          = 'status';
-    const PARAM_LOGIN           = 'login';
+    public const PARAM_PATTERN      = 'pattern';
+    public const PARAM_USER_TYPE    = 'user_type';
+    public const PARAM_MEMBERSHIP   = 'membership';
+    public const PARAM_COUNTRY      = 'country';
+    public const PARAM_STATE        = 'state';
+    public const PARAM_CUSTOM_STATE = 'customState';
+    public const PARAM_ADDRESS      = 'address';
+    public const PARAM_PHONE        = 'phone';
+    public const PARAM_DATE_TYPE    = 'date_type';
+    public const PARAM_DATE_PERIOD  = 'date_period';
+    public const PARAM_DATE_RANGE   = 'dateRange';
+    public const PARAM_STATUS       = 'status';
+    public const PARAM_LOGIN        = 'login';
 
     /**
      * Allowed sort criterion
      */
-    const SORT_BY_MODE_LOGIN        = 'p.login';
-    const SORT_BY_MODE_NAME         = 'fullname';
-    const SORT_BY_MODE_ACCESS_LEVEL = 'p.access_level';
-    const SORT_BY_MODE_CREATED      = 'p.added';
-    const SORT_BY_MODE_LAST_LOGIN   = 'p.last_login';
+    public const SORT_BY_MODE_LOGIN        = 'p.login';
+    public const SORT_BY_MODE_NAME         = 'fullname';
+    public const SORT_BY_MODE_ACCESS_LEVEL = 'p.access_level';
+    public const SORT_BY_MODE_CREATED      = 'p.added';
+    public const SORT_BY_MODE_LAST_LOGIN   = 'p.last_login';
+
+    public const MULTISELECT_TYPES = [
+        \XLite\Model\Repo\Profile::SEARCH_MEMBERSHIP,
+        \XLite\Model\Repo\Profile::SEARCH_USER_TYPE
+    ];
 
     /**
      * Define and set widget attributes; initialize widget
      *
      * @param array $params Widget params OPTIONAL
      */
-    public function __construct(array $params = array())
+    public function __construct(array $params = [])
     {
-        $this->sortByModes += array(
-            static::SORT_BY_MODE_LOGIN          => 'Login/Email',
-            static::SORT_BY_MODE_NAME           => 'Name',
-            static::SORT_BY_MODE_ACCESS_LEVEL   => 'Access level',
-            static::SORT_BY_MODE_CREATED        => 'Created',
-            static::SORT_BY_MODE_LAST_LOGIN     => 'Last login',
-        );
+        $this->sortByModes += [
+            static::SORT_BY_MODE_LOGIN        => 'Login/Email',
+            static::SORT_BY_MODE_NAME         => 'Name',
+            static::SORT_BY_MODE_ACCESS_LEVEL => 'Access level',
+            static::SORT_BY_MODE_CREATED      => 'Created',
+            static::SORT_BY_MODE_LAST_LOGIN   => 'Last login',
+        ];
 
         parent::__construct($params);
     }
 
     /**
-     * Return list of allowed targets
-     *
      * @return array
      */
     public static function getAllowedTargets()
     {
-        return array_merge(parent::getAllowedTargets(), array('profile_list'));
+        $list   = parent::getAllowedTargets();
+        $list[] = 'profile_list';
+
+        return $list;
     }
 
     /**
-     * Should itemsList be wrapped with form
-     *
      * @return boolean
      */
     protected function wrapWithFormByDefault()
@@ -87,9 +92,7 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Get wrapper form target
-     *
-     * @return array
+     * @return string
      */
     protected function getFormTarget()
     {
@@ -97,64 +100,64 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Get search panel widget class
-     *
      * @return string
      */
     protected function getSearchPanelClass()
     {
-        return '\XLite\View\SearchPanel\Profile\Admin\Main';
+        return 'XLite\View\SearchPanel\Profile\Admin\Main';
     }
 
     /**
-     * Define columns structure
-     *
      * @return array
      */
     protected function defineColumns()
     {
-        return array(
-            'login' => array(
+        return [
+            'login' => [
                 static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Login/E-mail'),
                 static::COLUMN_NO_WRAP  => true,
                 static::COLUMN_LINK     => 'profile',
                 static::COLUMN_SORT     => static::SORT_BY_MODE_LOGIN,
                 static::COLUMN_ORDERBY  => 100,
-            ),
-            'name' => array(
+            ],
+            'name' => [
                 static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Name'),
                 static::COLUMN_NO_WRAP  => true,
                 static::COLUMN_LINK     => 'address_book',
                 static::COLUMN_MAIN     => true,
                 static::COLUMN_SORT     => static::SORT_BY_MODE_NAME,
                 static::COLUMN_ORDERBY  => 200,
-            ),
-            'access_level' => array(
+            ],
+            'access_level' => [
                 static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Access level'),
                 static::COLUMN_SORT     => static::SORT_BY_MODE_ACCESS_LEVEL,
                 static::COLUMN_ORDERBY  => 300,
-            ),
-            'orders_count' => array(
+            ],
+            'membership' => [
+                static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Membership'),
+                static::COLUMN_ORDERBY  => 400,
+            ],
+            'orders_count' => [
                 static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Orders'),
                 static::COLUMN_TEMPLATE => 'profiles/parts/cell/orders.twig',
-                static::COLUMN_ORDERBY  => 400,
-            ),
-            'added' => array(
-                static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Created'),
-                static::COLUMN_SORT     => static::SORT_BY_MODE_CREATED,
                 static::COLUMN_ORDERBY  => 500,
-            ),
-            'last_login' => array(
-                static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Last login'),
-                static::COLUMN_SORT     => static::SORT_BY_MODE_LAST_LOGIN,
+            ],
+            'added' => [
+                static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Created'),
+                static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/profile/cell.added.twig',
+                static::COLUMN_SORT     => static::SORT_BY_MODE_CREATED,
                 static::COLUMN_ORDERBY  => 600,
-            ),
-        );
+            ],
+            'last_login' => [
+                static::COLUMN_NAME     => \XLite\Core\Translation::lbl('Last login'),
+                static::COLUMN_TEMPLATE => $this->getDir() . '/' . $this->getPageBodyDir() . '/profile/cell.last_login.twig',
+                static::COLUMN_SORT     => static::SORT_BY_MODE_LAST_LOGIN,
+                static::COLUMN_ORDERBY  => 700,
+            ],
+        ];
     }
 
     /**
-     * getSortByModeDefault
-     *
      * @return string
      */
     protected function getSortByModeDefault()
@@ -163,8 +166,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * getSortOrderModeDefault
-     *
      * @return string
      */
     protected function getSortOrderModeDefault()
@@ -173,8 +174,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Define repository name
-     *
      * @return string
      */
     protected function defineRepositoryName()
@@ -183,32 +182,25 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Register CSS files
-     *
      * @return array
      */
     public function getCSSFiles()
     {
-        $list = parent::getCSSFiles();
-
+        $list   = parent::getCSSFiles();
         $list[] = 'profiles/style.css';
 
         return $list;
     }
 
     /**
-     * Get create entity URL
-     *
      * @return string
      */
     protected function getCreateURL()
     {
-        return \XLite\Core\Converter::buildUrl('profile', null, array('mode' => 'register'));
+        return \XLite\Core\Converter::buildUrl('profile', null, ['mode' => 'register']);
     }
 
     /**
-     * Get create button label
-     *
      * @return string
      */
     protected function getCreateButtonLabel()
@@ -216,11 +208,7 @@ class Profile extends \XLite\View\ItemsList\Model\Table
         return 'Add user';
     }
 
-    // {{{ Behaviors
-
     /**
-     * Checks if this itemslist is exportable through 'Export all' button
-     *
      * @return boolean
      */
     protected function isExportable()
@@ -229,8 +217,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Mark list as selectable
-     *
      * @return boolean
      */
     protected function isSelectable()
@@ -239,8 +225,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Mark list as removable
-     *
      * @return boolean
      */
     protected function isRemoved()
@@ -249,8 +233,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Creation button position
-     *
      * @return integer
      */
     protected function isCreation()
@@ -259,24 +241,18 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Check - remove entity or not
-     *
      * @param \XLite\Model\AEntity $entity Entity
      *
-     * @return boolean
+     * @return bool
      */
     protected function isAllowEntityRemove(\XLite\Model\AEntity $entity)
     {
         // Admin user cannot remove own account
         return parent::isAllowEntityRemove($entity)
-            && \XLite\Core\Auth::getInstance()->getProfile()->getProfileId() !== $entity->getProfileId();
+            && Auth::getInstance()->getProfile()->getProfileId() !== $entity->getProfileId();
     }
 
-    // }}}
-
     /**
-     * Get container class
-     *
      * @return string
      */
     protected function getContainerClass()
@@ -285,8 +261,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Get column cell class
-     *
      * @param array                $column Column
      * @param \XLite\Model\AEntity $entity Model OPTIONAL
      *
@@ -296,32 +270,27 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     {
         $class = parent::getColumnClass($column, $entity);
 
-        if ('access_level' == $column[static::COLUMN_CODE] && $entity && $entity->getAnonymous()) {
+        if ($column[static::COLUMN_CODE] == 'access_level' && $entity && $entity->getAnonymous()) {
             $class = trim($class . ' anonymous');
         }
 
         return $class;
     }
+
     /**
-     * Get panel class
-     *
-     * @return \XLite\View\Base\FormStickyPanel
+     * @return string|\XLite\View\Base\FormStickyPanel
      */
     protected function getPanelClass()
     {
         return 'XLite\View\StickyPanel\ItemsList\Profile';
     }
 
-    // {{{ Search
-
     /**
-     * Return search parameters
-     *
      * @return array
      */
     public static function getSearchParams()
     {
-        return array(
+        return [
             \XLite\Model\Repo\Profile::SEARCH_PATTERN      => static::PARAM_PATTERN,
             \XLite\Model\Repo\Profile::SEARCH_USER_TYPE    => static::PARAM_USER_TYPE,
             \XLite\Model\Repo\Profile::SEARCH_MEMBERSHIP   => static::PARAM_MEMBERSHIP,
@@ -335,38 +304,34 @@ class Profile extends \XLite\View\ItemsList\Model\Table
             \XLite\Model\Repo\Profile::SEARCH_DATE_RANGE   => static::PARAM_DATE_RANGE,
             \XLite\Model\Repo\Profile::SEARCH_STATUS       => static::PARAM_STATUS,
             \XLite\Model\Repo\Profile::SEARCH_AND_LOGIN    => static::PARAM_LOGIN,
-        );
+        ];
     }
 
     /**
-     * Define widget parameters
-     *
      * @return void
      */
     protected function defineWidgetParams()
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_PATTERN         => new \XLite\Model\WidgetParam\TypeString('Pattern', ''),
-            static::PARAM_USER_TYPE       => new \XLite\Model\WidgetParam\TypeSet('Type', '', false, array('', 'A', 'C')),
-            static::PARAM_MEMBERSHIP      => new \XLite\Model\WidgetParam\TypeString('Membership', ''),
+            static::PARAM_USER_TYPE       => new \XLite\Model\WidgetParam\TypeSet('Type', '', false, ['', 'A', 'C']),
+            static::PARAM_MEMBERSHIP      => new \XLite\Model\WidgetParam\TypeCollection('Membership', []),
             static::PARAM_COUNTRY         => new \XLite\Model\WidgetParam\TypeString('Country', ''),
             static::PARAM_STATE           => new \XLite\Model\WidgetParam\TypeInt('State', null),
             static::PARAM_CUSTOM_STATE    => new \XLite\Model\WidgetParam\TypeString('State name (custom)', ''),
             static::PARAM_ADDRESS         => new \XLite\Model\WidgetParam\TypeString('Address', ''),
             static::PARAM_PHONE           => new \XLite\Model\WidgetParam\TypeString('Phone', ''),
-            static::PARAM_DATE_TYPE       => new \XLite\Model\WidgetParam\TypeSet('Date type', '', false, array('', 'R', 'L')),
-            static::PARAM_DATE_PERIOD     => new \XLite\Model\WidgetParam\TypeSet('Date period', '', false, array('', 'M', 'W', 'D', 'C')),
+            static::PARAM_DATE_TYPE       => new \XLite\Model\WidgetParam\TypeSet('Date type', '', false, ['', 'R', 'L']),
+            static::PARAM_DATE_PERIOD     => new \XLite\Model\WidgetParam\TypeSet('Date period', '', false, ['', 'M', 'W', 'D', 'C']),
             static::PARAM_DATE_RANGE      => new \XLite\Model\WidgetParam\TypeString('Date range', null),
             static::PARAM_STATUS          => new \XLite\Model\WidgetParam\TypeString('Status', null),
             static::PARAM_LOGIN           => new \XLite\Model\WidgetParam\TypeString('Login', null),
-        );
+        ];
     }
 
     /**
-     * Define so called "request" parameters
-     *
      * @return void
      */
     protected function defineRequestParams()
@@ -377,29 +342,33 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Get permitted user types
-     * 
      * @return array Array of ids
      */
-    protected function getPermittedUserTypes(){
-        $permittedUserTypes = array('N', 'C');
+    protected function getPermittedUserTypes()
+    {
+        $permittedUserTypes = Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_USERS')
+            ? ['N', 'C']
+            : [];
+        $auth = Auth::getInstance();
+        $isRoot = $auth->hasRootAccess();
 
-        if (\XLite\Core\Auth::getInstance()->isPermissionAllowed('manage admins')) {
-            $adminRoles = array_map(
-                function($role){
+        if ($auth->isPermissionAllowed('ROLE_MANAGE_ADMINS')) {
+            $adminRoles         = array_map(
+                static function ($role) {
                     return $role->getId();
                 },
-                \XLite\Core\Database::getRepo('XLite\Model\Role')->findAll()
+                array_filter(
+                    \XLite\Core\Database::getRepo('XLite\Model\Role')->findAll(),
+                    static fn(Role $role): bool => ($isRoot || !$role->isPermissionAllowed(Permission::ROOT_ACCESS))
+                )
             );
             $permittedUserTypes = array_merge($adminRoles, $permittedUserTypes);
         }
 
         return $permittedUserTypes;
     }
-    
+
     /**
-     * Return params list to use for search
-     *
      * @return \XLite\Core\CommonCell
      */
     protected function getSearchCondition()
@@ -413,10 +382,14 @@ class Profile extends \XLite\View\ItemsList\Model\Table
             $paramValue = $this->getParam($requestParam);
 
             if (is_string($paramValue)) {
-                $paramValue = trim($paramValue);
+                if (in_array($modelParam, self::MULTISELECT_TYPES)) {
+                    $paramValue = explode(',', $paramValue);
+                } else {
+                    $paramValue = trim($paramValue);
+                }
             }
 
-            if ('' !== $paramValue && 0 !== $paramValue) {
+            if ($paramValue !== '' && $paramValue !== 0) {
                 $result->$modelParam = $paramValue;
             }
         }
@@ -436,7 +409,7 @@ class Profile extends \XLite\View\ItemsList\Model\Table
 
         if (filter_var($result->{\XLite\Model\Repo\Profile::SEARCH_PATTERN}, FILTER_VALIDATE_EMAIL)) {
             $result->{\XLite\Model\Repo\Profile::SEARCH_AND_LOGIN} = $result->{\XLite\Model\Repo\Profile::SEARCH_PATTERN};
-            $result->{\XLite\Model\Repo\Profile::SEARCH_PATTERN} = null;
+            $result->{\XLite\Model\Repo\Profile::SEARCH_PATTERN}   = null;
         } else {
             $result->{\XLite\Model\Repo\Profile::SEARCH_AND_LOGIN} = null;
         }
@@ -447,15 +420,15 @@ class Profile extends \XLite\View\ItemsList\Model\Table
             if (is_array($membershipCondition)) {
                 $membershipIds = array_reduce(
                     $membershipCondition,
-                    function ($carry, $item) {
+                    static function ($carry, $item) {
                         $item = explode('_', $item);
-                        if (2 == count($item)) {
+                        if (count($item) == 2) {
                             $carry[$item[0]][] = $item[1];
                         }
 
                         return $carry;
                     },
-                    array()
+                    []
                 );
 
                 $result->{\XLite\Model\Repo\Profile::SEARCH_MEMBERSHIP} = $membershipIds;
@@ -463,30 +436,37 @@ class Profile extends \XLite\View\ItemsList\Model\Table
         }
 
         $permittedUserTypes = $this->getPermittedUserTypes();
+
         if (
-            isset($result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE}[0]) 
-            && '' !== $result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE}[0]
+            isset($result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE}[0])
+            && $result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE}[0] !== ''
         ) {
-            $userTypes = array_filter(
+            $userTypes                                             = array_filter(
                 $result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE},
-                function($type) use ($permittedUserTypes){
+                static function ($type) use ($permittedUserTypes) {
                     return in_array($type, $permittedUserTypes);
                 }
             );
             $result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE} = $userTypes;
-
-        } elseif (!\XLite\Core\Auth::getInstance()->isPermissionAllowed('manage admins')) {
+        } elseif (!Auth::getInstance()->isPermissionAllowed(Permission::ROOT_ACCESS)) {
             $result->{\XLite\Model\Repo\Profile::SEARCH_USER_TYPE} = $permittedUserTypes;
         }
 
         return $result;
     }
 
-    // }}}
+    /**
+     * @return array
+     */
+    protected function getCommonParams()
+    {
+        $this->commonParams = parent::getCommonParams();
+        $this->commonParams[\XLite\Model\Repo\Profile::SEARCH_MEMBERSHIP] = $this->getParam(\XLite\Model\Repo\Profile::SEARCH_MEMBERSHIP);
+
+        return $this->commonParams;
+    }
 
     /**
-     * Preprocess added
-     *
      * @param integer              $date   Date
      * @param array                $column Column data
      * @param \XLite\Model\Profile $entity Profile
@@ -501,8 +481,6 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Preprocess last login
-     *
      * @param integer              $date   Date
      * @param array                $column Column data
      * @param \XLite\Model\Profile $entity Profile
@@ -517,46 +495,16 @@ class Profile extends \XLite\View\ItemsList\Model\Table
     }
 
     /**
-     * Preprocess access level
-     *
      * @param integer              $accessLevel Access level
      * @param array                $column      Column data
      * @param \XLite\Model\Profile $entity      Profile
-     *
-     * @return string
      */
-    protected function preprocessAccessLevel($accessLevel, array $column, \XLite\Model\Profile $entity)
+    protected function preprocessAccessLevel($accessLevel, array $column, \XLite\Model\Profile $entity): string
     {
-        if (0 == $accessLevel) {
+        if ($accessLevel == 0) {
             $result = $entity->getAnonymous()
                 ? static::t('Anonymous')
                 : static::t('Customer');
-
-            if ($entity->getMembership()
-                || $entity->getPendingMembership()
-            ) {
-                $result .= ' (';
-            }
-
-            if ($entity->getMembership()) {
-                $result .= $entity->getMembership()->getName();
-            }
-
-            if ($entity->getPendingMembership()) {
-                if ($entity->getMembership()) {
-                    $result .= ', ';
-                }
-
-                $result .= static::t('requested for') . ' '
-                    . $entity->getPendingMembership()->getName();
-            }
-
-            if ($entity->getMembership()
-                || $entity->getPendingMembership()
-            ) {
-                $result .= ')';
-            }
-
         } else {
             $result = static::t('Administrator');
         }
@@ -564,12 +512,30 @@ class Profile extends \XLite\View\ItemsList\Model\Table
         return $result;
     }
 
+    /** @noinspection PhpUnused */
+    protected function preprocessMembership(?\XLite\Model\Membership $membership, array $column, \XLite\Model\Profile $entity): string
+    {
+        $result = '';
+        if ($entity->getMembership()) {
+            $result .= $entity->getMembership()->getName();
+        }
+
+        if ($entity->getPendingMembership()) {
+            if ($entity->getMembership()) {
+                $result .= ', ';
+            }
+
+            $result .= static::t('requested for') . ' '
+                . $entity->getPendingMembership()->getName();
+        }
+
+        return $result;
+    }
+
     /**
-     * Remove entity
-     *
      * @param \XLite\Model\Profile $entity Entity
      *
-     * @return boolean
+     * @return bool
      */
     protected function removeEntity(\XLite\Model\AEntity $entity)
     {
@@ -583,4 +549,22 @@ class Profile extends \XLite\View\ItemsList\Model\Table
 
         return $result;
     }
+
+    /**
+     * @return string
+     */
+    protected function getDefaultTemplate()
+    {
+        return 'common/search_container.twig';
+    }
+
+    /**
+     * @return array
+     */
+    protected function getAttributes()
+    {
+        return [
+            'data-widget' => 'XLite\View\ItemsList\Model\Profile'
+        ];
+    }
 }
