@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -73,67 +72,69 @@ class Markups extends \XLite\View\ItemsList\Model\Table
      */
     protected function defineColumns()
     {
-        return array(
-            'subtotalRange' => array(
+        return [
+            'subtotalRange' => [
                 static::COLUMN_NAME => static::t('Subtotal range'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\PriceRange',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 100,
-            ),
-            'discountedSubtotalRange' => array(
+            ],
+            'discountedSubtotalRange' => [
                 static::COLUMN_NAME => static::t('Discounted subtotal range'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\PriceRange',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 100,
-            ),
-            'weightRange' => array(
+            ],
+            'weightRange' => [
                 static::COLUMN_NAME => static::t('Weight range'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\FloatRange',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 200,
-            ),
-            'itemsRange' => array(
+                static::COLUMN_PARAMS => [
+                    \XLite\View\FormField\Input\Text\FloatInput::PARAM_E => 4
+                ],
+            ],
+            'itemsRange' => [
                 static::COLUMN_NAME => static::t('Items range'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\IntegerRange',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 300,
-            ),
-            'markup_flat' => array(
+            ],
+            'markup_flat' => [
                 static::COLUMN_NAME => static::t('flat rate'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\Price',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 400,
-            ),
-            'markup_per_item' => array(
+            ],
+            'markup_per_item' => [
                 static::COLUMN_NAME => static::t('per item'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\Price',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 500,
-            ),
-            'markup_percent' => array(
-                static::COLUMN_NAME => static::t('%'),
-                static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\FloatInput',
-                static::COLUMN_PARAMS => array(
+            ],
+            'markup_percent' => [
+                static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\Percent',
+                static::COLUMN_PARAMS => [
                     \XLite\View\FormField\Input\Text\Base\Numeric::PARAM_MOUSE_WHEEL_ICON => false,
-                ),
+                ],
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 600,
-            ),
-            'markup_per_weight' => array(
+            ],
+            'markup_per_weight' => [
                 static::COLUMN_NAME => static::t('per weight unit'),
                 static::COLUMN_CLASS => 'XLite\View\FormField\Inline\Input\Text\Price',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.header.twig',
                 static::COLUMN_EDIT_ONLY => true,
                 static::COLUMN_ORDERBY => 700,
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -225,12 +226,12 @@ class Markups extends \XLite\View\ItemsList\Model\Table
     protected function getCreateColumns()
     {
         $list = parent::getCreateColumns();
-        $list[] = array(
+        $list[] = [
             static::COLUMN_CODE => 'formula',
             static::COLUMN_NAME => '',
             static::COLUMN_SERVICE => true,
             static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.formula.twig'
-        );
+        ];
 
         return $list;
     }
@@ -243,12 +244,12 @@ class Markups extends \XLite\View\ItemsList\Model\Table
     protected function getColumns()
     {
         $list = parent::getColumns();
-        $list[] = array(
+        $list[] = [
             static::COLUMN_CODE => 'formula',
             static::COLUMN_NAME => '',
             static::COLUMN_SERVICE => true,
             static::COLUMN_TEMPLATE => 'items_list/model/table/shipping/markups/cell.formula.twig'
-        );
+        ];
 
         return $list;
     }
@@ -279,7 +280,7 @@ class Markups extends \XLite\View\ItemsList\Model\Table
      */
     protected function getCurrentShippingZone()
     {
-        if (null === $this->currentShippingZone) {
+        if ($this->currentShippingZone === null) {
             $zoneId = \XLite\Core\Request::getInstance()->shippingZone ?: $this->getShippingZone();
             $this->currentShippingZone = \XLite\Core\Database::getRepo('XLite\Model\Zone')->find($zoneId);
         }
@@ -294,7 +295,7 @@ class Markups extends \XLite\View\ItemsList\Model\Table
      */
     protected function getPageDataForUpdate()
     {
-        $list = array();
+        $list = [];
         $zone = $this->getCurrentShippingZone();
         foreach (parent::getPageDataForUpdate() as $entity) {
             if ($zone && $entity->getZone() && $zone->getZoneId() === $entity->getZone()->getZoneId()) {
@@ -386,7 +387,7 @@ class Markups extends \XLite\View\ItemsList\Model\Table
             $method = $this->getModelForm()->getModelObject();
 
             $zones = \XLite\Core\Database::getRepo('XLite\Model\Zone')->getOfflineShippingZones($method);
-            $list = array_keys($zones[0] ? $zones[0] : ($zones[1] ? $zones[1] : array(1)));
+            $list = array_keys($zones[0] ? $zones[0] : ($zones[1] ? $zones[1] : [1]));
 
             return $list[0];
         }
