@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,6 @@
 
 namespace XLite\View\ItemsList\Model;
 
-use XLite\Core\MagicMethodsIntrospectionInterface;
 use XLite\Core\PreloadedLabels\ProviderInterface;
 
 /**
@@ -16,33 +14,38 @@ use XLite\Core\PreloadedLabels\ProviderInterface;
  */
 abstract class Table extends \XLite\View\ItemsList\Model\AModel implements ProviderInterface
 {
-    const COLUMN_NAME          = 'name';
-    const COLUMN_TEMPLATE      = 'template';
-    const COLUMN_HEAD_TEMPLATE = 'headTemplate';
-    const COLUMN_HEAD_HELP     = 'headHelp';
-    const COLUMN_SUBHEADER     = 'subheader';
-    const COLUMN_CLASS         = 'class';
-    const COLUMN_CODE          = 'code';
-    const COLUMN_LINK          = 'link';
-    const COLUMN_METHOD_SUFFIX = 'methodSuffix';
-    const COLUMN_CREATE_CLASS  = 'createClass';
-    const COLUMN_CREATE_TEMPLATE = 'createTemplate';
-    const COLUMN_MAIN          = 'main';
-    const COLUMN_SERVICE       = 'service';
-    const COLUMN_PARAMS        = 'params';
-    const COLUMN_SORT          = 'sort';
-    const COLUMN_SEARCH_WIDGET = 'searchWidget';
-    const COLUMN_NO_WRAP       = 'noWrap';
-    const COLUMN_EDIT_ONLY     = 'editOnly';
-    const COLUMN_SELECTOR      = 'columnSelector';
-    const COLUMN_REMOVE        = 'columnRemove';
-    const COLUMN_ORDERBY       = 'orderBy';
-    const COLUMN_EDIT_LINK     = 'editLink';
+    public const COLUMN_NAME          = 'name';
+    public const COLUMN_TEMPLATE      = 'template';
+    public const COLUMN_HEAD_TEMPLATE = 'headTemplate';
+    public const COLUMN_HEAD_HELP     = 'headHelp';
+    public const COLUMN_SUBHEADER     = 'subheader';
+    public const COLUMN_CLASS         = 'class';
+    public const COLUMN_CODE          = 'code';
+    public const COLUMN_LINK          = 'link';
+    public const COLUMN_METHOD_SUFFIX = 'methodSuffix';
+    public const COLUMN_CREATE_CLASS  = 'createClass';
+    public const COLUMN_CREATE_TEMPLATE = 'createTemplate';
+    public const COLUMN_MAIN          = 'main';
+    public const COLUMN_SERVICE       = 'service';
+    public const COLUMN_PARAMS        = 'params';
+    public const COLUMN_SORT          = 'sort';
+    public const COLUMN_SEARCH_WIDGET = 'searchWidget';
+    public const COLUMN_NO_WRAP       = 'noWrap';
+    public const COLUMN_EXPAND        = 'expand';
+    public const COLUMN_SQUEEZE       = 'squeeze';
+    public const COLUMN_ALIGN_RIGHT   = 'textRight';
+    public const COLUMN_EDIT_ONLY     = 'editOnly';
+    public const COLUMN_SELECTOR      = 'columnSelector';
+    public const COLUMN_REMOVE        = 'columnRemove';
+    public const COLUMN_ORDERBY       = 'orderBy';
+    public const COLUMN_EDIT_LINK     = 'editLink';
+    public const COLUMN_NO_HEAD       = 'noHead';
+    public const COLUMN_HEAD_COLSPAN  = 'headColspan';
 
     /**
      * Widget param names
      */
-    const PARAM_WRAP_WITH_FORM = 'wrapWithForm';
+    public const PARAM_WRAP_WITH_FORM = 'wrapWithForm';
 
     /**
      * Columns (local cache)
@@ -74,12 +77,12 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_WRAP_WITH_FORM => new \XLite\Model\WidgetParam\TypeBool(
                 'Wrap with form',
                 $this->wrapWithFormByDefault()
             ),
-        );
+        ];
     }
 
     /**
@@ -119,13 +122,13 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getFormOptions()
     {
-        return array(
+        return [
             'class'     => '\XLite\View\Form\ItemsList\AItemsList',
             'name'      => str_replace('\\', '', get_class($this)),
             'target'    => $this->getFormTarget(),
             'action'    => $this->getFormAction(),
             'params'    => $this->getFormParams()
-        );
+        ];
     }
 
     /**
@@ -155,9 +158,9 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getFormParams()
     {
-        return array(
+        return [
             'itemsList' => get_class($this),
-        );
+        ];
     }
 
     /**
@@ -166,18 +169,14 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      * @param array $column1
      * @param array $column2
      *
-     * @return boolean
+     * @return int
      */
     public function sortColumnsByOrder($column1, $column2)
     {
-        $column1[static::COLUMN_ORDERBY] = isset($column1[static::COLUMN_ORDERBY])
-            ? $column1[static::COLUMN_ORDERBY]
-            : 0;
-        $column2[static::COLUMN_ORDERBY] = isset($column2[static::COLUMN_ORDERBY])
-            ? $column2[static::COLUMN_ORDERBY]
-            : 0;
+        $column1[static::COLUMN_ORDERBY] = $column1[static::COLUMN_ORDERBY] ?? 0;
+        $column2[static::COLUMN_ORDERBY] = $column2[static::COLUMN_ORDERBY] ?? 0;
 
-        return $column1[static::COLUMN_ORDERBY] > $column2[static::COLUMN_ORDERBY];
+        return $column1[static::COLUMN_ORDERBY] > $column2[static::COLUMN_ORDERBY] ? 1 : -1;
     }
 
     /**
@@ -196,11 +195,25 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             }
         }
 
-        uasort($columns, array($this, 'sortColumnsByOrder'));
+        uasort($columns, [$this, 'sortColumnsByOrder']);
 
         return $columns;
     }
 
+    protected function getCommonFiles()
+    {
+        $newResources = [
+            static::RESOURCE_JS => [
+                [
+                    'file'      => 'js/jquery.floatThead.min.js',
+                    'no_minify' => true,
+                ]
+            ]
+        ];
+
+        return array_merge_recursive(parent::getCommonFiles(), $newResources);
+    }
+
     /**
      * Get a list of CSS files
      *
@@ -213,11 +226,11 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
         $list[] = $this->getDir() . '/' . $this->getPageBodyDir() . '/style.less';
         $list[] = $this->getDir() . '/' . $this->getPageBodyDir() . '/style.css';
 
-        if (static::SORT_TYPE_MOVE === $this->getSortableType()) {
+        if ($this->getSortableType() === static::SORT_TYPE_MOVE) {
             $list = array_merge(
                 $list,
-                $this->getWidget(array(), $this->getMovePositionWidgetClassName())->getCSSFiles(),
-                $this->getWidget(array(), $this->getOrderByWidgetClassName())->getCSSFiles()
+                $this->getWidget([], $this->getMovePositionWidgetClassName())->getCSSFiles(),
+                $this->getWidget([], $this->getOrderByWidgetClassName())->getCSSFiles()
             );
         }
 
@@ -235,11 +248,11 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
 
         $list[] = $this->getDir() . '/' . $this->getPageBodyDir() . '/controller.js';
 
-        if (static::SORT_TYPE_MOVE === $this->getSortableType()) {
+        if ($this->getSortableType() === static::SORT_TYPE_MOVE) {
             $list = array_merge(
                 $list,
-                $this->getWidget(array(), $this->getMovePositionWidgetClassName())->getJSFiles(),
-                $this->getWidget(array(), $this->getOrderByWidgetClassName())->getJSFiles()
+                $this->getWidget([], $this->getMovePositionWidgetClassName())->getJSFiles(),
+                $this->getWidget([], $this->getOrderByWidgetClassName())->getJSFiles()
             );
         }
 
@@ -275,7 +288,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
     protected function getColumns()
     {
         if (!isset($this->columns)) {
-            $this->columns = array();
+            $this->columns = [];
 
             if ($this->getLeftActions()) {
                 $this->columns[] = $this->getLeftActionsColumn();
@@ -284,40 +297,142 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             foreach ($this->prepareColumns() as $idx => $column) {
                 $column[static::COLUMN_CODE] = $idx;
                 $column[static::COLUMN_METHOD_SUFFIX]
-                    = \XLite\Core\Converter::convertToCamelCase($column[static::COLUMN_CODE]);
+                    = \Includes\Utils\Converter::convertToUpperCamelCase($column[static::COLUMN_CODE]);
                 if (!isset($column[static::COLUMN_TEMPLATE]) && !isset($column[static::COLUMN_CLASS])) {
                     $column[static::COLUMN_TEMPLATE] = 'items_list/model/table/field.twig';
                 }
-                $column[static::COLUMN_PARAMS] = isset($column[static::COLUMN_PARAMS])
-                    ? $column[static::COLUMN_PARAMS]
-                    : array();
+                $column[static::COLUMN_PARAMS] = $column[static::COLUMN_PARAMS] ?? [];
+                $column[static::COLUMN_NO_HEAD] = false;
+                $column[static::COLUMN_HEAD_COLSPAN] = 1;
+
                 $this->columns[] = $column;
             }
 
             if ($this->getEditLink()) {
-                $this->columns[] = array(
+                $this->columns[] = [
                     static::COLUMN_CODE     => 'edit-link',
                     static::COLUMN_NAME     => '',
                     static::COLUMN_TEMPLATE => 'items_list/model/table/parts/edit_link.twig',
                     static::COLUMN_SERVICE  => true,
                     static::COLUMN_LINK     => $this->getEditLink(),
-                );
+                ];
             }
 
             if ($this->getRightActions()) {
-                $this->columns[] = array(
+                $this->columns[] = [
                     static::COLUMN_CODE     => 'actions right',
                     static::COLUMN_NAME     => '',
                     static::COLUMN_TEMPLATE => 'items_list/model/table/right_actions.twig',
                     static::COLUMN_SERVICE  => true,
                     static::COLUMN_REMOVE   => $this->isRemoved(),
-                );
+                ];
             }
+
+            $this->assignColspanHeaders($this->columns);
         }
 
         return $this->columns;
     }
 
+    /**
+     * @param $columns array
+     */
+    protected function assignColspanHeaders(&$columns)
+    {
+        foreach ($this->getColspanHeaders() as $code => $union) {
+            $index = $this->getColumnIndex($columns, $code);
+
+            $columns = $this->assignColspanHeader($columns, $index, $union);
+        }
+    }
+
+    /**
+     * @param array    $columns
+     * @param int      $index
+     * @param string[] $union
+     *
+     * @return array
+     */
+    protected function assignColspanHeader($columns, $index, $union): array
+    {
+        $columns = $this->assignColspanHeaderLeft($columns, $index, $union);
+        $columns = $this->assignColspanHeaderRight($columns, $index, $union);
+
+        return $columns;
+    }
+
+    /**
+     * @param array    $columns
+     * @param int      $index
+     * @param string[] $union
+     *
+     * @return array
+     */
+    protected function assignColspanHeaderLeft($columns, $index, $union): array
+    {
+        $columnIndex = $index;
+        while (--$columnIndex >= 0) {
+            if (in_array($columns[$columnIndex][static::COLUMN_CODE], $union, true)) {
+                $columns[$columnIndex][static::COLUMN_NO_HEAD] = true;
+                $columns[$index][static::COLUMN_HEAD_COLSPAN]++;
+            } else {
+                break;
+            }
+        }
+
+        return $columns;
+    }
+
+    /**
+     * @param array    $columns
+     * @param int      $index
+     * @param string[] $union
+     *
+     * @return array
+     */
+    protected function assignColspanHeaderRight($columns, $index, $union): array
+    {
+        $columnIndex = $index;
+        while (++$columnIndex <= count($columns)) {
+            if (in_array($columns[$columnIndex][static::COLUMN_CODE], $union, true)) {
+                $columns[$columnIndex][static::COLUMN_NO_HEAD] = true;
+                $columns[$index][static::COLUMN_HEAD_COLSPAN]++;
+            } else {
+                break;
+            }
+        }
+
+        return $columns;
+    }
+
+    /**
+     * @param array  $columns
+     * @param string $code
+     *
+     * @return int|null
+     */
+    protected function getColumnIndex($columns, $code): ?int
+    {
+        foreach ($columns as $index => $column) {
+            if ($column[static::COLUMN_CODE] === $code) {
+                return (int) $index;
+            }
+        }
+
+        return null;
+    }
+
+    /**
+     * Define columns with same header
+     * Format: ['main_column_code' => ['merged_column_1', 'merged_column_2', 'merged_column_3']]
+     *
+     * @return array
+     */
+    protected function getColspanHeaders()
+    {
+        return [];
+    }
+
     /**
      * @return array
      */
@@ -328,9 +443,9 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             static::COLUMN_NAME     => '',
             static::COLUMN_TEMPLATE => 'items_list/model/table/left_actions.twig',
             static::COLUMN_SERVICE  => true,
-            static::COLUMN_HEAD_TEMPLATE => static::SORT_TYPE_INPUT === $this->getSortType()
+            static::COLUMN_HEAD_TEMPLATE => $this->getSortType() === static::SORT_TYPE_INPUT
                 ? 'items_list/model/table/parts/pos_input.twig'
-                : (static::SORT_TYPE_MOVE === $this->getSortType()
+                : ($this->getSortType() === static::SORT_TYPE_MOVE
                     ? 'items_list/model/table/parts/pos_move.twig'
                     : ''
                 ),
@@ -363,7 +478,8 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
     {
         parent::setWidgetParams($params);
 
-        if (!$this->isPositionSortable()
+        if (
+            !$this->isPositionSortable()
             && in_array($this->getSortableType(), [static::SORT_TYPE_MOVE, static::SORT_TYPE_INPUT], true)
         ) {
             unset($this->widgetParams[static::PARAM_SORT_BY]);
@@ -427,6 +543,22 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
         return $result;
     }
 
+    /**
+     * Check if at least one of headers has subheader
+     *
+     * @return boolean
+     */
+    protected function hasSubheaders()
+    {
+        foreach ($this->getColumns() as $column) {
+            if (!empty($column[static::COLUMN_SUBHEADER])) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     /**
      * @return string
      */
@@ -448,9 +580,42 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             $result[] = 'list-no-items';
         }
 
+        $result[] = $this->getClassBasedOnColumns();
+
         return $result;
     }
 
+    protected function getClassBasedOnColumns(): string
+    {
+        $result = '';
+        $columns = $this->getColumnsCount();
+
+        foreach ($this->getClassBasedOnColumnsMap() as $item) {
+            if ($columns >= $item[0] && $columns <= $item[1]) {
+                $result = $item[2];
+                break;
+            }
+        }
+
+        return $result;
+    }
+
+    protected function getClassBasedOnColumnsMap(): array
+    {
+        return [
+            [
+                0,
+                3,
+                'small-table'
+            ],
+            [
+                4,
+                INF,
+                'big-table'
+            ],
+        ];
+    }
+
     /**
      * Get main column
      *
@@ -476,10 +641,10 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
                 }
             }
 
-            $this->mainColumn = isset($result) ? $result : $first;
+            $this->mainColumn = $result ?? $first;
         }
 
-        return isset($columns[$this->mainColumn]) ? $columns[$this->mainColumn] : null;
+        return $columns[$this->mainColumn] ?? null;
     }
 
     /**
@@ -515,7 +680,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             : $this->getEntityValue($entity, $column[static::COLUMN_CODE]);
 
         // Preprocessing
-        $method = 'preprocess' . \XLite\Core\Converter::convertToCamelCase($column[static::COLUMN_CODE]);
+        $method = 'preprocess' . \Includes\Utils\Converter::convertToUpperCamelCase($column[static::COLUMN_CODE]);
         if (method_exists($this, $method)) {
             // $method assembled frm 'preprocess' + field name
             $value = $this->$method($value, $column, $entity);
@@ -536,14 +701,11 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
     {
         $result = null;
 
-        $method = 'get' . \XLite\Core\Converter::convertToCamelCase($name);
+        $method = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
-        if (method_exists($entity, $method)
-            || ($entity instanceof MagicMethodsIntrospectionInterface && $entity->hasMagicMethod($method))
-        ) {
+        if (method_exists($entity, $method)) {
             // $method assembled frm 'get' + field name
             $result = $entity->$method();
-
         } elseif ($entity->isPropertyExists($name)) {
             $result = $entity->$name;
         }
@@ -558,35 +720,36 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getFieldObjects()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getColumns() as $column) {
             $name = $column[static::COLUMN_CODE];
-            if (isset($column[static::COLUMN_CLASS])
+            if (
+                isset($column[static::COLUMN_CLASS])
                 && is_subclass_of($column[static::COLUMN_CLASS], 'XLite\View\FormField\Inline\AInline')
             ) {
-                $params = isset($column[static::COLUMN_PARAMS]) ? $column[static::COLUMN_PARAMS] : array();
-                $list[] = array(
+                $params = $column[static::COLUMN_PARAMS] ?? [];
+                $list[] = [
                     'class'      => $column[static::COLUMN_CLASS],
-                    'parameters' => array('fieldName' => $name, 'fieldParams' => $params),
-                );
+                    'parameters' => ['fieldName' => $name, 'fieldParams' => $params],
+                ];
             }
         }
 
         if ($this->isSwitchable()) {
             $cell = $this->getSwitcherField();
-            $list[] = array(
+            $list[] = [
                 'class'      => $cell['class'],
-                'parameters' => array('fieldName' => $cell['name'], 'fieldParams' => $cell['params']),
-            );
+                'parameters' => ['fieldName' => $cell['name'], 'fieldParams' => $cell['params']],
+            ];
         }
 
-        if (static::SORT_TYPE_NONE != $this->getSortType()) {
+        if ($this->getSortType() != static::SORT_TYPE_NONE) {
             $cell = $this->getSortField();
-            $list[] = array(
+            $list[] = [
                 'class'      => $cell['class'],
-                'parameters' => array('fieldName' => $cell['name'], 'fieldParams' => $cell['params']),
-            );
+                'parameters' => ['fieldName' => $cell['name'], 'fieldParams' => $cell['params']],
+            ];
         }
 
         foreach ($list as $i => $class) {
@@ -603,11 +766,11 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getSwitcherField()
     {
-        return array(
+        return [
             'class'  => 'XLite\View\FormField\Inline\Input\Checkbox\Switcher\Enabled',
             'name'   => 'enabled',
-            'params' => array(),
-        );
+            'params' => [],
+        ];
     }
 
     /**
@@ -617,18 +780,18 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getSortField()
     {
-        return static::SORT_TYPE_INPUT == $this->getSortType()
-            ? array(
+        return $this->getSortType() == static::SORT_TYPE_INPUT
+            ? [
                 'class'  => $this->getOrderByWidgetClassName(),
                 'name'   => 'position',
-                'params' => array(),
-            )
+                'params' => [],
+            ]
             :
-            array(
+            [
                 'class'  => $this->getMovePositionWidgetClassName(),
                 'name'   => 'position',
-                'params' => array(),
-            );
+                'params' => [],
+            ];
     }
 
     /**
@@ -658,32 +821,33 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getCreateFieldClasses()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getColumns() as $column) {
             $name = $column[static::COLUMN_CODE];
             $class = null;
-            if (isset($column[static::COLUMN_CREATE_CLASS])
+            if (
+                isset($column[static::COLUMN_CREATE_CLASS])
                 && is_subclass_of($column[static::COLUMN_CREATE_CLASS], 'XLite\View\FormField\Inline\AInline')
             ) {
                 $class = $column[static::COLUMN_CREATE_CLASS];
-
-            } elseif (isset($column[static::COLUMN_CLASS])
+            } elseif (
+                isset($column[static::COLUMN_CLASS])
                 && is_subclass_of($column[static::COLUMN_CLASS], 'XLite\View\FormField\Inline\AInline')
             ) {
                 $class = $column[static::COLUMN_CLASS];
             }
 
             if ($class) {
-                $params = isset($column[static::COLUMN_PARAMS]) ? $column[static::COLUMN_PARAMS] : array();
-                $list[] = array(
+                $params = $column[static::COLUMN_PARAMS] ?? [];
+                $list[] = [
                     'class'      => $class,
-                    'parameters' => array(
+                    'parameters' => [
                         \XLite\View\FormField\Inline\AInline::PARAM_FIELD_NAME   => $name,
                         \XLite\View\FormField\Inline\AInline::PARAM_FIELD_PARAMS => $params,
                         \XLite\View\FormField\Inline\AInline::PARAM_EDIT_ONLY    => true,
-                    ),
-                );
+                    ],
+                ];
             }
         }
 
@@ -701,64 +865,63 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getCreateColumns()
     {
-        $columns = array();
+        $columns = [];
 
         if ($this->getLeftActions()) {
-            $columns[] = array(
+            $columns[] = [
                 static::COLUMN_CODE     => 'actions left',
                 static::COLUMN_NAME     => '',
                 static::COLUMN_SERVICE  => true,
                 static::COLUMN_TEMPLATE => 'items_list/model/table/parts/empty_left.twig',
-            );
+            ];
         }
 
         foreach ($this->prepareColumns() as $idx => $column) {
-            if ((isset($column[static::COLUMN_CREATE_CLASS]) && $column[static::COLUMN_CREATE_CLASS])
+            if (
+                (isset($column[static::COLUMN_CREATE_CLASS]) && $column[static::COLUMN_CREATE_CLASS])
                 || (isset($column[static::COLUMN_CLASS]) && $column[static::COLUMN_CLASS])
             ) {
                 // By class
                 $column[static::COLUMN_CODE] = $idx;
                 $column[static::COLUMN_METHOD_SUFFIX]
-                    = \XLite\Core\Converter::convertToCamelCase($column[static::COLUMN_CODE]);
+                    = \Includes\Utils\Converter::convertToUpperCamelCase($column[static::COLUMN_CODE]);
                 if (!isset($column[static::COLUMN_CREATE_CLASS]) || !$column[static::COLUMN_CREATE_CLASS]) {
                     $column[static::COLUMN_CREATE_CLASS] = $column[static::COLUMN_CLASS];
                 }
                 $columns[] = $column;
-
             } elseif (!empty($column[static::COLUMN_CREATE_TEMPLATE])) {
                 // By template
-                $columns[] = array(
+                $columns[] = [
                     static::COLUMN_CODE     => $idx,
                     static::COLUMN_TEMPLATE => $column[static::COLUMN_CREATE_TEMPLATE],
-                );
-
+                ];
             } else {
                 // Empty
-                $columns[] = array(
+                $columns[] = [
                     static::COLUMN_CODE     => $idx,
                     static::COLUMN_TEMPLATE => 'items_list/model/table/empty.twig',
-                );
+                ];
             }
         }
 
         if ($this->getEditLink()) {
-            $columns[] = array(
+            $columns[] = [
                 static::COLUMN_CODE     => 'edit-link',
                 static::COLUMN_NAME     => '',
                 static::COLUMN_TEMPLATE => 'items_list/model/table/parts/empty.twig',
                 static::COLUMN_SERVICE  => true,
-            );
+            ];
         }
 
         if ($this->getRightActions()) {
-            $columns[] = array(
+            $columns[] = [
                 static::COLUMN_CODE     => 'actions right',
                 static::COLUMN_NAME     => '',
                 static::COLUMN_SERVICE  => true,
                 static::COLUMN_TEMPLATE => $this->isRemoved()
                     ? 'items_list/model/table/parts/remove_create.twig'
                     : 'items_list/model/table/parts/empty_right.twig',
-            );
+            ];
         }
 
         return $columns;
@@ -771,7 +934,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function isTopInlineCreation()
     {
-        return static::CREATE_INLINE_TOP === $this->isInlineCreation();
+        return $this->isInlineCreation() === static::CREATE_INLINE_TOP;
     }
 
     /**
@@ -781,7 +944,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function isBottomInlineCreation()
     {
-        return static::CREATE_INLINE_BOTTOM === $this->isInlineCreation();
+        return $this->isInlineCreation() === static::CREATE_INLINE_BOTTOM;
     }
 
     /**
@@ -834,7 +997,8 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
 
         $class .= ' ' . $this->getIdentifierClass();
 
-        if (!$this->isPositionSortable()
+        if (
+            !$this->isPositionSortable()
             || $this->isPositionSort($this->getSortBy())
         ) {
             $class .= ' position-sort';
@@ -874,6 +1038,24 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
         return $column[static::COLUMN_CODE];
     }
 
+    /**
+     * @param array $column
+     * @return bool|mixed
+     */
+    protected function isNoColumnHead(array $column)
+    {
+        return $column[static::COLUMN_NO_HEAD] ?? false;
+    }
+
+    /**
+     * @param array $column
+     * @return int|mixed
+     */
+    protected function getColumnHeadColspan(array $column)
+    {
+        return $column[static::COLUMN_HEAD_COLSPAN] ?? 1;
+    }
+
     /**
      * Get column cell class
      *
@@ -889,7 +1071,10 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
             . ($this->hasColumnAttention($column, $entity) ? ' attention' : '')
             . ($this->isMainColumn($column) ? ' main' : '')
             . ($this->isEditLinkEnabled($column, $entity) ? ' has-edit-link' : '')
-            . (empty($column[static::COLUMN_NO_WRAP]) ? '' : ' no-wrap');
+            . (empty($column[static::COLUMN_NO_WRAP]) ? '' : ' no-wrap')
+            . (empty($column[static::COLUMN_EXPAND]) ? '' : ' expand')
+            . (empty($column[static::COLUMN_SQUEEZE]) ? '' : ' squeeze')
+            . (empty($column[static::COLUMN_ALIGN_RIGHT]) ? '' : ' text-right');
     }
 
     /**
@@ -929,16 +1114,16 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getTopActions()
     {
-        $actions = array();
+        $actions = [];
 
         if (!$this->isStatic()) {
-            if (static::CREATE_INLINE_TOP == $this->isCreation()
+            if (
+                $this->isCreation() == static::CREATE_INLINE_TOP
                 && $this->getCreateURL()
-                && static::CREATE_INLINE_NONE == $this->isInlineCreation()
+                && $this->isInlineCreation() == static::CREATE_INLINE_NONE
             ) {
                 $actions[] = 'items_list/model/table/parts/create.twig';
-
-            } elseif (static::CREATE_INLINE_TOP == $this->isInlineCreation()) {
+            } elseif ($this->isInlineCreation() == static::CREATE_INLINE_TOP) {
                 $actions[] = 'items_list/model/table/parts/create_inline.twig';
             }
         }
@@ -953,16 +1138,16 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getBottomActions()
     {
-        $actions = array();
+        $actions = [];
 
         if (!$this->isStatic()) {
-            if (static::CREATE_INLINE_BOTTOM == $this->isCreation()
+            if (
+                $this->isCreation() == static::CREATE_INLINE_BOTTOM
                 && $this->getCreateURL()
-                && static::CREATE_INLINE_NONE == $this->isInlineCreation()
+                && $this->isInlineCreation() == static::CREATE_INLINE_NONE
             ) {
                 $actions[] = 'items_list/model/table/parts/create.twig';
-
-            } elseif (static::CREATE_INLINE_BOTTOM == $this->isInlineCreation()) {
+            } elseif ($this->isInlineCreation() == static::CREATE_INLINE_BOTTOM) {
                 $actions[] = 'items_list/model/table/parts/create_inline.twig';
             }
         }
@@ -981,7 +1166,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getSortType()
     {
-        return (static::SORT_TYPE_MOVE === $this->getSortableType() && 1 < $this->getPager()->getPagesCount())
+        return ($this->getSortableType() === static::SORT_TYPE_MOVE && 1 < $this->getPager()->getPagesCount())
             ? static::SORT_TYPE_INPUT
             : $this->getSortableType();
     }
@@ -993,13 +1178,12 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getLeftActions()
     {
-        $list = array();
+        $list = [];
 
         if (!$this->isStatic()) {
-            if (static::SORT_TYPE_MOVE === $this->getSortType()) {
+            if ($this->getSortType() === static::SORT_TYPE_MOVE) {
                 $list[] = $this->getMoveActionTemplate();
-
-            } elseif (static::SORT_TYPE_INPUT === $this->getSortType()) {
+            } elseif ($this->getSortType() === static::SORT_TYPE_INPUT) {
                 $list[] = $this->getPositionActionTemplate();
             }
 
@@ -1126,7 +1310,7 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
      */
     protected function getRightActions()
     {
-        $list = array();
+        $list = [];
 
         if (!$this->isStatic() && $this->isRemoved()) {
             $list[] = $this->getRemoveActionTemplate();
@@ -1275,10 +1459,9 @@ abstract class Table extends \XLite\View\ItemsList\Model\AModel implements Provi
     protected function getSortDirectionNext(array $column)
     {
         if ($this->isColumnSorted($column)) {
-            $direction = static::SORT_ORDER_DESC == $this->getSortOrder()
+            $direction = $this->getSortOrder() == static::SORT_ORDER_DESC
                 ? static::SORT_ORDER_ASC
                 : static::SORT_ORDER_DESC;
-
         } else {
             $direction = $this->getSortOrder() ?: static::SORT_ORDER_DESC;
         }
