@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,71 +8,69 @@
 namespace XLite\View\ItemsList\Product\Customer;
 
 use XLite\Core\Model\EntityVersion\BulkEntityVersionFetcher;
-use XLite\Core\Model\EntityVersion\EntityVersionFetcher;
 use XLite\View\Product\ListItem;
 
-/**
- * ACustomer
- */
 abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
 {
     /**
      * Widget param names
      */
-    const PARAM_WIDGET_TYPE  = 'widgetType';
-    const PARAM_DISPLAY_MODE = 'displayMode';
-    const PARAM_GRID_COLUMNS = 'gridColumns';
+    public const PARAM_WIDGET_TYPE  = 'widgetType';
+    public const PARAM_DISPLAY_MODE = 'displayMode';
+    public const PARAM_GRID_COLUMNS = 'gridColumns';
 
-    const PARAM_SHOW_DISPLAY_MODE_SELECTOR = 'showDisplayModeSelector';
-    const PARAM_SHOW_SORT_BY_SELECTOR      = 'showSortBySelector';
+    public const PARAM_SHOW_DISPLAY_MODE_SELECTOR = 'showDisplayModeSelector';
+    public const PARAM_SHOW_SORT_BY_SELECTOR      = 'showSortBySelector';
 
-    const PARAM_ICON_MAX_WIDTH = 'iconWidth';
-    const PARAM_ICON_MAX_HEIGHT = 'iconHeight';
+    public const PARAM_MAX_ITEMS_TO_DISPLAY = 'maxItemsToDisplay';
+
+    public const PARAM_ICON_MAX_WIDTH = 'iconWidth';
+    public const PARAM_ICON_MAX_HEIGHT = 'iconHeight';
 
     /**
      * Allowed widget types
      */
-    const WIDGET_TYPE_SIDEBAR = 'sidebar';
-    const WIDGET_TYPE_CENTER  = 'center';
+    public const WIDGET_TYPE_SIDEBAR = 'sidebar';
+    public const WIDGET_TYPE_CENTER  = 'center';
 
     /**
      * Allowed display modes
      */
-    const DISPLAY_MODE_LIST    = 'list';
-    const DISPLAY_MODE_GRID    = 'grid';
-    const DISPLAY_MODE_TABLE   = 'table';
-    const DISPLAY_MODE_ROTATOR = 'rotator';
+    public const DISPLAY_MODE_LIST    = 'list';
+    public const DISPLAY_MODE_GRID    = 'grid';
+    public const DISPLAY_MODE_TABLE   = 'table';
+    public const DISPLAY_MODE_ROTATOR = 'rotator';
 
-    const DISPLAY_MODE_STHUMB = 'small_thumbnails';
-    const DISPLAY_MODE_BTHUMB = 'big_thumbnails';
-    const DISPLAY_MODE_TEXTS  = 'text_links';
+    public const DISPLAY_MODE_STHUMB = 'small_thumbnails';
+    public const DISPLAY_MODE_BTHUMB = 'big_thumbnails';
+    public const DISPLAY_MODE_TEXTS  = 'text_links';
 
 
     /**
      * A special option meaning that a CSS layout is to be used
      */
-    const DISPLAY_GRID_CSS_LAYOUT = 'css-defined';
+    public const DISPLAY_GRID_CSS_LAYOUT = 'css-defined';
 
     /**
      * Columns number range
      */
-    const GRID_COLUMNS_MIN = 1;
-    const GRID_COLUMNS_MAX = 5;
+    public const GRID_COLUMNS_MIN = 1;
+    public const GRID_COLUMNS_MAX = 5;
 
     /**
      * Template to use for sidebars
      */
-    const TEMPLATE_SIDEBAR = 'common/sidebar_box.twig';
+    public const TEMPLATE_SIDEBAR = 'common/sidebar_box.twig';
 
     /**
      * Widget types
      *
      * @var array
      */
-    protected $widgetTypes = array(
+    protected $widgetTypes = [
         self::WIDGET_TYPE_SIDEBAR  => 'Sidebar',
         self::WIDGET_TYPE_CENTER   => 'Center',
-    );
+    ];
 
     /**
      * Runtime cache of item hover text params, see method defineItemHoverParams()
@@ -83,8 +80,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     protected $itemHoverParams = null;
 
     /**
-     * Return list of targets allowed for this widget
-     *
      * @return array
      */
     public static function getAllowedTargets()
@@ -102,11 +97,11 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     public static function getSidebarDisplayModes()
     {
-        return array(
+        return [
             static::DISPLAY_MODE_STHUMB  => 'Cells',
             static::DISPLAY_MODE_BTHUMB  => 'List',
             static::DISPLAY_MODE_TEXTS   => 'Text links',
-        );
+        ];
     }
 
     /**
@@ -116,11 +111,11 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     public static function getCenterDisplayModes()
     {
-        return array(
+        return [
             static::DISPLAY_MODE_GRID  => 'Grid',
             static::DISPLAY_MODE_LIST  => 'List',
             static::DISPLAY_MODE_TABLE => 'Table',
-        );
+        ];
     }
 
     /**
@@ -132,7 +127,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     {
         $model = \XLite\Logic\ImageResize\Generator::MODEL_PRODUCT;
 
-        return array(
+        return [
             static::WIDGET_TYPE_SIDEBAR . '.' . static::DISPLAY_MODE_STHUMB =>
                 \XLite\Logic\ImageResize\Generator::getImageSizes($model, 'SBSmallThumbnail'),
             static::WIDGET_TYPE_SIDEBAR . '.' . static::DISPLAY_MODE_BTHUMB =>
@@ -143,22 +138,20 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
                 \XLite\Logic\ImageResize\Generator::getImageSizes($model, 'LGThumbnailList'),
             'other' =>
                 \XLite\Logic\ImageResize\Generator::getImageSizes($model, 'CommonThumbnail'),
-        );
+        ];
     }
 
     /**
-     * Define and set widget attributes; initialize widget
-     *
      * @param array $params Widget params OPTIONAL
      */
-    public function __construct(array $params = array())
+    public function __construct(array $params = [])
     {
         parent::__construct($params);
 
-        $this->sortByModes = array(
+        $this->sortByModes = [
             static::SORT_BY_MODE_PRICE  => 'Price-sort-option',
             static::SORT_BY_MODE_NAME   => 'Name-sort-option',
-        );
+        ];
     }
 
     /**
@@ -200,8 +193,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getSortOrder
-     *
      * @return string
      */
     protected function getSortOrder()
@@ -225,7 +216,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
         }
 
         if ($this->isSortByModeSelected($sortBy)) {
-            $result = static::SORT_ORDER_DESC === $this->getSortOrder()
+            $result = $this->getSortOrder() === static::SORT_ORDER_DESC
                 ? 'sort-arrow-desc'
                 : 'sort-arrow-asc';
         }
@@ -234,8 +225,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getSortOrderToChange
-     *
      * @param string $sortOrder Sorting order
      *
      * @return string
@@ -248,8 +237,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Initialize widget (set attributes)
-     *
      * @param array $params Widget params
      *
      * @return void
@@ -273,44 +260,37 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
             );
         }
 
-        if (!isset($params[static::PARAM_ICON_MAX_WIDTH])
+        if (
+            !isset($params[static::PARAM_ICON_MAX_WIDTH])
             && !isset($params[static::PARAM_ICON_MAX_HEIGHT])
         ) {
             $sizes = static::getIconSizes();
             $key = $this->getWidgetType() . '.' . $this->getDisplayMode();
-            $size = isset($sizes[$key]) ? $sizes[$key] : $sizes['other'];
+            $size = $sizes[$key] ?? $sizes['other'];
 
             $this->widgetParams[static::PARAM_ICON_MAX_WIDTH]->setValue($size[0]);
             $this->widgetParams[static::PARAM_ICON_MAX_HEIGHT]->setValue($size[1]);
         }
 
         // FIXME - not a good idea, but I don't see a better way
-        if ($this->isWrapper() && $this->checkSideBarParams($params)) {
+        if ($this->checkSideBarParams($params)) {
             $this->defaultTemplate = static::TEMPLATE_SIDEBAR;
             $this->widgetParams[static::PARAM_TEMPLATE]->setValue($this->getDefaultTemplate());
         }
     }
 
     /**
-     * Get a list of CSS files required to display the widget properly
-     *
      * @return array
      */
     public function getCSSFiles()
     {
-        $list = parent::getCSSFiles();
-
+        $list   = parent::getCSSFiles();
         $list[] = $this->getDir() . '/quick_look.css';
 
-        //TODO: Remove after CSS loading feature is added.
-        $list[] = 'labels/style.css';
-
         return array_merge($list, $this->getPopupCSS());
     }
 
     /**
-     * Get a list of JavaScript files required to display the widget properly
-     *
      * @return array
      */
     public function getJSFiles()
@@ -319,9 +299,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Return title
-     *
-     * @return string
+     * @return string|null
      */
     protected function getHead()
     {
@@ -329,8 +307,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Return name of the base widgets list
-     *
      * @return string
      */
     protected function getListName()
@@ -339,37 +315,52 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Define widget parameters
-     *
      * @return void
      */
     protected function defineWidgetParams()
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_WIDGET_TYPE => new \XLite\Model\WidgetParam\TypeSet(
-                'Widget type', static::WIDGET_TYPE_CENTER, true, $this->widgetTypes
+                'Widget type',
+                static::WIDGET_TYPE_CENTER,
+                true,
+                $this->widgetTypes
             ),
             static::PARAM_DISPLAY_MODE => new \XLite\Model\WidgetParam\TypeSet(
-                'Display mode', $this->getDefaultDisplayMode(), true, array()
+                'Display mode',
+                $this->getDefaultDisplayMode(),
+                true,
+                []
             ),
             static::PARAM_SHOW_DISPLAY_MODE_SELECTOR => new \XLite\Model\WidgetParam\TypeCheckbox(
-                'Show "Display mode" selector', true, true
+                'Show "Display mode" selector',
+                true,
+                true
             ),
             static::PARAM_SHOW_SORT_BY_SELECTOR => new \XLite\Model\WidgetParam\TypeCheckbox(
-                'Show "Sort by" selector', true, true
+                'Show "Sort by" selector',
+                true,
+                true
             ),
             static::PARAM_GRID_COLUMNS => new \XLite\Model\WidgetParam\TypeSet(
-                'Number of columns (for Grid mode only)', 3, true, $this->getGridColumnsRange()
+                'Number of columns (for Grid mode only)',
+                3,
+                true,
+                $this->getGridColumnsRange()
             ),
             static::PARAM_ICON_MAX_WIDTH => new \XLite\Model\WidgetParam\TypeInt(
-                'Maximal icon width', 0, true
+                'Maximal icon width',
+                0,
+                true
             ),
             static::PARAM_ICON_MAX_HEIGHT => new \XLite\Model\WidgetParam\TypeInt(
-                'Maximal icon height', 0, true
+                'Maximal icon height',
+                0,
+                true
             ),
-        );
+        ];
     }
 
     /**
@@ -381,9 +372,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Get display modes
-     *
-     * @return string
+     * @return array
      */
     protected function getDisplayModes()
     {
@@ -393,8 +382,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getSortByModeDefault
-     *
      * @return string
      */
     protected function getSortByModeDefault()
@@ -403,8 +390,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Define so called "request" parameters
-     *
      * @return void
      */
     protected function defineRequestParams()
@@ -415,8 +400,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * checkSideBarParams
-     *
      * @param array $params Params to check
      *
      * @return boolean
@@ -427,8 +410,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Return dir which contains the page body template
-     *
      * @return string
      */
     protected function getPageBodyDir()
@@ -453,7 +434,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function isSidebar()
     {
-        return static::WIDGET_TYPE_SIDEBAR === $this->getWidgetType();
+        return $this->getWidgetType() === static::WIDGET_TYPE_SIDEBAR;
     }
 
     /**
@@ -469,18 +450,16 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * isDisplayModeSelectorVisible
-     *
      * @return boolean
      */
     protected function isDisplayModeSelectorVisible()
     {
-        return $this->getParam(static::PARAM_SHOW_DISPLAY_MODE_SELECTOR) && !$this->isSidebar();
+        return $this->getParam(static::PARAM_SHOW_DISPLAY_MODE_SELECTOR)
+            && !$this->isSidebar()
+            && (!$this->isMobileDevice() || $this->isTablet());
     }
 
     /**
-     * isSortBySelectorVisible
-     *
      * @return boolean
      */
     protected function isSortBySelectorVisible()
@@ -489,8 +468,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * isHeaderVisible
-     *
      * @return boolean
      */
     protected function isHeaderVisible()
@@ -499,14 +476,11 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getDisplayMode
-     *
      * @return string
      */
     protected function getDisplayMode()
     {
         if ($this->isMobileDevice() && !$this->isTablet()) {
-
             return self::DISPLAY_MODE_GRID;
         }
 
@@ -514,8 +488,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * isDisplayModeSelected
-     *
      * @param string $displayMode Value to check
      *
      * @return boolean
@@ -535,15 +507,15 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function getDisplayModeLinkClassName($displayMode)
     {
-        $classes = array(
+        $classes = [
             'list-type-' . $displayMode
-        );
+        ];
 
-        if ('grid' === $displayMode) {
+        if ($displayMode === 'grid') {
             $classes[] = 'first';
         }
 
-        if ('table' === $displayMode) {
+        if ($displayMode === 'table') {
             $classes[] = 'last';
         }
 
@@ -564,9 +536,9 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function getDisplayModeCSS($displayMode)
     {
-        $classes = array(
+        $classes = [
             $displayMode
-        );
+        ];
 
         switch ($displayMode) {
             case static::DISPLAY_MODE_GRID:
@@ -599,7 +571,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     protected function getProductRows()
     {
         $data = $this->getPageData();
-        $rows = array();
+        $rows = [];
 
         if (!empty($data)) {
             $rows = array_chunk($data, $this->getParam(static::PARAM_GRID_COLUMNS));
@@ -611,14 +583,12 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * Get grid columns range
-     *
      * @return array
      */
     protected function getGridColumnsRange()
     {
         $range = array_merge(
-            array(static::DISPLAY_GRID_CSS_LAYOUT => static::DISPLAY_GRID_CSS_LAYOUT),
+            [static::DISPLAY_GRID_CSS_LAYOUT => static::DISPLAY_GRID_CSS_LAYOUT],
             range(static::GRID_COLUMNS_MIN, static::GRID_COLUMNS_MAX)
         );
 
@@ -636,13 +606,12 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getPageBodyFile
-     *
      * @return string
      */
     protected function getPageBodyFile()
     {
-        if ($this->getWidgetType() === static::WIDGET_TYPE_CENTER
+        if (
+            $this->getWidgetType() === static::WIDGET_TYPE_CENTER
             && $this->getDisplayMode() === static::DISPLAY_MODE_GRID
         ) {
             return $this->isCSSLayout() ? 'body-css-layout.twig' : 'body-table-layout.twig';
@@ -652,8 +621,6 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     }
 
     /**
-     * getSidebarMaxItems
-     *
      * @return integer
      */
     protected function getSidebarMaxItems()
@@ -683,9 +650,9 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function getAdditionalItemClass($i, $count)
     {
-        $classes = array();
+        $classes = [];
 
-        if (1 == $i) {
+        if ($i == 1) {
             $classes[] = 'first';
         }
 
@@ -693,7 +660,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
             $classes[] = 'last';
         }
 
-        if (0 == $i % 2) {
+        if ($i % 2 == 0) {
             $classes[] = 'odd';
         }
 
@@ -759,11 +726,11 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     protected function getPopupCSS()
     {
         return array_merge(
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Page\QuickLook')->getCSSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Image')->getCSSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Gallery')->getCSSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\QuantityBox')->getCSSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\AttributesModify')->getCSSFiles()
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Page\QuickLook')->getCSSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Image')->getCSSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Gallery')->getCSSFiles(),
+            $this->getWidget([], 'XLite\View\Product\QuantityBox')->getCSSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\AttributesModify')->getCSSFiles()
         );
     }
 
@@ -776,17 +743,15 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
     protected function getPopupJS()
     {
         return array_merge(
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Page\QuickLook')->getJSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Image')->getJSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\Gallery')->getJSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\QuantityBox')->getJSFiles(),
-            $this->getWidget(array(), 'XLite\View\Product\Details\Customer\AttributesModify')->getJSFiles()
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Page\QuickLook')->getJSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Image')->getJSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\Gallery')->getJSFiles(),
+            $this->getWidget([], 'XLite\View\Product\QuantityBox')->getJSFiles(),
+            $this->getWidget([], 'XLite\View\Product\Details\Customer\AttributesModify')->getJSFiles()
         );
     }
 
     /**
-     * Define widget significant arguments
-     *
      * @return array
      */
     protected function defineWidgetSignificantArguments()
@@ -797,11 +762,7 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
         return $list;
     }
 
-    // {{{ Cache
-
     /**
-     * Get cache parameters
-     *
      * @return array
      */
     protected function getCacheParameters()
@@ -832,21 +793,17 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function defineCachedParams()
     {
-        return array(
+        return [
             \XLite\View\Pager\APager::PARAM_PAGE_ID,
             \XLite\View\Pager\APager::PARAM_ITEMS_PER_PAGE,
             static::PARAM_WIDGET_TYPE,
             static::PARAM_DISPLAY_MODE,
             static::PARAM_SORT_BY,
             static::PARAM_SORT_ORDER,
-        );
+        ];
     }
 
-    // }}}
-
     /**
-     * Compose URL from target, action and additional params
-     *
      * @param string  $target      Page identifier OPTIONAL
      * @param string  $action      Action to perform OPTIONAL
      * @param array   $params      Additional params OPTIONAL
@@ -854,9 +811,10 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      *
      * @return string
      */
-    public function buildURL($target = '', $action = '', array $params = array(), $forceCuFlag = null)
+    public function buildURL($target = '', $action = '', array $params = [], $forceCuFlag = null)
     {
-        if ('product' === $target
+        if (
+            $target === 'product'
             && isset($params['category_id'])
             && $this->getRootCategoryId() === (int) $params['category_id']
         ) {
@@ -910,12 +868,12 @@ abstract class ACustomer extends \XLite\View\ItemsList\Product\AProduct
      */
     protected function getProductWidgetParams(\XLite\Model\Product $product)
     {
-        $productIds = array_map(function ($product) {
+        $productIds = array_map(static function ($product) {
             /** @var \XLite\Model\Product $product */
             return $product->getProductId();
         }, $this->getPageData());
 
-        $entityVersionFetcher = new BulkEntityVersionFetcher('XLite\Model\Product', $productIds);
+        $entityVersionFetcher = new BulkEntityVersionFetcher('XLite\Model\Product', array_filter($productIds));
 
         return [
             ListItem::PARAM_PRODUCT_ID                        => $product->getId(),
