@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,17 +17,17 @@ abstract class ACategory extends \XLite\View\ItemsList\Product\Customer\ACustome
     /**
      * Widget parameter names
      */
-    const PARAM_CATEGORY_ID  = 'category_id';
+    public const PARAM_CATEGORY_ID  = 'category_id';
 
     /**
      * Allowed sort criteria
      */
-    const SORT_BY_MODE_DEFAULT = 'cp.orderby';
+    public const SORT_BY_MODE_DEFAULT = 'cp.orderby';
 
     /**
      * Widget target
      */
-    const WIDGET_TARGET = 'category';
+    public const WIDGET_TARGET = 'category';
 
     /**
      * Return search parameters.
@@ -120,7 +119,7 @@ abstract class ACategory extends \XLite\View\ItemsList\Product\Customer\ACustome
     {
         $categoryId = $this->getCategoryId();
 
-        return $this->executeCachedRuntime(function () use ($categoryId) {
+        return $this->executeCachedRuntime(static function () use ($categoryId) {
             return \XLite\Core\Database::getRepo('XLite\Model\Category')->find($categoryId);
         }, ['getCategory', $categoryId]);
     }
@@ -172,8 +171,9 @@ abstract class ACategory extends \XLite\View\ItemsList\Product\Customer\ACustome
     protected function postprocessSearchCase(\XLite\Core\CommonCell $searchCase)
     {
         $searchCase = parent::postprocessSearchCase($searchCase);
-        if ('directLink' !== \XLite\Core\Config::getInstance()->General->show_out_of_stock_products
-            && 'searchOnly' !== \XLite\Core\Config::getInstance()->General->show_out_of_stock_products
+        if (
+            \XLite\Core\Config::getInstance()->General->show_out_of_stock_products !== 'directLink'
+            && \XLite\Core\Config::getInstance()->General->show_out_of_stock_products !== 'searchOnly'
             && !\XLite::isAdminZone()
         ) {
             $searchCase->{\XLite\Model\Repo\Product::P_INVENTORY} = false;
@@ -214,7 +214,7 @@ abstract class ACategory extends \XLite\View\ItemsList\Product\Customer\ACustome
      */
     protected function getSavedRequestParam($param)
     {
-        return \XLite\View\Pager\APager::PARAM_PAGE_ID !== $param ? parent::getSavedRequestParam($param) : null;
+        return $param !== \XLite\View\Pager\APager::PARAM_PAGE_ID ? parent::getSavedRequestParam($param) : null;
     }
 
     /**
@@ -254,23 +254,12 @@ abstract class ACategory extends \XLite\View\ItemsList\Product\Customer\ACustome
     }
 
     /**
-     * Defines if the widget is listening to #hash changes
+     * Defines if the widget is listening to get params
      *
      * @return boolean
      */
-    protected function getListenToHash()
+    protected function isListenToGetParams()
     {
         return true;
     }
-
-    /**
-     * Defines the #hash prefix of the data for the widget
-     * @TODO implement!
-     *
-     * @return string
-     */
-    protected function getListenToHashPrefix()
-    {
-        return 'product.category';
-    }
 }
