@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\View\ItemsList\Product\Customer\Category;
 
+use XCart\Extender\Mapping\ListChild;
 use XLite\View\CacheableTrait;
 
 /**
@@ -29,6 +29,26 @@ class Main extends \XLite\View\ItemsList\Product\Customer\Category\ACategory
         return parent::getSessionCell() . \XLite\Core\Request::getInstance()->category_id;
     }
 
+    /**
+     * Check if header is visible
+     *
+     * @return boolean
+     */
+    protected function isHeaderVisible()
+    {
+        return $this->hasResults();
+    }
+
+    /**
+     * Check if pager is visible
+     *
+     * @return boolean
+     */
+    protected function isPagerVisible()
+    {
+        return $this->hasResults();
+    }
+
     /**
      * Return "empty list" catalog
      *
