@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -19,23 +18,23 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
     /**
      * Widget param names
      */
-    const PARAM_SUBSTRING         = 'substring';
-    const PARAM_CATEGORY_ID       = 'categoryId';
-    const PARAM_SEARCH_IN_SUBCATS = 'searchInSubcats';
-    const PARAM_INCLUDING         = 'including';
-    const PARAM_BY_TITLE          = 'by_title';
-    const PARAM_BY_DESCR          = 'by_descr';
-    const PARAM_BY_SKU            = 'by_sku';
+    public const PARAM_SUBSTRING         = 'substring';
+    public const PARAM_CATEGORY_ID       = 'categoryId';
+    public const PARAM_SEARCH_IN_SUBCATS = 'searchInSubcats';
+    public const PARAM_INCLUDING         = 'including';
+    public const PARAM_BY_TITLE          = 'by_title';
+    public const PARAM_BY_DESCR          = 'by_descr';
+    public const PARAM_BY_SKU            = 'by_sku';
 
     /**
      * Allowed sort criteria
      */
-    const SORT_BY_MODE_DEFAULT = 'p.product_id';
+    public const SORT_BY_MODE_DEFAULT = 'p.product_id';
 
     /**
      * Widget target
      */
-    const WIDGET_TARGET = 'search';
+    public const WIDGET_TARGET = 'search';
 
     /**
      * Get default sort order value
@@ -52,7 +51,7 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      *
      * @param array $params Widget params OPTIONAL
      */
-    public function __construct(array $params = array())
+    public function __construct(array $params = [])
     {
         parent::__construct($params);
 
@@ -72,6 +71,16 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
         ];
     }
 
+    /**
+     * Defines if the widget is replacing history state
+     *
+     * @return boolean
+     */
+    protected function getReplaceState()
+    {
+        return true;
+    }
+
     /**
      * Return search parameters.
      * :TODO: refactor
@@ -80,14 +89,14 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      */
     public static function getSearchParams()
     {
-        return array(
+        return [
             \XLite\Model\Repo\Product::P_SUBSTRING   => self::PARAM_SUBSTRING,
             \XLite\Model\Repo\Product::P_CATEGORY_ID => self::PARAM_CATEGORY_ID,
             \XLite\Model\Repo\Product::P_INCLUDING   => self::PARAM_INCLUDING,
             \XLite\Model\Repo\Product::P_BY_TITLE    => self::PARAM_BY_TITLE,
             \XLite\Model\Repo\Product::P_BY_DESCR    => self::PARAM_BY_DESCR,
             \XLite\Model\Repo\Product::P_BY_SKU      => self::PARAM_BY_SKU,
-        );
+        ];
     }
 
     /**
@@ -97,11 +106,11 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      */
     public static function getBasicSearchParams()
     {
-        return array(
+        return [
             \XLite\Model\Repo\Product::P_SUBSTRING         => self::PARAM_SUBSTRING,
             \XLite\Model\Repo\Product::P_INCLUDING         => self::PARAM_INCLUDING,
             \XLite\Model\Repo\Product::P_SEARCH_IN_SUBCATS => self::PARAM_SEARCH_IN_SUBCATS,
-        );
+        ];
     }
 
     /**
@@ -190,7 +199,7 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      */
     protected function getListHead()
     {
-        return static::t('X products found', array('count' => $this->getItemsCount()));
+        return static::t('X products found', ['count' => $this->getItemsCount()]);
     }
 
     /**
@@ -260,7 +269,7 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      */
     protected function getCommonParams()
     {
-        return parent::getCommonParams() + array('mode' => 'search');
+        return parent::getCommonParams() + ['mode' => 'search'];
     }
 
     /**
@@ -272,32 +281,37 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_SUBSTRING => new \XLite\Model\WidgetParam\TypeString(
-                'Substring', ''
+                'Substring',
+                ''
             ),
             self::PARAM_CATEGORY_ID => new \XLite\Model\WidgetParam\TypeInt(
-                'Category ID', 0
+                'Category ID',
+                0
             ),
             self::PARAM_INCLUDING => new \XLite\Model\WidgetParam\TypeSet(
                 'Including',
                 \XLite\Model\Repo\Product::INCLUDING_ALL,
-                array(
+                [
                     \XLite\Model\Repo\Product::INCLUDING_ALL,
                     \XLite\Model\Repo\Product::INCLUDING_ANY,
                     \XLite\Model\Repo\Product::INCLUDING_PHRASE,
-                )
+                ]
             ),
             self::PARAM_BY_TITLE => new \XLite\Model\WidgetParam\TypeCheckbox(
-                'Search in title', 0
+                'Search in title',
+                0
             ),
             self::PARAM_BY_DESCR => new \XLite\Model\WidgetParam\TypeCheckbox(
-                'Search in description', 0
+                'Search in description',
+                0
             ),
             self::PARAM_BY_SKU => new \XLite\Model\WidgetParam\TypeString(
-                'Search in SKU', 0
+                'Search in SKU',
+                0
             ),
-        );
+        ];
     }
 
     /**
@@ -325,7 +339,7 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
     {
         $result = parent::getSearchCondition();
 
-        if ('directLink' !== \XLite\Core\Config::getInstance()->General->show_out_of_stock_products) {
+        if (\XLite\Core\Config::getInstance()->General->show_out_of_stock_products !== 'directLink') {
             $result->{\XLite\Model\Repo\Product::P_INVENTORY} = false;
         }
 
@@ -376,7 +390,7 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
      */
     protected function getSavedRequestParam($param)
     {
-        return \XLite\View\Pager\APager::PARAM_PAGE_ID !== $param ? parent::getSavedRequestParam($param) : null;
+        return $param !== \XLite\View\Pager\APager::PARAM_PAGE_ID ? parent::getSavedRequestParam($param) : null;
     }
 
     /**
@@ -388,14 +402,4 @@ class Search extends \XLite\View\ItemsList\Product\Customer\ACustomer
             'searchUrlParams' => $this->getSearchUrlParams()
         ]));
     }
-
-    /**
-     * Return file name for the center part template
-     *
-     * @return string
-     */
-    protected function getBody()
-    {
-        return $list[] = $this->getDir() . '/search/body.twig';
-    }
 }
