@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -54,9 +53,7 @@ class RequestSearchValuesStorage extends \XLite\View\ItemsList\ASearchValuesStor
      */
     protected function getInnerValue($serviceName)
     {
-        return isset($this->requestData[$serviceName])
-            ? $this->requestData[$serviceName]
-            : null;
+        return $this->requestData[$serviceName] ?? null;
     }
 
     /**
