@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -38,7 +37,7 @@ class SearchCaseProcessor implements \XLite\View\ItemsList\ISearchCaseProvider
     {
         $this->searchParams = array_filter(
             $searchParams,
-            function ($condition) {
+            static function ($condition) {
                 return isset($condition['condition']);
             }
         );
@@ -92,7 +91,7 @@ class SearchCaseProcessor implements \XLite\View\ItemsList\ISearchCaseProvider
 
         $searchConditions = array_filter(
             $this->searchParams,
-            function ($condition) {
+            static function ($condition) {
                 return isset($condition['condition'])
                 && is_object($condition['condition'])
                 && $condition['condition']->getValue();
@@ -100,16 +99,16 @@ class SearchCaseProcessor implements \XLite\View\ItemsList\ISearchCaseProvider
         );
 
         foreach ($searchConditions as $name => $condition) {
-            if (is_object($condition['condition'])
+            if (
+                is_object($condition['condition'])
                 && $condition['condition'] instanceof IExpressionProvider
             ) {
                 $cell->{$condition['condition']->getName()} = $condition['condition'];
-
-            } elseif (is_object($condition['condition'])
+            } elseif (
+                is_object($condition['condition'])
                 && $condition['condition'] instanceof IRepositoryHandlerCarrier
             ) {
                 $cell->{$condition['condition']->getName()} = $this->getSearchConditionValue($name);
-
             } else {
                 $cell->{$name} = $this->getSearchConditionValue($name);
             }
