@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * JS container. Must be the last element on the page
  * TODO: refactor admin area JS code.
@@ -32,7 +33,7 @@ class JSContainer extends \XLite\View\AResourcesContainer
         $records = $this->getCSSResources() + $this->getJSResources();
 
         $resources = array_map(
-            function ($item) {
+            static function ($item) {
                 return $item['url'];
             },
             $records
