@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\LanguageSelector;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Language selector (customer)
  *
@@ -52,5 +53,4 @@ class Customer extends \XLite\View\LanguageSelector\ALanguageSelector
     {
         return !$this->isCheckoutLayout() && 0 < count($this->getActiveLanguages());
     }
-
 }
