@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,9 @@
 
 namespace XLite\View\LanguagesModify;
 
+use Includes\Utils\Module\Manager;
+use Includes\Utils\Module\Module;
+
 /**
  * Add (activate) language dialog
  */
@@ -24,7 +26,6 @@ class AddLanguage extends \XLite\View\AView
             ->findInactiveLanguages();
     }
 
-
     /**
      * Return widget default template
      *
@@ -55,15 +56,14 @@ class AddLanguage extends \XLite\View\AView
      */
     protected function getModulePageURL($entity)
     {
-        $url = null;
+        if ($entity->getValidModule()) {
+            [$author, $name] = Module::explodeModuleId($entity->getModule());
 
-        $module = $entity->getModule();
-
-        if (!empty($module) && preg_match('/(\w+)\\\\(\w+)/', $module, $match)) {
-            $moduleObj = \XLite\Core\Database::getRepo('XLite\Model\Module')->findModuleByName($module);
-            $url = $moduleObj->getInstalledURL();
+            return $author && $name
+                ? Manager::getRegistry()->getModuleServiceURL($author, $name)
+                : null;
         }
 
-        return $url;
+        return null;
     }
 }
