@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,8 +15,10 @@ class AddNewLabel extends \XLite\View\Button\Regular
     /**
      * Widget parameters
      */
-    const PARAM_LANGUAGE = 'language';
-    const PARAM_PAGE = 'page';
+    public const PARAM_LANGUAGE = 'label-language';
+    public const PARAM_PAGE = 'page';
+    public const PARAM_SECTION = 'section';
+    public const DEFAULT_SECTION = 'design';
 
     /**
      * Define widget parameters
@@ -28,11 +29,17 @@ class AddNewLabel extends \XLite\View\Button\Regular
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
-            self::PARAM_LANGUAGE => new \XLite\Model\WidgetParam\TypeString('Language code',
-                \XLite\Core\Request::getInstance()->code),
-            self::PARAM_PAGE     => new \XLite\Model\WidgetParam\TypeInt('Page index', 1),
-        );
+        $this->widgetParams += [
+            self::PARAM_LANGUAGE    => new \XLite\Model\WidgetParam\TypeString(
+                'Language code',
+                \XLite\Core\Request::getInstance()->code ?: static::getDefaultLanguage()
+            ),
+            self::PARAM_PAGE        => new \XLite\Model\WidgetParam\TypeInt('Page index', 1),
+            self::PARAM_SECTION     => new \XLite\Model\WidgetParam\TypeString(
+                'Section index',
+                \XLite\Core\Request::getInstance()->section ?: self::DEFAULT_SECTION
+            ),
+        ];
     }
 
     /**
@@ -64,7 +71,7 @@ class AddNewLabel extends \XLite\View\Button\Regular
     {
         return 'openAddNewLabel(this, '
             . '\'' . $this->getParam(self::PARAM_LANGUAGE) . '\', '
-            . '\'' . $this->getParam(self::PARAM_PAGE) . '\');';
+            . '\'' . $this->getParam(self::PARAM_SECTION) . '\');';
     }
 
     /**
@@ -76,5 +83,4 @@ class AddNewLabel extends \XLite\View\Button\Regular
     {
         return trim(parent::getClass() . ' always-reload');
     }
-
 }
