@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,17 +7,12 @@
 
 namespace XLite\View\LayoutSettings;
 
-use Includes\Utils\Module\Manager;
+use Includes\Utils\Converter;
 use XLite\Core\Skin;
 
-/**
- * Layout settings
- */
 class Settings extends \XLite\View\AView
 {
     /**
-     * Get a list of CSS files required to display the widget properly
-     *
      * @return array
      */
     public function getCSSFiles()
@@ -30,8 +24,6 @@ class Settings extends \XLite\View\AView
     }
 
     /**
-     * Get a list of JS files required to display the widget properly
-     *
      * @return array
      */
     public function getJSFiles()
@@ -43,9 +35,7 @@ class Settings extends \XLite\View\AView
     }
 
     /**
-     * Returns current skin
-     *
-     * @return \Includes\Utils\Module\Module
+     * @return array
      */
     public function getCurrentSkin()
     {
@@ -53,8 +43,6 @@ class Settings extends \XLite\View\AView
     }
 
     /**
-     * Return widget default template
-     *
      * @return string
      */
     protected function getDefaultTemplate()
@@ -63,18 +51,14 @@ class Settings extends \XLite\View\AView
     }
 
     /**
-     * Returns preview image url
-     *
      * @return string
      */
     protected function getPreviewImageURL()
     {
-        return Skin::getInstance()->getCurrentLayoutPreview();
+        return Skin::getInstance()->getCurrentLayoutPreview(\XLite\Core\Layout::LAYOUT_GROUP_HOME);
     }
 
     /**
-     * Returns current skin name
-     *
      * @return string
      */
     protected function getCurrentSkinName()
@@ -83,28 +67,27 @@ class Settings extends \XLite\View\AView
     }
 
     /**
-     * Check show settings
-     *
      * @return boolean
      */
     protected function showSettingsForm()
     {
-        /** @var \Includes\Utils\Module\Module $module */
         $module = $this->getCurrentSkin();
 
-        return $module && $module->showSettingsForm;
+        return $module && $module['showSettingsForm'];
     }
 
     /**
-     * Check has custom options
-     *
-     * @return boolean
+     * @return string
      */
     protected function getSettingsForm()
     {
-        /** @var \Includes\Utils\Module\Module $module */
         $module = $this->getCurrentSkin();
 
-        return Manager::getRegistry()->getModuleSettingsUrl($module->id);
+        return Converter::buildURL(
+            'module',
+            '',
+            ['moduleId' => $module['id']],
+            \XLite::getAdminScript()
+        );
     }
 }
