@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,13 +7,15 @@
 
 namespace XLite\View;
 
-use Includes\Utils\Module\Manager;
+use PHPMailer\PHPMailer\OAuth;
+use XCart\Messenger\OAuthProviderFactory;
 use XLite\Core\Cache\ExecuteCachedTrait;
 use XLite\Core\Config;
 use XLite\Core\Database;
 use XLite\Core\Mail\AMail;
 use XLite\Core\Mailer\Entries;
-use XLite\Core\Mailer\Entry;
+use XLite\InjectLoggerTrait;
+use XLite\View\FormField\Select\AuthEmailFrom;
 use XLite\View\FormField\Select\EmailFrom;
 
 /**
@@ -23,15 +24,11 @@ use XLite\View\FormField\Select\EmailFrom;
 class Mailer extends \XLite\View\AView
 {
     use ExecuteCachedTrait;
+    use InjectLoggerTrait;
 
-    const CRLF = "\r\n";
+    public const CRLF = "\r\n";
 
-    /**
-     * Mail separator symbol
-     */
-    const MAIL_SEPARATOR = ',';
-
-    const ATTACHMENT_ENCODING = 'base64';
+    public const ATTACHMENT_ENCODING = 'base64';
 
     /**
      * Subject template file name
@@ -75,13 +72,6 @@ class Mailer extends \XLite\View\AView
      */
     protected $charset = 'UTF-8';
 
-    /**
-     * Saved templates skin
-     *
-     * @var string
-     */
-    protected $templatesSkin;
-
     /**
      * Current template
      *
@@ -164,7 +154,7 @@ class Mailer extends \XLite\View\AView
      */
     public function set($name, $value)
     {
-        if (in_array($name, ['to', 'from'], true)) {
+        if (in_array($name, ['from'], true)) {
             $value = $this->prepareAddress($value);
         }
 
@@ -195,6 +185,7 @@ class Mailer extends \XLite\View\AView
         $value = str_replace("\r", '', $value);
         $value = str_replace('\n', "\n", $value);
         $value = explode("\n", $value);
+
         return $value[0];
     }
 
@@ -299,12 +290,13 @@ class Mailer extends \XLite\View\AView
         $this->set('from', $mail->getFrom());
         $this->set('to', $mail->getTo());
         $this->set('dir', $mail::getDir());
-        $subject = $this->compile($this->get('subjectTemplate'), $mail::getInterface());
+        $this->set('hideCompanyInSubject', $mail->getData()['hideCompanyInSubject'] ?? false);
+        $subject = $this->compile($this->get('subjectTemplate'), $mail::getZone());
         $subject = $populateVariables($subject);
 
         $this->set('subject', $subject);
 
-        $body = $this->compile($this->get('layoutTemplate'), $mail::getInterface(), true);
+        $body = $this->compile($this->get('layoutTemplate'), $mail::getZone(), true);
         $this->set('body', $body);
 
         $body = $populateVariables($body);
@@ -313,8 +305,8 @@ class Mailer extends \XLite\View\AView
 
         file_put_contents($fname, $body);
 
-        $this->imageParser = new \XLite\Model\MailImageParser();
-        $this->imageParser->webdir = \XLite::getInstance()->getShopURL('', false);
+        $this->imageParser         = new \XLite\Model\MailImageParser();
+        $this->imageParser->webdir = \XLite::getInstance()->getShopURL('/', false);
         $this->imageParser->parse($fname);
 
         $this->set('body', $this->imageParser->result);
@@ -330,13 +322,13 @@ class Mailer extends \XLite\View\AView
         $output = ob_get_contents();
         ob_end_clean();
 
-        if ('' !== $output) {
-            \XLite\Logger::getInstance()->log('Mailer echoed: "' . $output . '". Error: ' . $this->mail->ErrorInfo);
+        if ($output !== '') {
+            $this->getLogger()->debug('Mailer echoed: "' . $output . '". Error: ' . $this->mail->ErrorInfo);
         }
 
         // Check if there is any error during mail composition. Log it.
         if ($this->mail->isError()) {
-            \XLite\Logger::getInstance()->log('Compose mail error: ' . $this->mail->ErrorInfo);
+            $this->getLogger()->debug('Compose mail error: ' . $this->mail->ErrorInfo);
         }
 
         if (file_exists($fname)) {
@@ -370,15 +362,13 @@ class Mailer extends \XLite\View\AView
      */
     public function send()
     {
-        $result = false;
+        $result       = false;
         $errorMessage = null;
 
-        if ('' === $this->get('to')) {
+        if ($this->get('to') === '') {
             $errorMessage = 'Send mail FAILED: sender address is empty';
-
-        } elseif (null === $this->mail) {
+        } elseif ($this->mail === null) {
             $errorMessage = 'Send mail FAILED: not initialized inner mailer';
-
         } else {
             $this->errorInfo = null;
 
@@ -393,7 +383,6 @@ class Mailer extends \XLite\View\AView
                     . $this->prepareErrorMessage($error);
 
                 $this->errorInfo = $this->mail->ErrorInfo;
-
             } else {
                 $result = true;
             }
@@ -401,13 +390,7 @@ class Mailer extends \XLite\View\AView
 
         if ($errorMessage) {
             $this->errorMessage = $errorMessage;
-            \XLite\Logger::getInstance()->log($errorMessage, \LOG_ERR);
-        }
-
-        // Restore layout
-        if (null !== $this->templatesSkin) {
-            \XLite\Core\Layout::getInstance()->setSkin($this->templatesSkin);
-            $this->templatesSkin = null;
+            $this->getLogger()->error($errorMessage);
         }
 
         $this->imageParser->unlinkImages();
@@ -444,10 +427,10 @@ class Mailer extends \XLite\View\AView
      *
      * @return string
      */
-    public function getLanguageCode($interface = \XLite::CUSTOMER_INTERFACE, $code = '')
+    public function getLanguageCode($interface = \XLite::ZONE_CUSTOMER, $code = '')
     {
         if (!$code) {
-            $code = \XLite::CUSTOMER_INTERFACE === $interface
+            $code = $interface === \XLite::ZONE_CUSTOMER
                 ? Config::getInstance()->General->default_language
                 : Config::getInstance()->General->default_admin_language;
         }
@@ -477,13 +460,9 @@ class Mailer extends \XLite\View\AView
     protected function defineBodyClasses()
     {
         $classes = [
-            'area-' . (\XLite\Core\Layout::getInstance()->getInnerInterface() === \XLite::ADMIN_INTERFACE ? 'a' : 'c'),
+            'area-' . (\XLite\Core\Layout::getInstance()->getZone() === \XLite::ZONE_ADMIN ? 'a' : 'c'),
         ];
 
-        foreach (array_reverse(\XLite\Core\Layout::getInstance()->getSkins()) as $skin) {
-            $classes[] = 'skin-' . $this->prepareCSSClass($skin);
-        }
-
         return $classes;
     }
 
@@ -521,7 +500,7 @@ class Mailer extends \XLite\View\AView
      */
     protected function createAltBody($html)
     {
-        $transTbl = array_flip(get_html_translation_table(HTML_ENTITIES));
+        $transTbl           = array_flip(get_html_translation_table(HTML_ENTITIES));
         $transTbl['&nbsp;'] = ' '; // Default: ['&nbsp;'] = 0xa0 (in ISO-8859-1)
 
         // remove style tag with all content
@@ -532,7 +511,7 @@ class Mailer extends \XLite\View\AView
 
         $txt = preg_replace_callback(
             '/&#\d+;/',
-            function ($m) {
+            static function ($m) {
                 return mb_convert_encoding($m[0], 'UTF-8', 'HTML-ENTITIES');
             },
             $txt
@@ -550,6 +529,7 @@ class Mailer extends \XLite\View\AView
                 return Config::getInstance()->Email->mail_from_manual;
             default:
                 $from = $this->get('from');
+
                 return $from instanceof Entries
                     ? $from->getFrom()
                     : $from;
@@ -566,9 +546,9 @@ class Mailer extends \XLite\View\AView
         );
 
         $this->mail->CharSet = $this->get('charset');
-        $fromMail = $this->getFromMail();
+        $fromMail            = $this->getFromMail();
         if (!empty($fromMail)) {
-            $this->mail->From = $fromMail;
+            $this->mail->From   = $fromMail;
             $this->mail->Sender = $fromMail;
         }
 
@@ -578,15 +558,15 @@ class Mailer extends \XLite\View\AView
         $this->mail->clearAttachments();
         $this->mail->clearCustomHeaders();
 
-        $emails = explode(static::MAIL_SEPARATOR, $this->get('to'));
-
-        foreach ($emails as $email) {
-            $this->mail->addAddress($email);
+        foreach ($this->get('to') as $email) {
+            $value = $this->prepareAddress($email['email']);
+            $name  = !empty($email['name']) ? $this->prepareAddress($email['name']) : $value;
+            $this->mail->addAddress($value, $name);
         }
 
         $this->mail->Subject = $this->get('subject');
         $this->mail->AltBody = $this->createAltBody($this->get('body'));
-        $this->mail->Body = $this->get('body');
+        $this->mail->Body    = $this->get('body');
 
         if (is_array($this->get('images'))) {
             foreach ($this->get('images') as $image) {
@@ -603,7 +583,7 @@ class Mailer extends \XLite\View\AView
 
         $attachments = $this->get('attachments');
 
-        if (count($attachments) > 0) {
+        if (is_array($attachments) && count($attachments) > 0) {
             foreach ($attachments as $file) {
                 $this->mail->addAttachment($file['path'], $file['name'], $file['encoding'], $file['mime']);
             }
@@ -612,7 +592,7 @@ class Mailer extends \XLite\View\AView
 
         $attachments = $this->get('stringAttachments');
 
-        if (count($attachments) > 0) {
+        if (is_array($attachments) && count($attachments) > 0) {
             foreach ($attachments as $file) {
                 $this->mail->addStringAttachment($file['string'], $file['name'], $file['encoding'], $file['mime']);
             }
@@ -620,6 +600,11 @@ class Mailer extends \XLite\View\AView
         $this->set('stringAttachments', []);
     }
 
+    public function __construct(array $params = [])
+    {
+        parent::__construct($params);
+    }
+
     /**
      * Inner mailer initialization from DB configuration
      *
@@ -627,27 +612,66 @@ class Mailer extends \XLite\View\AView
      */
     protected function initMailFromConfig()
     {
-        if (null === $this->mail) {
+        if ($this->mail === null) {
             $this->mail = new \PHPMailer\PHPMailer\PHPMailer();
             // SMTP settings
             if (Config::getInstance()->Email->use_smtp) {
                 $this->mail->Mailer = 'smtp';
-                $this->mail->Host = Config::getInstance()->Email->smtp_server_url;
-                $this->mail->Port = Config::getInstance()->Email->smtp_server_port;
+                $this->mail->Host   = Config::getInstance()->Email->smtp_server_url;
+                $this->mail->Port   = Config::getInstance()->Email->smtp_server_port;
 
-                if (Config::getInstance()->Email->use_smtp_auth) {
+                $authMode = Config::getInstance()->Email->smtp_auth_mode;
+
+                if ($authMode === AuthEmailFrom::AUTH_CUSTOM) {
+                    if (
+                        !empty(Config::getInstance()->Email->smtp_username)
+                        && !empty(Config::getInstance()->Email->smtp_password)
+                    ) {
+                        $this->mail->SMTPAuth = true;
+                        $this->mail->Username = Config::getInstance()->Email->smtp_username;
+                        $this->mail->Password = Config::getInstance()->Email->smtp_password;
+                    }
+
+                    if (
+                        in_array(Config::getInstance()->Email->smtp_security, ['ssl', 'tls'], true)
+                    ) {
+                        $this->mail->SMTPSecure = Config::getInstance()->Email->smtp_security;
+                    }
+                } else {
                     $this->mail->SMTPAuth = true;
-                    $this->mail->Username = Config::getInstance()->Email->smtp_username;
-                    $this->mail->Password = Config::getInstance()->Email->smtp_password;
-                }
-                if (in_array(Config::getInstance()->Email->smtp_security, ['ssl',
-                    'tls'], true)) {
-                    $this->mail->SMTPSecure = Config::getInstance()->Email->smtp_security;
+                    $this->mail->AuthType = 'XOAUTH2';
+                    $this->mail->SMTPSecure = \PHPMailer\PHPMailer\PHPMailer::ENCRYPTION_SMTPS;
+
+                    $oAuthConfig = OAuthProviderFactory::create(
+                        $authMode,
+                        Config::getInstance()->Email->smtp_client_id,
+                        Config::getInstance()->Email->smtp_secret_key,
+                        $this->buildURL('email_settings')
+                    );
+
+                    $this->mail->Host   = $oAuthConfig->getHost();
+                    $this->mail->Port   = $oAuthConfig->getPort();
+
+                    $tokenData = \json_decode(Config::getInstance()->Email->smtp_auth_token, false);
+
+                    if (!empty($tokenData)) {
+                        $this->mail->setOAuth(
+                            new OAuth(
+                                [
+                                    'provider'     => $oAuthConfig->getProvider(),
+                                    'clientId'     => Config::getInstance()->Email->smtp_client_id,
+                                    'clientSecret' => Config::getInstance()->Email->smtp_secret_key,
+                                    'refreshToken' => $tokenData->refresh_token,
+                                    'userName'     => $this->get('from')
+                                ]
+                            )
+                        );
+                    }
                 }
             }
 
             $this->mail->SMTPDebug = true;
-            $this->mail->isHTML(true);
+            $this->mail->isHTML();
             $this->mail->Encoding = 'base64';
         }
     }
@@ -661,57 +685,31 @@ class Mailer extends \XLite\View\AView
      *
      * @return string
      */
-    protected function compile($template, $interface = \XLite::CUSTOMER_INTERFACE, $inline = false)
+    protected function compile($template, $zone = \XLite::ZONE_CUSTOMER, $inline = false)
     {
         // replace layout with mailer skinned
         /** @var \XLite\Core\Layout $layout */
         $layout = \XLite\Core\Layout::getInstance();
 
-        $baseSkin = $layout->getSkin();
-        $baseInterface = $layout->getInterface();
-        $baseInnerInterface = $layout->getInnerInterface();
+        return $layout->callInInterfaceZone(function () use ($template, $inline) {
+            $this->widgetParams[static::PARAM_TEMPLATE]->setValue($template);
+            $this->template = $template;
+            $this->init();
 
-        $layout->setMailSkin($interface);
+            $text = $this->getContent();
 
-        $this->widgetParams[static::PARAM_TEMPLATE]->setValue($template);
-        $this->template = $template;
-        $this->init();
+            if ($inline) {
+                $text = $this->convertToInline($text);
+            }
 
-        $text = $this->getContent();
-
-        if ($inline) {
-            $text = $this->convertToInline($text);
-        }
-
-        // restore old skin
-        switch ($baseInterface) {
-            default:
-            case \XLite::ADMIN_INTERFACE:
-                $layout->setAdminSkin();
-                break;
-
-            case \XLite::CUSTOMER_INTERFACE:
-                $layout->setCustomerSkin();
-                break;
-
-            case \XLite::CONSOLE_INTERFACE:
-                $layout->setConsoleSkin();
-                break;
-
-            case \XLite::MAIL_INTERFACE:
-                $layout->setMailSkin($baseInnerInterface);
-                break;
-        }
-
-        $layout->setSkin($baseSkin);
-
-        return $text;
+            return $text;
+        }, \XLite::INTERFACE_MAIL, $zone);
     }
 
     /**
      * Convert html to inline
      *
-     * @param  string $html Initial HTML
+     * @param string $html Initial HTML
      *
      * @return string
      */
@@ -736,29 +734,24 @@ class Mailer extends \XLite\View\AView
     /**
      * Get CSS string from passed array of files
      *
-     * @param  array $styles Style files
+     * @param array $styles Style files
      *
      * @return string
      */
-    protected function getStylesAsCSSString($styles, $interface = null)
+    protected function getStylesAsCSSString($styles)
     {
-        if (!$interface) {
-            $interface = \XLite\Core\Layout::getInstance()->getInterface();
-        }
         $result = '';
 
         foreach ($styles as $file) {
-            $path = $this->getStyleFilePath($file, $interface);
+            $path = $this->getStyleFilePath($file);
 
             if (!$path) {
                 continue;
             }
 
-            $fileInterface = isset($file['interface'])
-                ? $file['interface']
-                : \XLite\Core\Layout::getInstance()->getInterface();
+            $fileZone = $file['zone'] ?? \XLite\Core\Layout::getInstance()->getZone();
 
-            $result .= $this->getStyleFileContent($path, $fileInterface);
+            $result .= $this->getStyleFileContent($path, $fileZone);
         }
 
         return $result;
@@ -767,59 +760,47 @@ class Mailer extends \XLite\View\AView
     /**
      * Get style file path
      *
-     * @param string $path Path to style file
+     * @param $fileNode string|array
      *
-     * @return string
+     * @return string|null
      */
-    protected function getStyleFilePath($fileNode, $interface)
+    protected function getStyleFilePath($fileNode)
     {
-        $relativePath = $fileNode;
-
         if (is_array($fileNode)) {
-            if (isset($fileNode['original'])) {
-                $relativePath = $fileNode['original'];
-            } elseif (isset($fileNode['file'])) {
-                $relativePath = isset($fileNode['file']);
-            } else {
-                $relativePath = null;
-            }
+            return isset($fileNode['original'])
+                ? \XLite\Core\Layout::getInstance()->getResourceFullPath($fileNode['original'])
+                : null;
         }
 
-        $path = \XLite\Core\Layout::getInstance()
-            ->getResourceFullPath($relativePath, $interface);
-
-        if (!$path) {
-            $path = \XLite\Core\Layout::getInstance()
-                ->getResourceFullPath($relativePath, \XLite::COMMON_INTERFACE);
-        }
-
-        return $path;
+        return \XLite\Core\Layout::getInstance()->getResourceFullPath($fileNode);
     }
 
     /**
      * Get style file content
      *
      * @param string $path Path to style file
+     * @param string $zone
      *
      * @return string
      */
-    protected function getStyleFileContent($path, $interface)
+    protected function getStyleFileContent($path, $zone)
     {
         $pathinfo = pathinfo($path);
 
         $result = '';
-        if (isset($pathinfo['extension'])
+        if (
+            isset($pathinfo['extension'])
             && $pathinfo['extension'] === 'less'
         ) {
             $lessRaw = \XLite\Core\LessParser::getInstance()
                 ->makeCSS(
                     [
                         [
-                            'file'      => $path,
-                            'original'  => $path,
-                            'less'      => true,
-                            'media'     => 'all',
-                            'interface' => $interface,
+                            'file'     => $path,
+                            'original' => $path,
+                            'less'     => true,
+                            'media'    => 'all',
+                            'zone'     => $zone,
                         ],
                     ]
                 );
@@ -878,16 +859,16 @@ class Mailer extends \XLite\View\AView
      */
     protected function getNotificationSubject()
     {
-        $result = '';
+        $result       = '';
         $notification = $this->getNotification();
 
         if ($notification) {
-            switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-                case \XLite::CUSTOMER_INTERFACE:
+            switch (\XLite\Core\Layout::getInstance()->getZone()) {
+                case \XLite::ZONE_CUSTOMER:
                     $result = $notification->getCustomerSubject();
                     break;
 
-                case \XLite::ADMIN_INTERFACE:
+                case \XLite::ZONE_ADMIN:
                     $result = $notification->getAdminSubject();
                     break;
 
@@ -906,16 +887,16 @@ class Mailer extends \XLite\View\AView
      */
     protected function getNotificationText()
     {
-        $result = '';
+        $result       = '';
         $notification = $this->getNotification();
 
         if ($notification) {
-            switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-                case \XLite::CUSTOMER_INTERFACE:
+            switch (\XLite\Core\Layout::getInstance()->getZone()) {
+                case \XLite::ZONE_CUSTOMER:
                     $result = $notification->getCustomerText();
                     break;
 
-                case \XLite::ADMIN_INTERFACE:
+                case \XLite::ZONE_ADMIN:
                     $result = $notification->getAdminText();
                     break;
 
@@ -954,13 +935,13 @@ class Mailer extends \XLite\View\AView
     {
         $result = true;
 
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getCustomerHeaderEnabled();
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
+                $result = $this->getNotification() === null || $this->getNotification()->getCustomerHeaderEnabled();
                 break;
 
-            case \XLite::ADMIN_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getAdminHeaderEnabled();
+            case \XLite::ZONE_ADMIN:
+                $result = $this->getNotification() === null || $this->getNotification()->getAdminHeaderEnabled();
                 break;
 
             default:
@@ -979,12 +960,12 @@ class Mailer extends \XLite\View\AView
     {
         $result = '';
 
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
                 $result = static::t('emailNotificationCustomerHeader');
                 break;
 
-            case \XLite::ADMIN_INTERFACE:
+            case \XLite::ZONE_ADMIN:
                 $result = static::t('emailNotificationAdminHeader');
                 break;
 
@@ -1002,13 +983,13 @@ class Mailer extends \XLite\View\AView
     {
         $result = true;
 
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getCustomerGreetingEnabled();
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
+                $result = $this->getNotification() === null || $this->getNotification()->getCustomerGreetingEnabled();
                 break;
 
-            case \XLite::ADMIN_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getAdminGreetingEnabled();
+            case \XLite::ZONE_ADMIN:
+                $result = $this->getNotification() === null || $this->getNotification()->getAdminGreetingEnabled();
                 break;
 
             default:
@@ -1023,11 +1004,11 @@ class Mailer extends \XLite\View\AView
      */
     protected function getNotificationGreeting()
     {
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
                 return static::t('emailNotificationCustomerGreeting');
 
-            case \XLite::ADMIN_INTERFACE:
+            case \XLite::ZONE_ADMIN:
                 return static::t('emailNotificationAdminGreeting');
 
             default:
@@ -1042,13 +1023,13 @@ class Mailer extends \XLite\View\AView
     {
         $result = true;
 
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getCustomerSignatureEnabled();
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
+                $result = $this->getNotification() === null || $this->getNotification()->getCustomerSignatureEnabled();
                 break;
 
-            case \XLite::ADMIN_INTERFACE:
-                $result = null === $this->getNotification() || $this->getNotification()->getAdminSignatureEnabled();
+            case \XLite::ZONE_ADMIN:
+                $result = $this->getNotification() === null || $this->getNotification()->getAdminSignatureEnabled();
                 break;
 
             default:
@@ -1067,12 +1048,12 @@ class Mailer extends \XLite\View\AView
     {
         $result = '';
 
-        switch (\XLite\Core\Layout::getInstance()->getInnerInterface()) {
-            case \XLite::CUSTOMER_INTERFACE:
+        switch (\XLite\Core\Layout::getInstance()->getZone()) {
+            case \XLite::ZONE_CUSTOMER:
                 $result = static::t('emailNotificationCustomerSignature');
                 break;
 
-            case \XLite::ADMIN_INTERFACE:
+            case \XLite::ZONE_ADMIN:
                 $result = static::t('emailNotificationAdminSignature');
                 break;
 
@@ -1096,16 +1077,17 @@ class Mailer extends \XLite\View\AView
      */
     protected function getCompanyAddressFirstLine()
     {
-        return $this->executeCachedRuntime(function () {
+        return $this->executeCachedRuntime(static function () {
             $countryCode = Config::getInstance()->Company->location_country;
 
-            $country = Database::getRepo('XLite\Model\Country')->find($countryCode);
+            $country     = Database::getRepo('XLite\Model\Country')->find($countryCode);
             $countryName = $country
                 ? $country->getCountry()
                 : $countryCode;
 
             $state = Config::getInstance()->Company->location_custom_state;
-            if ($country instanceof \XLite\Model\Country
+            if (
+                $country instanceof \XLite\Model\Country
                 && $country->hasStates()
                 && Config::getInstance()->Company->location_state
             ) {
@@ -1134,9 +1116,9 @@ class Mailer extends \XLite\View\AView
      */
     protected function getCompanyAddressSecondLine()
     {
-        return $this->executeCachedRuntime(function () {
+        return $this->executeCachedRuntime(static function () {
             $phone = trim(Config::getInstance()->Company->company_phone);
-            $fax = trim(Config::getInstance()->Company->company_fax);
+            $fax   = trim(Config::getInstance()->Company->company_fax);
 
             return implode(' ', array_filter([
                 strlen($phone) ? static::t('Phone') . ": $phone" : null,
@@ -1144,46 +1126,4 @@ class Mailer extends \XLite\View\AView
             ]));
         });
     }
-
-    /**
-     * @return bool
-     */
-    protected function isNotificationTipEnabled()
-    {
-        return \XLite\Core\Layout::getInstance()->getInnerInterface() === \XLite::ADMIN_INTERFACE && !$this->isGoogleAdsConfigured();
-    }
-
-    /**
-     * @return string
-     */
-    protected function getNotificationTip()
-    {
-        if (!Manager::getRegistry()->isModuleEnabled('Kliken','GoogleAds')) {
-            $url = Manager::getRegistry()->getModuleServiceURL('Kliken','GoogleAds');
-        } else {
-            $url = \XLite::getInstance()->getShopURL(\XLite\Core\Converter::buildURL('kga_settings', '', [], \XLite::getAdminScript()));
-        }
-
-        return static::t('emailNotificationTipGoogleADS', ['url' => $url]);
-    }
-
-
-    /**
-     * Check module Kliken-GoogleAds is configured
-     * @return bool
-     */
-    protected function isGoogleAdsConfigured()
-    {
-        $class = '\\XLite\\Module\\Kliken\\GoogleAds\\Logic\\Helper';
-
-        if (!class_exists($class) || !Manager::getRegistry()->isModuleEnabled('Kliken','GoogleAds')) {
-            return false;
-        }
-
-        try {
-            return $class::hasAccountInfo();
-        } catch (\Exception $e) {
-           return false;
-        }
-    }
 }
