@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\MembershipsQuickData;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Memberships items list
  *
@@ -54,4 +55,4 @@ class Main extends \XLite\View\AView
     {
         return parent::isVisible() && \XLite::getController()->isCalculationNotFinished();
     }
-}
\ No newline at end of file
+}
