@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -41,49 +40,36 @@ class Menu extends \XLite\View\Menu\Admin\AAdmin
     protected function defineItems()
     {
         $result = [
-            'profile'      => [
+            'profile'         => [
                 static::ITEM_TITLE         => static::t('My profile'),
                 static::ITEM_TARGET        => 'profile',
+                static::ITEM_DESCRIPTION   => \XLite\Core\Auth::getInstance()->getProfile()->getLogin(),
                 static::ITEM_WEIGHT        => 100,
                 static::ITEM_PUBLIC_ACCESS => true,
+                static::ITEM_CLASS         => 'bottom-separator',
             ],
-            'account_info' => [
-                static::ITEM_TITLE         => \XLite\Core\Auth::getInstance()->getProfile()->getLogin(),
-                static::ITEM_CLASS         => 'login-text',
-                static::ITEM_WEIGHT        => 200,
-                static::ITEM_PUBLIC_ACCESS => true,
-            ],
-
             'knoweledge_base' => [
                 static::ITEM_TITLE      => static::t('Knowledge Base'),
-                static::ITEM_LINK       => static::t('https://kb.x-cart.com/'),
+                static::ITEM_LINK       => static::t('https://support.x-cart.com/en/'),
                 static::ITEM_CLASS      => 'knoweledge-base external',
                 static::ITEM_WEIGHT     => 300,
                 static::ITEM_BLANK_PAGE => true,
             ],
             'developers_docs' => [
                 static::ITEM_TITLE      => static::t('Developers docs'),
-                static::ITEM_LINK       => 'https://devs.x-cart.com/',
+                static::ITEM_LINK       => 'https://developer.x-cart.com/',
                 static::ITEM_CLASS      => 'developers-docs external',
                 static::ITEM_WEIGHT     => 400,
                 static::ITEM_BLANK_PAGE => true,
             ],
             'report_bug'      => [
                 static::ITEM_TITLE      => static::t('Report a bug'),
-                static::ITEM_LINK       => 'https://bt.x-cart.com/',
-                static::ITEM_CLASS      => 'report-bug external',
+                static::ITEM_LINK       => 'mailto:support@x-cart.com?subject=Report%20a%20Bug&body=WHAT%20STEPS%20WILL%20REPRODUCE%20THE%20PROBLEM%3F%0D%0A1.%0D%0A2.%0D%0A..%0D%0AWHAT%20IS%20THE%20EXPECTED%20RESULT%3F%0D%0A1.%0D%0A2.%0D%0A..%0D%0AWHAT%20HAPPENS%20INSTEAD%3F%0D%0A1.%0D%0A2.%0D%0A..%0D%0A',
+                static::ITEM_CLASS      => 'report-bug external bottom-separator',
                 static::ITEM_WEIGHT     => 600,
                 static::ITEM_BLANK_PAGE => true,
             ],
-            'contact_us'      => [
-                static::ITEM_TITLE      => static::t('Contact us'),
-                static::ITEM_LINK       => \XLite::getXCartURL('https://www.x-cart.com/contact-us.html'),
-                static::ITEM_CLASS      => 'contact-us external',
-                static::ITEM_WEIGHT     => 700,
-                static::ITEM_BLANK_PAGE => true,
-            ],
-
-            'logoff' => [
+            'logoff'          => [
                 static::ITEM_TITLE         => static::t('Sign out'),
                 static::ITEM_CLASS         => 'logoff',
                 static::ITEM_TARGET        => 'login',
@@ -93,15 +79,15 @@ class Menu extends \XLite\View\Menu\Admin\AAdmin
             ],
         ];
 
-        $installationData = \XLite\Core\Marketplace::getInstance()->getInstallationData();
-
+        // todo: implement this in frontend
+        $installationData = [];
         $purchasesCount = $installationData['purchasesCount'] ?? 0;
         if ($purchasesCount) {
             $result['my_purchases'] = [
                 static::ITEM_TITLE      => static::t('My purchases'),
                 static::ITEM_LABEL      => $purchasesCount,
                 static::ITEM_LABEL_LINK => \XLite::getInstance()->getServiceURL('#/my-purchases'),
-                static::ITEM_CLASS      => 'my-purchases',
+                static::ITEM_CLASS      => 'my-purchases bottom-separator',
                 static::ITEM_WEIGHT     => 250,
             ];
         }
