@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,7 +7,12 @@
 
 namespace XLite\View\Menu\Admin;
 
+use XCart\Domain\ModuleManagerDomain;
+use XCart\Extender\Mapping\ListChild;
+use XLite\Controller\TitleFromController;
+use XLite\Core\Auth;
 use XLite\Core\Cache\ExecuteCached;
+use XLite\View\Menu\Admin\LeftMenu\Communications;
 
 /**
  * Left side menu widget
@@ -22,6 +26,15 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
      */
     protected $bottomItems;
 
+    private ModuleManagerDomain $moduleManagerDomain;
+
+    public function __construct(array $params = [])
+    {
+        parent::__construct($params);
+
+        $this->moduleManagerDomain = \XCart\Container::getContainer()->get(ModuleManagerDomain::class);
+    }
+
     /**
      * Register JS files
      *
@@ -35,19 +48,6 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
         return $list;
     }
 
-    /**
-     * Register JS files
-     *
-     * @return array
-     */
-    public function getCSSFiles()
-    {
-        $list   = parent::getJSFiles();
-        $list[] = $this->getDir() . '/style.less';
-
-        return $list;
-    }
-
     /**
      * Get menu items
      *
@@ -56,7 +56,7 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
     protected function getItems()
     {
         if (!isset($this->items)) {
-            $items = $this->defineItems();
+            $items = $this->getItemsLeftMenuForDecider();
 
             $this->setSelectedDecider(
                 $this->createSelectedDecider('getItemsLeftMenuForDecider')
@@ -69,110 +69,147 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
     }
 
     /**
-     * Get menu items
-     *
      * @return array
      */
     public function getItemsLeftMenuForDecider()
     {
         $cacheParams = [
             'getItemsLeftMenuForDecider',
-            get_class($this)
+            get_class($this),
         ];
 
-        return ExecuteCached::executeCachedRuntime(function() {
-            return $this->defineItems();
-        }, $cacheParams);
-    }
+        return ExecuteCached::executeCachedRuntime(function () {
+            $bottomItems = array_map(static function ($item) {
+                $item['weight'] += 10000;
 
-    /**
-     * @return array
-     */
-    public function getBottomItems()
-    {
-        if ($this->bottomItems === null) {
-            $items = $this->defineBottomItems();
+                return $item;
+            }, $this->defineBottomItems());
 
-            $this->setSelectedDecider(
-                $this->createSelectedDecider('getBottomItemsForDecider')
+            return array_merge(
+                $this->defineItems(),
+                $bottomItems
             );
-
-            $this->bottomItems = $this->prepareItems($items);
-        }
-
-        return $this->bottomItems;
-    }
-
-    /**
-     * Get menu items
-     *
-     * @return array
-     */
-    public function getBottomItemsForDecider()
-    {
-        $cacheParams = [
-            'getBottomItemsForDecider',
-            get_class($this)
-        ];
-
-        return ExecuteCached::executeCachedRuntime(function() {
-            return $this->defineBottomItems();
         }, $cacheParams);
     }
 
     /**
-     * Initialize handler
-     *
-     * @return void
-     */
-    public function init()
-    {
-        \XLite\Core\Marketplace::getInstance()->getXC5Notifications();
-    }
-
-    /**
-     * Bottom items
+     * Define items
      *
      * @return array
      */
-    protected function defineBottomItems()
+    protected function defineItems()
     {
-        $result = [
-            'extensions'      => [
-                static::ITEM_TITLE    => static::t('My addons'),
-                static::ITEM_WIDGET   => 'XLite\View\Menu\Admin\LeftMenu\Extensions',
-                static::ITEM_LINK     => \XLite::getInstance()->getServiceURL('#/installed-addons'),
-                static::ITEM_ICON_SVG => 'images/fa-puzzle-piece.svg',
-                static::ITEM_WEIGHT   => 100,
-                static::ITEM_TARGET   => 'addons_list_installed',
+        $items = [
+            'sales'           => [
+                static::ITEM_TITLE      => static::t('Orders'),
+                static::ITEM_ICON_SVG   => 'images/left_menu/orders.svg',
+                static::ITEM_WEIGHT     => 100,
+                static::ITEM_TARGET     => 'order_list',
+                static::ITEM_WIDGET      => 'XLite\View\Menu\Admin\LeftMenu\Sales',
+                static::ITEM_CHILDREN   => [
+                    'order_list'           => [
+                        static::ITEM_TITLE       => new TitleFromController('order_list'),
+                        static::ITEM_TARGET      => 'order_list',
+                        static::ITEM_PERMISSION  => 'ROLE_MANAGE_ORDERS',
+                        static::ITEM_WIDGET      => 'XLite\View\Menu\Admin\LeftMenu\Orders',
+                        static::ITEM_LABEL_TITLE => static::t('Orders awaiting processing'),
+                        static::ITEM_LABEL_LINK  => $this->buildURL('order_list', 'search', ['filter_id' => 'recent']),
+                        static::ITEM_WEIGHT      => 100,
+                    ],
+                    'payment_transactions' => [
+                        static::ITEM_TITLE      => static::t('Payments'),
+                        static::ITEM_TARGET     => 'payment_transactions',
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_ORDERS',
+                        static::ITEM_WEIGHT     => 200,
+                    ],
+                    'accounting'           => [
+                        static::ITEM_TITLE  => new TitleFromController('accounting'),
+                        static::ITEM_TARGET => 'accounting',
+                        static::ITEM_WEIGHT => 300,
+                    ],
+                ],
             ],
-            'css_js'          => [
-                static::ITEM_TITLE    => static::t('Look & Feel'),
-                static::ITEM_ICON_SVG => 'images/fa-picture-o.svg',
-                static::ITEM_TARGET   => 'layout',
+            'catalog'         => [
+                static::ITEM_TITLE    => static::t('Catalog'),
+                static::ITEM_ICON_SVG => 'images/left_menu/catalog.svg',
+                static::ITEM_TARGET   => 'product_list',
                 static::ITEM_WEIGHT   => 200,
                 static::ITEM_CHILDREN => [
-                    'layout'             => [
-                        static::ITEM_TITLE  => static::t('Layout'),
+                    'product_list'      => [
+                        static::ITEM_TITLE      => new TitleFromController('product_list'),
+                        static::ITEM_TARGET     => 'product_list',
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_CATALOG',
+                        static::ITEM_WEIGHT     => 100,
+                    ],
+                    'categories'        => [
+                        static::ITEM_TITLE      => static::t('Categories'),
+                        static::ITEM_TARGET     => 'root_categories',
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_CATALOG',
+                        static::ITEM_WEIGHT     => 200,
+                    ],
+                    'global_attributes' => [
+                        static::ITEM_TITLE      => static::t('Classes & attributes'),
+                        static::ITEM_TARGET     => 'global_attributes',
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_CATALOG',
+                        static::ITEM_WEIGHT     => 300,
+                    ],
+                    'import_export'     => [
+                        static::ITEM_TITLE      => static::t('Import & export'),
+                        static::ITEM_WEIGHT     => 900,
+                        static::ITEM_TARGET     =>
+                            Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_IMPORT') ? 'import' : 'export',
+                        static::ITEM_PERMISSION => ['ROLE_MANAGE_IMPORT', 'ROLE_MANAGE_EXPORT'],
+                    ]
+                ],
+            ],
+            'communications'  => [
+                static::ITEM_TITLE    => static::t('Communication'),
+                static::ITEM_ICON_SVG => 'images/left_menu/communications.svg',
+                static::ITEM_WIDGET   => Communications::class,
+                static::ITEM_WEIGHT   => 300,
+                static::ITEM_CHILDREN => [
+                    'customer_profiles' => [
+                        static::ITEM_TITLE      => static::t('Customers'),
+                        static::ITEM_TARGET     => 'customer_profiles',
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_USERS',
+                        static::ITEM_WEIGHT     => 0,
+                    ],
+                ],
+            ],
+            'promotions'      => [
+                static::ITEM_TITLE    => static::t('Promotions'),
+                static::ITEM_ICON_SVG => 'images/left_menu/promotions.svg',
+                static::ITEM_WEIGHT   => 300,
+                static::ITEM_CHILDREN => [],
+            ],
+            'store_design'    => [
+                static::ITEM_TITLE    => static::t('Design'),
+                static::ITEM_ICON_SVG => 'images/left_menu/design.svg',
+                static::ITEM_TARGET   => 'layout',
+                static::ITEM_WEIGHT   => 450,
+                static::ITEM_CHILDREN => [
+                    'layout' => [
+                        static::ITEM_TITLE  => static::t('Themes'),
                         static::ITEM_TARGET => 'layout',
                         static::ITEM_WEIGHT => 100,
                     ],
-                    'images'             => [
-                        static::ITEM_TITLE  => static::t('Images'),
-                        static::ITEM_TARGET => 'images',
-                        static::ITEM_WEIGHT => 600,
+                    'front_page' => [
+                        static::ITEM_TITLE => static::t('Front page'),
+                        static::ITEM_TARGET => 'front_page',
+                        static::ITEM_WEIGHT => 200,
+                        static::ITEM_PERMISSION => ['ROLE_MANAGE_FRONT_PAGE']
                     ],
-                    'css_js_performance' => [
-                        static::ITEM_TITLE  => static::t('Performance'),
-                        static::ITEM_TARGET => 'css_js_performance',
-                        static::ITEM_WEIGHT => 700,
+                    'images' => [
+                        static::ITEM_TITLE  => static::t('Images settings'),
+                        static::ITEM_TARGET => 'images',
+                        static::ITEM_WEIGHT => 300,
                     ],
                 ],
             ],
             'store_setup'     => [
-                static::ITEM_TITLE    => static::t('Store setup'),
-                static::ITEM_ICON_SVG => 'images/fa-info-circle.svg',
-                static::ITEM_WEIGHT   => 300,
+                static::ITEM_TITLE    => static::t('Store'),
+                static::ITEM_ICON_SVG => 'images/left_menu/store.svg',
+                static::ITEM_WEIGHT   => 500,
                 static::ITEM_TARGET   => 'settings',
                 static::ITEM_EXTRA    => ['page' => 'Company'],
                 static::ITEM_CHILDREN => [
@@ -185,16 +222,11 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
                     'general'          => [
                         static::ITEM_TITLE  => static::t('Cart & checkout'),
                         static::ITEM_TARGET => 'general_settings',
-                        static::ITEM_WEIGHT => 200,
-                    ],
-                    'payment_settings' => [
-                        static::ITEM_TITLE  => static::t('Payments'),
-                        static::ITEM_TARGET => 'payment_settings',
                         static::ITEM_WEIGHT => 300,
                     ],
-                    'countries'        => [
-                        static::ITEM_TITLE  => static::t('Countries, states and zones'),
-                        static::ITEM_TARGET => 'countries',
+                    'payment_settings' => [
+                        static::ITEM_TITLE  => static::t('Payment Methods'),
+                        static::ITEM_TARGET => 'payment_settings',
                         static::ITEM_WEIGHT => 400,
                     ],
                     'shipping_methods' => [
@@ -212,225 +244,172 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
                         static::ITEM_TARGET => 'units_formats',
                         static::ITEM_WEIGHT => 700,
                     ],
-                    'translations'     => [
-                        static::ITEM_TITLE  => static::t('Translations'),
-                        static::ITEM_TARGET => 'languages',
-                        static::ITEM_WEIGHT => 800,
+                    'profile_list'     => [
+                        static::ITEM_TITLE      => static::t('Users'),
+                        static::ITEM_TARGET     => 'profile_list',
+                        static::ITEM_PERMISSION => ['ROLE_MANAGE_ADMINS', 'ROLE_MANAGE_USERS'],
+                        static::ITEM_WEIGHT     => 800,
                     ],
-                    'notifications'    => [
+                ],
+            ],
+            'extensions'      => [
+                static::ITEM_TITLE    => static::t('Apps'),
+                static::ITEM_ICON_SVG => 'images/left_menu/apps.svg',
+                static::ITEM_LINK     => \XLite::getInstance()->getServiceURL('#/installed-addons'),
+                static::ITEM_WEIGHT   => 400,
+                static::ITEM_TARGET   => 'apps',
+                static::ITEM_CHILDREN => [
+                    /*'marketplace'      => [
+                        static::ITEM_TITLE  => static::t('App Store'),
+                        static::ITEM_LINK   => \XLite::getInstance()->getServiceURL('#/marketplace'),
+                        static::ITEM_WEIGHT => 100,
+                    ],
+                    'templates'        => [
+                        static::ITEM_TITLE  => static::t('Theme Store'),
+                        static::ITEM_LINK   => \XLite::getInstance()->getServiceURL('#/templates'),
+                        static::ITEM_WEIGHT => 200,
+                    ],*/
+                    'installed_addons' => [
+                        static::ITEM_TITLE  => static::t('My Apps'),
+                        static::ITEM_LINK   => \XLite::getInstance()->getServiceURL('#/installed-addons'),
+                        static::ITEM_WEIGHT => 300,
+                    ],
+                    /*'my_purchases'     => [
+                        static::ITEM_TITLE  => static::t('Purchases'),
+                        static::ITEM_LINK   => \XLite::getInstance()->getServiceURL('#/my-purchases'),
+                        static::ITEM_WEIGHT => 400,
+                    ],*/
+                ],
+            ],
+            'marketing'       => [
+                static::ITEM_TITLE    => static::t('Channels'),
+                static::ITEM_ICON_SVG => 'images/left_menu/channels.svg',
+                static::ITEM_WEIGHT   => 350,
+                static::ITEM_CHILDREN => [],
+            ],
+            'reports' => [
+                static::ITEM_TITLE     => static::t('Reports'),
+                static::ITEM_ICON_SVG  => 'images/left_menu/reports.svg',
+                static::ITEM_WEIGHT    => 380,
+                static::ITEM_CHILDREN  => [
+                    'top_sellers' => [
+                        static::ITEM_TITLE      => static::t('Bestsellers'),
+                        static::ITEM_TARGET     => 'top_sellers',
+                        static::ITEM_WEIGHT     => 100,
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_ORDERS',
+                    ],
+                    'orders_stats' => [
+                        static::ITEM_TITLE      => static::t('Sale statistics'),
+                        static::ITEM_TARGET     => 'orders_stats',
+                        static::ITEM_WEIGHT     => 200,
+                        static::ITEM_PERMISSION => 'ROLE_MANAGE_ORDERS',
+                    ],
+                ],
+            ],
+            'common_settings' => [
+                static::ITEM_TITLE    => static::t('Settings'),
+                static::ITEM_ICON_SVG => 'images/left_menu/settings.svg',
+                static::ITEM_WEIGHT   => 800,
+                static::ITEM_CHILDREN => [
+                    'email_notifications' => [
                         static::ITEM_TITLE  => static::t('Email notifications'),
                         static::ITEM_TARGET => 'notifications',
-                        static::ITEM_WEIGHT => 900,
+                        static::ITEM_WEIGHT => 100,
                     ],
-                    'seo'              => [
-                        static::ITEM_TITLE  => static::t('SEO settings'),
+                    'email_transfer'      => [
+                        static::ITEM_TITLE  => static::t('Email transfer'),
+                        static::ITEM_TARGET => 'email_settings',
+                        static::ITEM_WEIGHT => 200,
+                    ],
+                    'api'                 => [
+                        static::ITEM_TITLE      => static::t('API'),
+                        static::ITEM_TARGET     => 'settings',
+                        static::ITEM_EXTRA      => ['page' => 'API'],
+                        static::ITEM_PERMISSION => \XLite\Model\Role\Permission::ROOT_ACCESS,
+                        static::ITEM_WEIGHT     => 500,
+                    ],
+                    'seo'                 => [
+                        static::ITEM_TITLE  => static::t('SEO'),
                         static::ITEM_TARGET => 'settings',
                         static::ITEM_EXTRA  => ['page' => 'CleanURL'],
-                        static::ITEM_WEIGHT => 1200,
+                        static::ITEM_WEIGHT => 600,
                     ],
                 ],
             ],
             'system_settings' => [
-                static::ITEM_TITLE    => static::t('System tools'),
-                static::ITEM_ICON_SVG => 'images/fa-cog.svg',
-                static::ITEM_WEIGHT   => 400,
-                static::ITEM_TARGET   => 'db_backup',
+                static::ITEM_TITLE    => static::t('System'),
+                static::ITEM_ICON_SVG => 'images/left_menu/system.svg',
+                static::ITEM_WEIGHT   => 800,
                 static::ITEM_CHILDREN => [
-                    'environment'       => [
-                        static::ITEM_TITLE  => static::t('Environment'),
-                        static::ITEM_TARGET => 'settings',
-                        static::ITEM_EXTRA  => ['page' => 'Environment'],
-                        static::ITEM_WEIGHT => 100,
-                    ],
                     'rebuild_cache'     => [
                         static::ITEM_TITLE  => static::t('Cache management'),
                         static::ITEM_TARGET => 'cache_management',
                         static::ITEM_CLASS  => 'rebuild-cache',
                         static::ITEM_WEIGHT => 200,
                     ],
-                    'db_backup'         => [
-                        static::ITEM_TITLE  => static::t('Database'),
-                        static::ITEM_TARGET => 'db_backup',
-                        static::ITEM_WEIGHT => 300,
-                    ],
-                    'integrity_check'   => [
-                        static::ITEM_TITLE  => static::t('Integrity check'),
-                        static::ITEM_LINK     => \XLite::getInstance()->getServiceURL('#/integrity-check'),
-                        static::ITEM_TARGET => 'integrity_check',
-                        static::ITEM_WEIGHT => 400,
-                    ],
                     'consistency_check' => [
                         static::ITEM_TITLE  => static::t('Consistency check'),
                         static::ITEM_TARGET => 'consistency_check',
                         static::ITEM_WEIGHT => 450,
                     ],
-                    'view_log_file'     => [
-                        static::ITEM_TITLE      => static::t('System logs'),
-                        static::ITEM_TARGET     => 'logs',
-                        static::ITEM_WEIGHT     => 500,
-                    ],
                     'remove_data'       => [
                         static::ITEM_TITLE  => static::t('Remove data'),
                         static::ITEM_TARGET => 'remove_data',
                         static::ITEM_WEIGHT => 700,
                     ],
-                    'security_settings' => [
-                        static::ITEM_TITLE  => static::t('HTTPS settings'),
-                        static::ITEM_TARGET => 'https_settings',
-                        static::ITEM_WEIGHT => 800,
-                    ],
                 ],
             ],
         ];
 
-        return $result;
-    }
-
-    /**
-     * Define items
-     *
-     * @return array
-     */
-    protected function defineItems()
-    {
-        $items = [
-            'sales'          => [
-                static::ITEM_TITLE       => static::t('Orders'),
-                static::ITEM_ICON_SVG    => 'images/orders.svg',
-                static::ITEM_WIDGET      => 'XLite\View\Menu\Admin\LeftMenu\Sales',
-                static::ITEM_WEIGHT      => 100,
-                static::ITEM_TARGET      => 'order_list',
-                static::ITEM_LABEL_LINK  => $this->buildURL('order_list', 'search', ['filter_id' => 'recent']),
-                static::ITEM_LABEL_TITLE => static::t('Orders awaiting processing'),
-                static::ITEM_CHILDREN    => [
-                    'order_list'           => [
-                        static::ITEM_TITLE      => static::t('Orders list'),
-                        static::ITEM_TARGET     => 'order_list',
-                        static::ITEM_PERMISSION => 'manage orders',
-                        static::ITEM_WEIGHT     => 100,
-                    ],
-                    'orders_stats'         => [
-                        static::ITEM_TITLE      => static::t('Statistics'),
-                        static::ITEM_TARGET     => 'orders_stats',
-                        static::ITEM_PERMISSION => 'manage orders',
-                        static::ITEM_WEIGHT     => 200,
-                    ],
-                    'accounting'           => [
-                        static::ITEM_TITLE  => static::t('Accounting'),
-                        static::ITEM_TARGET => 'accounting',
+        if (!\XLite::isTrial()) {
+            $items['common_settings'][static::ITEM_CHILDREN] = array_merge(
+                $items['common_settings'][static::ITEM_CHILDREN],
+                [
+                    'css_js_performance' => [
+                        static::ITEM_TITLE  => static::t('Performance'),
+                        static::ITEM_TARGET => 'css_js_performance',
                         static::ITEM_WEIGHT => 300,
                     ],
-                    'payment_transactions' => [
-                        static::ITEM_TITLE      => static::t('Payment transactions'),
-                        static::ITEM_TARGET     => 'payment_transactions',
-                        static::ITEM_PERMISSION => 'manage orders',
-                        static::ITEM_WEIGHT     => 400,
+                    'security_settings'  => [
+                        static::ITEM_TITLE  => static::t('Security'),
+                        static::ITEM_TARGET => 'https_settings',
+                        static::ITEM_WEIGHT => 400,
                     ],
-                ],
-            ],
-            'catalog'        => [
-                static::ITEM_TITLE    => static::t('Catalog'),
-                static::ITEM_ICON_SVG => 'images/fa-tags.svg',
-                //static::ITEM_TARGET   => 'product_list',
-                static::ITEM_WEIGHT   => 200,
-                static::ITEM_CHILDREN => [
-                    'product_list'    => [
-                        static::ITEM_TITLE      => static::t('Products'),
-                        static::ITEM_TARGET     => 'product_list',
-                        static::ITEM_PERMISSION => 'manage catalog',
-                        static::ITEM_WEIGHT     => 200,
+                ]
+            );
+            $items['system_settings'][static::ITEM_CHILDREN] = array_merge(
+                $items['system_settings'][static::ITEM_CHILDREN],
+                [
+                    'environment'   => [
+                        static::ITEM_TITLE  => static::t('Environment'),
+                        static::ITEM_TARGET => 'settings',
+                        static::ITEM_EXTRA  => ['page' => 'Environment'],
+                        static::ITEM_WEIGHT => 100,
                     ],
-                    'categories'      => [
-                        static::ITEM_TITLE      => static::t('Categories'),
-                        static::ITEM_TARGET     => 'categories',
-                        static::ITEM_PERMISSION => 'manage catalog',
-                        static::ITEM_WEIGHT     => 300,
+                    'view_log_file' => [
+                        static::ITEM_TITLE  => static::t('System logs'),
+                        static::ITEM_TARGET => 'logs',
+                        static::ITEM_WEIGHT => 500,
                     ],
-                    'product_classes' => [
-                        static::ITEM_TITLE      => static::t('Classes & attributes'),
-                        static::ITEM_TARGET     => 'product_classes',
-                        static::ITEM_PERMISSION => 'manage catalog',
-                        static::ITEM_WEIGHT     => 400,
-                    ],
-                    'import'          => [
-                        static::ITEM_TITLE      => static::t('Import'),
-                        static::ITEM_TARGET     => 'import',
-                        static::ITEM_PERMISSION => 'manage import',
-                        static::ITEM_WEIGHT     => 500,
-                    ],
-                    'export'          => [
-                        static::ITEM_TITLE      => static::t('Export'),
-                        static::ITEM_TARGET     => 'export',
-                        static::ITEM_PERMISSION => 'manage export',
-                        static::ITEM_WEIGHT     => 600,
-                    ],
-                ],
-            ],
-            'promotions'     => [
-                static::ITEM_TITLE    => static::t('Discounts'),
-                static::ITEM_ICON_SVG => 'images/fa-gift.svg',
-                static::ITEM_WEIGHT   => 300,
-                static::ITEM_CHILDREN => [],
-            ],
-            'users'          => [
-                static::ITEM_TITLE    => static::t('Users'),
-                static::ITEM_ICON_SVG => 'images/fa-users.svg',
-                static::ITEM_WEIGHT   => 400,
-                //static::ITEM_TARGET   => 'profile_list',
-                static::ITEM_CHILDREN => [
-                    'profile_list' => [
-                        static::ITEM_TITLE      => static::t('Users list'),
-                        static::ITEM_TARGET     => 'profile_list',
-                        static::ITEM_PERMISSION => 'manage users',
-                        static::ITEM_WEIGHT     => 100,
-                    ],
-                    'memberships'  => [
-                        static::ITEM_TITLE      => static::t('Membership levels'),
-                        static::ITEM_TARGET     => 'memberships',
-                        static::ITEM_PERMISSION => 'manage users',
-                        static::ITEM_WEIGHT     => 200,
-                    ],
-                ],
-            ],
-            'content'        => [
-                static::ITEM_TITLE    => static::t('Content'),
-                static::ITEM_WEIGHT   => 500,
-                static::ITEM_ICON_SVG => 'images/contacts.svg',
-                static::ITEM_CHILDREN => [
-                    'front_page' => [
-                        static::ITEM_TITLE      => static::t('Front page'),
-                        static::ITEM_TARGET     => 'front_page',
-                        static::ITEM_PERMISSION => 'manage front page',
-                        static::ITEM_WEIGHT     => 100,
-                    ],
-                ],
-            ],
-            'sales_channels' => [
-                static::ITEM_TITLE    => static::t('Sales channels'),
-                //static::ITEM_TARGET   => 'sales_channels',
-                static::ITEM_WIDGET   => 'XLite\View\Menu\Admin\LeftMenu\SalesChannels',
-                static::ITEM_WEIGHT   => 250,
-                static::ITEM_ICON_SVG => 'images/sales_channels.svg',
-                static::ITEM_CHILDREN => [
-                ],
-            ],
-        ];
+                ]
+            );
+        }
 
-        $items['content'][static::ITEM_CHILDREN]['banner_rotation'] = [
-            static::ITEM_TITLE      => static::t('Banner rotation'),
-            static::ITEM_WIDGET     => 'XLite\View\Menu\Admin\LeftMenu\BannerRotation',
-            static::ITEM_TARGET     => 'banner_rotation',
-            static::ITEM_PERMISSION => 'manage banners',
-            static::ITEM_WEIGHT     => 100,
-        ];
+        if (\XLite::areUpdateNotificationsEnabled()) {
+            $items['extensions'][static::ITEM_CHILDREN]['upgrade'] = [
+                static::ITEM_TITLE  => static::t('Updates'),
+                static::ITEM_LINK   => \XLite::getInstance()->getServiceURL('#/upgrade'),
+                static::ITEM_WEIGHT => 500,
+            ];
+        }
 
-        $items['catalog'][static::ITEM_CHILDREN]['clone_products'] = [
-            static::ITEM_TITLE      => static::t('Cloned products'),
-            static::ITEM_WIDGET     => 'XLite\View\Menu\Admin\LeftMenu\ClonedProducts',
-            static::ITEM_TARGET     => 'cloned_products',
-            static::ITEM_PERMISSION => 'manage catalog',
-            static::ITEM_WEIGHT     => 220,
-        ];
+        if ($this->moduleManagerDomain->isEnabled('Kliken-GoogleAds')) {
+            $items['marketing'][static::ITEM_CHILDREN]['google_shopping_by_kliken'] = [
+                static::ITEM_TITLE  => static::t('Google ads by kliken'),
+                static::ITEM_TARGET => 'kga_settings',
+                static::ITEM_WEIGHT => 100,
+            ];
+        }
 
         $pagesStatic = \XLite\Controller\Admin\Promotions::getPagesStatic();
         if ($pagesStatic) {
@@ -440,6 +419,7 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
                     static::ITEM_TARGET     => 'promotions',
                     static::ITEM_EXTRA      => ['page' => $k],
                     static::ITEM_PERMISSION => !empty($v['permission']) ? $v['permission'] : null,
+                    static::ITEM_WEIGHT     => $v['weight'] ?? 0,
                 ];
 
                 $items['promotions'][static::ITEM_EXTRA] = ['page' => $k];
@@ -453,16 +433,26 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
         return $items;
     }
 
+    /**
+     * Bottom items
+     *
+     * @return array
+     */
+    protected function defineBottomItems()
+    {
+        return [];
+    }
+
     /**
      * Get content of the dynamic widget that renders 'product-added' css class if product was added to cart.
      *
-     * @return integer
+     * @return int
      */
     public function getRecentOrdersCount()
     {
         $widget = $this->getChildWidget('XLite\View\Menu\Admin\RecentOrdersCount');
 
-        return (int)$widget->getOrdersCount();
+        return (int) $widget->getOrdersCount();
     }
 
     /**
@@ -485,6 +475,18 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
         return 'XLite\View\Menu\Admin\LeftMenu\Node';
     }
 
+    /**
+     * Get content of the dynamic widget that renders css classes 'expanded or compressed' for left menu
+     *
+     * @return string
+     */
+    public function getClassesForLeftMenu()
+    {
+        $widget = $this->getChildWidget(LeftMenuState::class);
+
+        return $widget->getContent();
+    }
+
     /**
      * Get container tag attributes
      *
@@ -492,54 +494,32 @@ class LeftMenu extends \XLite\View\Menu\Admin\AAdmin
      */
     protected function getContainerTagAttributes()
     {
-        $offsetTop = 60;
-
-        if (!\XLite::hasXCNLicenseKey()) {
-            $offsetTop += 50;
-        }
-
-        //$flags = \XLite\Core\Marketplace::getInstance()->checkForUpdates();
-        $flags = null;
-        if (is_array($flags)
-            && (!empty($flags[\XCart\Marketplace\Constant::FIELD_ARE_UPDATES_AVAILABLE])
-                || !empty($flags[\XCart\Marketplace\Constant::FIELD_IS_UPGRADE_AVAILABLE])
-            )
-        ) {
-            $offsetTop += 25;
-        }
-
-        $attributes = [
-            'id'              => 'leftMenu',
-            'data-spy'        => 'affix',
-            'data-offset-top' => $offsetTop,
+        return [
+            'id'       => 'leftMenu',
+            'data-spy' => 'affix',
+            'class'    => $this->getClassesForLeftMenu(),
         ];
-
-        if (!empty($_COOKIE['XCAdminLeftMenuCompressed'])) {
-            $attributes['class'] = ['compressed'];
-        }
-
-        return $attributes;
     }
 
+    /**
+     * @return bool
+     */
     protected function isCacheAvailable()
     {
         return true;
     }
 
+    /**
+     * @return array
+     */
     protected function getCacheParameters()
     {
-        $menuCompressed = isset($_COOKIE['XCAdminLeftMenuCompressed'])
-            ? $_COOKIE['XCAdminLeftMenuCompressed']
-            : false;
-
         return array_merge(
             parent::getCacheParameters(),
             [
-                $menuCompressed,
-                \XLite\Core\Auth::getInstance()->getProfile()
-                    ? \XLite\Core\Auth::getInstance()->getProfile()->getProfileId()
+                Auth::getInstance()->getProfile()
+                    ? Auth::getInstance()->getProfile()->getProfileId()
                     : 'no_profile',
-                \XLite::isFreeLicense(),
             ]
         );
     }
