@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -42,18 +41,12 @@ abstract class ANode extends \XLite\View\Menu\Admin\ANode
     }
 
     /**
-     * Get container tag attributes
+     * Return CSS class for the link item
      *
-     * @return array
+     * @return string
      */
-    protected function getContainerTagAttributes()
+    protected function getCSSClass()
     {
-        $attributes = parent::getContainerTagAttributes();
-
-        if (!empty($_COOKIE['XCAdminLeftMenuCompressed'])) {
-            //$attributes['class'] = str_replace('pre-expanded', 'has-expanded', $attributes['class']);
-        }
-
-        return $attributes;
+        return parent::getCSSClass() . ' text-capitalize';
     }
 }
