@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,8 +17,8 @@ class BannerRotation extends \XLite\View\Menu\Admin\LeftMenu\Node implements Dyn
     public function isVisible()
     {
         return parent::isVisible()
-            && !\XLite\Core\Auth::getInstance()->isPermissionAllowed('manage catalog')
-            && \XLite\Core\Auth::getInstance()->isPermissionAllowed('manage banners');
+            && !\XLite\Core\Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_CATALOG')
+            && \XLite\Core\Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_BANNERS');
     }
 
     protected function getCacheParameters()
