@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Menu\Customer;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Footer menu
  *
@@ -32,6 +33,6 @@ class Footer extends \XLite\View\Menu\Customer\ACustomer
      */
     protected function defineItems()
     {
-        return array();
+        return [];
     }
 }
