@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Minicart widget
  *
@@ -18,17 +19,17 @@ class Minicart extends \XLite\View\SideBarBox
     /**
      * Widget parameter names
      */
-    const PARAM_DISPLAY_MODE = 'displayMode';
+    public const PARAM_DISPLAY_MODE = 'displayMode';
 
     /**
      * Allowed display modes
      */
-    const DISPLAY_MODE_HORIZONTAL = 'horizontal';
+    public const DISPLAY_MODE_HORIZONTAL = 'horizontal';
 
     /**
      * Number of cart items to display by default
      */
-    const ITEMS_TO_DISPLAY = 3;
+    public const ITEMS_TO_DISPLAY = 3;
 
 
     /**
@@ -36,9 +37,9 @@ class Minicart extends \XLite\View\SideBarBox
      *
      * @var array
      */
-    protected $displayModes = array(
+    protected $displayModes = [
         self::DISPLAY_MODE_HORIZONTAL => 'Horizontal',
-    );
+    ];
 
 
     /**
@@ -77,6 +78,16 @@ class Minicart extends \XLite\View\SideBarBox
         return 'mini_cart/' . strtolower($this->getParam(self::PARAM_DISPLAY_MODE));
     }
 
+    /**
+     * Get number of cart items to display by default
+     *
+     * @return int
+     */
+    protected function getCountCartItemsToDisplay()
+    {
+        return self::ITEMS_TO_DISPLAY;
+    }
+
     /**
      * Get cart object without calculation
      *
@@ -98,16 +109,17 @@ class Minicart extends \XLite\View\SideBarBox
     }
 
     /**
-     * Return up to 3 items from cart
+     * Return up to 3 last items from cart
      *
      * @return array
      */
     protected function getItemsList()
     {
-        return array_slice(
-            $this->getCart()->getItems()->toArray(),
-            0,
-            min(self::ITEMS_TO_DISPLAY, $this->getCart()->countItems())
+        return array_reverse(
+            array_slice(
+                $this->getCart()->getItems()->toArray(),
+                -$this->getCountCartItemsToDisplay()
+            )
         );
     }
 
@@ -118,7 +130,7 @@ class Minicart extends \XLite\View\SideBarBox
      */
     protected function isTruncated()
     {
-        return self::ITEMS_TO_DISPLAY < $this->getCart()->countItems();
+        return $this->getCountCartItemsToDisplay() < $this->getCart()->countItems();
     }
 
     /**
@@ -128,7 +140,7 @@ class Minicart extends \XLite\View\SideBarBox
      */
     protected function getTotals()
     {
-        return array('Total' => $this->getCart()->getTotal());
+        return ['Total' => $this->getCart()->getTotal()];
     }
 
     /**
@@ -140,11 +152,14 @@ class Minicart extends \XLite\View\SideBarBox
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_DISPLAY_MODE => new \XLite\Model\WidgetParam\TypeSet(
-                'Display mode', self::DISPLAY_MODE_HORIZONTAL, true, $this->displayModes
+                'Display mode',
+                self::DISPLAY_MODE_HORIZONTAL,
+                true,
+                $this->displayModes
             ),
-        );
+        ];
     }
 
     /**
@@ -161,10 +176,8 @@ class Minicart extends \XLite\View\SideBarBox
 
         if ($cart->isMaxOrderAmountError()) {
             $result = $this->getMaxOrderAmountErrorReason();
-
         } elseif ($cart->isMinOrderAmountError()) {
             $result = $this->getMinOrderAmountErrorReason();
-
         } elseif ($cart->getItemsWithWrongAmounts()) {
             $result = $this->getItemsWithWrongAmountErrorReason();
         }
@@ -191,13 +204,13 @@ class Minicart extends \XLite\View\SideBarBox
     {
         return static::t(
             'The order subtotal exceeds the maximum allowed value ({{max_order_amount}})',
-            array(
+            [
                 'max_order_amount' => static::formatPrice(
                     \XLite\Core\Config::getInstance()->General->maximal_order_amount,
                     null,
                     true
                 ),
-            )
+            ]
         );
     }
 
@@ -210,13 +223,13 @@ class Minicart extends \XLite\View\SideBarBox
     {
         return static::t(
             'The order subtotal less than the minimum allowed value ({{min_order_amount}})',
-            array(
+            [
                 'min_order_amount' => static::formatPrice(
                     \XLite\Core\Config::getInstance()->General->minimal_order_amount,
                     null,
                     true
                 ),
-            )
+            ]
         );
     }
 
@@ -237,14 +250,14 @@ class Minicart extends \XLite\View\SideBarBox
      */
     protected function getContainerAttributes()
     {
-        $attributes = array(
-            'class' => array(
+        $attributes = [
+            'class' => [
                 'lc-minicart',
                 'lc-minicart-' . $this->getParam(static::PARAM_DISPLAY_MODE),
                 'collapsed'
-            ),
+            ],
             'title' => static::t('Your cart')
-        );
+        ];
 
         if ($this->getCart()->isEmpty()) {
             $attributes['class'][] = 'empty';
@@ -272,9 +285,9 @@ class Minicart extends \XLite\View\SideBarBox
      */
     protected function getItemsContainerAttributes()
     {
-        $attributes = array(
-            'class' => array('internal-popup', 'items-list'),
-        );
+        $attributes = [
+            'class' => ['internal-popup', 'items-list'],
+        ];
 
         $attributes['class'][] = $this->getCart()->isEmpty() ? 'empty-cart' : 'full-cart';
 
@@ -302,8 +315,8 @@ class Minicart extends \XLite\View\SideBarBox
     {
         $list = parent::getCacheParameters();
 
-        $params[] = $this->getCacheKeyPartsGenerator()->getMembershipPart();
-        $params[] = $this->getCacheKeyPartsGenerator()->getShippingZonesPart();
+        $list[] = $this->getCacheKeyPartsGenerator()->getMembershipPart();
+        $list[] = $this->getCacheKeyPartsGenerator()->getShippingZonesPart();
 
         // If the cart is changed the widget content must be recalculated
         $list[] = $this->getCart()->getItemsFingerprint();
