@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,8 +7,6 @@
 
 namespace XLite\View\Model;
 
-use XLite\Core\MagicMethodsIntrospectionInterface;
-
 /**
  * Abstract model widget
  */
@@ -18,8 +15,8 @@ abstract class AModel extends \XLite\View\Dialog
     /**
      * Widget param names
      */
-    const PARAM_MODEL_OBJECT      = 'modelObject';
-    const PARAM_USE_BODY_TEMPLATE = 'useBodyTemplate';
+    public const PARAM_MODEL_OBJECT      = 'modelObject';
+    public const PARAM_USE_BODY_TEMPLATE = 'useBodyTemplate';
 
     /**
      * Indexes in field schemas
@@ -27,60 +24,61 @@ abstract class AModel extends \XLite\View\Dialog
      * FIXME: keep this list synchronized with the classes,
      * derived from the \XLite\View\FormField\AFormField
      */
-    const SCHEMA_CLASS           = 'class';
-    const SCHEMA_VALUE           = \XLite\View\FormField\AFormField::PARAM_VALUE;
-    const SCHEMA_REQUIRED        = \XLite\View\FormField\AFormField::PARAM_REQUIRED;
-    const SCHEMA_ATTRIBUTES      = \XLite\View\FormField\AFormField::PARAM_ATTRIBUTES;
-    const SCHEMA_NAME            = \XLite\View\FormField\AFormField::PARAM_NAME;
-    const SCHEMA_LABEL           = \XLite\View\FormField\AFormField::PARAM_LABEL;
-    const SCHEMA_LABEL_PARAMS    = \XLite\View\FormField\AFormField::PARAM_LABEL_PARAMS;
-    const SCHEMA_FIELD_ONLY      = \XLite\View\FormField\AFormField::PARAM_FIELD_ONLY;
-    const SCHEMA_PLACEHOLDER     = \XLite\View\FormField\Input\Base\StringInput::PARAM_PLACEHOLDER;
-    const SCHEMA_COMMENT         = \XLite\View\FormField\AFormField::PARAM_COMMENT;
-    const SCHEMA_HELP            = \XLite\View\FormField\AFormField::PARAM_HELP;
-    const SCHEMA_LINK_HREF       = \XLite\View\FormField\AFormField::PARAM_LINK_HREF;
-    const SCHEMA_LINK_TEXT       = \XLite\View\FormField\AFormField::PARAM_LINK_TEXT;
-    const SCHEMA_LINK_IMG        = \XLite\View\FormField\AFormField::PARAM_LINK_IMG;
-    const SCHEMA_TRUSTED         = \XLite\View\FormField\AFormField::PARAM_TRUSTED;
-    const SCHEMA_TRUSTED_PERMISSION = 'trustedPermission';
+    public const SCHEMA_CLASS           = 'class';
+    public const SCHEMA_VALUE           = \XLite\View\FormField\AFormField::PARAM_VALUE;
+    public const SCHEMA_REQUIRED        = \XLite\View\FormField\AFormField::PARAM_REQUIRED;
+    public const SCHEMA_ATTRIBUTES      = \XLite\View\FormField\AFormField::PARAM_ATTRIBUTES;
+    public const SCHEMA_NAME            = \XLite\View\FormField\AFormField::PARAM_NAME;
+    public const SCHEMA_LABEL           = \XLite\View\FormField\AFormField::PARAM_LABEL;
+    public const SCHEMA_LABEL_PARAMS    = \XLite\View\FormField\AFormField::PARAM_LABEL_PARAMS;
+    public const SCHEMA_FIELD_ONLY      = \XLite\View\FormField\AFormField::PARAM_FIELD_ONLY;
+    public const SCHEMA_PLACEHOLDER     = \XLite\View\FormField\Input\Base\StringInput::PARAM_PLACEHOLDER;
+    public const SCHEMA_COMMENT         = \XLite\View\FormField\AFormField::PARAM_COMMENT;
+    public const SCHEMA_HELP            = \XLite\View\FormField\AFormField::PARAM_HELP;
+    public const SCHEMA_LINK_HREF       = \XLite\View\FormField\AFormField::PARAM_LINK_HREF;
+    public const SCHEMA_LINK_TEXT       = \XLite\View\FormField\AFormField::PARAM_LINK_TEXT;
+    public const SCHEMA_LINK_IMG        = \XLite\View\FormField\AFormField::PARAM_LINK_IMG;
+    public const SCHEMA_TRUSTED         = \XLite\View\FormField\AFormField::PARAM_TRUSTED;
+    public const SCHEMA_TRUSTED_PERMISSION = 'trustedPermission';
 
-    const SCHEMA_OPTIONS = \XLite\View\FormField\Select\ASelect::PARAM_OPTIONS;
-    const SCHEMA_IS_CHECKED = \XLite\View\FormField\Input\Checkbox::PARAM_IS_CHECKED;
+    public const SCHEMA_OPTIONS = \XLite\View\FormField\Select\ASelect::PARAM_OPTIONS;
+    public const SCHEMA_IS_CHECKED = \XLite\View\FormField\Input\Checkbox::PARAM_IS_CHECKED;
 
-    const SCHEMA_MODEL_ATTRIBUTES = 'model_attributes';
+    public const SCHEMA_MODEL_ATTRIBUTES = 'model_attributes';
 
-    const SCHEMA_DEPENDENCY = \XLite\View\FormField\AFormField::PARAM_DEPENDENCY;
+    public const SCHEMA_DEPENDENCY = \XLite\View\FormField\AFormField::PARAM_DEPENDENCY;
 
     /**
      * Session cell to store form data
      */
-    const SAVED_FORMS     = 'savedForms';
-    const SAVED_FORM_DATA = 'savedFormData';
+    public const SAVED_FORMS       = 'savedForms';
+    public const SAVED_FORM_DATA   = 'savedFormData';
+    public const SAVED_FORM_ERRORS = 'savedFormErrors';
 
     /**
      * Form sections
      */
     // Title for this section will not be displayed
-    const SECTION_DEFAULT = 'default';
+    public const SECTION_DEFAULT = 'default';
     // This section will not be displayed
-    const SECTION_HIDDEN  = 'hidden';
+    public const SECTION_HIDDEN  = 'hidden';
 
     /**
      * Indexes in the "formFields" array
      */
-    const SECTION_PARAM_WIDGET = 'sectionParamWidget';
-    const SECTION_PARAM_FIELDS = 'sectionParamFields';
+    public const SECTION_PARAM_WIDGET = 'sectionParamWidget';
+    public const SECTION_PARAM_FIELDS = 'sectionParamFields';
 
     /**
      * Name prefix of the methods to handle actions
      */
-    const ACTION_HANDLER_PREFIX = 'performAction';
+    public const ACTION_HANDLER_PREFIX = 'performAction';
 
     /**
      * Dependency
      */
-    const DEPENDENCY_SHOW = 'show';
-    const DEPENDENCY_HIDE = 'hide';
+    public const DEPENDENCY_SHOW = 'show';
+    public const DEPENDENCY_HIDE = 'hide';
 
     /**
      * Current form object
@@ -108,7 +106,7 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @var array
      */
-    protected $formFieldNames = array();
+    protected $formFieldNames = [];
 
     /**
      * Form error messages cache
@@ -124,15 +122,22 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected $savedData = null;
 
+    /**
+     * Form saved errors
+     *
+     * @var array
+     */
+    protected $savedErrorMessages = null;
+
     /**
      * Available form sections
      *
      * @var array
      */
-    protected $sections = array(
+    protected $sections = [
         self::SECTION_DEFAULT => null,
         self::SECTION_HIDDEN  => null,
-    );
+    ];
 
     /**
      * Current action
@@ -153,21 +158,21 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @var array
      */
-    protected $schemaDefault = array();
+    protected $schemaDefault = [];
 
     /**
      * schemaHidden
      *
      * @var array
      */
-    protected $schemaHidden = array();
+    protected $schemaHidden = [];
 
     /**
      * The list of fields (field names) that must be excluded from the array(data) for mapping to the object
      *
      * @var array
      */
-    protected $excludedFields = array();
+    protected $excludedFields = [];
 
     /**
      * This object will be used if another one is not passed
@@ -190,7 +195,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getFormWidgetParams()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -211,7 +216,7 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @return void
      */
-    public function __construct(array $params = array(), array $sections = array())
+    public function __construct(array $params = [], array $sections = [])
     {
         if (!empty($sections)) {
             $this->sections = \Includes\Utils\ArrayManager::filterByKeys($this->sections, $sections);
@@ -239,7 +244,7 @@ abstract class AModel extends \XLite\View\Dialog
             if (!isset($value)) {
                 // Check if $name is in fields list
                 $fields = $this->getFormFields(true);
-                if ($fields && false !== array_search($name, $fields)) {
+                if ($fields && in_array($name, $fields)) {
                     $value = $this->getModelObjectValue($name);
                 }
             }
@@ -266,7 +271,7 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @return boolean
      */
-    public function performAction($action, array $data = array())
+    public function performAction($action, array $data = [])
     {
         // Save some data
         $this->currentAction = $action;
@@ -282,7 +287,6 @@ abstract class AModel extends \XLite\View\Dialog
 
         if ($result) {
             $this->postprocessSuccessAction();
-
         } else {
             $this->rollbackModel();
             $this->saveFormData($requestData);
@@ -300,7 +304,18 @@ abstract class AModel extends \XLite\View\Dialog
     public function getCSSFiles()
     {
         $list = parent::getCSSFiles();
-        $list[] = $this->getDir() . '/model.css';
+        $list[] = $this->getDir() . '/model.less';
+
+        return $list;
+    }
+
+    /**
+     * @return array
+     */
+    public function getJSFiles()
+    {
+        $list = parent::getJSFiles();
+        $list[] = $this->getDir() . '/model.js';
 
         return $list;
     }
@@ -319,7 +334,7 @@ abstract class AModel extends \XLite\View\Dialog
         }
 
         return isset($name)
-            ? (isset($this->savedData[$name]) ? $this->savedData[$name] : null)
+            ? ($this->savedData[$name] ?? null)
             : $this->savedData;
     }
 
@@ -333,11 +348,11 @@ abstract class AModel extends \XLite\View\Dialog
     public function getRequestData($name = null)
     {
         if (!isset($this->requestData)) {
-            $this->defineRequestData(array(), $name);
+            $this->defineRequestData([], $name);
         }
 
         return isset($name)
-            ? (isset($this->requestData[$name]) ? $this->requestData[$name] : null)
+            ? ($this->requestData[$name] ?? null)
             : $this->requestData;
     }
 
@@ -448,7 +463,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getFormFieldsForSection($section)
     {
-        $method = __FUNCTION__ . ucfirst($section);
+        $method = __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($section);
 
         // Return the method getFormFieldsForSection<SectionName>
         return method_exists($this, $method) ? $this->$method() : $this->translateSchema($section);
@@ -461,13 +476,13 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function defineFormFields()
     {
-        $this->formFields = array();
+        $this->formFields = [];
 
         foreach ($this->sections as $section => $label) {
-            $this->formFields[$section] = array(
+            $this->formFields[$section] = [
                 self::SECTION_PARAM_WIDGET => $this->defineSectionWidget($section, [self::SCHEMA_LABEL => $label]),
                 self::SECTION_PARAM_FIELDS => $this->getFormFieldsForSection($section),
-            );
+            ];
         }
     }
 
@@ -493,14 +508,18 @@ abstract class AModel extends \XLite\View\Dialog
 
         $object = $this->getDefaultModelObject();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_MODEL_OBJECT => new \XLite\Model\WidgetParam\TypeObject(
-                'Object', $object, false, $object ? get_class($object) : ''
+                'Object',
+                $object,
+                false,
+                $object ? get_class($object) : ''
             ),
             self::PARAM_USE_BODY_TEMPLATE => new \XLite\Model\WidgetParam\TypeBool(
-                'Use default body template', false
+                'Use default body template',
+                false
             ),
-        );
+        ];
     }
 
     /**
@@ -520,7 +539,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function useButtonPanel()
     {
-        return !is_null($this->getButtonPanelClass());
+        return $this->getButtonPanelClass() !== null;
     }
 
     /**
@@ -531,7 +550,7 @@ abstract class AModel extends \XLite\View\Dialog
     protected function getButtonPanelClass()
     {
         return \XLite::isAdminZone()
-            ? '\XLite\View\StickyPanel\Model\Model'
+            ? \XLite\View\StickyPanel\Model\Model::class
             : null;
     }
 
@@ -546,10 +565,11 @@ abstract class AModel extends \XLite\View\Dialog
 
         if ($this->useButtonPanel()) {
             $class = $this->getButtonPanelClass();
-            $buttonPanel = new $class;
+            $buttonPanel = new $class();
             $buttons = $this->getFormButtons();
 
-            if ($buttons
+            if (
+                $buttons
                 && method_exists($buttonPanel, 'setButtons')
             ) {
                 $buttonPanel->setButtons($buttons);
@@ -591,7 +611,6 @@ abstract class AModel extends \XLite\View\Dialog
     protected function getFieldMappings()
     {
         if (!isset($this->fieldMappings)) {
-
             // Collect metadata for fields of class and its translation class if there is one.
             $metaData = \XLite\Core\Database::getEM()->getClassMetadata(get_class($this->getModelObject()));
             $this->fieldMappings = $metaData->fieldMappings;
@@ -601,7 +620,6 @@ abstract class AModel extends \XLite\View\Dialog
                 : false;
 
             if ($metaDataTranslationClass) {
-
                 $metaDataTranslation = \XLite\Core\Database::getEM()->getClassMetadata($metaDataTranslationClass);
                 $this->fieldMappings += $metaDataTranslation->fieldMappings;
             }
@@ -622,7 +640,7 @@ abstract class AModel extends \XLite\View\Dialog
         $fieldMappings = $this->getFieldMappings();
         $fieldName = $this->getModelFieldName($name);
 
-        return isset($fieldMappings[$fieldName]) ? $fieldMappings[$fieldName] : null;
+        return $fieldMappings[$fieldName] ?? null;
     }
 
     /**
@@ -637,14 +655,11 @@ abstract class AModel extends \XLite\View\Dialog
     {
         $fieldMapping = $this->getFieldMapping($name);
 
-        $result = array();
+        $result = [];
 
         if ($fieldMapping) {
-
             foreach ($data[static::SCHEMA_MODEL_ATTRIBUTES] as $widgetAttribute => $modelAttribute) {
-
                 if (isset($fieldMapping[$modelAttribute])) {
-
                     $result[$widgetAttribute] = $fieldMapping[$modelAttribute];
                 }
             }
@@ -669,10 +684,10 @@ abstract class AModel extends \XLite\View\Dialog
 
         $data[static::SCHEMA_VALUE] = $this->getDefaultFieldValue($name);
 
-        $data[static::SCHEMA_ATTRIBUTES] = !empty($data[static::SCHEMA_ATTRIBUTES]) ? $data[static::SCHEMA_ATTRIBUTES] : array();
-        $data[static::SCHEMA_ATTRIBUTES] += isset($data[static::SCHEMA_MODEL_ATTRIBUTES]) ? $this->getModelAttributes($name, $data) : array();
+        $data[static::SCHEMA_ATTRIBUTES] = !empty($data[static::SCHEMA_ATTRIBUTES]) ? $data[static::SCHEMA_ATTRIBUTES] : [];
+        $data[static::SCHEMA_ATTRIBUTES] += isset($data[static::SCHEMA_MODEL_ATTRIBUTES]) ? $this->getModelAttributes($name, $data) : [];
 
-        $data[static::SCHEMA_DEPENDENCY] = isset($data[static::SCHEMA_DEPENDENCY]) ? $data[static::SCHEMA_DEPENDENCY] : array();
+        $data[static::SCHEMA_DEPENDENCY] = $data[static::SCHEMA_DEPENDENCY] ?? [];
 
         if (isset($data[static::SCHEMA_TRUSTED_PERMISSION]) && $data[static::SCHEMA_TRUSTED_PERMISSION]) {
             $data[static::SCHEMA_TRUSTED] = $this->isContentTrustedByPermission($name, $data);
@@ -689,10 +704,10 @@ abstract class AModel extends \XLite\View\Dialog
     protected function getFilesFormFields()
     {
         if (!isset($this->filesFormFields)) {
-            $this->filesFormFields = array();
+            $this->filesFormFields = [];
             foreach ($this->formFields as $section) {
                 foreach ($section[static::SECTION_PARAM_FIELDS] as $k => $v) {
-                    if (is_subclass_of($v, '\XLite\View\FormField\FileUploader\AFileUploader')) {
+                    if (is_subclass_of($v, \XLite\View\FormField\FileUploader\AFileUploader::class)) {
                         $this->filesFormFields[$k] = $v;
                     }
                 }
@@ -711,7 +726,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function setModelProperties(array $data)
     {
-        $filesData = array();
+        $filesData = [];
         if ($this->getFilesFormFields()) {
             foreach ($this->getFilesFormFields() as $k => $v) {
                 if (isset($data[$k])) {
@@ -727,10 +742,9 @@ abstract class AModel extends \XLite\View\Dialog
 
         foreach ($data as $name => $value) {
             // Correct data: remove fields which cannot be mapped to the model
-            $method = 'set' . \XLite\Core\Converter::convertToCamelCase($name);
+            $method = 'set' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
-            $methodExists = method_exists($model, $method)
-                            || ($model instanceof MagicMethodsIntrospectionInterface && $model->hasMagicMethod($method));
+            $methodExists = method_exists($model, $method);
 
             // $method - assemble from 'set' + property name
             if (!$methodExists && !$model->isPropertyExists($name)) {
@@ -741,7 +755,6 @@ abstract class AModel extends \XLite\View\Dialog
         $model->map($data);
 
         if ($filesData) {
-
             $errors = $this->processFiles($filesData);
 
             if ($errors) {
@@ -761,7 +774,7 @@ abstract class AModel extends \XLite\View\Dialog
     protected function processFileUploadErrors($errors)
     {
         foreach ($errors as $error) {
-            \XLite\Core\TopMessage::addError(static::t($error[0], !empty($error[1]) ? $error[1] : array()));
+            \XLite\Core\TopMessage::addError(static::t($error[0], !empty($error[1]) ? $error[1] : []));
         }
     }
 
@@ -774,7 +787,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function processFiles(array $data)
     {
-        $errors = array();
+        $errors = [];
 
         $model = $this->getModelObject();
 
@@ -795,7 +808,7 @@ abstract class AModel extends \XLite\View\Dialog
     protected function mapCleanURL($data)
     {
         /** @var \XLite\Model\Repo\CleanURL $cleanURLRepo */
-        $cleanURLRepo = \XLite\Core\Database::getRepo('XLite\Model\CleanURL');
+        $cleanURLRepo = \XLite\Core\Database::getRepo(\XLite\Model\CleanURL::class);
 
         if (
             $this->getPostedData('autogenerateCleanURL')
@@ -837,6 +850,16 @@ abstract class AModel extends \XLite\View\Dialog
         return $data;
     }
 
+    /**
+     * Return true if form errors should be shown via top message
+     *
+     * @return boolean
+     */
+    public function showErrorsViaTopMessage()
+    {
+        return true;
+    }
+
     /**
      * Fetch saved forms data from session
      *
@@ -859,7 +882,7 @@ abstract class AModel extends \XLite\View\Dialog
         $data = $this->getSavedForms();
         $name = $this->getFormName();
 
-        $data = isset($data[$name]) ? $data[$name] : array();
+        $data = $data[$name] ?? [];
 
         if (isset($field) && isset($data[$field])) {
             $data = $data[$field];
@@ -878,17 +901,21 @@ abstract class AModel extends \XLite\View\Dialog
     protected function saveFormData($data)
     {
         $savedData = $this->getSavedForms();
+        $formName = $this->getFormName();
 
         if (isset($data)) {
-            $savedData[$this->getFormName()] = array(
-                self::SAVED_FORM_DATA => $data,
-            );
-
+            $savedData[$formName] = [
+                self::SAVED_FORM_DATA   => $data,
+                self::SAVED_FORM_ERRORS => $this->getErrorMessages(),
+            ];
         } else {
-            $savedData[$this->getFormName()] = array();
+            $savedData[$formName] = [];
         }
 
-        \XLite\Core\Session::getInstance()->set(self::SAVED_FORMS, empty($savedData) ? null : $savedData);
+        \XLite\Core\Session::getInstance()->set(
+            self::SAVED_FORMS,
+            $savedData ?: null
+        );
     }
 
     /**
@@ -968,7 +995,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function postprocessSuccessAction()
     {
-        $method = __FUNCTION__ . ucfirst($this->currentAction);
+        $method = __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($this->currentAction);
 
         if (method_exists($this, $method)) {
             // Run the corresponded function
@@ -985,9 +1012,11 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function postprocessErrorAction()
     {
-        \XLite\Core\TopMessage::getInstance()->addBatch($this->getErrorMessages(), \XLite\Core\TopMessage::ERROR);
+        if ($this->showErrorsViaTopMessage()) {
+            \XLite\Core\TopMessage::getInstance()->addBatch($this->getErrorMessages(), \XLite\Core\TopMessage::ERROR);
+        }
 
-        $method = __FUNCTION__ . ucfirst($this->currentAction);
+        $method = __FUNCTION__ . \Includes\Utils\Converter::convertToUpperCamelCase($this->currentAction);
 
         if (method_exists($this, $method)) {
             // Run corresponded function
@@ -1006,7 +1035,7 @@ abstract class AModel extends \XLite\View\Dialog
     {
         $em = \XLite\Core\Database::getEM();
         $model = $this->getModelObject();
-        if ($em->contains($model)) {
+        if (is_object($model) && $em->contains($model)) {
             $em->refresh($model);
         }
     }
@@ -1046,8 +1075,8 @@ abstract class AModel extends \XLite\View\Dialog
 
         $class = $data[self::SCHEMA_CLASS];
 
-        if (\XLite\Core\Operator::isClassExists($class)) {
-            $method = 'prepareFieldParams' . \XLite\Core\Converter::convertToCamelCase($name);
+        if (class_exists($class)) {
+            $method = 'prepareFieldParams' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
             if (method_exists($this, $method)) {
                 // Call the corresponded method
@@ -1069,7 +1098,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getFieldsBySchema(array $schema)
     {
-        $result = array();
+        $result = [];
 
         foreach ($schema as $name => $data) {
             $field = $this->getFieldBySchema($name, $data);
@@ -1090,10 +1119,8 @@ abstract class AModel extends \XLite\View\Dialog
     {
         // First dimension - sections list
         foreach ($this->formFields as $section => &$data) {
-
             // Second dimension - fields
             foreach ($data[self::SECTION_PARAM_FIELDS] as $index => $field) {
-
                 if (!$field->checkVisibility()) {
                     // Exclude field from list if it's not visible
                     unset($data[self::SECTION_PARAM_FIELDS][$index]);
@@ -1121,7 +1148,7 @@ abstract class AModel extends \XLite\View\Dialog
     {
         $schema = 'schema' . ucfirst($name);
 
-        return property_exists($this, $schema) ? $this->getFieldsBySchema($this->$schema) : array();
+        return property_exists($this, $schema) ? $this->getFieldsBySchema($this->$schema) : [];
     }
 
     /**
@@ -1188,7 +1215,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function isShowSectionHeader($section)
     {
-        return !in_array($section, array(self::SECTION_DEFAULT, self::SECTION_HIDDEN));
+        return !in_array($section, [self::SECTION_DEFAULT, self::SECTION_HIDDEN]);
     }
 
     /**
@@ -1211,7 +1238,7 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @return void
      */
-    protected function defineRequestData(array $data = array(), $name = null)
+    protected function defineRequestData(array $data = [], $name = null)
     {
         if (empty($data)) {
             $data = $this->prepareRequestParamsList();
@@ -1242,7 +1269,6 @@ abstract class AModel extends \XLite\View\Dialog
         $nonFilteredData = \XLite\Core\Request::getInstance()->getNonFilteredData();
 
         foreach ($requestData as $name => $value) {
-
             $formField = $this->getFormFieldsByName($name);
 
             if (
@@ -1250,7 +1276,6 @@ abstract class AModel extends \XLite\View\Dialog
                 && is_object($formField)
                 && method_exists($formField, 'prepareRequestData')
             ) {
-
                 if ($formField->isTrusted() || !empty($schemas[$name][static::SCHEMA_TRUSTED])) {
                     // Formfield value is trusted
                     $value = $nonFilteredData[$name];
@@ -1271,12 +1296,11 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getAllSchemaCells()
     {
-        $result = array();
+        $result = [];
 
         if (method_exists($this, 'getSchemaFields')) {
             // Some classes define schema fields by method getSchemaFields()
             $result = $this->getSchemaFields();
-
         } else {
             // Get schema fields from properties schemaSectionName if defined
             foreach ($this->sections as $section => $label) {
@@ -1322,7 +1346,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getFormButtons()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -1358,7 +1382,7 @@ abstract class AModel extends \XLite\View\Dialog
     {
         foreach ($data[self::SECTION_PARAM_FIELDS] as $field) {
             if ($this->checkDependency($field)) {
-                list($flag, $message) = $field->validate();
+                [$flag, $message] = $field->validate();
                 if (!$flag) {
                     $this->addErrorMessage($field->getName(), $message, $data);
                 }
@@ -1376,12 +1400,12 @@ abstract class AModel extends \XLite\View\Dialog
      */
     public function validateFormField($field)
     {
-        $result = array(true, null);
+        $result = [true, null];
 
         $name = $field->getName();
 
         if (in_array($name, $this->getFormFields(true))) {
-            $method = 'validateFormField' . \XLite\Core\Converter::convertToCamelCase($name) . 'Value';
+            $method = 'validateFormField' . \Includes\Utils\Converter::convertToUpperCamelCase($name) . 'Value';
             if (method_exists($this, $method)) {
                 $result = $this->$method($field, $this->getFormFields());
             }
@@ -1398,7 +1422,7 @@ abstract class AModel extends \XLite\View\Dialog
     protected function getErrorMessages()
     {
         if (!isset($this->errorMessages)) {
-            $this->errorMessages = array();
+            $this->errorMessages = [];
 
             foreach ($this->getFormFields() as $section => $data) {
                 $this->validateFields($data, $section);
@@ -1417,11 +1441,39 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @return void
      */
-    protected function addErrorMessage($name, $message, array $data = array())
+    protected function addErrorMessage($name, $message, array $data = [])
     {
         $this->errorMessages[$name] = $this->prepareErrorMessage($message, $data);
     }
 
+    /**
+     * Return list of saved form error messages
+     *
+     * @return array
+     */
+    protected function getSavedErrorMessages()
+    {
+        if (!isset($this->savedErrorMessages)) {
+            $this->savedErrorMessages = $this->getSavedForm(self::SAVED_FORM_ERRORS);
+        }
+
+        return $this->savedErrorMessages;
+    }
+
+    /**
+     * Return saved error message for the field
+     *
+     * @param string $fieldName
+     *
+     * @return \XLite\Core\Translation\Label
+     */
+    public function getSavedErrorMessage($fieldName)
+    {
+        $savedErrorMessages = $this->getSavedErrorMessages();
+
+        return $savedErrorMessages[$fieldName] ?? null;
+    }
+
     /**
      * Some JavaScript code to insert at the begin of form page
      *
@@ -1487,7 +1539,6 @@ abstract class AModel extends \XLite\View\Dialog
         if ($this->getModelObject()->isPersistent()) {
             $this->currentAction = 'update';
             $result = $this->callActionHandler('update');
-
         } else {
             $this->currentAction = 'create';
             $result = $this->callActionHandler('create');
@@ -1548,23 +1599,13 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getModelValue($model, $name)
     {
-        $method = 'get' . \XLite\Core\Converter::convertToCamelCase($name);
+        $method = 'get' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
         // $method - assemble from 'get' + property name
-        return method_exists($model, $method) || ($model instanceof MagicMethodsIntrospectionInterface && $model->hasMagicMethod($method))
+        return method_exists($model, $method)
             ? $model->$method()
             : ($model->isPropertyExists($name) ? $model->getterProperty($name) : null);
     }
 
-    /**
-     * Check if widget is visible
-     *
-     * @return boolean
-     */
-    protected function isVisible()
-    {
-        return parent::isVisible() || $this->isExported();
-    }
-
     /**
      * Add field into the list of excluded fields
      *
@@ -1632,11 +1673,11 @@ abstract class AModel extends \XLite\View\Dialog
      *
      * @return void
      */
-    protected function displayViewSubList($suffix, array $arguments = array())
+    protected function displayViewSubList($suffix, array $arguments = [])
     {
-        $class = preg_replace('/^.+\\\View\\\Model\\\/Ss', '', get_called_class());
+        $class = preg_replace('/^.+\\\View\\\Model\\\/Ss', '', static::class);
         $class = str_replace('\\', '.', $class);
-        if (preg_match('/\\\Module\\\(a-z0-9+)\\\(a-z0-9+)\\\View\\\Model\\\/Sis', get_called_class(), $match)) {
+        if (preg_match('/^(a-z0-9+)\\\(a-z0-9+)\\\View\\\Model\\\/Sis', static::class, $match)) {
             $class = $match[1] . '.' . $match[2] . '.' . $class;
         }
 
@@ -1650,7 +1691,7 @@ abstract class AModel extends \XLite\View\Dialog
     }
 
     /**
-     * Assemble biew sublist arguments
+     * Assemble view sublist arguments
      *
      * @param string $suffix    List suffix
      * @param array  $arguments Arguments
@@ -1688,7 +1729,7 @@ abstract class AModel extends \XLite\View\Dialog
     {
         $classes = preg_grep('/.+/Ss', array_map('trim', explode(' ', $field->getWrapperClass())));
 
-        if (1 === $index) {
+        if ($index === 1) {
             $classes[] = 'first';
         }
 
@@ -1700,6 +1741,13 @@ abstract class AModel extends \XLite\View\Dialog
             $classes[] = 'has-dependency';
         }
 
+        if (
+            !$this->showErrorsViaTopMessage()
+            && $this->getSavedErrorMessage($field->getName())
+        ) {
+            $classes[] = 'has-error';
+        }
+
         return implode(' ', $classes);
     }
 
@@ -1712,7 +1760,7 @@ abstract class AModel extends \XLite\View\Dialog
      */
     protected function getFieldCommentedData($filed)
     {
-        $commentedData = array();
+        $commentedData = [];
 
         if ($filed->getParam(static::SCHEMA_DEPENDENCY)) {
             $commentedData['dependency'] = $filed->getParam(static::SCHEMA_DEPENDENCY);
@@ -1735,10 +1783,9 @@ abstract class AModel extends \XLite\View\Dialog
 
         foreach ($dependency as $depType => $dependencies) {
             foreach ($dependencies as $depField => $depValue) {
-
-                if (static::DEPENDENCY_SHOW == $depType) {
+                if ($depType == static::DEPENDENCY_SHOW) {
                     if ($this->checkRequestHasExpectedValue($depField, $depValue)) {
-                        if (false !== $result) {
+                        if ($result !== false) {
                             $result = true;
                         }
                     } else {
@@ -1748,7 +1795,7 @@ abstract class AModel extends \XLite\View\Dialog
                     if ($this->checkRequestHasExpectedValue($depField, $depValue)) {
                         $result = false;
                     } else {
-                        if (false !== $result) {
+                        if ($result !== false) {
                             $result = true;
                         }
                     }
@@ -1781,7 +1828,7 @@ abstract class AModel extends \XLite\View\Dialog
     protected function isContentTrustedByPermission($fieldName, array $fieldData)
     {
         return \XLite\Core\Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
-            || \XLite\Core\Auth::getInstance()->isPermissionAllowed('unfiltered html');
+            || \XLite\Core\Auth::getInstance()->isPermissionAllowed('ROLE_UNFILTERED_HTML');
     }
 
     /**
