@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,94 +7,103 @@
 
 namespace XLite\View\Model;
 
+use XLite\View\FormField\FileUploader\AFileUploader;
+
 /**
  * Category view model
  */
 class Category extends \XLite\View\Model\AModel
 {
+    /**
+     * @var bool
+     */
+    private $correctCategories = false;
+
     /**
      * Schema default
      *
      * @var array
      */
-    protected $schemaDefault = array(
-        'name' => array(
+    protected $schemaDefault = [
+        'name' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
             self::SCHEMA_LABEL    => 'Category name',
             self::SCHEMA_REQUIRED => true,
-        ),
-        'parent' => array(
+        ],
+        'parent' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Select\Select2\Category',
             self::SCHEMA_LABEL    => 'Parent category',
             self::SCHEMA_REQUIRED => true,
-        ),
-        'show_title' => array(
+            \XLite\View\FormField\Select\Select2\Category::PARAM_OBJECT_CLASS_NAME => 'XLite\Model\Category',
+        ],
+        'show_title' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Select\CategoryShowTitle',
             self::SCHEMA_LABEL    => 'Show Category title',
             self::SCHEMA_REQUIRED => false,
-        ),
-        'image' => array(
-            self::SCHEMA_CLASS    => 'XLite\View\FormField\FileUploader\Image',
-            self::SCHEMA_LABEL    => 'Category icon',
-            self::SCHEMA_REQUIRED => false,
-        ),
-        'banner' => array(
+        ],
+        'image' => [
+            self::SCHEMA_CLASS               => 'XLite\View\FormField\FileUploader\Image',
+            self::SCHEMA_LABEL               => 'Category icon',
+            self::SCHEMA_REQUIRED            => false,
+            AFileUploader::PARAM_SVG_ALLOWED => true,
+        ],
+        'banner' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\FileUploader\Image',
             self::SCHEMA_LABEL    => 'Top banner',
             self::SCHEMA_REQUIRED => false,
-            \XLite\View\FormField\AFormField::PARAM_LABEL_HELP => 'Learn more about the top banner and how it shows in the page layout',
-        ),
-        'description' => array(
+            self::SCHEMA_HELP => 'Learn more about the top banner and how it shows in the page layout',
+        ],
+        'description' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Textarea\Advanced',
             self::SCHEMA_LABEL    => 'Description',
             self::SCHEMA_REQUIRED => false,
             self::SCHEMA_TRUSTED_PERMISSION => true,
             \XLite\View\FormField\Textarea\Advanced::PARAM_STYLE => 'category-description',
-        ),
-        'cleanURL' => array(
+        ],
+        'cleanURL' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text\CleanURL',
             self::SCHEMA_LABEL    => 'Clean URL',
             self::SCHEMA_REQUIRED => false,
-            \XLite\View\FormField\AFormField::PARAM_LABEL_HELP => 'Human readable and SEO friendly web address for the page.',
+            self::SCHEMA_HELP => 'Human readable and SEO friendly web address for the page.',
             \XLite\View\FormField\Input\Text\CleanURL::PARAM_OBJECT_CLASS_NAME => 'XLite\Model\Category',
-        ),
-        'meta_title' => array(
+        ],
+        'meta_title' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
             self::SCHEMA_LABEL    => 'Category page title',
             self::SCHEMA_REQUIRED => false,
             self::SCHEMA_COMMENT  => 'Leave blank to use category name as Page Title.',
-        ),
-        'meta_tags' => array(
+        ],
+        'meta_tags' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
             self::SCHEMA_LABEL    => 'Meta keywords',
             self::SCHEMA_REQUIRED => false,
-        ),
-        'meta_desc_type' => array(
+        ],
+        'meta_desc_type' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Select\MetaDescriptionType',
             self::SCHEMA_LABEL    => 'Meta description',
             self::SCHEMA_REQUIRED => false,
-        ),
-        'meta_desc' => array(
+        ],
+        'meta_desc' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Textarea\Simple',
             self::SCHEMA_LABEL    => '',
             self::SCHEMA_REQUIRED => true,
-            self::SCHEMA_DEPENDENCY => array(
-                self::DEPENDENCY_SHOW => array (
-                    'meta_desc_type' => array('C'),
-                ),
-            ),
-        ),
-        'memberships' => array(
+            self::SCHEMA_DEPENDENCY => [
+                self::DEPENDENCY_SHOW =>  [
+                    'meta_desc_type' => ['C'],
+                ],
+            ],
+        ],
+        'memberships' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Select\Memberships',
             self::SCHEMA_LABEL    => 'Memberships',
             self::SCHEMA_REQUIRED => false,
-        ),
-        'enabled' => array(
+        ],
+        'enabled' => [
             self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Checkbox\Enabled',
             self::SCHEMA_LABEL    => 'Enabled',
             self::SCHEMA_REQUIRED => false,
-        ),
-    );
+        ],
+    ];
 
     /**
      * Save current form reference and sections list, and initialize the cache
@@ -103,7 +111,7 @@ class Category extends \XLite\View\Model\AModel
      * @param array $params   Widget params OPTIONAL
      * @param array $sections Sections list OPTIONAL
      */
-    public function __construct(array $params = array(), array $sections = array())
+    public function __construct(array $params = [], array $sections = [])
     {
         if (\XLite\Model\Repo\CleanURL::isCategoryUrlHasExt()) {
             $this->schemaDefault['cleanURL'][\XLite\View\FormField\Input\Text\CleanURL::PARAM_EXTENSION] = \XLite\Model\Repo\CleanURL::CLEAN_URL_DEFAULT_EXTENSION;
@@ -151,9 +159,9 @@ class Category extends \XLite\View\Model\AModel
      */
     protected function getFieldBySchema($name, array $data)
     {
-        if ('meta_title' === $name) {
+        if ($name === 'meta_title') {
             $data[static::SCHEMA_PLACEHOLDER] = static::t('Default');
-        } else if ('enabled' === $name) {
+        } elseif ($name === 'enabled') {
             $data[static::SCHEMA_HELP] = static::t(
                 'If the category is disabled, the system will return 404.',
                 ['categoryLink' => $this->getModelObject()->getFrontUrl(true)]
@@ -174,7 +182,7 @@ class Category extends \XLite\View\Model\AModel
             ? \XLite\Core\Database::getRepo('XLite\Model\Category')->find($this->getModelId())
             : null;
 
-        return $model ?: new \XLite\Model\Category;
+        return $model ?: new \XLite\Model\Category();
     }
 
     /**
@@ -229,10 +237,7 @@ class Category extends \XLite\View\Model\AModel
             }
 
             $model->setParent($parent);
-            $model->update();
-
-            // Update lpos, rpos, depth properties of categories tree
-            \XLite\Core\Database::getRepo('XLite\Model\Category')->correctCategoriesStructure();
+            $this->correctCategories = true;
         }
 
         if (!$model->isPersistent()) {
@@ -246,6 +251,20 @@ class Category extends \XLite\View\Model\AModel
         }
     }
 
+    /**
+     * Correct categories structure after success saved
+     */
+    protected function postprocessSuccessActionUpdate()
+    {
+        if ($this->correctCategories) {
+            // Update lpos, rpos, depth properties of categories tree
+            \XLite\Core\Database::getRepo('XLite\Model\Category')->correctCategoriesStructure();
+            $this->correctCategories = false;
+        }
+
+        parent::postprocessSuccessActionUpdate();
+    }
+
     /**
      * Return name of web form widget class
      *
@@ -268,11 +287,11 @@ class Category extends \XLite\View\Model\AModel
         $label = $this->getModelObject()->isPersistent() ? 'Update' : 'Create';
 
         $result['submit'] = new \XLite\View\Button\Submit(
-            array(
+            [
                 \XLite\View\Button\AButton::PARAM_LABEL    => $label,
                 \XLite\View\Button\AButton::PARAM_BTN_TYPE => 'regular-main-button',
                 \XLite\View\Button\AButton::PARAM_STYLE    => 'action',
-            )
+            ]
         );
 
         return $result;
@@ -285,9 +304,8 @@ class Category extends \XLite\View\Model\AModel
      */
     protected function addDataSavedTopMessage()
     {
-        if ('create' !== $this->currentAction) {
+        if ($this->currentAction !== 'create') {
             \XLite\Core\TopMessage::addInfo('The category has been updated');
-
         } else {
             \XLite\Core\TopMessage::addInfo('The category has been added');
         }
