@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -24,13 +23,13 @@ class ModuleSettings extends \XLite\View\Model\Settings
 
         $returnTarget = \XLite\Core\Request::getInstance()->returnTarget;
 
-        if ('layout' === $returnTarget) {
+        if ($returnTarget === 'layout') {
             $result['layout'] = new \XLite\View\Button\SimpleLink(
-                array(
+                [
                     \XLite\View\Button\AButton::PARAM_LABEL => static::t('Back to layout settings'),
                     \XLite\View\Button\AButton::PARAM_STYLE => 'action addons-list-back-button',
                     \XLite\View\Button\Link::PARAM_LOCATION => $this->buildURL('layout'),
-                )
+                ]
             );
         }
 
