@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -10,6 +9,8 @@ namespace XLite\View\Model\Profile;
 
 use XLite\Core\Auth;
 use XLite\Core\Database;
+use XLite\Model\Profile;
+use XLite\Model\Role;
 
 /**
  * Administrator profile model widget. This widget is used in the admin interface
@@ -19,9 +20,9 @@ class AdminMain extends \XLite\View\Model\AModel
     /**
      * Form sections
      */
-    const SECTION_SUMMARY = 'summary';
-    const SECTION_MAIN    = 'main';
-    const SECTION_ACCESS  = 'access';
+    public const SECTION_SUMMARY = 'summary';
+    public const SECTION_MAIN    = 'main';
+    public const SECTION_ACCESS  = 'access';
 
     /**
      * Schema of the "Account summary" section
@@ -72,7 +73,7 @@ class AdminMain extends \XLite\View\Model\AModel
             ],
         ],
         'password'      => [
-            self::SCHEMA_CLASS            => '\XLite\View\FormField\Input\Password',
+            self::SCHEMA_CLASS            => '\XLite\View\FormField\Input\PasswordWithButton',
             self::SCHEMA_LABEL            => 'Password',
             self::SCHEMA_REQUIRED         => false,
             self::SCHEMA_MODEL_ATTRIBUTES => [
@@ -83,7 +84,7 @@ class AdminMain extends \XLite\View\Model\AModel
             ],
         ],
         'password_conf' => [
-            self::SCHEMA_CLASS            => '\XLite\View\FormField\Input\Password',
+            self::SCHEMA_CLASS            => '\XLite\View\FormField\Input\PasswordWithButton',
             self::SCHEMA_LABEL            => 'Confirm password',
             self::SCHEMA_REQUIRED         => false,
             self::SCHEMA_MODEL_ATTRIBUTES => [
@@ -221,7 +222,7 @@ class AdminMain extends \XLite\View\Model\AModel
      */
     public function isValid()
     {
-        return ('validateInput' === $this->currentAction) ?: parent::isValid();
+        return ($this->currentAction === 'validateInput') ?: parent::isValid();
     }
 
     /**
@@ -249,12 +250,10 @@ class AdminMain extends \XLite\View\Model\AModel
         $value = parent::getDefaultFieldValue($name);
 
         switch ($name) {
-
             case 'added':
             case 'last_login':
                 if (0 < $value) {
                     $value = \XLite\Core\Converter::formatTime($value);
-
                 } else {
                     $value = 'never';
                 }
@@ -281,7 +280,6 @@ class AdminMain extends \XLite\View\Model\AModel
                     } else {
                         $value = '<span>' . $value . '</span>';
                     }
-
                 } else {
                     $value = '0&nbsp;';
                 }
@@ -298,22 +296,26 @@ class AdminMain extends \XLite\View\Model\AModel
                 break;
 
             case 'roles':
-                if ($this->getModelObject()
+                if (
+                    $this->getModelObject()
                     && Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
                     && Auth::getInstance()->getProfile()->getProfileId() == $this->getModelObject()->getProfileId()
+                    && $value
                 ) {
-                    if ($value) {
-                        $roles = [];
-                        /** @var \XLite\Model\Role $role */
-                        foreach ($value as $role) {
-                            $roles[] = $role->getPublicName();
-                        }
-
-                        $value = implode(', ', $roles);
+                    $roles = [];
+                    /** @var \XLite\Model\Role $role */
+                    foreach ($value as $role) {
+                        $roles[] = $role->getPublicName();
                     }
+
+                    $value = implode(', ', $roles);
                 }
 
-                if (!$value) {
+                if ($this->getModelObject()->getProfileId()) {
+                    break;
+                }
+
+                if (!$value || (is_object($value) && !count($value))) {
                     $rootRole = \XLite\Core\Database::getRepo('XLite\Model\Role')->findOneRoot();
 
                     if ($rootRole) {
@@ -339,7 +341,7 @@ class AdminMain extends \XLite\View\Model\AModel
     protected function isOrdersLinkAvailable()
     {
         return Auth::getInstance()->hasRootAccess()
-            || Auth::getInstance()->isPermissionAllowed('manage orders');
+            || Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_ORDERS');
     }
 
     /**
@@ -351,19 +353,18 @@ class AdminMain extends \XLite\View\Model\AModel
      */
     protected function isShowSectionHeader($section)
     {
-        return parent::isShowSectionHeader($section) && !in_array($section, array(self::SECTION_SUMMARY));
+        return parent::isShowSectionHeader($section) && $section != self::SECTION_SUMMARY;
     }
 
     /**
      * This object will be used if another one is not passed
      *
-     * @return \XLite\Model\Profile
+     * @return Profile
      */
     protected function getDefaultModelObject()
     {
         if ($this->isRegisterMode()) {
-            $obj = new \XLite\Model\Profile();
-
+            $obj = new Profile();
         } else {
             $obj = \XLite\Core\Database::getRepo('XLite\Model\Profile')->find($this->getProfileId());
         }
@@ -398,7 +399,7 @@ class AdminMain extends \XLite\View\Model\AModel
      */
     protected function getFormFieldsForSectionMain()
     {
-        /** @var \XLite\Model\Profile $profile */
+        /** @var Profile $profile */
         $profile = $this->getModelObject();
 
         if ($profile) {
@@ -428,7 +429,8 @@ class AdminMain extends \XLite\View\Model\AModel
                 }
             }
 
-            if ($profile->getProfileId()
+            if (
+                $profile->getProfileId()
                 && $profile->getProfileId() === Auth::getInstance()->getProfile()->getProfileId()
             ) {
                 $this->mainSchema['login'][\XLite\View\FormField\AFormField::PARAM_EDIT_ON_CLICK] = true;
@@ -446,7 +448,7 @@ class AdminMain extends \XLite\View\Model\AModel
 
                     if ($name === 'password') {
                         $mainSchema['password_current'] = [
-                            self::SCHEMA_CLASS            => 'XLite\View\FormField\Input\Password',
+                            self::SCHEMA_CLASS            => 'XLite\View\FormField\Input\PasswordWithButton',
                             self::SCHEMA_LABEL            => 'Current password',
                             self::SCHEMA_MODEL_ATTRIBUTES => [
                                 \XLite\View\FormField\Input\Base\StringInput::PARAM_MAX_LENGTH => 'length',
@@ -456,7 +458,7 @@ class AdminMain extends \XLite\View\Model\AModel
                             ],
                         ];
 
-                        if (null === $this->currentAction) {
+                        if ($this->currentAction === null) {
                             $mainSchema['password_current'][self::SCHEMA_REQUIRED] = true;
                         }
                     }
@@ -476,16 +478,21 @@ class AdminMain extends \XLite\View\Model\AModel
      */
     protected function getFormFieldsForSectionAccess()
     {
+        if (
+            !Auth::getInstance()->hasRootAccess()
+            && (int) Auth::getInstance()->getProfile()->getProfileId() === (int) $this->getModelObject()->getProfileId()
+        ) {
+            return null;
+        }
+
         // Logged user cannot see own status
         if ($this->isLoggedProfile() || $this->getModelObject()->getAnonymous()) {
-            unset($this->accessSchema['status']);
-            unset($this->accessSchema['statusComment']);
+            unset($this->accessSchema['status'], $this->accessSchema['statusComment']);
         }
 
         // New profile cannot see pending membership
         if ($this->isRegisterMode()) {
             unset($this->accessSchema['pending_membership_id']);
-
         } else {
             $this->accessSchema['access_level'][static::SCHEMA_CLASS] = '\XLite\View\FormField\Label';
             $this->accessSchema['access_level'][static::SCHEMA_REQUIRED] = false;
@@ -501,20 +508,26 @@ class AdminMain extends \XLite\View\Model\AModel
             }
         }
 
-        if (!Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
+        $auth = Auth::getInstance();
+
+        $roles = \XLite\Model\Repo\Role::getAvailableRoles();
+
+        if (
+            !Auth::getInstance()->isPermissionAllowed('ROLE_MANAGE_ADMINS')
             || (
                 $this->getModelObject()
                 && $this->getModelObject()->getProfileId()
                 && !$this->getModelObject()->isAdmin()
             )
-            || (2 > \XLite\Core\Database::getRepo('XLite\Model\Role')->count())
+            || (empty($roles))
         ) {
             unset($this->accessSchema['roles']);
         }
 
-        if ($this->getModelObject()
-            && Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS)
-            && Auth::getInstance()->getProfile()->getProfileId() == $this->getModelObject()->getProfileId()
+        if (
+            $this->getModelObject()
+            && $auth->hasRootAccess()
+            && $auth->getProfile()->getProfileId() === $this->getModelObject()->getProfileId()
         ) {
             unset($this->accessSchema['forceChangePassword']);
             $this->accessSchema['roles'][static::SCHEMA_CLASS] = '\XLite\View\FormField\Label';
@@ -537,7 +550,6 @@ class AdminMain extends \XLite\View\Model\AModel
             $referer = $this->getModelObjectValue('referer');
             if (empty($referer)) {
                 unset($this->summarySchema['referer']);
-
             } else {
                 if (empty($this->summarySchema['referer'][static::SCHEMA_ATTRIBUTES])) {
                     $this->summarySchema['referer'][static::SCHEMA_ATTRIBUTES] = [];
@@ -561,14 +573,14 @@ class AdminMain extends \XLite\View\Model\AModel
      */
     protected function getModelObjectValue($name)
     {
-        if ('access_level' === $name) {
+        if ($name === 'access_level') {
             $field = $this->getFormField('access', 'access_level');
             if ($field && $field instanceof \XLite\View\FormField\Label) {
                 $value = $this->getAccessLevelAsText();
             }
         }
 
-        return isset($value) ? $value : parent::getModelObjectValue($name);
+        return $value ?? parent::getModelObjectValue($name);
     }
 
     /**
@@ -580,7 +592,6 @@ class AdminMain extends \XLite\View\Model\AModel
     {
         if (Auth::getInstance()->getAdminAccessLevel() <= $this->getModelObject()->getAccessLevel()) {
             $label = static::t('Administrator');
-
         } elseif ($this->getModelObject()->getAnonymous()) {
             $sameProfile = \XLite\Core\Database::getRepo('XLite\Model\Profile')
                 ->findUserWithSameLogin($this->getModelObject());
@@ -591,11 +602,9 @@ class AdminMain extends \XLite\View\Model\AModel
                         'URL' => static::buildURL('profile', '', ['profile_id' => $sameProfile->getProfileId()]),
                     ]
                 );
-
             } else {
                 $label = static::t('Anonymous Customer');
             }
-
         } else {
             $sameProfile = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findOneBy([
                 'login'     => $this->getModelObject()->getLogin(),
@@ -609,7 +618,6 @@ class AdminMain extends \XLite\View\Model\AModel
                         'URL' => static::buildURL('profile', '', ['profile_id' => $sameProfile->getProfileId()]),
                     ]
                 );
-
             } else {
                 $label = static::t('Registered Customer');
             }
@@ -631,6 +639,11 @@ class AdminMain extends \XLite\View\Model\AModel
                || Auth::getInstance()->getProfile()->getProfileId() == $request->profile_id;
     }
 
+    protected function isAllowedToEditAdminProfiles(): bool
+    {
+        return Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS);
+    }
+
     /**
      * Populate model object properties by the passed data
      *
@@ -642,6 +655,14 @@ class AdminMain extends \XLite\View\Model\AModel
     {
         $adminAccessLevel = Auth::getInstance()->getAdminAccessLevel();
 
+        if (
+            !empty($data['language'])
+            && strlen($data['language']) >= 3
+        ) {
+            // WA for XCB-344. Block incoming values like en_US xlite_profiles.language is varchar(2)
+            unset($data['language']);
+        }
+
         if (!empty($data['password'])) {
             // Encrypt password if if is not empty
             $data['password'] = Auth::encryptPassword($data['password']);
@@ -664,16 +685,36 @@ class AdminMain extends \XLite\View\Model\AModel
             $data['forceChangePassword'] = (bool)$data['forceChangePassword'];
         }
 
-        $isRoot = Auth::getInstance()->isPermissionAllowed(\XLite\Model\Role\Permission::ROOT_ACCESS);
+        $isAllowedToEditAdminProfiles = $this->isAllowedToEditAdminProfiles();
+
+        $profileId = $this->getModelObject()->getProfileId();
+        $unavailableRoles = array_filter(
+            Database::getRepo('XLite\Model\Role')->findBy([
+                'id' => array_map(
+                    static fn(Role $role): int => $role->getId(),
+                    \XLite\Model\Repo\Role::getUnavailableRoles()
+                )
+            ]),
+            static fn(Role $role): bool => in_array(
+                $profileId,
+                array_map(
+                    static fn(Profile $profile): int => $profile->getProfileId(),
+                    $role->getProfiles()->toArray()
+                )
+            )
+        );
 
         if (
             isset($data['roles'])
-            && (!$isRoot || (isset($data['access_level']) && $adminAccessLevel != $data['access_level']))
+            && (
+                !$isAllowedToEditAdminProfiles
+                || (isset($data['access_level']) && $adminAccessLevel != $data['access_level'])
+            )
         ) {
             unset($data['roles']);
         }
 
-        /** @var \XLite\Model\Profile $model */
+        /** @var Profile $model */
         $model = $this->getModelObject();
 
         // Assign only role for admin
@@ -691,11 +732,12 @@ class AdminMain extends \XLite\View\Model\AModel
             }
         }
 
-        if ($isAdmin && !isset($data['roles']) && $isRoot && !$this->isLoggedProfile()) {
+        if ($isAdmin && !isset($data['roles']) && $isAllowedToEditAdminProfiles && !$this->isLoggedProfile()) {
             $data['roles'] = [];
         }
 
-        if (isset($data['roles'])
+        if (
+            isset($data['roles'])
             || (isset($data['access_level']) && $adminAccessLevel != $data['access_level'])
             || ($model->getProfileId() && !$model->isAdmin())
         ) {
@@ -718,12 +760,12 @@ class AdminMain extends \XLite\View\Model\AModel
             }
         }
 
-        if (isset($data['roles'])) {
-            unset($data['roles']);
+        foreach ($unavailableRoles as $role) {
+            $role->addProfiles($model);
         }
 
-        if (isset($data['login']) && $data['login'] !== $model->getLogin() && $model->getOrdersCount()) {
-            \XLite\Core\Database::getRepo('XLite\Model\Profile')->updateOrderProfileEmailByOrigProfile($model, $data['login']);
+        if (isset($data['roles'])) {
+            unset($data['roles']);
         }
 
         parent::setModelProperties($data);
@@ -747,16 +789,16 @@ class AdminMain extends \XLite\View\Model\AModel
     /**
      * Check - need set root access or not
      *
-     * @param \XLite\Model\Profile $profile Profile
+     * @param Profile $profile Profile
      *
      * @return boolean
      */
-    protected function needSetRootAccess(\XLite\Model\Profile $profile)
+    protected function needSetRootAccess(Profile $profile)
     {
         $onlyOneRootAdmin = false;
 
         if ($profile->getProfileId()) {
-            $cnd = new \XLite\Core\CommonCell;
+            $cnd = new \XLite\Core\CommonCell();
             $cnd->permissions = \XLite\Model\Role\Permission::ROOT_ACCESS;
             $i = 0;
             foreach (\XLite\Core\Database::getRepo('XLite\Model\Profile')->search($cnd) as $p) {
@@ -771,10 +813,23 @@ class AdminMain extends \XLite\View\Model\AModel
             }
         }
 
-        return 1 == \XLite\Core\Database::getRepo('XLite\Model\Role')->count()
+        return \XLite\Core\Database::getRepo('XLite\Model\Role')->count() == 1
                || $onlyOneRootAdmin;
     }
 
+    /**
+     * Prepare error message before display
+     *
+     * @param string $message Message itself
+     * @param array  $data    Current section data
+     *
+     * @return string
+     */
+    protected function prepareErrorMessage($message, array $data): string
+    {
+        return $this->showErrorsViaTopMessage() ? $message : parent::prepareErrorMessage($message, $data);
+    }
+
     /**
      * Prepare request data for mapping profile object
      *
@@ -810,26 +865,27 @@ class AdminMain extends \XLite\View\Model\AModel
         $result = true;
         $data = $this->getRequestData();
 
-        /** @var \XLite\Model\Profile $model */
+        /** @var Profile $model */
         $model = $this->getModelObject();
 
-        if ($model
+        if (
+            $model
             && $model->getProfileId() === Auth::getInstance()->getProfile()->getProfileId()
         ) {
             $result = true;
-        } elseif (isset($this->sections[self::SECTION_MAIN])
+        } elseif (
+            isset($this->sections[self::SECTION_MAIN])
             && (!empty($data['password']) || !empty($data['password_conf']))
         ) {
-            if ($data['password'] != $data['password_conf']) {
+            if ($data['password'] !== $data['password_conf']) {
                 $result = false;
                 $formFields = $this->getFormFields();
                 $this->addErrorMessage(
                     'password',
-                    'Password and its confirmation do not match',
+                    static::t('Password and its confirmation do not match'),
                     $formFields[self::SECTION_MAIN]
                 );
             }
-
         } else {
             $this->excludeField('password');
             $this->excludeField('password_conf');
@@ -838,6 +894,37 @@ class AdminMain extends \XLite\View\Model\AModel
         return $result;
     }
 
+    /**
+     * @param \XLite\View\FormField\AFormField $field      Form field object
+     * @param array                            $formFields
+     *
+     * @return bool
+     */
+    protected function validateFormFieldPasswordValue($field, $formFields)
+    {
+        $result = true;
+
+        $data = $this->getRequestData();
+
+        /** @var Profile $model */
+        $model = $this->getModelObject();
+
+        if (
+            $data && $model
+            && !empty($data['password'])
+            && (!Profile::isAppropriatePasswordLength($data['password']))
+        ) {
+            $result = false;
+            $this->addErrorMessage(
+                'password',
+                Profile::getPasswordLengthError(),
+                $formFields[self::SECTION_MAIN]
+            );
+        }
+
+        return $result;
+    }
+
     /**
      * @param \XLite\View\FormField\AFormField $field      Form field object
      * @param array                            $formFields
@@ -850,17 +937,20 @@ class AdminMain extends \XLite\View\Model\AModel
 
         $data = $this->getRequestData();
 
-        /** @var \XLite\Model\Profile $model */
+        /** @var Profile $model */
         $model = $this->getModelObject();
 
-        if ($data
+        if (
+            $data
             && $model
             && $model->getProfileId() === Auth::getInstance()->getProfile()->getProfileId()
         ) {
             $savedData = \XLite\Core\Database::getRepo('XLite\Model\Profile')->getArrayData($model->getProfileId());
 
-            if (($data['login'] !== $savedData['login'] || !empty($data['password']))
-                && !Auth::comparePassword($savedData['password'], $data['password_current'])) {
+            if (
+                ($data['login'] !== $savedData['login'] || !empty($data['password']))
+                && !Auth::comparePassword($savedData['password'], $data['password_current'])
+            ) {
                 $result = [false, 'Incorrect password. Please try again.'];
             }
         }
@@ -886,7 +976,7 @@ class AdminMain extends \XLite\View\Model\AModel
                 $formFields = $this->getFormFields();
                 $this->addErrorMessage(
                     'login',
-                    'User with specified email is already registered',
+                    static::t('User with specified email is already registered'),
                     $formFields[self::SECTION_MAIN]
                 );
                 $result = false;
@@ -995,8 +1085,19 @@ class AdminMain extends \XLite\View\Model\AModel
         $data = $this->getRequestData();
         $result = $this->checkPassword() ? parent::performActionUpdate() : false;
 
-        if ($result && !empty($data['password']) && $profile = $this->getModelObject()) {
-            $profile->logoffSessions(true);
+        /** @var Profile $profile */
+        $profile = $this->getModelObject();
+
+        if ($result && $profile) {
+            if (
+                isset($data['login'])
+                && $profile->getOldLogin()
+                && $data['login'] !== $profile->getOldLogin()
+                && $profile->getOrdersCount()
+            ) {
+                Database::getRepo('XLite\Model\Profile')
+                    ->updateOrderProfileEmailByOrigProfile($profile, $data['login'], $profile->getOldLogin());
+            }
         }
 
         return $result;
@@ -1005,23 +1106,14 @@ class AdminMain extends \XLite\View\Model\AModel
     /**
      * Perform certain action for the model object
      *
-     * @return boolean
-     */
-    protected function performActionDelete()
-    {
-        return parent::performActionDelete();
-    }
-
-    /**
-     * Perform certain action for the model object
-     *
-     * @return boolean
+     * @return mixed
      */
     protected function performActionValidateInput()
     {
-        $result = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findUserWithSameLogin($this->getModelObject());
-
-        return $result;
+        return \XLite\Core\Database::getRepo('XLite\Model\Profile')
+            ->findUserWithSameLogin(
+                $this->getModelObject()
+            );
     }
 
     /**
@@ -1053,7 +1145,8 @@ class AdminMain extends \XLite\View\Model\AModel
     {
         $result = parent::getButtonPanelClass();
 
-        if ($this->getModelObject()
+        if (
+            $this->getModelObject()
             && $this->getModelObject()->isPersistent()
             && $this->getModelObject()->getAnonymous()
             && !$this->getModelObject()->getOrder()
@@ -1073,7 +1166,7 @@ class AdminMain extends \XLite\View\Model\AModel
 
         if ($duplicate) {
             $this->addErrorMessage('login', static::t(
-                'This e-mail address is already in use by another user.'
+                'This user e-mail already exists'
             ));
         }
     }
@@ -1099,7 +1192,8 @@ class AdminMain extends \XLite\View\Model\AModel
 
         $same = \XLite\Core\Database::getRepo('XLite\Model\Profile')->findUserWithSameLogin($this->getModelObject());
 
-        if ($this->getModelObject()
+        if (
+            $this->getModelObject()
             && $this->getModelObject()->isPersistent()
             && $this->getModelObject()->getAnonymous()
             && !$this->getModelObject()->getOrder()
@@ -1116,7 +1210,6 @@ class AdminMain extends \XLite\View\Model\AModel
                         ],
                     ]
                 );
-
             } elseif ($same && !$same->isAdmin()) {
                 $result['merge'] = new \XLite\View\Button\Regular(
                     [
@@ -1130,4 +1223,12 @@ class AdminMain extends \XLite\View\Model\AModel
 
         return $result;
     }
+
+    /**
+     * @return boolean
+     */
+    public function showErrorsViaTopMessage()
+    {
+        return true;
+    }
 }
