@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,10 @@
 
 namespace XLite\View\Model;
 
+use XLite\Core\Auth;
+use XLite\Model\Role\Permission;
+use XCart\Domain\ServiceDataDomain;
+
 /**
  * Settings dialog model widget
  */
@@ -20,7 +23,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected $rowIndexDelta = 0;
 
-    public function __construct(array $params = array(), array $sections = array())
+    public function __construct(array $params = [], array $sections = [])
     {
         $this->sections = $this->getSectionFromOptions();
 
@@ -30,11 +33,11 @@ class Settings extends \XLite\View\Model\AModel
     protected function getSectionFromOptions()
     {
         $sections = ['default' => null];
-        $index = 0;
+        $index    = 0;
 
         foreach ($this->getOptions() as $option) {
-            if ('separator' === $option->getType()) {
-                if (0 === $index) {
+            if ($option->getType() === 'separator') {
+                if ($index === 0) {
                     $sections = [$option->getName() => $option->getOptionName()];
                 } else {
                     $sections[$option->getName()] = $option->getOptionName();
@@ -71,7 +74,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     public function getCSSFiles()
     {
-        $list = parent::getCSSFiles();
+        $list   = parent::getCSSFiles();
         $list[] = 'settings/summary/summary.css';
         if (\XLite\Core\Request::getInstance()->page == 'CleanURL') {
             $list[] = 'settings/clean_url/style.less';
@@ -91,7 +94,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     public function getSchemaFields()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getOptions() as $option) {
             $cell = $this->getFormFieldByOption($option);
@@ -112,13 +115,12 @@ class Settings extends \XLite\View\Model\AModel
      */
     public function getSchemaFieldsForSection($section)
     {
-        $flag = 'default' === $section;
+        $flag = $section === 'default';
         $list = [];
 
         foreach ($this->getOptions() as $option) {
-
             if ($flag) {
-                if ('separator' === $option->getType()) {
+                if ($option->getType() === 'separator') {
                     break;
                 }
 
@@ -126,7 +128,7 @@ class Settings extends \XLite\View\Model\AModel
                 if ($cell) {
                     $list[$option->getName()] = $cell;
                 }
-            } elseif ('separator' === $option->getType()) {
+            } elseif ($option->getType() === 'separator') {
                 $flag = $option->getName() === $section;
             }
         }
@@ -143,7 +145,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function getFormFieldByOption(\XLite\Model\Config $option)
     {
-        $cell = null;
+        $cell  = null;
         $class = $this->detectFormFieldClassByOption($option);
 
         if ($class) {
@@ -173,7 +175,7 @@ class Settings extends \XLite\View\Model\AModel
     protected function detectFormFieldClassByOption(\XLite\Model\Config $option)
     {
         $class = null;
-        $type = $option->getType() ?: 'text';
+        $type  = $option->getType() ?: 'text';
 
         switch ($type) {
             case 'textarea':
@@ -208,7 +210,7 @@ class Settings extends \XLite\View\Model\AModel
                 break;
 
             default:
-                if (preg_match('/^\\\?XLite\\\/S', $option->getType())) {
+                if (strpos($option->getType(), '\\') !== false) {
                     $class = $option->getType();
                 }
         }
@@ -229,7 +231,7 @@ class Settings extends \XLite\View\Model\AModel
             'site_administrator',
             'support_department',
             'users_department',
-            'orders_department'
+            'orders_department',
         ];
 
         if (in_array($option->getName(), $emailOptions, true)) {
@@ -280,16 +282,16 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function getCountryStateSelectorFields()
     {
-        return array(
-            'location_country' => array(
+        return [
+            'location_country'  => [
                 'location_state',
                 'location_custom_state',
-            ),
-            'anonymous_country' => array(
+            ],
+            'anonymous_country' => [
                 'anonymous_state',
                 'anonymous_custom_state',
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -326,7 +328,7 @@ class Settings extends \XLite\View\Model\AModel
     {
         $data = $this->getCountryStateSelectorFields();
 
-        foreach ($data as $countryField => $stateFields) {
+        foreach ($data as $stateFields) {
             if ($stateFields[1] === $field->getName()) {
                 $this->rowIndexDelta++;
             }
@@ -344,34 +346,34 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function getFormButtons()
     {
-        $result = parent::getFormButtons();
+        $result           = parent::getFormButtons();
         $result['submit'] = new \XLite\View\Button\Submit(
-            array(
+            [
                 \XLite\View\Button\AButton::PARAM_LABEL    => 'Submit',
                 \XLite\View\Button\AButton::PARAM_BTN_TYPE => 'regular-main-button',
                 \XLite\View\Button\AButton::PARAM_STYLE    => 'action',
-            )
+            ]
         );
 
-        if ('css_js_performance' === $this->getTarget()) {
+        if ($this->getTarget() === 'css_js_performance') {
             $url = $this->buildURL('css_js_performance', 'clean_aggregation_cache');
             $result['clear_aggregation_cache'] = new \XLite\View\Button\Tooltip(
-                array(
+                [
                     \XLite\View\Button\AButton::PARAM_LABEL => 'Clean aggregation cache',
                     \XLite\View\Button\AButton::PARAM_STYLE => 'action always-enabled',
                     \XLite\View\Button\Tooltip::PARAM_SEPARATE_TOOLTIP => static::t('Clean aggregation cache help text'),
                     \XLite\View\Button\Regular::PARAM_JS_CODE => 'self.location=\'' . $url . '\'',
-                )
+                ]
             );
 
-            $url = $this->buildURL('css_js_performance', 'clean_view_cache');
+            $url                           = $this->buildURL('css_js_performance', 'clean_view_cache');
             $result['clear_widgets_cache'] = new \XLite\View\Button\Tooltip(
-                array(
+                [
                     \XLite\View\Button\AButton::PARAM_LABEL => 'Clean widgets cache',
                     \XLite\View\Button\AButton::PARAM_STYLE => 'action always-enabled',
                     \XLite\View\Button\Tooltip::PARAM_SEPARATE_TOOLTIP => static::t('Clean widgets cache help text'),
                     \XLite\View\Button\Regular::PARAM_JS_CODE => 'self.location=\'' . $url . '\'',
-                )
+                ]
             );
         }
 
@@ -385,9 +387,40 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function performActionUpdate()
     {
+        \XLite\Core\Config::dropRuntimeCache();
+
         return true;
     }
 
+    /**
+     * @return array
+     */
+    protected function prepareDataForMapping()
+    {
+        /** @var array $data */
+        $data = parent::prepareDataForMapping();
+
+        $apiKeys = [];
+        if (!empty($data['token_all'])) {
+            $apiKeys[] = $data['token_all'];
+        }
+
+        if (!empty($data['token_read'])) {
+            $apiKeys[] = $data['token_read'];
+        }
+
+        if (!empty($data['storefront_token'])) {
+            $apiKeys[] = $data['storefront_token'];
+        }
+
+        if (count($apiKeys) !== count(array_unique($apiKeys))) {
+            $this->addErrorMessage('tokens', self::t('API keys must be unique'));
+            unset($data['token_all'], $data['token_read'], $data['storefront_token']);
+        }
+
+        return $data;
+    }
+
     /**
      * Retrieve property from the model object
      *
@@ -422,8 +455,26 @@ class Settings extends \XLite\View\Model\AModel
 
         $this->updateOptions($optionsToUpdate);
 
-        if (isset($data['upgrade_wave'])) {
-            \XLite\Core\Marketplace::getInstance()->setWave($data['upgrade_wave']);
+        if (isset($data['site_administrator'])) {
+            /** @var ServiceDataDomain $serviceDataDomain */
+            $serviceDataDomain = \XCart\Container::getContainer()->get(ServiceDataDomain::class);
+
+            $emails = @unserialize($data['site_administrator'], ['allowed_classes' => false]);
+            $serviceDataDomain->setData('xcart.marketplace.admin-email', $emails[0] ?? '');
+        }
+
+        if (isset($data['location_country'])) {
+            /** @var ServiceDataDomain $serviceDataDomain */
+            $serviceDataDomain = \XCart\Container::getContainer()->get(ServiceDataDomain::class);
+
+            $serviceDataDomain->setData('xcart.marketplace.shop-country', $data['location_country']);
+        }
+
+        if (
+            isset($data['location_country'])
+            && Auth::getInstance()->isPermissionAllowed(Permission::ROOT_ACCESS)
+        ) {
+            \XLite\Core\Marketplace::getInstance()->clearCache();
         }
     }
 
@@ -436,7 +487,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function getOptionsToUpdate(array $data)
     {
-        $result = array();
+        $result = [];
 
         // Find changed options and store them in $optionsToUpdate
         foreach ($this->getEditableOptions() as $key => $option) {
@@ -444,12 +495,14 @@ class Settings extends \XLite\View\Model\AModel
                 continue;
             }
 
-            $name  = $option->getName();
-            $newValue = $this->sanitizeOptionValue($option, isset($data[$name]) ? $data[$name] : null);
+            $name = $option->getName();
+            if (array_key_exists($name, $data)) {
+                $newValue = $this->sanitizeOptionValue($option, $data[$name]);
 
-            if ($this->isChanged($option, $newValue)) {
-                $option->setNewValue($newValue);
-                $result[] = $option;
+                if ($this->isChanged($option, $newValue)) {
+                    $option->setNewValue($newValue);
+                    $result[] = $option;
+                }
             }
         }
 
@@ -468,13 +521,13 @@ class Settings extends \XLite\View\Model\AModel
         foreach ($options as $option) {
             if ($this->preprocessOption($option)) {
                 \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption(
-                    array(
+                    [
                         'category' => $option->getCategory(),
                         'name'     => $option->getName(),
                         'type'     => $option->getType(),
                         'value'    => $option->getNewValue(),
                         'orderby'  => $option->getOrderby(),
-                    )
+                    ]
                 );
             }
         }
@@ -491,7 +544,7 @@ class Settings extends \XLite\View\Model\AModel
     {
         $result = true;
 
-        $method = 'preprocess' . \XLite\Core\Converter::convertToCamelCase($option->name) . 'Option';
+        $method = 'preprocess' . \Includes\Utils\Converter::convertToUpperCamelCase($option->name) . 'Option';
 
         if (method_exists($this, $method)) {
             $result = $this->$method($option);
@@ -514,7 +567,7 @@ class Settings extends \XLite\View\Model\AModel
         }
 
         $requiredExtensions = ['DOM', 'GD'];
-        $missedExtensions = [];
+        $missedExtensions   = [];
 
         foreach ($requiredExtensions as $extension) {
             if (!extension_loaded($extension)) {
@@ -557,9 +610,12 @@ class Settings extends \XLite\View\Model\AModel
     protected function getNotEditableOptionTypes()
     {
         return [
-            'separator',
+            'XLite\View\FormField\Input\TextProxiedLabel',
+            'XLite\View\FormField\Label\TranslationLabel',
+            'XLite\View\FormField\Textarea\AdvancedProxiedLabel',
+            'XLite\View\FormField\Textarea\SimpleProxiedLabel',
             'hidden',
-            'XLite\View\FormField\Label\TranslationLabel'
+            'separator',
         ];
     }
 
@@ -593,7 +649,7 @@ class Settings extends \XLite\View\Model\AModel
      */
     protected function isChanged($option, $value)
     {
-        return null !== $value && $option->getValue() !== $value;
+        return $value !== null && $option->getValue() !== $value;
     }
 
     /**
@@ -607,11 +663,11 @@ class Settings extends \XLite\View\Model\AModel
     protected function sanitizeOptionValue($option, $value)
     {
         $category = $option->getCategory();
-        $name = $option->getName();
+        $name     = $option->getName();
 
         $validationMethod = 'sanitize'
-            . str_replace("\\", '', \Includes\Utils\Converter::convertToCamelCase($category))
-            . \Includes\Utils\Converter::convertToCamelCase($name);
+            . str_replace("\\", '', \Includes\Utils\Converter::convertToUpperCamelCase($category))
+            . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
         if (method_exists($this, $validationMethod)) {
             $value = $this->$validationMethod($value);
@@ -619,20 +675,16 @@ class Settings extends \XLite\View\Model\AModel
 
         $type = $option->getType();
 
-        if ('checkbox' === $type) {
+        if ($type === 'checkbox') {
             $result = empty($value) ? 'N' : 'Y';
-
-        } elseif ('serialized' === $type && null !== $value && is_array($value)) {
+        } elseif ($type === 'serialized' && $value !== null && is_array($value)) {
             $result = serialize($value);
-
-        } elseif ('text' === $type) {
-            $result = null !== $value ? trim($value) : '';
-
-        } elseif('XLite\View\FormField\Input\PasswordWithValue' === $type) {
-            $result = null !== $value ? $value : null;
-
+        } elseif ($type === 'text') {
+            $result = $value !== null ? trim($value) : '';
+        } elseif ($type === 'XLite\View\FormField\Input\PasswordWithValue') {
+            $result = $value ?? null;
         } else {
-            $result = null !== $value ? $value : '';
+            $result = $value ?? '';
         }
 
         return $result;
@@ -663,7 +715,7 @@ class Settings extends \XLite\View\Model\AModel
     protected function defineSectionWidget($section, $params)
     {
         if ($this->isSectionCollapsible($section)) {
-            $params['section'] = $section;
+            $params['section']   = $section;
             $params['collapsed'] = $this->isSectionCollapsed($section);
 
             return new \XLite\View\FormField\Separator\Collapsible($params);
