@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -10,6 +9,7 @@ namespace XLite\View\Order\Details\Admin;
 
 use XLite\Core\PreloadedLabels\ProviderInterface;
 use XLite\Model\Order;
+use XLite\Model\Payment\BackendTransaction;
 
 /**
  * Order info
@@ -48,8 +48,8 @@ class Info extends \XLite\View\AView implements ProviderInterface
         $list = parent::getCSSFiles();
 
         $list[] = 'order/page/info.less';
-        $list[] = 'address/order/style.css';
-        $list[] = 'select_address/style.css';
+        $list[] = 'address/order/style.less';
+        $list[] = 'select_address/style.less';
 
         return $list;
     }
@@ -122,7 +122,7 @@ class Info extends \XLite\View\AView implements ProviderInterface
         return \XLite\Core\Converter::buildURL(
             'profile',
             '',
-            array('profile_id' => $this->getOrder()->getOrigProfile()->getProfileId())
+            ['profile_id' => $this->getOrder()->getOrigProfile()->getProfileId()]
         );
     }
 
@@ -166,6 +166,16 @@ class Info extends \XLite\View\AView implements ProviderInterface
             && $order->getOrigProfile()->getProfileId() !== $order->getProfile()->getProfileId();
     }
 
+    /**
+     * Check if need to show customer login
+     *
+     * @return bool
+     */
+    protected function isShowProfileLogin()
+    {
+        return true;
+    }
+
     /**
      * Get order formatted subtotal
      *
@@ -246,14 +256,14 @@ class Info extends \XLite\View\AView implements ProviderInterface
      */
     protected function getSurchargeAttributes($type, array $surcharge)
     {
-        return array(
-            'class' => array(
+        return [
+            'class' => [
                 'order-modifier',
                 strtolower($type) . '-modifier',
                 strtolower($surcharge['code']) . '-code-modifier',
                 ($this->isAutoSurcharge($surcharge) ? 'ctrl-auto' : 'ctrl-manual'),
-            ),
-        );
+            ],
+        ];
     }
 
     /**
@@ -296,7 +306,7 @@ class Info extends \XLite\View\AView implements ProviderInterface
         $result = false;
 
         if ($this->getOrder()) {
-            $result = (bool) \XLite\Core\Database::getRepo('XLite\Model\OrderHistoryEvents')->findOneBy(array('order' => $this->getOrder()));
+            $result = (bool) \XLite\Core\Database::getRepo('XLite\Model\OrderHistoryEvents')->findOneBy(['order' => $this->getOrder()]);
         }
 
         return $result;
@@ -340,13 +350,12 @@ class Info extends \XLite\View\AView implements ProviderInterface
     {
         if ($backorderCompetitiorsText = $this->getBackorderCompetitorsText()) {
             $warningText = static::t('This order was placed at the same time as {{orders}}; as a result, some items were out of stock at the time of order placement.', [
-                'orders' => $this->getBackorderCompetitorsText(),
-                'kb_link' => 'https://kb.x-cart.com/orders/understanding_x-cart_order_statuses.html',
+                'orders' => $backorderCompetitiorsText,
+                'kb_link' => 'https://support.x-cart.com/en/articles/4634599-order-payment-statuses-in-x-cart',
             ]);
-
         } else {
             $warningText = static::t('Some items were out of stock at the time of order placement.', [
-                'kb_link' => 'https://kb.x-cart.com/orders/understanding_x-cart_order_statuses.html',
+                'kb_link' => 'https://support.x-cart.com/en/articles/4634599-order-payment-statuses-in-x-cart',
             ]);
         }
 
@@ -367,7 +376,42 @@ class Info extends \XLite\View\AView implements ProviderInterface
                         'order_number' => $order->getOrderNumber(),
                     ]),
                     '#' . $order->getOrderNumber()
-                    );
+                );
             }, $this->getOrder()->getBackorderCompetitors()->toArray()));
     }
+
+    /**
+     * @return bool
+     */
+    public function isRefundInProgress()
+    {
+        $result = false;
+
+        /** @var \XLite\Model\Order $order */
+        $order = $this->getOrder();
+        $transactions = $order
+            ? $order->getPaymentTransactions()
+            : [];
+
+        foreach ($transactions as $t) {
+            $backendTransactions = $t->getBackendTransactions();
+
+            if (!$backendTransactions) {
+                continue;
+            }
+
+            foreach ($backendTransactions as $bt) {
+                /** @var BackendTransaction $bt */
+                if (
+                    $bt->isRefund()
+                    && in_array($bt->getStatus(), [ $bt::STATUS_INPROGRESS, $bt::STATUS_PENDING ], true)
+                ) {
+                    $result = true;
+                    break 2;
+                }
+            }
+        }
+
+        return $result;
+    }
 }
