@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -101,10 +100,9 @@ class Model extends \XLite\View\Order\Details\Base\AModel
     {
         $object = parent::getModelObject();
 
-        if ('recalculate' === $this->currentAction) {
+        if ($this->currentAction === 'recalculate') {
             // Get temporary order (force to create this)
             $object = \XLite\Controller\Admin\Order::getTemporaryOrder($object->getOrderId(), true);
-
         } else {
             // Get temporary order if exists otherwise get current object
             $object = \XLite\Controller\Admin\Order::getTemporaryOrder($object->getOrderId(), false) ?: $object;
@@ -169,14 +167,14 @@ class Model extends \XLite\View\Order\Details\Base\AModel
     public function getComplexField($name)
     {
         if (!isset($this->widgets[$name])) {
-            $method = 'define' . ucfirst($name);
+            $method = 'define' . \Includes\Utils\Converter::convertToUpperCamelCase($name);
 
             if (method_exists($this, $method)) {
                 $this->widgets[$name] = $this->$method();
             }
         }
 
-        return isset($this->widgets[$name]) ? $this->widgets[$name] : null;
+        return $this->widgets[$name] ?? null;
     }
 
     /**
@@ -486,7 +484,7 @@ class Model extends \XLite\View\Order\Details\Base\AModel
      */
     public function getSurchargeTotals()
     {
-        if (null === $this->modifiers) {
+        if ($this->modifiers === null) {
             $this->modifiers = $this->defineSurchargeTotals();
         }
 
@@ -506,7 +504,6 @@ class Model extends \XLite\View\Order\Details\Base\AModel
             $method = 'define' . ucfirst(strtolower($code)) . 'ModifierWidget';
             if (method_exists($this, $method)) {
                 $list[$code]['formField'] = $this->$method($modifier);
-
             } else {
                 $list[$code]['formField'] = $this->defineDefaultModifierWidget($modifier);
             }
@@ -583,7 +580,7 @@ class Model extends \XLite\View\Order\Details\Base\AModel
     protected function prepareInlineWidget(\XLite\View\FormField\Inline\AInline $widget)
     {
         $widget->setValueFromRequest();
-        list($flag, $message) = $widget->validate();
+        [$flag, $message] = $widget->validate();
         if (!$flag) {
             \XLite\Core\TopMessage::getInstance()->addError($message);
         }
@@ -634,7 +631,8 @@ class Model extends \XLite\View\Order\Details\Base\AModel
 
                 $billAddressObj = \XLite\Core\Database::getRepo('XLite\Model\Address')->find($id);
 
-                if ($billAddressObj
+                if (
+                    $billAddressObj
                     && $billAddressObj->getProfile()->getProfileId() == $origOrder->getProfile()->getProfileId()
                 ) {
                     foreach ($profile->getAddresses() as $address) {
@@ -652,13 +650,11 @@ class Model extends \XLite\View\Order\Details\Base\AModel
                 // Set shipping address by ID
                 $id = (int)$shippingAddress['id'];
 
-                if ($shippingAddress['id'] == $billingAddress['id'] && !empty($newBillingAddressId)) {
-                    $newShippingAddressId = $newBillingAddressId;
-
-                } else {
+                if ($shippingAddress['id'] != $billingAddress['id'] || empty($newBillingAddressId)) {
                     $shipAddressObj = \XLite\Core\Database::getRepo('XLite\Model\Address')->find($id);
 
-                    if ($shipAddressObj
+                    if (
+                        $shipAddressObj
                         && $shipAddressObj->getProfile()->getProfileId() == $origOrder->getProfile()->getProfileId()
                     ) {
                         foreach ($profile->getAddresses() as $address) {
@@ -688,54 +684,7 @@ class Model extends \XLite\View\Order\Details\Base\AModel
         $shippingAddress = $request->shippingAddress;
 
         $profile = $this->getOrder()->getProfile();
-        if (!empty($billingAddress['id'])) {
-            // Set billing address by ID
-            $id = (int)$billingAddress['id'];
-            if ($id != $profile->getBillingAddress()->getAddressId()) {
-                foreach ($profile->getAddresses() as $address) {
-                    $address->setIsBilling($address->getAddressId() == $id);
-                }
-
-                // Address from original profile
-                if (!$profile->getBillingAddress()) {
-                    foreach ($this->getOrder()->getOrigProfile()->getAddresses() as $address) {
-                        if ($id == $address->getAddressId()) {
-                            $address = $address->cloneEntity();
-                            $profile->addAddresses($address);
-                            $address->setProfile($profile);
-                            $address->setIsBilling(true);
-                            $address->setIsShipping(false);
-                            break;
-                        }
-                    }
-                }
-
-                // Address not found - set first
-                if (!$profile->getBillingAddress() && $profile->getAddresses()->first()) {
-                    $profile->getAddresses()->first()->setIsBilling(true);
-                }
-
-            }
-        }
-
-        if (!empty($shippingAddress['id'])
-            && $shippingAddress['id'] == $billingAddress['id']
-        ) {
-            $shippingAddress['same_as_billing'] = true;
-        }
-
-        if (!empty($shippingAddress['same_as_billing'])) {
-            // Set shipping address as same-as-billing
-            if (!$profile->getBillingAddress()
-                || !$profile->getBillingAddress()->getIsShipping()
-            ) {
-                foreach ($profile->getAddresses() as $address) {
-                    $address->setIsShipping(false);
-                }
-                $profile->getBillingAddress()->setIsShipping(true);
-            }
-
-        } elseif (!empty($shippingAddress['id'])) {
+        if (!empty($shippingAddress['id'])) {
             // Set shipping address by ID
             $id = (int)$shippingAddress['id'];
             if ($id != $profile->getShippingAddress()->getAddressId()) {
@@ -750,8 +699,8 @@ class Model extends \XLite\View\Order\Details\Base\AModel
                             $address = $address->cloneEntity();
                             $profile->addAddresses($address);
                             $address->setProfile($profile);
-                            $address->setIsBilling(false);
                             $address->setIsShipping(true);
+                            $address->setIsBilling(false);
                             break;
                         }
                     }
@@ -762,22 +711,62 @@ class Model extends \XLite\View\Order\Details\Base\AModel
                     $profile->getAddresses()->first()->setIsShipping(true);
                 }
             }
+        }
 
+        if (
+            !empty($billingAddress['id'])
+            && $billingAddress['id'] == $shippingAddress['id']
+        ) {
+            $billingAddress['same_as_shipping'] = true;
+        }
+
+        if (!empty($billingAddress['same_as_shipping'])) {
+            // Set billing address as same-as-shipping
+            if (
+                !$profile->getShippingAddress()
+                || !$profile->getShippingAddress()->getIsBilling()
+            ) {
+                foreach ($profile->getAddresses() as $address) {
+                    $address->setIsBilling(false);
+                }
+                $profile->getShippingAddress()->setIsBilling(true);
+            }
+        } elseif (!empty($billingAddress['id'])) {
+            // Set billing address by ID
+            $id = (int)$billingAddress['id'];
+            if ($id != $profile->getBillingAddress()->getAddressId()) {
+                foreach ($profile->getAddresses() as $address) {
+                    $address->setIsBilling($address->getAddressId() == $id);
+                }
+
+                // Address from original profile
+                if (!$profile->getBillingAddress()) {
+                    foreach ($this->getOrder()->getOrigProfile()->getAddresses() as $address) {
+                        if ($id == $address->getAddressId()) {
+                            $address = $address->cloneEntity();
+                            $profile->addAddresses($address);
+                            $address->setProfile($profile);
+                            $address->setIsShipping(false);
+                            $address->setIsBilling(true);
+                            break;
+                        }
+                    }
+                }
+
+                // Address not found - set first
+                if (!$profile->getBillingAddress() && $profile->getAddresses()->first()) {
+                    $profile->getAddresses()->first()->setIsBilling(true);
+                }
+            }
         } else {
-            // Clone billing address as shipping
-            if ($profile->getShippingAddress() && $profile->getShippingAddress()->getIsBilling()) {
-                $address = $profile->getShippingAddress()->cloneEntity();
-                $address->setIsBilling(false);
-                $profile->getShippingAddress()->setIsShipping(false);
+            // Clone shipping address as billing
+            if ($profile->getBillingAddress() && $profile->getBillingAddress()->getIsShipping()) {
+                $address = $profile->getBillingAddress()->cloneEntity();
+                $address->setIsShipping(false);
+                $profile->getBillingAddress()->setIsBilling(false);
 
                 $profile->addAddresses($address);
                 $address->setProfile($profile);
-
-            } elseif ($this->getOrder()->isShippable() && !$profile->getShippingAddress()) {
-                // Order is shippable but shipping address is not defined
-                // Set billing address as shipping
-                $profile->getBillingAddress()->setIsShipping(true);
-                $shippingAddress['same_as_billing'] = true;
             }
         }
 
@@ -850,7 +839,7 @@ class Model extends \XLite\View\Order\Details\Base\AModel
      *
      * @return boolean
      */
-    public function performAction($action, array $data = array())
+    public function performAction($action, array $data = [])
     {
         if ($action === 'recalculate') {
             $this->recalculateMode = true;
@@ -870,7 +859,7 @@ class Model extends \XLite\View\Order\Details\Base\AModel
      */
     protected function addDataSavedTopMessage()
     {
-        if($this->recalculateMode) {
+        if ($this->recalculateMode) {
             \XLite\Core\TopMessage::addInfo('The totals have been recalculated. Press "Save changes" to adjust the order');
         } else {
             parent::addDataSavedTopMessage();
