@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Order\Details\Admin;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Payment actions unit widget (button capture or refund or void etc)
  *
@@ -18,10 +19,10 @@ class PaymentActionsUnit extends \XLite\View\AView
     /**
      *  Widget parameter names
      */
-    const PARAM_TRANSACTION = 'transaction';
-    const PARAM_UNIT        = 'unit';
-    const PARAM_DISPLAY_SEPARATOR = 'displaySeparator';
-    const PARAM_ORDER_NUMBER = 'order_number';
+    public const PARAM_TRANSACTION = 'transaction';
+    public const PARAM_UNIT        = 'unit';
+    public const PARAM_DISPLAY_SEPARATOR = 'displaySeparator';
+    public const PARAM_ORDER_NUMBER = 'order_number';
 
     /**
      * @return array
@@ -42,14 +43,14 @@ class PaymentActionsUnit extends \XLite\View\AView
 
     /**
      * Payment action units that need confirmation
-     * 
+     *
      * @return array
      */
     protected function needConfirm()
     {
-        return array(
+        return [
             \XLite\Model\Payment\BackendTransaction::TRAN_TYPE_REFUND
-        );
+        ];
     }
 
     /**
@@ -59,10 +60,10 @@ class PaymentActionsUnit extends \XLite\View\AView
      */
     protected function needAmount()
     {
-        return array(
+        return [
             \XLite\Model\Payment\BackendTransaction::TRAN_TYPE_REFUND_PART,
             \XLite\Model\Payment\BackendTransaction::TRAN_TYPE_REFUND_MULTI,
-        );
+        ];
     }
 
     /**
@@ -104,12 +105,12 @@ class PaymentActionsUnit extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_TRANSACTION => new \XLite\Model\WidgetParam\TypeObject('Transaction', null, false, 'XLite\Model\Payment\Transaction'),
             self::PARAM_UNIT        => new \XLite\Model\WidgetParam\TypeString('Unit', '', false),
             self::PARAM_DISPLAY_SEPARATOR => new \XLite\Model\WidgetParam\TypeBool('Display separator', false, false),
             self::PARAM_ORDER_NUMBER => new \XLite\Model\WidgetParam\TypeString('OrderNumber', '', false),
-        );
+        ];
     }
 
     /**
@@ -174,10 +175,11 @@ class PaymentActionsUnit extends \XLite\View\AView
 
     /**
      * Button widget class
-     * 
+     *
      * @return string
      */
-    protected function getButtonWidgetClass(){
+    protected function getButtonWidgetClass()
+    {
         $class = '\XLite\View\Button\Regular';
 
         if (in_array($this->getParam(self::PARAM_UNIT), $this->needConfirm())) {
@@ -201,10 +203,10 @@ class PaymentActionsUnit extends \XLite\View\AView
         return $this->buildURL(
             'order',
             $this->getParam(self::PARAM_UNIT),
-            array(
+            [
                 'order_number' => $this->getParam(self::PARAM_ORDER_NUMBER),
                 'trn_id'       => $this->getParam(self::PARAM_TRANSACTION)->getTransactionId(),
-            )
+            ]
         );
     }
 
