@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -18,17 +17,17 @@ trait OutputHelpersTrait
      * @param array $attributes
      * @return string
      */
-    public static function convertToHtmlAttributeString (array $attributes)
+    public static function convertToHtmlAttributeString(array $attributes)
     {
-        $pairs = array();
+        $pairs = [];
         foreach ($attributes as $name => $value) {
             if (is_array($value)) {
                 $value = implode(' ', $value);
             }
 
-            $pairs[] = func_htmlspecialchars(strtolower($name)) . '="' . func_htmlspecialchars(trim($value)) . '"';
+            $pairs[] = func_htmlspecialchars(strtolower($name)) . '="' . func_htmlspecialchars(trim((string) $value)) . '"';
         }
 
         return implode(' ', $pairs);
     }
-}
\ No newline at end of file
+}
