@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,27 +7,8 @@
 
 namespace XLite\View\Page\Admin;
 
-/**
- * Import page
- *
- * @ListChild (list="admin.center", zone="admin")
- */
 class Import extends \XLite\View\AView
 {
-    /**
-     * Return list of allowed targets
-     *
-     * @return array
-     */
-    public static function getAllowedTargets()
-    {
-        $list = parent::getAllowedTargets();
-
-        $list[] = 'import';
-
-        return $list;
-    }
-
     /**
      * Register CSS files
      *
@@ -78,10 +58,8 @@ class Import extends \XLite\View\AView
 
         if ($this->isImportNotFinished()) {
             $result = 'XLite\View\Import\Progress';
-
         } elseif ($this->isImportFailed()) {
             $result = 'XLite\View\Import\Failed';
-
         } elseif ($this->isImportFinished()) {
             $result = 'XLite\View\Import\Completed';
         }
@@ -92,16 +70,16 @@ class Import extends \XLite\View\AView
     /**
      * Check - import process is not-finished or not
      *
-     * @return boolean
+     * @return bool
      */
     protected function isImportNotFinished()
     {
-        $repo = \XLite\Core\Database::getRepo('XLite\Model\TmpVar');
+        $repo = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class);
         $state = $repo->getEventState($this->getEventName());
 
         return $state
             && isset($state['state'])
-            && in_array($state['state'], array(\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS))
+            && in_array($state['state'], [\XLite\Core\EventTask::STATE_STANDBY, \XLite\Core\EventTask::STATE_IN_PROGRESS])
             && !$repo->getVar($this->getImportUserBreakFlagVarName())
             && !$repo->getVar($this->getImportCancelFlagVarName());
     }
@@ -109,18 +87,18 @@ class Import extends \XLite\View\AView
     /**
      * Check - import process is finished
      *
-     * @return boolean
+     * @return bool
      */
     protected function isImportFinished()
     {
-        $repo = \XLite\Core\Database::getRepo('XLite\Model\TmpVar');
+        $repo = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class);
         $state = $repo->getEventState($this->getEventName());
 
         return \XLite\Core\Request::getInstance()->failed
             || (
                 $state
                 && isset($state['state'])
-                && \XLite\Core\EventTask::STATE_FINISHED == $state['state']
+                && $state['state'] == \XLite\Core\EventTask::STATE_FINISHED
                 && \XLite\Core\Request::getInstance()->completed
                 && (!$this->getImporter() || !$this->getImporter()->isNextStepAllowed())
                 && !$repo->getVar($this->getImportCancelFlagVarName())
@@ -130,27 +108,26 @@ class Import extends \XLite\View\AView
     /**
      * Check - import process is finished
      *
-     * @return boolean
+     * @return bool
      */
     protected function isImportFailed()
     {
-        $repo = \XLite\Core\Database::getRepo('XLite\Model\TmpVar');
+        $repo = \XLite\Core\Database::getRepo(\XLite\Model\TmpVar::class);
         $event = $repo->getEventState($this->getEventName());
 
         $result = $repo->getVar($this->getImportUserBreakFlagVarName());
 
         if (!$result) {
-
             $result = $event
                 && isset($event['state'])
                 && !$repo->getVar($this->getImportCancelFlagVarName())
                 && \XLite\Core\Request::getInstance()->completed
                 && (
                     (
-                        \XLite\Core\EventTask::STATE_FINISHED == $event['state']
+                        $event['state'] == \XLite\Core\EventTask::STATE_FINISHED
                         && !$event['options']['step']
                     )
-                    || \XLite\Core\EventTask::STATE_ABORTED == $event['state']
+                    || $event['state'] == \XLite\Core\EventTask::STATE_ABORTED
                 )
                 && (
                     \XLite\Logic\Import\Importer::hasErrors()
@@ -203,8 +180,8 @@ class Import extends \XLite\View\AView
      */
     protected function getImportCommentedData()
     {
-        return array(
+        return [
             'importTarget' => $this->getImportTarget(),
-        );
+        ];
     }
 }
