@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Page;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Layout page
  *
@@ -47,4 +48,4 @@ class Layout extends \XLite\View\AView
     {
         return 'layout_settings/body.twig';
     }
-}
\ No newline at end of file
+}
