@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Page;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Payment transaction page view
  *
@@ -22,7 +23,7 @@ class PaymentTransaction extends \XLite\View\AView
      */
     public static function getAllowedTargets()
     {
-        return array_merge(parent::getAllowedTargets(), array('payment_transaction'));
+        return array_merge(parent::getAllowedTargets(), ['payment_transaction']);
     }
 
     /**
@@ -34,5 +35,4 @@ class PaymentTransaction extends \XLite\View\AView
     {
         return 'payment_transaction/body.twig';
     }
-
-}
\ No newline at end of file
+}
