@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,21 +19,23 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     /**
      * Widget parameter names
      */
-    const PARAM_PAGE_ID                      = 'pageId';
-    const PARAM_ITEMS_COUNT                  = 'itemsCount';
-    const PARAM_ONLY_PAGES                   = 'onlyPages';
-    const PARAM_ITEMS_PER_PAGE               = 'itemsPerPage';
-    const PARAM_SHOW_ITEMS_PER_PAGE_SELECTOR = 'showItemsPerPageSelector';
-    const PARAM_LIST                         = 'list';
-    const PARAM_MAX_ITEMS_COUNT              = 'maxItemsCount';
+    public const PARAM_PAGE_ID                      = 'pageId';
+    public const PARAM_ITEMS_COUNT                  = 'itemsCount';
+    public const PARAM_ONLY_PAGES                   = 'onlyPages';
+    public const PARAM_ITEMS_PER_PAGE               = 'itemsPerPage';
+    public const PARAM_SHOW_ITEMS_PER_PAGE_SELECTOR = 'showItemsPerPageSelector';
+    public const PARAM_LIST                         = 'list';
+    public const PARAM_MAX_ITEMS_COUNT              = 'maxItemsCount';
 
     /**
      * Page short names
      */
-    const PAGE_FIRST    = 'first';
-    const PAGE_PREVIOUS = 'previous';
-    const PAGE_NEXT     = 'next';
-    const PAGE_LAST     = 'last';
+    public const PAGE_FIRST    = 'first';
+    public const PAGE_PREVIOUS = 'previous';
+    public const PAGE_NEXT     = 'next';
+    public const PAGE_LAST     = 'last';
+
+    public const MAX_VISIBLE_PAGES = 5;
 
     /**
      * currentPageId
@@ -76,6 +77,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     public function getCSSFiles()
     {
         $list = parent::getCSSFiles();
+        $list[] = $this->getDir() . '/pager.less';
         $list[] = $this->getDir() . '/pager.css';
 
         if (!\XLite::isAdminZone()) {
@@ -106,11 +108,11 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
      */
     public function getLimitCondition($start = null, $count = null, \XLite\Core\CommonCell $cnd = null)
     {
-        if (null === $start) {
+        if ($start === null) {
             $start = $this->getStartItem();
         }
 
-        if (null === $count) {
+        if ($count === null) {
             $count = $this->getItemsPerPage();
         }
 
@@ -146,7 +148,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
      */
     public function getItemsPerPage()
     {
-        $current = (integer)$this->getParam(static::PARAM_ITEMS_PER_PAGE);
+        $current = (int)$this->getParam(static::PARAM_ITEMS_PER_PAGE);
 
         return max(
             min($this->getItemsPerPageMax(), $current),
@@ -175,6 +177,16 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
         return 'pager';
     }
 
+    /**
+     * getPagerLabel
+     *
+     * @return label
+     */
+    protected function getPagerLabel()
+    {
+        return static::t('Products');
+    }
+
     /**
      * Return widget default template
      *
@@ -247,29 +259,40 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_PAGE_ID => new \XLite\Model\WidgetParam\TypeInt(
-                'Page ID', 1
+                'Page ID',
+                1
             ),
             static::PARAM_ITEMS_COUNT => new \XLite\Model\WidgetParam\TypeInt(
-                'Items number', 0
+                'Items number',
+                0
             ),
             static::PARAM_ONLY_PAGES => new \XLite\Model\WidgetParam\TypeBool(
-                'Only display pages list', false
+                'Only display pages list',
+                false
             ),
             static::PARAM_ITEMS_PER_PAGE => new \XLite\Model\WidgetParam\TypeInt(
-                'Items per page', $this->getItemsPerPageDefault(), true
+                'Items per page',
+                $this->getItemsPerPageDefault(),
+                true
             ),
             static::PARAM_SHOW_ITEMS_PER_PAGE_SELECTOR => new \XLite\Model\WidgetParam\TypeCheckbox(
-                'Show pagination', true, true
+                'Show pagination',
+                true,
+                true
             ),
             static::PARAM_LIST => new \XLite\Model\WidgetParam\TypeObject(
-                'List object', null, false, '\XLite\View\ItemsList\AItemsList'
+                'List object',
+                null,
+                false,
+                '\XLite\View\ItemsList\AItemsList'
             ),
             static::PARAM_MAX_ITEMS_COUNT => new \XLite\Model\WidgetParam\TypeInt(
-                'Maximum number of items to display in the list', 0
+                'Maximum number of items to display in the list',
+                0
             ),
-        );
+        ];
     }
 
     /**
@@ -294,7 +317,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
      */
     protected function buildURLByPageId($pageId)
     {
-        return $this->getList()->getActionURL(array(static::PARAM_PAGE_ID => $pageId));
+        return $this->getList()->getActionURL([static::PARAM_PAGE_ID => $pageId]);
     }
 
     /**
@@ -382,30 +405,30 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     protected function getPages()
     {
         if (!isset($this->pages)) {
-            $this->pages = array();
+            $this->pages = [];
 
             // Define the list of pages
 
             // Add "previous page" link
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type'  => 'previous-page',
                 'num'   => $this->getPreviousPageId(),
                 'title' => 'Previous page',
-            );
+            ];
 
             // If we are able to display the whole list without omitting the pages then we do it
-            if ($this->getPagesCount() > ($this->getFrameLength() + 5)) {
+            if ($this->getPagesCount() > ($this->getFrameLength() + static::MAX_VISIBLE_PAGES)) {
                 $this->buildFramedPageList();
             } else {
                 $this->buildPlainPageList();
             }
 
             // Add "next page" link
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type'  => 'next-page',
                 'num'   => $this->getNextPageId(),
                 'title' => 'Next page',
-            );
+            ];
 
             // Now prepare data for the view
             $this->preparePagesForView();
@@ -422,13 +445,12 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     protected function preparePagesForView()
     {
         foreach ($this->pages as $k => $page) {
-
-            $num = isset($page['num']) ? $page['num'] : null;
+            $num = $page['num'] ?? null;
             $type = $page['type'];
 
-            $isItem = isset($num) && (in_array($type, array('item', 'first-page', 'last-page'), true));
+            $isItem = isset($num) && (in_array($type, ['item', 'first-page', 'last-page'], true));
 
-            $isOmittedItems = 'more-pages' === $type;
+            $isOmittedItems = $type === 'more-pages';
             $isSpecialItem = !$isItem && !$isOmittedItems;
 
             $isCurrent = isset($num) && $this->isCurrentPage($num);
@@ -438,13 +460,13 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
             $isActive = (!$isSelected && !$isOmittedItems && !$isDisabled && !\XLite::isAdminZone())
                 || ($isSelected && \XLite::isAdminZone());
 
-            if ($isItem || ('first-page' === $type) || ('last-page' === $type)) {
+            if ($isItem || ($type === 'first-page') || ($type === 'last-page')) {
                 $this->pages[$k]['text'] = $num;
             } elseif ($isOmittedItems) {
                 $this->pages[$k]['text'] = '...';
-            } elseif ('previous-page' === $type && \XLite::isAdminZone()) {
+            } elseif ($type === 'previous-page' && \XLite::isAdminZone()) {
                 $this->pages[$k]['text'] = '&laquo;';
-            } elseif ('next-page' === $type && \XLite::isAdminZone()) {
+            } elseif ($type === 'next-page' && \XLite::isAdminZone()) {
                 $this->pages[$k]['text'] = '&raquo;';
             } else {
                 $this->pages[$k]['text'] = '&nbsp;';
@@ -465,16 +487,16 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
                 $this->pages[$k]['href'] = $this->buildURLByPageId($num);
             }
 
-            $classes = array(
+            $classes = [
                 'item'                   => $isItem || $isSpecialItem,
                 'selected'               => $isSelected,
                 'disabled'               => $isDisabled,
                 'active'                 => $isActive,
                 $this->pages[$k]['page'] => $isItem,
                 $type                    => true,
-            );
+            ];
 
-            $css = array();
+            $css = [];
 
             foreach ($classes as $class => $enabled) {
                 if ($enabled) {
@@ -494,11 +516,11 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     protected function buildPlainPageList()
     {
         for ($i = 1; $i <= $this->getPagesCount(); $i++) {
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type' => 'item',
                 'num' => $i,
                 'title' => '',
-            );
+            ];
         }
     }
 
@@ -533,45 +555,45 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
         }
 
         // The first page is always displayed
-        $this->pages[] = array(
+        $this->pages[] = [
             'type' => 'first-page',
             'num' => $firstId,
             'title' => 'First page',
-        );
+        ];
 
         // Defines whether to display the "More pages" on the left
         if ($leftMore) {
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type' => 'more-pages',
                 'num' => null,
                 'title' => '',
-            );
+            ];
         }
 
         // Display the visible frame of pages
         for ($i = $leftFrame; $i <= $rightFrame; $i++) {
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type' => 'item',
                 'num' => $i,
                 'title' => '',
-            );
+            ];
         }
 
         // Defines whether to display the "More pages" on the right
         if ($rightMore) {
-            $this->pages[] = array(
+            $this->pages[] = [
                 'type' => 'more-pages',
                 'num' => null,
                 'title' => '',
-            );
+            ];
         }
 
         // The last page is always displayed
-        $this->pages[] = array(
+        $this->pages[] = [
             'type' => 'last-page',
             'num' => $lastId,
             'title' => 'Last page',
-        );
+        ];
     }
 
     /**
@@ -594,7 +616,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     protected function getPageId()
     {
         if (!isset($this->currentPageId)) {
-            $this->currentPageId = min((integer)$this->getParam(static::PARAM_PAGE_ID), $this->getPagesCount());
+            $this->currentPageId = min((int)$this->getParam(static::PARAM_PAGE_ID), $this->getPagesCount());
         }
 
         return $this->currentPageId;
@@ -667,7 +689,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
      */
     protected function isSearchTotalVisible()
     {
-        return 'order_list' === \XLite\Core\Request::getInstance()->target;
+        return \XLite\Core\Request::getInstance()->target === 'order_list';
     }
 
     /**
@@ -725,7 +747,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
 
     /**
      * Should we use cache for pageId
-     * 
+     *
      * @return boolean
      */
     protected function isSavedPageId()
@@ -744,7 +766,7 @@ abstract class APager extends \XLite\View\RequestHandler\ARequestHandler
     {
         $result = null;
 
-        if (static::PARAM_PAGE_ID !== $param || $this->isSavedPageId()) {
+        if ($param !== static::PARAM_PAGE_ID || $this->isSavedPageId()) {
             $result = parent::getSavedRequestParam($param);
         }
 
