@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -40,7 +39,7 @@ class AttributeOption extends \XLite\View\Pager\Admin\Model\Table
      */
     protected function getItemsPerPageRanges()
     {
-        return array(10);
+        return [10];
     }
 
     /**
@@ -52,4 +51,4 @@ class AttributeOption extends \XLite\View\Pager\Admin\Model\Table
     {
         return 6;
     }
-}
\ No newline at end of file
+}
