@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -17,7 +16,7 @@ class Search extends \XLite\View\Pager\Admin\Product\AProduct
      * Widget parameter names
      */
 
-    const PARAM_CATEGORY_ID = 'category_id';
+    public const PARAM_CATEGORY_ID = 'category_id';
 
 
     /**
@@ -39,11 +38,12 @@ class Search extends \XLite\View\Pager\Admin\Product\AProduct
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_CATEGORY_ID => new \XLite\Model\WidgetParam\ObjectId\Category(
-                'Category ID', null
+                'Category ID',
+                null
             ),
-        );
+        ];
     }
 
     /**
