@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -30,6 +29,6 @@ abstract class ACustomer extends \XLite\View\Pager\APager
      */
     protected function getPagesPerFrame()
     {
-        return 4;
+        return \XLite\Core\Request::isMobileDevice() ? 2 : 4;
     }
 }
