@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Payment;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Add payment method dialog widget
  *
@@ -22,7 +23,7 @@ class AddMethod extends \XLite\View\SimpleDialog
      */
     public static function getAllowedTargets()
     {
-        $list = parent::getAllowedTargets();
+        $list   = parent::getAllowedTargets();
         $list[] = 'payment_method_selection';
 
         return $list;
@@ -35,18 +36,6 @@ class AddMethod extends \XLite\View\SimpleDialog
      */
     protected function getBody()
     {
-        return \XLite\Model\Payment\Method::TYPE_OFFLINE === $this->getPaymentType()
-            ? 'payment/add_method/offline.twig'
-            : 'payment/add_method/body.twig';
-    }
-
-    /**
-     * Return payment methods type which is provided to the widget
-     *
-     * @return string
-     */
-    protected function getPaymentType()
-    {
-        return \XLite\Core\Request::getInstance()->{\XLite\View\Button\Payment\AddMethod::PARAM_PAYMENT_METHOD_TYPE};
+        return 'payment/add_method/body.twig';
     }
 }
