@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,9 @@
 
 namespace XLite\View\Popup;
 
-
 class BackstockStatusChangeNotification extends \XLite\View\AView
 {
-    const PARAM_ORDER = 'order';
+    public const PARAM_ORDER = 'order';
 
     protected function getDefaultTemplate()
     {
@@ -44,10 +42,13 @@ class BackstockStatusChangeNotification extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_ORDER => new \XLite\Model\WidgetParam\TypeObject(
-                'Order', null, false, '\XLite\Model\Order'
+                'Order',
+                null,
+                false,
+                '\XLite\Model\Order'
             ),
-        );
+        ];
     }
-}
\ No newline at end of file
+}
