@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -9,7 +8,7 @@
 namespace XLite\View\Product\Details\Admin;
 
 /**
- * Product class 
+ * Product class
  */
 class ProductClass extends \XLite\View\Product\Details\Admin\AAdmin
 {
@@ -34,7 +33,7 @@ class ProductClass extends \XLite\View\Product\Details\Admin\AAdmin
     public function getCSSFiles()
     {
         $list = parent::getCSSFiles();
-        $list[] = $this->getDir() . '/style.css';
+        $list[] = $this->getDir() . '/style.less';
 
         return $list;
     }
