@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,14 +7,9 @@
 
 namespace XLite\View\Product\Details\Customer;
 
-/**
- * ACustomer
- */
 abstract class ACustomer extends \XLite\View\Product\Details\ADetails
 {
     /**
-     * Get image alternative text
-     *
      * @param \XLite\Model\Base\Image $image Image
      * @param integer                 $i     Image index OPTIONAL
      *
@@ -29,8 +23,6 @@ abstract class ACustomer extends \XLite\View\Product\Details\ADetails
     }
 
     /**
-     * Check if widget is visible
-     *
      * @return boolean
      */
     protected function isVisible()
@@ -39,17 +31,12 @@ abstract class ACustomer extends \XLite\View\Product\Details\ADetails
     }
 
     /**
-     * @inheritDoc
+     * @return array
      */
-    public function getCSSFiles()
+    public function getJSFiles()
     {
-        return array_merge(
-            parent::getCSSFiles(),
-            [
-                'labels/style.css'
-            ]
-        );
+        return array_merge(parent::getJSFiles(), [
+            'js/attributetoform.js'
+        ]);
     }
-
-
 }
