@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -64,10 +63,8 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
     {
         if ($a['weight'] == $b['weight']) {
             $result = 0;
-
         } elseif ($a['weight'] > $b['weight']) {
             $result = 1;
-
         } else {
             $result = -1;
         }
@@ -88,38 +85,34 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
             foreach ($list as $k => $data) {
                 $id = $data['id'] ?? preg_replace('/\W+/Ss', '-', strtolower($k));
 
-                $list[$k] = array(
+                $list[$k] = [
                     'index'  => $i,
                     'id'     => 'product-details-tab-' . $id,
                     'name'   => is_array($data) && !empty($data['name'])
                         ? $data['name']
                         : static::t($k),
                     'weight' => $data['weight'] ?? $i,
-                );
+                ];
 
-                if(!empty($data['alt_id'])) {
+                if (!empty($data['alt_id'])) {
                     $list[$k]['alt_id'] = 'product-details-tab-' . $data['alt_id'];
                 }
 
                 if (is_string($data)) {
                     $list[$k]['template'] = $data;
-
                 } elseif (is_array($data) && !empty($data['template'])) {
                     $list[$k]['template'] = $data['template'];
-
                 } elseif (is_array($data) && !empty($data['list'])) {
                     $list[$k]['list'] = $data['list'];
-
                 } elseif (is_array($data) && !empty($data['widget'])) {
-                    $parameters = array(
+                    $parameters = [
                         'product' => $this->getProduct(),
-                    );
+                    ];
                     if (!empty($data['parameters'])) {
                         $parameters += $data['parameters'];
                     }
                     $list[$k]['widgetObject'] = $this->getWidget($parameters, $data['widget']);
                     unset($data['widget']);
-
                 } else {
                     unset($list[$k]);
                 }
@@ -128,7 +121,7 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
             }
 
             $this->tabs = $list;
-            uasort($this->tabs, array($this, 'compareTabs'));
+            uasort($this->tabs, [$this, 'compareTabs']);
         }
 
         return $this->tabs;
@@ -141,7 +134,7 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
      */
     protected function defineTabs()
     {
-        $list = array();
+        $list = [];
 
         foreach ($this->getProduct()->getGlobalTabs() as $tab) {
             $this->processGlobalTab($list, $tab);
@@ -173,7 +166,7 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
     {
         switch ($tab->getServiceName()) {
             case 'Description':
-                if ($this->hasDescription()) {
+                if (strlen($this->getProduct()->getDescription()) > 0) {
                     $list[$tab->getServiceName()] = [
                         'list'   => 'product.details.page.tab.description',
                         'weight' => $tab->getPosition(),
@@ -221,49 +214,49 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
      */
     protected function defineAttributesWidgets()
     {
-        $this->attributesWidgets = array();
+        $this->attributesWidgets = [];
 
         $product = $this->getProduct();
 
         $this->attributesWidgets[] = $this->getWidget(
-            array(
+            [
                 'product' => $product
-            ),
+            ],
             'XLite\View\Product\Details\Customer\CommonAttributes'
         );
 
         if ($product->getProductClass()) {
             $this->attributesWidgets[] = $this->getWidget(
-                array(
+                [
                     'product'      => $product,
                     'productClass' => $product->getProductClass()
-                ),
+                ],
                 'XLite\View\Product\Details\Customer\Attributes'
             );
         }
 
         $this->attributesWidgets[] = $this->getWidget(
-            array(
+            [
                 'product' => $product
-            ),
+            ],
             'XLite\View\Product\Details\Customer\Attributes'
         );
 
         $this->attributesWidgets[] = $this->getWidget(
-            array(
+            [
                 'product'      => $product,
                 'personalOnly' => true
-            ),
+            ],
             'XLite\View\Product\Details\Customer\Attributes'
         );
 
         if ($product->getProductClass()) {
             foreach ($product->getProductClass()->getAttributeGroups() as $group) {
                 $this->attributesWidgets[] = $this->getWidget(
-                    array(
+                    [
                         'product' => $product,
                         'group'   => $group
-                    ),
+                    ],
                     'XLite\View\Product\Details\Customer\Attributes'
                 );
             }
@@ -271,10 +264,10 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
 
         foreach (\XLite\Core\Database::getRepo('XLite\Model\AttributeGroup')->findByProductClass(null) as $group) {
             $this->attributesWidgets[] = $this->getWidget(
-                array(
+                [
                     'product' => $product,
                     'group'   => $group
-                ),
+                ],
                 'XLite\View\Product\Details\Customer\Attributes'
             );
         }
@@ -327,7 +320,7 @@ abstract class APage extends \XLite\View\Product\Details\Customer\ACustomer
      */
     protected function isTabActive(array $tab)
     {
-        return 0 === $tab['index'];
+        return $tab['index'] === 0;
     }
 
     // }}}
