@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,9 @@
 
 namespace XLite\View\Product\Details\Customer\Page;
 
+use XCart\Extender\Mapping\ListChild;
+use XLite\Model\Cart;
+
 /**
  * Main
  *
@@ -45,17 +47,21 @@ class Main extends \XLite\View\Product\Details\Customer\Page\APage
      */
     protected function getContainerAttributes()
     {
-        $collection = new \XLite\View\ProductPageCollection(array('product' => $this->getProduct()));
+        $collection = new \XLite\View\ProductPageCollection(['product' => $this->getProduct()]);
         $collection = $collection->getWidgetsCollection();
+        $productId = $this->getProduct()->getProductId();
+        $classes = [
+            'product-details',
+            'product-info-' . $productId,
+            'box-product',
+        ];
+        if (Cart::getInstance()->isProductAdded($productId)) {
+            $classes[] = 'product-added';
+        }
 
-        return array(
-            'class'                       => array(
-                'product-details',
-                'product-info-' . $this->getProduct()->getProductId(),
-                'box-product',
-            ),
+        return [
+            'class'                       => $classes,
             'data-use-widgets-collection' => !empty($collection),
-        );
+        ];
     }
-
 }
