@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -28,14 +27,14 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     /**
      * Widget parameters
      */
-    const PARAM_PRODUCT_ID                        = 'productId';
-    const PARAM_VIEW_LIST_NAME                    = 'productViewListName';
-    const PARAM_DISPLAY_MODE                      = 'displayMode';
-    const PARAM_ITEM_LIST_WIDGET_TARGET           = 'itemListWidgetTarget';
-    const PARAM_ICON_MAX_WIDTH                    = 'iconWidth';
-    const PARAM_ICON_MAX_HEIGHT                   = 'iconHeight';
-    const PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY = 'productStockAvailabilityPolicy';
-    const PARAM_PRODUCT_ENTITY_VERSION_FETCHER    = 'productEntityVersionFetcher';
+    public const PARAM_PRODUCT_ID                        = 'productId';
+    public const PARAM_VIEW_LIST_NAME                    = 'productViewListName';
+    public const PARAM_DISPLAY_MODE                      = 'displayMode';
+    public const PARAM_ITEM_LIST_WIDGET_TARGET           = 'itemListWidgetTarget';
+    public const PARAM_ICON_MAX_WIDTH                    = 'iconWidth';
+    public const PARAM_ICON_MAX_HEIGHT                   = 'iconHeight';
+    public const PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY = 'productStockAvailabilityPolicy';
+    public const PARAM_PRODUCT_ENTITY_VERSION_FETCHER    = 'productEntityVersionFetcher';
 
     /**
      * An associated product instance
@@ -56,7 +55,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      *
      * Note:
      *  If you decorate this method you must use $this->getSafeValue() on return value
-     * 
+     *
      * @return object
      */
 
@@ -65,12 +64,13 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
         $product = $this->getProduct();
 
         $classes = 'product productid-'
-               . $product->getProductId()
-               . ($product->isOutOfStock() ? ' out-of-stock' : '')
-               . ($product->isShowStockWarning() ? ' low-stock' : '')
-               . ($product->isAvailable() ? '' : ' not-available')
-               . ($this->isGotoProduct() ? ' need-choose-options' : '')
-               . ' ' . $this->getDynamicProductCellClasses();
+            . $product->getProductId()
+            . ($product->isOutOfStock() ? ' out-of-stock' : '')
+            . ($product->isShowStockWarning() ? ' low-stock' : '')
+            . ($product->isAvailable() ? '' : ' not-available')
+            . ($this->isGotoProduct() ? ' need-choose-options' : '')
+            . ($this->hasButtons() ? '' : ' no-buttons')
+            . ' ' . $this->getDynamicProductCellClasses();
 
         return $this->getSafeValue($classes);
     }
@@ -86,6 +86,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     {
         $classes = [
             $this->getProductAddedToCartCellClass(),
+            $this->getIsAllStockInCartCellClass(),
         ];
 
         return trim(implode(' ', $classes));
@@ -98,13 +99,27 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     public function getProductAddedToCartCellClass()
     {
-        $widget = $this->getChildWidget('XLite\View\Product\ProductAddedToCartCellClass', [
+        $widget = $this->getChildWidget(ProductAddedToCartCellClass::class, [
             ProductAddedToCartCellClass::PARAM_PRODUCT_ID => $this->getProduct()->getProductId(),
         ]);
 
         return $widget->getContent();
     }
 
+    /**
+     * Get content of the dynamic widget that renders 'all-stock-in-cart' css class if all stock was added to cart.
+     *
+     * @return string
+     */
+    public function getIsAllStockInCartCellClass()
+    {
+        $widget = $this->getChildWidget(IsAllStockInCartCellClass::class, [
+            IsAllStockInCartCellClass::PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY => $this->getParam(self::PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY),
+        ]);
+
+        return $widget->getContent();
+    }
+
     /**
      * Check - go to product page instead of adding to cart
      *
@@ -113,7 +128,17 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     protected function isGotoProduct()
     {
         return \XLite\Core\Config::getInstance()->General->force_choose_product_options !== ''
-               && $this->getProduct()->hasEditableAttributes();
+            && $this->getProduct()->hasEditableAttributes();
+    }
+
+    /**
+     * Check - if .buttons-container is present
+     *
+     * @return boolean
+     */
+    protected function hasButtons()
+    {
+        return \XLite\Core\Config::getInstance()->General->enable_add2cart_button_grid;
     }
 
     /**
@@ -133,9 +158,10 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function getAdd2CartBlockWidget()
     {
-        $widget = null;
+        $widget  = null;
+        $product = $this->getProduct();
 
-        if ($this->getProduct()->isOutOfStock()) {
+        if ($product->isOutOfStock()) {
             $widget = $this->getWidget(
                 [
                     'style' => 'out-of-stock',
@@ -143,20 +169,12 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
                 ],
                 'XLite\View\Button\Simple'
             );
-
-        } elseif ($this->getProduct()->isAllStockInCart()) {
-            $widget = $this->getWidget(
-                [
-                    'location' => $this->buildURL('cart'),
-                    'label'    => 'View cart',
-                ],
-                'XLite\View\Button\SimpleLink'
-            );
-
         } else {
+            $classes = 'add-to-cart product-add2cart productid-' . $product->getProductId();
+
             $widget = $this->getWidget(
                 [
-                    'style' => 'add-to-cart product-add2cart productid-' . $this->getProduct()->getProductId(),
+                    'style' => $classes,
                     'label' => 'Add to cart',
                 ],
                 'XLite\View\Button\Simple'
@@ -166,6 +184,20 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
         return $widget;
     }
 
+    /**
+     * @return \XLite\View\AView
+     */
+    protected function getChangeQtyBlockWidget()
+    {
+        return $this->getChildWidget(
+            ChangeQty::class,
+            [
+                ChangeQty::PARAM_PRODUCT_ID                        => $this->getProduct()->getProductId(),
+                ChangeQty::PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY => $this->getParam(self::PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY),
+                ChangeQty::PARAM_ALL_STOCK_IN_CART_TOOLTIP_TEXT    => $this->getProduct()->getAllStockInCartTooltipText(),
+            ]
+        );
+    }
 
     /**
      * Get product labels
@@ -174,7 +206,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function getLabels()
     {
-        return array();
+        return [];
     }
 
     /**
@@ -194,11 +226,10 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function isDisplayAdd2CartButton()
     {
-        return $this->getDisplayMode() !== ACustomer::DISPLAY_MODE_GRID
-            || (
-                \XLite\Core\Config::getInstance()->General->enable_add2cart_button_grid
-                && !$this->getProduct()->isOutOfStock()
-            );
+        return (
+            $this->getDisplayMode() !== ACustomer::DISPLAY_MODE_GRID
+            || \XLite\Core\Config::getInstance()->General->enable_add2cart_button_grid
+        ) && !$this->getProduct()->isOutOfStock();
     }
 
     /**
@@ -219,7 +250,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     protected function getProductURL($categoryId = null)
     {
         $product              = $this->getProduct();
-        $params               = array();
+        $params               = [];
         $params['product_id'] = $product->getProductId();
 
         // TODO: Optimize/rewrite. Very heavy logic. It seems that there's no need to fetch product categories in this method since the "current" category has already been taken into account when category listing was rendered
@@ -246,7 +277,6 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
                 if (!$found) {
                     $categoryId = $firstId;
                 }
-
             } else {
                 $categoryId = null;
             }
@@ -322,7 +352,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             self::PARAM_PRODUCT_ID                        => new TypeInt('ProductId'),
             self::PARAM_ICON_MAX_WIDTH                    => new TypeInt('Max icon width', 0, true),
             self::PARAM_ICON_MAX_HEIGHT                   => new TypeInt('Max icon height', 0, true),
@@ -331,7 +361,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
             self::PARAM_ITEM_LIST_WIDGET_TARGET           => new TypeString('Item list widget target'),
             self::PARAM_PRODUCT_STOCK_AVAILABILITY_POLICY => new TypeObject('Product stock availability policy'),
             self::PARAM_PRODUCT_ENTITY_VERSION_FETCHER    => new TypeObject('Product entity version fetcher'),
-        );
+        ];
     }
 
     /**
@@ -387,7 +417,7 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
             $this->itemHoverParams = $this->defineItemHoverParams();
         }
 
-        return $this->itemHoverParams ?: array();
+        return $this->itemHoverParams ?: [];
     }
 
     /**
@@ -397,16 +427,14 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function defineItemHoverParams()
     {
-        $result = array();
+        $result = [];
 
         $product = $this->getProduct();
 
         if ($product->isOutOfStock()) {
-            $result['out_of_stock']     = $this->defineItemHoverParamOutOfStock();
-
+            $result['out_of_stock'] = $this->defineItemHoverParamOutOfStock();
         } elseif ($this->isGotoProduct()) {
-            $result['choose_options']   = $this->defineItemHoverParamChooseOptions();
-
+            $result['choose_options'] = $this->defineItemHoverParamChooseOptions();
         }
 
         return $result;
@@ -415,14 +443,14 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
     /**
      * @return array
      */
-    public function getAllItemHoverParams(){
+    public function getAllItemHoverParams()
+    {
         return [
-            'out_of_stock'      => $this->defineItemHoverParamOutOfStock(),
-            'choose_options'    => $this->defineItemHoverParamChooseOptions(),
+            'out_of_stock'   => $this->defineItemHoverParamOutOfStock(),
+            'choose_options' => $this->defineItemHoverParamChooseOptions(),
         ];
     }
 
-    
     /**
      * Get item hover data for out-of-stock item
      *
@@ -430,11 +458,11 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function defineItemHoverParamOutOfStock()
     {
-        return array(
-            'text'      => static::t('Product is out of stock'),
-            'style'     => 'out-message',
+        return [
+            'text'          => static::t('Product is out of stock'),
+            'style'         => 'out-message',
             'showCondClass' => 'out-of-stock',
-        );
+        ];
     }
 
     /**
@@ -444,11 +472,11 @@ class ListItem extends \XLite\View\AView implements DynamicWidgetInterface
      */
     protected function defineItemHoverParamChooseOptions()
     {
-        return array(
-            'text'      => static::t('Choose the product options first'),
-            'style'     => 'choose-product-option',
+        return [
+            'text'          => static::t('Choose the product options first'),
+            'style'         => 'choose-product-option',
             'showCondClass' => 'need-choose-options',
-        );
+        ];
     }
 
     /**
