@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ use XLite\Model\WidgetParam\TypeInt;
  */
 class ProductAddedToCartCellClass extends \XLite\View\AView implements DynamicWidgetInterface
 {
-    const PARAM_PRODUCT_ID = 'product_id';
+    public const PARAM_PRODUCT_ID = 'product_id';
 
     /**
      * Display widget with the default or overriden template.
@@ -39,9 +38,9 @@ class ProductAddedToCartCellClass extends \XLite\View\AView implements DynamicWi
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_PRODUCT_ID => new TypeInt('ProductId'),
-        );
+        ];
     }
 
     /**
