@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,9 +7,11 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Promotions widget (admin)
- * 
+ *
  * @ListChild (list="admin.center", zone="admin")
  */
 class Promotions extends \XLite\View\AView
