@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,8 +7,10 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
- * Dashboard page widget 
+ * Dashboard page widget
  *
  * @ListChild (list="admin.center", zone="admin")
  */
@@ -22,7 +23,7 @@ class RecentLogin extends \XLite\View\Dialog
      */
     public static function getAllowedTargets()
     {
-        return array_merge(parent::getAllowedTargets(), array('recent_login'));
+        return array_merge(parent::getAllowedTargets(), ['recent_login']);
     }
 
     /**
@@ -35,7 +36,6 @@ class RecentLogin extends \XLite\View\Dialog
         $list = parent::getCSSFiles();
 
         $list[] = 'items_list/model/table/style.css';
-        $list[] = 'items_list/model/style.css';
 
         return $list;
     }
@@ -49,5 +49,4 @@ class RecentLogin extends \XLite\View\Dialog
     {
         return 'recent_login';
     }
-
 }
