@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,7 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
 
 /**
  * Remove data
@@ -33,7 +33,6 @@ class RemoveData extends \XLite\View\AView
      */
     public static function getAllowedTargets()
     {
-        return parent::getAllowedTargets() + array('remove_data');
+        return parent::getAllowedTargets() + ['remove_data'];
     }
-
-}
\ No newline at end of file
+}
