@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Product search widget
  *
@@ -22,9 +23,9 @@ class Search extends \XLite\View\Dialog
      */
     public static function getAllowedTargets()
     {
-        return array(
+        return [
             'search',
-        );
+        ];
     }
 
     /**
