@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -45,12 +44,12 @@ class Main extends \XLite\View\SearchPanel\ASearchPanel
      */
     protected function defineConditions()
     {
-        return parent::defineConditions() + array(
-            'substring' => array(
+        return parent::defineConditions() + [
+            'substring' => [
                 static::CONDITION_CLASS                             => 'XLite\View\FormField\Input\Text',
                 \XLite\View\FormField\AFormField::PARAM_FIELD_ONLY  => true,
                 \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER => static::t('Enter search pattern'),
-            ),
-        );
+            ],
+        ];
     }
 }
