@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Shipping;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Edit shipping method dialog widget
  *
@@ -35,7 +36,7 @@ class EditMethod extends \XLite\View\SimpleDialog
      */
     protected function getBody()
     {
-        return 'shipping/add_method/edit.twig';
+        return 'shipping/edit_offline_method/body.twig';
     }
 
     /**
@@ -45,16 +46,34 @@ class EditMethod extends \XLite\View\SimpleDialog
      */
     protected function getOfflineHelpTemplate()
     {
-        return 'shipping/add_method/parts/offline_help.twig';
+        return 'shipping/edit_offline_method/offline_help.twig';
     }
 
     /**
-     * Online help template
+     * Register CSS files
      *
-     * @return string
+     * @return array
      */
-    protected function getOnlineHelpTemplate()
+    public function getCSSFiles()
     {
-        return 'shipping/add_method/parts/online_help.twig';
+        $list = parent::getCSSFiles();
+
+        $list[] = 'shipping/edit_offline_method/style.less';
+
+        return $list;
+    }
+
+    /**
+     * Register JS files
+     *
+     * @return array
+     */
+    public function getJSFiles()
+    {
+        $list = parent::getJSFiles();
+
+        $list[] = 'shipping/edit_offline_method/controller.js';
+
+        return $list;
     }
 }
