@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\ShippingEstimator;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Shipping estimator
  *
@@ -95,7 +96,6 @@ class ShippingEstimate extends \XLite\View\AView
         if ($this->hasField('state_id')) {
             if ($this->hasField('country_code')) {
                 $result = true;
-
             } else {
                 $address = $this->getAddress();
 
@@ -124,7 +124,6 @@ class ShippingEstimate extends \XLite\View\AView
         $address = $this->getAddress();
         if ($address && isset($address['country'])) {
             $result = $address['country'];
-
         } elseif (\XLite\Model\Address::getDefaultFieldValue('country')) {
             $result = \XLite\Model\Address::getDefaultFieldValue('country')->getCode();
         }
@@ -147,25 +146,23 @@ class ShippingEstimate extends \XLite\View\AView
         if ($address && !empty($address['state'])) {
             if (is_integer($address['state'])) {
                 $state = \XLite\Core\Database::getRepo('XLite\Model\State')->find($address['state']);
-
             } elseif (!empty($address['country'])) {
                 $state = \XLite\Core\Database::getRepo('XLite\Model\State')->findOneByCountryAndCode($address['country'], $address['state']);
             }
-
-        } elseif ($this->getCart()->getProfile()
+        } elseif (
+            $this->getCart()->getProfile()
             && $this->getCart()->getProfile()->getShippingAddress()
             && $this->getCart()->getProfile()->getShippingAddress()->getState()
         ) {
             // From shipping address
             $state = $this->getCart()->getProfile()->getShippingAddress()->getState();
-
-        } elseif (!$address
+        } elseif (
+            !$address
             && \XLite\Model\Address::getDefaultFieldValue('custom_state')
         ) {
             // From config
             $state = new \XLite\Model\State();
             $state->setState(\XLite\Model\Address::getDefaultFieldValue('custom_state'));
-
         }
 
         return $state;
@@ -184,8 +181,8 @@ class ShippingEstimate extends \XLite\View\AView
 
         if (isset($address) && isset($address['custom_state'])) {
             $state = $address['custom_state'];
-
-        } elseif ($this->getCart()->getProfile()
+        } elseif (
+            $this->getCart()->getProfile()
             && $this->getCart()->getProfile()->getShippingAddress()
             && $this->getCart()->getProfile()->getShippingAddress()->getCustomState()
         ) {
@@ -257,7 +254,7 @@ class ShippingEstimate extends \XLite\View\AView
      */
     protected function hasRates()
     {
-        return (boolean) $this->getModifier()->getRates();
+        return (bool) $this->getModifier()->getRates();
     }
 
     /**
