@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,6 +7,8 @@
 
 namespace XLite\View\Sort;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Order sort widget
  *
@@ -15,7 +16,6 @@ namespace XLite\View\Sort;
  */
 class Order extends \XLite\View\Sort\ASort
 {
-
     /**
      * Define widget parameters
      *
@@ -26,19 +26,19 @@ class Order extends \XLite\View\Sort\ASort
         parent::defineWidgetParams();
 
         $this->widgetParams[self::PARAM_PARAMS]->setValue(
-            array(
+            [
                 'target' => 'order_list',
                 'mode' => 'search',
-            )
+            ]
         );
 
         $this->widgetParams[self::PARAM_SORT_CRITERIA]->setValue(
-            array(
+            [
                 'order_id' => 'Order id',
                 'date'     => 'Date',
                 'status'   => 'Status',
                 'total'    => 'Total',
-            )
+            ]
         );
 
         $this->widgetParams[self::PARAM_CELL]->setValue(\XLite\Core\Session::getInstance()->orders_search);
