@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -24,7 +23,7 @@ class Main extends \XLite\View\StickyPanel\ItemsListForm
             'status' => [
                 'class'    => 'XLite\View\Button\Dropdown\Status',
                 'params'   => [
-                    'label'          => static::t('Status'),
+                    'label'          => '',
                     'style'          => 'more-action hide-on-disable hidden',
                     'icon-style'     => 'fa fa-power-off iconfont',
                     'showCaret'      => true,
