@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
     /**
      * Widget parameter names
      */
-    const PARAM_ALWAYS_VISIBLE = 'alwaysVisible';
+    public const PARAM_ALWAYS_VISIBLE = 'alwaysVisible';
 
     /**
      * Buttons list (cache)
@@ -32,9 +31,9 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_ALWAYS_VISIBLE => new \XLite\Model\WidgetParam\TypeBool('alwaysVisible', false)
-        );
+        ];
     }
 
     /**
@@ -55,7 +54,7 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
     protected function getButtons()
     {
         if (!isset($this->buttonsList)) {
-            $this->buttonsList = $this->defineButtons();
+            $this->buttonsList = $this->defineButtons() + $this->defineLastButtons();
         }
 
         return $this->buttonsList;
@@ -68,12 +67,72 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
      */
     protected function defineButtons()
     {
-        $list = array();
+        $list = [];
         $list['save'] = $this->getSaveWidget();
 
         return $list;
     }
 
+    /**
+     * Is product preview widget visible
+     *
+     * @return boolean
+     */
+    protected function isProductPreviewWidgetVisible()
+    {
+        return \XLite\Core\Request::getInstance()->target == 'product'
+            && !empty(\XLite\Core\Request::getInstance()->product_id);
+    }
+
+    /**
+     * Return product preview widget
+     *
+     * @return \XLite\View\Button\SimpleLink
+     */
+    protected function getProductPreviewWidget()
+    {
+        return $this->getWidget(
+            [
+                \XLite\View\Button\AButton::PARAM_LABEL => 'Preview product page',
+                \XLite\View\Button\AButton::PARAM_STYLE => 'model-button link action',
+                \XLite\View\Button\Link::PARAM_BLANK    => true,
+                \XLite\View\Button\Link::PARAM_LOCATION => $this->getPreviewProductURL(),
+            ],
+            '\XLite\View\Button\SimpleLink'
+        );
+    }
+
+    /**
+     * Return product preview URL
+     *
+     * @return string
+     */
+    protected function getPreviewProductURL()
+    {
+        return \XLite\Core\Converter::buildURL(
+            'product',
+            'preview',
+            [
+                'product_id' => \XLite\Core\Request::getInstance()->product_id,
+                'shopKey'    => \XLite\Core\Auth::getInstance()->getShopKey(),
+            ],
+            \XLite::getCustomerScript()
+        );
+    }
+
+    /*
+     * Define buttons widgets that go the very end
+     */
+    protected function defineLastButtons(): array
+    {
+        $result = [];
+        if ($this->isProductPreviewWidgetVisible()) {
+            $result['preview-product'] = $this->getProductPreviewWidget();
+        }
+
+        return $result;
+    }
+
     /**
      * Get "save" widget
      *
@@ -82,12 +141,12 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
     protected function getSaveWidget()
     {
         return $this->getWidget(
-            array(
+            [
                 'style'    => 'action submit',
                 'label'    => $this->getSaveWidgetLabel(),
                 'disabled' => true,
                 \XLite\View\Button\AButton::PARAM_BTN_TYPE => $this->getSaveWidgetStyle(),
-            ),
+            ],
             'XLite\View\Button\Submit'
         );
     }
@@ -119,7 +178,7 @@ class ItemForm extends \XLite\View\Base\FormStickyPanel
      */
     protected function getClass()
     {
-        return $this->alwaysVisible()
+        return ($this->alwaysVisible() || $this->isProductPreviewWidgetVisible())
             ? parent::getClass() . ' always-visible'
             : parent::getClass();
     }
