@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -13,7 +12,7 @@ namespace XLite\View\StickyPanel\ItemsList;
  */
 class Profile extends \XLite\View\StickyPanel\ItemsListForm
 {
-	/**
+    /**
      * Define buttons widgets
      *
      * @return array
@@ -22,7 +21,7 @@ class Profile extends \XLite\View\StickyPanel\ItemsListForm
     {
         $list = parent::defineButtons();
         $list['export'] = $this->getWidget(
-            array(),
+            [],
             'XLite\View\Button\ItemsExport\Profile'
         );
         return $list;
