@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -38,7 +37,6 @@ class Admin extends \XLite\View\StickyPanel\ItemsListForm
                 'disabled'       => false,
                 'label'          => 'Add new language',
                 'style'          => 'more-action always-enabled',
-                'useCaretButton' => false,
                 'dropDirection'  => 'dropup',
             ],
             'position' => 100,
