@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -20,17 +19,16 @@ class LabelDetails extends \XLite\View\Base\FormStickyPanel
      */
     protected function getButtons()
     {
-        $buttons = array();
+        $buttons = [];
         $buttons['save'] = $this->getWidget(
-            array(
+            [
                 'style'    => 'action regular-main-button',
                 'label'    => static::t('Save changes'),
                 'disabled' => false,
-            ),
+            ],
             'XLite\View\Button\Submit'
         );
 
         return $buttons;
     }
 }
-
