@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -27,7 +26,7 @@ class Settings extends \XLite\View\StickyPanel\ItemForm
         return $list;
     }
 
-	/**
+    /**
      * Define buttons widgets
      *
      * @return array
@@ -36,15 +35,14 @@ class Settings extends \XLite\View\StickyPanel\ItemForm
     {
         $list = parent::defineButtons();
         $list['addons-list'] = $this->getWidget(
-            array(
-            	\XLite\View\Button\AButton::PARAM_LABEL => static::t('Back to methods'),
+            [
+                \XLite\View\Button\AButton::PARAM_LABEL => static::t('Back to methods'),
                 \XLite\View\Button\AButton::PARAM_STYLE => 'action addons-list-back-button',
                 \XLite\View\Button\Link::PARAM_LOCATION => $this->buildURL('payment_settings'),
-            ),
+            ],
             '\XLite\View\Button\SimpleLink'
         );
 
         return $list;
     }
 }
-
