@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -23,11 +22,11 @@ class ZoneDetails extends \XLite\View\StickyPanel\ItemForm
         $list = parent::defineButtons();
 
         $list['shipping_methods'] = new \XLite\View\Button\SimpleLink(
-            array(
+            [
                 \XLite\View\Button\AButton::PARAM_LABEL => static::t('Back to Zones list'),
                 \XLite\View\Button\AButton::PARAM_STYLE => 'action zone-back-button',
                 \XLite\View\Button\Link::PARAM_LOCATION => $this->buildURL('zones'),
-            )
+            ]
         );
 
         return $list;
