@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -16,7 +15,7 @@ abstract class ASurchargeInfo extends \XLite\View\AView
     /**
      * Widget param names
      */
-    const PARAM_SURCHARGE = 'surcharge';
+    public const PARAM_SURCHARGE = 'surcharge';
 
     /**
      * Define widget params
@@ -27,22 +26,20 @@ abstract class ASurchargeInfo extends \XLite\View\AView
     {
         parent::defineWidgetParams();
 
-        $this->widgetParams += array(
+        $this->widgetParams += [
             static::PARAM_SURCHARGE => new \XLite\Model\WidgetParam\TypeObject('Surcharge', null),
-        );
+        ];
     }
 
     /**
      * Get surcharge object
-     * 
+     *
      * @return \XLite\Model\Base\Surcharge
      */
     protected function getSurcharge()
     {
         $surchargeParam = $this->getParam(static::PARAM_SURCHARGE);
 
-        return isset($surchargeParam['object'])
-            ? $surchargeParam['object']
-            : null;
+        return $surchargeParam['object'] ?? null;
     }
 }
