@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -8,10 +7,12 @@
 
 namespace XLite\View\Tabs;
 
+use XCart\Extender\Mapping\ListChild;
+
 /**
  * Tabs related to payment settings
  *
- * @ListChild (list="admin.center", zone="admin")
+ * @ListChild (list="admin.center", zone="admin", weight="100")
  */
 class PaymentSettings extends \XLite\View\Tabs\ATabs
 {
@@ -37,12 +38,12 @@ class PaymentSettings extends \XLite\View\Tabs\ATabs
         return [
             'payment_settings' => [
                 'weight'   => 100,
-                'title'    => static::t('Configuration'),
+                'title'    => static::t('Methods'),
                 'template' => 'payment/configuration.twig',
             ],
             'payment_appearance' => [
                 'weight'   => 200,
-                'title'    => static::t('Sorting & Descriptions'),
+                'title'    => static::t('Names, descriptions & sorting'),
                 'widget'    => '\XLite\View\ItemsList\Model\Payment\Methods',
             ],
         ];
