@@ -1,5 +1,4 @@
 <?php
-// vim: set ts=4 sw=4 sts=4 et:
 
 /**
  * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
@@ -28,4 +27,16 @@ class TaxClasses extends Settings
     {
         return 'tax_classes';
     }
+
+    /**
+     * @return array
+     */
+    public function getCSSFiles()
+    {
+        $list = parent::getCSSFiles();
+
+        $list[] = 'tax_settings/style.less';
+
+        return $list;
+    }
 }
